@@ -18,10 +18,10 @@
 #include "vtkObjectFactory.h"
 
 #include "vtkContext2D.h"
-#include "vtkTransform2D.h"
-#include "vtkContextScene.h"
 #include "vtkContextMouseEvent.h"
+#include "vtkContextScene.h"
 #include "vtkPoints2D.h"
+#include "vtkTransform2D.h"
 
 #include "vtkPlotPie.h"
 
@@ -32,15 +32,12 @@
 
 class vtkChartPiePrivate
 {
-  public:
-    vtkChartPiePrivate()
-    {
-    }
+public:
+  vtkChartPiePrivate() = default;
 
   vtkSmartPointer<vtkPlotPie> Plot;
 };
 
-
 //-----------------------------------------------------------------------------
 vtkStandardNewMacro(vtkChartPie);
 
@@ -79,13 +76,12 @@ void vtkChartPie::Update()
 }
 
 //-----------------------------------------------------------------------------
-bool vtkChartPie::Paint(vtkContext2D *painter)
+bool vtkChartPie::Paint(vtkContext2D* painter)
 {
   // This is where everything should be drawn, or dispatched to other methods.
   vtkDebugMacro(<< "Paint event called.");
 
-  int geometry[] = { this->GetScene()->GetSceneWidth(),
-                     this->GetScene()->GetSceneHeight() };
+  int geometry[] = { this->GetScene()->GetSceneWidth(), this->GetScene()->GetSceneHeight() };
   if (geometry[0] == 0 || geometry[1] == 0 || !this->Visible)
   {
     // The geometry of the chart must be valid before anything can be drawn
@@ -94,25 +90,23 @@ bool vtkChartPie::Paint(vtkContext2D *painter)
 
   this->Update();
 
-  if ( geometry[0] != this->Geometry[0] || geometry[1] != this->Geometry[1] )
+  if (geometry[0] != this->Geometry[0] || geometry[1] != this->Geometry[1])
   {
     // Take up the entire window right now, this could be made configurable
     this->SetGeometry(geometry);
 
     vtkVector2i tileScale = this->Scene->GetLogicalTileScale();
-    this->SetBorders(20 * tileScale.GetX(), 20 * tileScale.GetY(),
-                     20 * tileScale.GetX(), 20 * tileScale.GetY());
+    this->SetBorders(
+      20 * tileScale.GetX(), 20 * tileScale.GetY(), 20 * tileScale.GetX(), 20 * tileScale.GetY());
 
     // Put the legend in the top corner of the chart
     vtkRectf rect = this->Legend->GetBoundingRect(painter);
-    this->Legend->SetPoint(this->Point2[0] - rect.GetWidth(),
-                           this->Point2[1] - rect.GetHeight());
+    this->Legend->SetPoint(this->Point2[0] - rect.GetWidth(), this->Point2[1] - rect.GetHeight());
 
     // Set the dimensions of the Plot
     if (this->Private->Plot)
     {
-      this->Private->Plot->SetDimensions(20, 20, this->Geometry[0]-40,
-                                         this->Geometry[1]-40);
+      this->Private->Plot->SetDimensions(20, 20, this->Geometry[0] - 40, this->Geometry[1] - 40);
     }
   }
 
@@ -120,9 +114,9 @@ bool vtkChartPie::Paint(vtkContext2D *painter)
 
   if (this->Title)
   {
-    vtkPoints2D *rect = vtkPoints2D::New();
+    vtkPoints2D* rect = vtkPoints2D::New();
     rect->InsertNextPoint(this->Point1[0], this->Point2[1]);
-    rect->InsertNextPoint(this->Point2[0]-this->Point1[0], 10);
+    rect->InsertNextPoint(this->Point2[0] - this->Point1[0], 10);
     painter->ApplyTextProp(this->TitleProperties);
     painter->DrawStringRect(rect, this->Title);
     rect->Delete();
@@ -134,14 +128,14 @@ bool vtkChartPie::Paint(vtkContext2D *painter)
 }
 
 //-----------------------------------------------------------------------------
-void vtkChartPie::SetScene(vtkContextScene *scene)
+void vtkChartPie::SetScene(vtkContextScene* scene)
 {
   this->vtkAbstractContextItem::SetScene(scene);
   this->Tooltip->SetScene(scene);
 }
 
 //-----------------------------------------------------------------------------
-vtkPlot * vtkChartPie::AddPlot(int /* type */)
+vtkPlot* vtkChartPie::AddPlot(int /* type */)
 {
   if (!this->Private->Plot)
   {
@@ -159,7 +153,7 @@ vtkPlot* vtkChartPie::GetPlot(vtkIdType index)
     return this->Private->Plot;
   }
 
-  return 0;
+  return nullptr;
 }
 
 //-----------------------------------------------------------------------------
@@ -183,19 +177,17 @@ void vtkChartPie::SetShowLegend(bool visible)
 }
 
 //-----------------------------------------------------------------------------
-vtkChartLegend * vtkChartPie::GetLegend()
+vtkChartLegend* vtkChartPie::GetLegend()
 {
   return this->Legend;
 }
 
 //-----------------------------------------------------------------------------
-bool vtkChartPie::Hit(const vtkContextMouseEvent &mouse)
+bool vtkChartPie::Hit(const vtkContextMouseEvent& mouse)
 {
   vtkVector2i pos(mouse.GetScreenPos());
-  if (pos[0] > this->Point1[0] &&
-      pos[0] < this->Point2[0] &&
-      pos[1] > this->Point1[1] &&
-      pos[1] < this->Point2[1])
+  if (pos[0] > this->Point1[0] && pos[0] < this->Point2[0] && pos[1] > this->Point1[1] &&
+    pos[1] < this->Point2[1])
   {
     return true;
   }
@@ -206,13 +198,13 @@ bool vtkChartPie::Hit(const vtkContextMouseEvent &mouse)
 }
 
 //-----------------------------------------------------------------------------
-bool vtkChartPie::MouseEnterEvent(const vtkContextMouseEvent &)
+bool vtkChartPie::MouseEnterEvent(const vtkContextMouseEvent&)
 {
   return true;
 }
 
 //-----------------------------------------------------------------------------
-bool vtkChartPie::MouseMoveEvent(const vtkContextMouseEvent &mouse)
+bool vtkChartPie::MouseMoveEvent(const vtkContextMouseEvent& mouse)
 {
   if (mouse.GetButton() == vtkContextMouseEvent::NO_BUTTON)
   {
@@ -224,30 +216,30 @@ bool vtkChartPie::MouseMoveEvent(const vtkContextMouseEvent &mouse)
 }
 
 //-----------------------------------------------------------------------------
-bool vtkChartPie::MouseLeaveEvent(const vtkContextMouseEvent &)
+bool vtkChartPie::MouseLeaveEvent(const vtkContextMouseEvent&)
 {
   return true;
 }
 
 //-----------------------------------------------------------------------------
-bool vtkChartPie::MouseButtonPressEvent(const vtkContextMouseEvent &/*mouse*/)
+bool vtkChartPie::MouseButtonPressEvent(const vtkContextMouseEvent& /*mouse*/)
 {
   return true;
 }
 
 //-----------------------------------------------------------------------------
-bool vtkChartPie::MouseButtonReleaseEvent(const vtkContextMouseEvent &/*mouse*/)
+bool vtkChartPie::MouseButtonReleaseEvent(const vtkContextMouseEvent& /*mouse*/)
 {
   return true;
 }
 
 //-----------------------------------------------------------------------------
-bool vtkChartPie::MouseWheelEvent(const vtkContextMouseEvent &, int /*delta*/)
+bool vtkChartPie::MouseWheelEvent(const vtkContextMouseEvent&, int /*delta*/)
 {
   return true;
 }
 
-bool vtkChartPie::LocatePointInPlots(const vtkContextMouseEvent &mouse)
+bool vtkChartPie::LocatePointInPlots(const vtkContextMouseEvent& mouse)
 {
   if (!this->Private->Plot || !this->Private->Plot->GetVisible())
   {
@@ -262,21 +254,17 @@ bool vtkChartPie::LocatePointInPlots(const vtkContextMouseEvent &mouse)
     this->Private->Plot->GetDimensions(dimensions);
 
     vtkVector2i pos(mouse.GetScreenPos());
-    if (pos[0] >= dimensions[0] &&
-        pos[0] <= dimensions[0] + dimensions[2] &&
-        pos[1] >= dimensions[1] &&
-        pos[1] <= dimensions[1] + dimensions[3])
+    if (pos[0] >= dimensions[0] && pos[0] <= dimensions[0] + dimensions[2] &&
+      pos[1] >= dimensions[1] && pos[1] <= dimensions[1] + dimensions[3])
     {
-      int labelIndex = this->Private->Plot->GetNearestPoint(position, tolerance,
-                                                            &plotPos);
+      int labelIndex = this->Private->Plot->GetNearestPoint(position, tolerance, &plotPos);
       if (labelIndex >= 0)
       {
-        const char *label = this->Private->Plot->GetLabel(labelIndex);
+        const char* label = this->Private->Plot->GetLabel(labelIndex);
         std::ostringstream ostr;
         ostr << label << ": " << plotPos.GetY();
         this->Tooltip->SetText(ostr.str().c_str());
-        this->Tooltip->SetPosition(mouse.GetScreenPos()[0] + 2,
-                                   mouse.GetScreenPos()[1] + 2);
+        this->Tooltip->SetPosition(mouse.GetScreenPos()[0] + 2, mouse.GetScreenPos()[1] + 2);
         return true;
       }
     }
@@ -285,12 +273,12 @@ bool vtkChartPie::LocatePointInPlots(const vtkContextMouseEvent &mouse)
 }
 
 //-----------------------------------------------------------------------------
-void vtkChartPie::PrintSelf(ostream &os, vtkIndent indent)
+void vtkChartPie::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
   if (this->Private->Plot)
   {
     os << indent << "Plot: " << endl;
-    this->Private->Plot->PrintSelf(os,indent.GetNextIndent());
+    this->Private->Plot->PrintSelf(os, indent.GetNextIndent());
   }
 }
