@@ -14,22 +14,24 @@
 =========================================================================*/
 
 #include "vtkBitArray.h"
+#include "vtkFloatArray.h"
 #include "vtkIdList.h"
 #include "vtkIdTypeArray.h"
 #include "vtkIntArray.h"
+#include "vtkNew.h"
 #include "vtkSortDataArray.h"
 #include "vtkStringArray.h"
 #include "vtkTimerLog.h"
 #include "vtkVariantArray.h"
 
 #include "vtkSmartPointer.h"
-#define VTK_CREATE(type,name) \
-  vtkSmartPointer<type> name = vtkSmartPointer<type>::New()
+#define VTK_CREATE(type, name) vtkSmartPointer<type> name = vtkSmartPointer<type>::New()
 
-#include <vector>
 #include <algorithm>
-#include <utility>
+#include <limits>
 #include <map>
+#include <utility>
+#include <vector>
 
 struct NodeCompare
 {
@@ -53,8 +55,7 @@ vtkIdType LookupValue(std::vector<std::pair<int, vtkIdType> >& lookup, int value
 {
   NodeCompare comp;
   std::pair<int, vtkIdType> val(value, 0);
-  std::pair<int, vtkIdType> found =
-    *std::lower_bound(lookup.begin(), lookup.end(), val, comp);
+  std::pair<int, vtkIdType> found = *std::lower_bound(lookup.begin(), lookup.end(), val, comp);
   if (found.first == value)
   {
     return found.second;
@@ -65,7 +66,8 @@ vtkIdType LookupValue(std::vector<std::pair<int, vtkIdType> >& lookup, int value
 vtkIdType LookupValue(vtkIntArray* lookup, vtkIdTypeArray* index, int value)
 {
   int* ptr = lookup->GetPointer(0);
-  vtkIdType place = static_cast<vtkIdType>(std::lower_bound(ptr, ptr + lookup->GetNumberOfTuples(), value) - ptr);
+  vtkIdType place =
+    static_cast<vtkIdType>(std::lower_bound(ptr, ptr + lookup->GetNumberOfTuples(), value) - ptr);
   if (place < lookup->GetNumberOfTuples() && ptr[place] == value)
   {
     return index->GetValue(place);
@@ -78,11 +80,11 @@ int TestArrayLookupBit(vtkIdType numVal)
   int errors = 0;
 
   // Create the array
-  vtkIdType arrSize = (numVal-1)*numVal/2;
+  vtkIdType arrSize = (numVal - 1) * numVal / 2;
   VTK_CREATE(vtkBitArray, arr);
   for (vtkIdType i = 0; i < arrSize; i++)
   {
-    arr->InsertNextValue(i < arrSize/2);
+    arr->InsertNextValue(i < arrSize / 2);
   }
 
   //
@@ -120,27 +122,31 @@ int TestArrayLookupBit(vtkIdType numVal)
   index = arr->LookupValue(-1);
   if (index != -1)
   {
-    cerr << "ERROR: lookup found value at " << index << " but is not there (should return -1)" << endl;
+    cerr << "ERROR: lookup found value at " << index << " but is not there (should return -1)"
+         << endl;
     errors++;
   }
   arr->LookupValue(-1, list);
   if (list->GetNumberOfIds() != 0)
   {
-    cerr << "ERROR: lookup found " << list->GetNumberOfIds() << " matches but there should be " << 0 << endl;
+    cerr << "ERROR: lookup found " << list->GetNumberOfIds() << " matches but there should be " << 0
+         << endl;
     errors++;
   }
 
   // Test for correctness (0)
   index = arr->LookupValue(0);
-  if (index < arrSize/2 || index > arrSize-1)
+  if (index < arrSize / 2 || index > arrSize - 1)
   {
-    cerr << "ERROR: vector lookup found value at " << index << " but is in range [" << arrSize/2 << "," << arrSize-1 << "]" << endl;
+    cerr << "ERROR: vector lookup found value at " << index << " but is in range [" << arrSize / 2
+         << "," << arrSize - 1 << "]" << endl;
     errors++;
   }
   arr->LookupValue(0, list);
-  if (list->GetNumberOfIds() != arrSize - arrSize/2)
+  if (list->GetNumberOfIds() != arrSize - arrSize / 2)
   {
-    cerr << "ERROR: lookup found " << list->GetNumberOfIds() << " matches but there should be " << arrSize - arrSize/2 << endl;
+    cerr << "ERROR: lookup found " << list->GetNumberOfIds() << " matches but there should be "
+         << arrSize - arrSize / 2 << endl;
     errors++;
   }
   else
@@ -157,15 +163,17 @@ int TestArrayLookupBit(vtkIdType numVal)
 
   // Test for correctness (1)
   index = arr->LookupValue(1);
-  if (index < 0 || index > arrSize/2-1)
+  if (index < 0 || index > arrSize / 2 - 1)
   {
-    cerr << "ERROR: vector lookup found value at " << index << " but is in range [" << 0 << "," << arrSize/2-1 << "]" << endl;
+    cerr << "ERROR: vector lookup found value at " << index << " but is in range [" << 0 << ","
+         << arrSize / 2 - 1 << "]" << endl;
     errors++;
   }
   arr->LookupValue(1, list);
-  if (list->GetNumberOfIds() != arrSize/2)
+  if (list->GetNumberOfIds() != arrSize / 2)
   {
-    cerr << "ERROR: lookup found " << list->GetNumberOfIds() << " matches but there should be " << arrSize/2 << endl;
+    cerr << "ERROR: lookup found " << list->GetNumberOfIds() << " matches but there should be "
+         << arrSize / 2 << endl;
     errors++;
   }
   else
@@ -188,13 +196,13 @@ int TestArrayLookupVariant(vtkIdType numVal)
   int errors = 0;
 
   // Create the array
-  vtkIdType arrSize = (numVal-1)*numVal/2;
+  vtkIdType arrSize = (numVal - 1) * numVal / 2;
   VTK_CREATE(vtkVariantArray, arr);
   for (vtkIdType i = 0; i < numVal; i++)
   {
-    for (vtkIdType j = 0; j < numVal-1-i; j++)
+    for (vtkIdType j = 0; j < numVal - 1 - i; j++)
     {
-      arr->InsertNextValue(numVal-1-i);
+      arr->InsertNextValue(numVal - 1 - i);
     }
   }
 
@@ -241,13 +249,134 @@ int TestArrayLookupVariant(vtkIdType numVal)
     }
     if (i != 0 && (index < correctIndex || index > correctIndex + i - 1))
     {
-      cerr << "ERROR: vector lookup found value at " << index << " but is in range [" << correctIndex << "," << correctIndex + i - 1 << "]" << endl;
+      cerr << "ERROR: vector lookup found value at " << index << " but is in range ["
+           << correctIndex << "," << correctIndex + i - 1 << "]" << endl;
       errors++;
     }
     arr->LookupValue(i, list);
     if (list->GetNumberOfIds() != i)
     {
-      cerr << "ERROR: lookup found " << list->GetNumberOfIds() << " matches but there should be " << i << endl;
+      cerr << "ERROR: lookup found " << list->GetNumberOfIds() << " matches but there should be "
+           << i << endl;
+      errors++;
+    }
+    else
+    {
+      for (vtkIdType j = correctIndex; j < correctIndex + i; j++)
+      {
+        bool inList = false;
+        for (vtkIdType k = 0; k < i; ++k)
+        {
+          if (list->GetId(k) == j)
+          {
+            inList = true;
+            break;
+          }
+        }
+        if (!inList)
+        {
+          cerr << "ERROR: could not find " << j << " in found list" << endl;
+          errors++;
+        }
+      }
+    }
+  }
+  return errors;
+}
+
+int TestArrayLookupFloat(vtkIdType numVal)
+{
+  int errors = 0;
+
+  // Create the array
+  vtkIdType arrSize = (numVal - 1) * numVal / 2;
+  VTK_CREATE(vtkFloatArray, arr);
+  for (vtkIdType i = 0; i < numVal; i++)
+  {
+    for (vtkIdType j = 0; j < numVal - 1 - i; j++)
+    {
+      arr->InsertNextValue(numVal - 1 - i);
+    }
+  }
+  arr->InsertNextValue(std::numeric_limits<float>::quiet_NaN());
+
+  //
+  // Test lookup implemented inside data array
+  //
+
+  // Time the lookup creation
+  VTK_CREATE(vtkTimerLog, timer);
+  timer->StartTimer();
+  arr->LookupValue(0);
+  timer->StopTimer();
+  cerr << "," << timer->GetElapsedTime();
+
+  // Time simple lookup
+  timer->StartTimer();
+  for (vtkIdType i = 0; i < numVal; i++)
+  {
+    arr->LookupValue(i);
+  }
+  timer->StopTimer();
+  cerr << "," << (timer->GetElapsedTime() / static_cast<double>(numVal));
+
+  // Time list lookup
+  VTK_CREATE(vtkIdList, list);
+  timer->StartTimer();
+  for (vtkIdType i = 0; i < numVal; i++)
+  {
+    arr->LookupValue(i, list);
+  }
+  timer->StopTimer();
+  cerr << "," << (timer->GetElapsedTime() / static_cast<double>(numVal));
+
+  // Test for NaN
+  {
+    vtkIdType index = arr->LookupValue(std::numeric_limits<float>::quiet_NaN());
+    if (index != arrSize)
+    {
+      cerr << "ERROR: lookup found NaN at " << index << " instead of " << arrSize << endl;
+      errors++;
+    }
+  }
+  {
+    vtkNew<vtkIdList> NaNlist;
+    arr->LookupValue(std::numeric_limits<float>::quiet_NaN(), NaNlist);
+    if (NaNlist->GetNumberOfIds() != 1)
+    {
+      cerr << "ERROR: lookup found " << list->GetNumberOfIds() << " values of NaN instead of " << 1
+           << endl;
+      errors++;
+    }
+    if (NaNlist->GetId(0) != arrSize)
+    {
+      cerr << "ERROR: lookup found NaN at " << list->GetId(0) << " instead of " << arrSize << endl;
+      errors++;
+    }
+  }
+
+  // Test for correctness
+  vtkIdType correctIndex = arrSize;
+  for (vtkIdType i = 0; i < numVal; i++)
+  {
+    correctIndex -= i;
+    vtkIdType index = arr->LookupValue(i);
+    if (i == 0 && index != -1)
+    {
+      cerr << "ERROR: lookup found value at " << index << " but is at -1" << endl;
+      errors++;
+    }
+    if (i != 0 && (index < correctIndex || index > correctIndex + i - 1))
+    {
+      cerr << "ERROR: vector lookup found value at " << index << " but is in range ["
+           << correctIndex << "," << correctIndex + i - 1 << "]" << endl;
+      errors++;
+    }
+    arr->LookupValue(i, list);
+    if (list->GetNumberOfIds() != i)
+    {
+      cerr << "ERROR: lookup found " << list->GetNumberOfIds() << " matches but there should be "
+           << i << endl;
       errors++;
     }
     else
@@ -279,13 +408,13 @@ int TestArrayLookupString(vtkIdType numVal)
   int errors = 0;
 
   // Create the array
-  vtkIdType arrSize = (numVal-1)*numVal/2;
+  vtkIdType arrSize = (numVal - 1) * numVal / 2;
   VTK_CREATE(vtkStringArray, arr);
   for (vtkIdType i = 0; i < numVal; i++)
   {
-    for (vtkIdType j = 0; j < numVal-1-i; j++)
+    for (vtkIdType j = 0; j < numVal - 1 - i; j++)
     {
-      arr->InsertNextValue(vtkVariant(numVal-1-i).ToString());
+      arr->InsertNextValue(vtkVariant(numVal - 1 - i).ToString());
     }
   }
 
@@ -332,13 +461,15 @@ int TestArrayLookupString(vtkIdType numVal)
     }
     if (i != 0 && (index < correctIndex || index > correctIndex + i - 1))
     {
-      cerr << "ERROR: vector lookup found value at " << index << " but is in range [" << correctIndex << "," << correctIndex + i - 1 << "]" << endl;
+      cerr << "ERROR: vector lookup found value at " << index << " but is in range ["
+           << correctIndex << "," << correctIndex + i - 1 << "]" << endl;
       errors++;
     }
     arr->LookupValue(vtkVariant(i).ToString(), list);
     if (list->GetNumberOfIds() != i)
     {
-      cerr << "ERROR: lookup found " << list->GetNumberOfIds() << " matches but there should be " << i << endl;
+      cerr << "ERROR: lookup found " << list->GetNumberOfIds() << " matches but there should be "
+           << i << endl;
       errors++;
     }
     else
@@ -370,13 +501,13 @@ int TestArrayLookupInt(vtkIdType numVal, bool runComparison)
   int errors = 0;
 
   // Create the array
-  vtkIdType arrSize = (numVal-1)*numVal/2;
+  vtkIdType arrSize = (numVal - 1) * numVal / 2;
   VTK_CREATE(vtkIntArray, arr);
   for (vtkIdType i = 0; i < numVal; i++)
   {
-    for (vtkIdType j = 0; j < numVal-1-i; j++)
+    for (vtkIdType j = 0; j < numVal - 1 - i; j++)
     {
-      arr->InsertNextValue(numVal-1-i);
+      arr->InsertNextValue(numVal - 1 - i);
     }
   }
 
@@ -423,13 +554,15 @@ int TestArrayLookupInt(vtkIdType numVal, bool runComparison)
     }
     if (i != 0 && (index < correctIndex || index > correctIndex + i - 1))
     {
-      cerr << "ERROR: vector lookup found value at " << index << " but is in range [" << correctIndex << "," << correctIndex + i - 1 << "]" << endl;
+      cerr << "ERROR: vector lookup found value at " << index << " but is in range ["
+           << correctIndex << "," << correctIndex + i - 1 << "]" << endl;
       errors++;
     }
     arr->LookupValue(i, list);
     if (list->GetNumberOfIds() != i)
     {
-      cerr << "ERROR: lookup found " << list->GetNumberOfIds() << " matches but there should be " << i << endl;
+      cerr << "ERROR: lookup found " << list->GetNumberOfIds() << " matches but there should be "
+           << i << endl;
       errors++;
     }
     else
@@ -537,7 +670,8 @@ int TestArrayLookupInt(vtkIdType numVal, bool runComparison)
       }
       if (i != 0 && (index < correctIndex || index > correctIndex + i - 1))
       {
-        cerr << "ERROR: vector lookup found value at " << index << " but is in range [" << correctIndex << "," << correctIndex + i - 1 << "]" << endl;
+        cerr << "ERROR: vector lookup found value at " << index << " but is in range ["
+             << correctIndex << "," << correctIndex + i - 1 << "]" << endl;
         errors++;
       }
     }
@@ -583,7 +717,8 @@ int TestArrayLookupInt(vtkIdType numVal, bool runComparison)
       }
       if (i != 0 && (index < correctIndex || index > correctIndex + i - 1))
       {
-        cerr << "ERROR: arr lookup found value at " << index << " but is in range [" << correctIndex << "," << correctIndex + i - 1 << "]" << endl;
+        cerr << "ERROR: arr lookup found value at " << index << " but is in range [" << correctIndex
+             << "," << correctIndex + i - 1 << "]" << endl;
         errors++;
       }
     }
@@ -592,6 +727,52 @@ int TestArrayLookupInt(vtkIdType numVal, bool runComparison)
   return errors;
 }
 
+int TestMultiComponent()
+{
+  int errors = 0;
+  auto array = vtkSmartPointer<vtkFloatArray>::New();
+  array->SetNumberOfComponents(3);
+  static const float data[3][3] = { { 1., 2., 3. }, { 2., 3., 4. }, { 3., 4., 5. } };
+  for (auto tuple : data)
+  {
+    array->InsertNextTypedTuple(tuple);
+  }
+
+  // a list of values and the index expected to be returned
+  static const int expected[][2] = { { 2, 1 }, { 3, 2 }, { 4, 5 }, { 5, 8 }, { 6, -1 } };
+  for (auto e : expected)
+  {
+    vtkIdType index = array->LookupTypedValue(e[0]);
+    if (index != e[1])
+    {
+      cerr << "TestMultiComponent: "
+           << "index of " << e[0] << " expected " << e[1] << " actual " << index;
+      ++errors;
+    }
+  }
+
+  // overwrite 3.0 (3rd component of 1st tuple) with NaN.
+  array->SetTypedComponent(0, 2, std::numeric_limits<float>::quiet_NaN());
+
+  // We need to trigger rebuilding the auxiliary data structures explicitly
+  array->ClearLookup();
+  vtkIdType index = array->LookupValue(std::numeric_limits<float>::quiet_NaN());
+  if (2 != index)
+  {
+    cerr << "TestMultiComponent: lookup of NaN: "
+         << "expected 0 actual " << index;
+    ++errors;
+  }
+  index = array->LookupValue(3.);
+  if (4 != index)
+  {
+    cerr << "TestMultiComponent: lookup of value 3.: "
+         << "expected 1 actual " << index;
+    ++errors;
+  }
+  return errors;
+}
+
 int TestArrayLookup(int argc, char* argv[])
 {
   vtkIdType min = 100;
@@ -604,26 +785,26 @@ int TestArrayLookup(int argc, char* argv[])
     {
       runComparison = true;
     }
-    if (!strcmp(argv[i], "-m") && i+1 < argc)
+    if (!strcmp(argv[i], "-m") && i + 1 < argc)
     {
       ++i;
       int size = atoi(argv[i]);
-      min = static_cast<int>((-1.0 + sqrt(1 + 8.0*size))/2.0);
+      min = static_cast<int>((-1.0 + sqrt(1 + 8.0 * size)) / 2.0);
     }
-    if (!strcmp(argv[i], "-M") && i+1 < argc)
+    if (!strcmp(argv[i], "-M") && i + 1 < argc)
     {
       ++i;
       int size = atoi(argv[i]);
-      max = static_cast<int>((-1.0 + sqrt(1 + 8.0*size))/2.0);
+      max = static_cast<int>((-1.0 + sqrt(1 + 8.0 * size)) / 2.0);
     }
-    if (!strcmp(argv[i], "-S") && i+1 < argc)
+    if (!strcmp(argv[i], "-S") && i + 1 < argc)
     {
       ++i;
       steps = atoi(argv[i]);
     }
   }
 
-  vtkIdType stepSize = (max-min)/(steps-1);
+  vtkIdType stepSize = (max - min) / (steps - 1);
   if (stepSize <= 0)
   {
     stepSize = 1;
@@ -656,13 +837,15 @@ int TestArrayLookup(int argc, char* argv[])
   cerr << endl;
   for (vtkIdType numVal = min; numVal <= max; numVal += stepSize)
   {
-    vtkIdType total = numVal*(numVal+1)/2;
+    vtkIdType total = numVal * (numVal + 1) / 2;
     cerr << numVal << "," << total;
     errors += TestArrayLookupInt(numVal, runComparison);
+    errors += TestArrayLookupFloat(numVal);
     errors += TestArrayLookupString(numVal);
     errors += TestArrayLookupVariant(numVal);
     errors += TestArrayLookupBit(numVal);
     cerr << endl;
   }
+  errors += TestMultiComponent();
   return errors;
 }
