@@ -20,43 +20,26 @@
 =========================================================================*/
 
 #include <vtkArrayPrint.h>
-#include <vtkSparseArray.h>
 #include <vtkSmartPointer.h>
+#include <vtkSparseArray.h>
 #include <vtkTestErrorObserver.h>
 
 #include <iostream>
 #include <stdexcept>
 
-#define CHECK_ERROR_MSG(observer, msg)   \
-  { \
-  std::string expectedMsg(msg); \
-  if (!observer->GetError()) \
-  { \
-    std::cout << "ERROR: Failed to catch any error. Expected the error message to contain \"" << expectedMsg << std::endl; \
-  } \
-  else \
-  { \
-    std::string gotMsg(observer->GetErrorMessage()); \
-    if (gotMsg.find(expectedMsg) == std::string::npos) \
-    { \
-      std::cout << "ERROR: Error message does not contain \"" << expectedMsg << "\" got \n\"" << gotMsg << std::endl; \
-    } \
-  } \
-  } \
-  observer->Clear()
+#define test_expression(expression)                                                                \
+  {                                                                                                \
+    if (!(expression))                                                                             \
+      throw std::runtime_error("Expression failed: " #expression);                                 \
+  }
 
-#define test_expression(expression) \
-{ \
-  if(!(expression)) \
-    throw std::runtime_error("Expression failed: " #expression); \
-}
-
-int TestSparseArrayValidation(int vtkNotUsed(argc), char *vtkNotUsed(argv)[])
+int TestSparseArrayValidation(int vtkNotUsed(argc), char* vtkNotUsed(argv)[])
 {
   try
   {
     // Create an array ...
-    vtkSmartPointer<vtkSparseArray<double> > array = vtkSmartPointer<vtkSparseArray<double> >::New();
+    vtkSmartPointer<vtkSparseArray<double> > array =
+      vtkSmartPointer<vtkSparseArray<double> >::New();
     test_expression(array->Validate());
 
     array->Resize(vtkArrayExtents::Uniform(2, 3));
@@ -76,8 +59,8 @@ int TestSparseArrayValidation(int vtkNotUsed(argc), char *vtkNotUsed(argv)[])
     array->AddValue(1, 2, 2);
     array->AddValue(0, 0, 4);
     test_expression(!array->Validate());
-    CHECK_ERROR_MSG(errorObserver,
-                    "Array contains 1 duplicate coordinates");
+    int status = 0;
+    status += errorObserver->CheckErrorMessage("Array contains 1 duplicate coordinates");
 
     array->Clear();
     array->AddValue(0, 0, 1);
@@ -86,7 +69,7 @@ int TestSparseArrayValidation(int vtkNotUsed(argc), char *vtkNotUsed(argv)[])
 
     return 0;
   }
-  catch(std::exception& e)
+  catch (std::exception& e)
   {
     cerr << e.what() << endl;
     return 1;
