@@ -15,45 +15,53 @@
 #include "vtkCommand.h"
 #include "vtkDebugLeaks.h"
 
+#ifdef VTK_DEBUG_LEAKS
+static const char* leakname = "vtkCommand or subclass";
+#endif
+
 //----------------------------------------------------------------
-vtkCommand::vtkCommand():AbortFlag(0),PassiveObserver(0)
+vtkCommand::vtkCommand()
+  : AbortFlag(0)
+  , PassiveObserver(0)
 {
 #ifdef VTK_DEBUG_LEAKS
-  vtkDebugLeaks::ConstructClass("vtkCommand or subclass");
+  vtkDebugLeaks::ConstructClass(leakname);
 #endif
 }
 
 //----------------------------------------------------------------
 void vtkCommand::UnRegister()
 {
-  int refcount = this->GetReferenceCount()-1;
+  int refcount = this->GetReferenceCount() - 1;
   this->SetReferenceCount(refcount);
   if (refcount <= 0)
   {
 #ifdef VTK_DEBUG_LEAKS
-    vtkDebugLeaks::DestructClass("vtkCommand or subclass");
+    vtkDebugLeaks::DestructClass(leakname);
 #endif
     delete this;
   }
 }
 
 //----------------------------------------------------------------
-const char *vtkCommand::GetStringFromEventId(unsigned long event)
+const char* vtkCommand::GetStringFromEventId(unsigned long event)
 {
   switch (event)
   {
-#define _vtk_add_event(Enum)\
-  case Enum: return #Enum;
+// clang-format off
+#define _vtk_add_event(Enum)                                                                       \
+  case Enum:                                                                                       \
+    return #Enum;
 
   vtkAllEventsMacro()
 
 #undef _vtk_add_event
+      // clang-format on
 
-  case UserEvent:
-    return "UserEvent";
+      case UserEvent : return "UserEvent";
 
-  case NoEvent:
-    return "NoEvent";
+    case NoEvent:
+      return "NoEvent";
   }
 
   // Unknown event. Original code was returning NoEvent, so I'll stick with
@@ -62,25 +70,40 @@ const char *vtkCommand::GetStringFromEventId(unsigned long event)
 }
 
 //----------------------------------------------------------------
-unsigned long vtkCommand::GetEventIdFromString(const char *event)
+unsigned long vtkCommand::GetEventIdFromString(const char* event)
 {
   if (event)
   {
-#define _vtk_add_event(Enum)\
-    if (strcmp(event, #Enum) == 0) {return Enum;}
+
+// clang-format off
+#define _vtk_add_event(Enum)                                                                       \
+  if (strcmp(event, #Enum) == 0)                                                                   \
+  {                                                                                                \
+    return Enum;                                                                                   \
+  }
+
     vtkAllEventsMacro()
+
 #undef _vtk_add_event
 
     if (strcmp("UserEvent",event) == 0)
     {
       return vtkCommand::UserEvent;
     }
+    // clang-format on
   }
 
   return vtkCommand::NoEvent;
 }
 
-
-
-
-
+bool vtkCommand::EventHasData(unsigned long event)
+{
+  switch (event)
+  {
+    case vtkCommand::Button3DEvent:
+    case vtkCommand::Move3DEvent:
+      return true;
+    default:
+      return false;
+  }
+}
