@@ -30,13 +30,14 @@
  *
  * @sa
  * vtkBitArray vtkGenericDataArray
-*/
+ */
 
 #ifndef vtkDataArray_h
 #define vtkDataArray_h
 
-#include "vtkCommonCoreModule.h" // For export macro
 #include "vtkAbstractArray.h"
+#include "vtkCommonCoreModule.h"          // For export macro
+#include "vtkVTK_USE_SCALED_SOA_ARRAYS.h" // For #define of VTK_USE_SCALED_SOA_ARRAYS
 
 class vtkDoubleArray;
 class vtkIdList;
@@ -48,16 +49,16 @@ class vtkPoints;
 class VTKCOMMONCORE_EXPORT vtkDataArray : public vtkAbstractArray
 {
 public:
-  vtkTypeMacro(vtkDataArray,vtkAbstractArray);
-  void PrintSelf(ostream& os, vtkIndent indent) VTK_OVERRIDE;
+  vtkTypeMacro(vtkDataArray, vtkAbstractArray);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
   /**
    * Perform a fast, safe cast from a vtkAbstractArray to a vtkDataArray.
    * This method checks if source->GetArrayType() returns DataArray
    * or a more derived type, and performs a static_cast to return
-   * source as a vtkDataArray pointer. Otherwise, NULL is returned.
+   * source as a vtkDataArray pointer. Otherwise, nullptr is returned.
    */
-  static vtkDataArray* FastDownCast(vtkAbstractArray *source);
+  static vtkDataArray* FastDownCast(vtkAbstractArray* source);
 
   /**
    * This method is here to make backward compatibility easier.  It
@@ -65,47 +66,43 @@ public:
    * All vtkDataArray subclasses contain numeric data, hence this method
    * always returns 1(true).
    */
-  int IsNumeric() VTK_OVERRIDE
-    { return 1; }
+  int IsNumeric() const override { return 1; }
 
   /**
    * Return the size, in bytes, of the lowest-level element of an
    * array.  For vtkDataArray and subclasses this is the size of the
    * data type.
    */
-  int GetElementComponentSize() VTK_OVERRIDE
-    { return this->GetDataTypeSize(); }
+  int GetElementComponentSize() const override { return this->GetDataTypeSize(); }
 
   // Reimplemented virtuals (doc strings are inherited from superclass):
-  void InsertTuple(vtkIdType dstTupleIdx, vtkIdType srcTupleIdx,
-                   vtkAbstractArray* source) VTK_OVERRIDE;
-  vtkIdType InsertNextTuple(vtkIdType srcTupleIdx,
-                                    vtkAbstractArray* source) VTK_OVERRIDE;
-  void InsertTuples(vtkIdList *dstIds, vtkIdList *srcIds,
-                            vtkAbstractArray *source) VTK_OVERRIDE;
-  void InsertTuples(vtkIdType dstStart, vtkIdType n, vtkIdType srcStart,
-                            vtkAbstractArray* source) VTK_OVERRIDE;
-  void GetTuples(vtkIdList *tupleIds, vtkAbstractArray *output) VTK_OVERRIDE;
-  void GetTuples(vtkIdType p1, vtkIdType p2, vtkAbstractArray *output) VTK_OVERRIDE;
-  void InterpolateTuple(vtkIdType dstTupleIdx, vtkIdList *ptIndices,
-                                vtkAbstractArray* source,  double* weights) VTK_OVERRIDE;
-  void InterpolateTuple(vtkIdType dstTupleIdx,
-    vtkIdType srcTupleIdx1, vtkAbstractArray* source1,
-    vtkIdType srcTupleIdx2, vtkAbstractArray* source2, double t) VTK_OVERRIDE;
+  void InsertTuple(vtkIdType dstTupleIdx, vtkIdType srcTupleIdx, vtkAbstractArray* source) override;
+  vtkIdType InsertNextTuple(vtkIdType srcTupleIdx, vtkAbstractArray* source) override;
+  void InsertTuples(vtkIdList* dstIds, vtkIdList* srcIds, vtkAbstractArray* source) override;
+  void InsertTuples(
+    vtkIdType dstStart, vtkIdType n, vtkIdType srcStart, vtkAbstractArray* source) override;
+  void GetTuples(vtkIdList* tupleIds, vtkAbstractArray* output) override;
+  void GetTuples(vtkIdType p1, vtkIdType p2, vtkAbstractArray* output) override;
+  void InterpolateTuple(vtkIdType dstTupleIdx, vtkIdList* ptIndices, vtkAbstractArray* source,
+    double* weights) override;
+  void InterpolateTuple(vtkIdType dstTupleIdx, vtkIdType srcTupleIdx1, vtkAbstractArray* source1,
+    vtkIdType srcTupleIdx2, vtkAbstractArray* source2, double t) override;
 
   /**
    * Get the data tuple at tupleIdx. Return it as a pointer to an array.
    * Note: this method is not thread-safe, and the pointer is only valid
    * as long as another method invocation to a vtk object is not performed.
    */
-  virtual double *GetTuple(vtkIdType tupleIdx) = 0;
+  virtual double* GetTuple(vtkIdType tupleIdx)
+    VTK_EXPECTS(0 <= tupleIdx && tupleIdx < GetNumberOfTuples()) = 0;
 
   /**
    * Get the data tuple at tupleIdx by filling in a user-provided array,
    * Make sure that your array is large enough to hold the NumberOfComponents
    * amount of data being returned.
    */
-  virtual void GetTuple(vtkIdType tupleIdx, double * tuple) = 0;
+  virtual void GetTuple(vtkIdType tupleIdx, double* tuple)
+    VTK_EXPECTS(0 <= tupleIdx && tupleIdx < GetNumberOfTuples()) = 0;
 
   //@{
   /**
@@ -113,16 +110,20 @@ public:
    * GetTuple() and SetTuple() which return/take arrays can not be
    * used from wrapped languages. These methods can be used instead.
    */
-  double GetTuple1(vtkIdType tupleIdx);
-  double* GetTuple2(vtkIdType tupleIdx);
-  double* GetTuple3(vtkIdType tupleIdx);
-  double* GetTuple4(vtkIdType tupleIdx);
-  double* GetTuple6(vtkIdType tupleIdx);
-  double* GetTuple9(vtkIdType tupleIdx);
+  double GetTuple1(vtkIdType tupleIdx) VTK_EXPECTS(0 <= tupleIdx && tupleIdx < GetNumberOfTuples());
+  double* GetTuple2(vtkIdType tupleIdx) VTK_EXPECTS(0 <= tupleIdx && tupleIdx < GetNumberOfTuples())
+    VTK_SIZEHINT(2);
+  double* GetTuple3(vtkIdType tupleIdx) VTK_EXPECTS(0 <= tupleIdx && tupleIdx < GetNumberOfTuples())
+    VTK_SIZEHINT(3);
+  double* GetTuple4(vtkIdType tupleIdx) VTK_EXPECTS(0 <= tupleIdx && tupleIdx < GetNumberOfTuples())
+    VTK_SIZEHINT(4);
+  double* GetTuple6(vtkIdType tupleIdx) VTK_EXPECTS(0 <= tupleIdx && tupleIdx < GetNumberOfTuples())
+    VTK_SIZEHINT(6);
+  double* GetTuple9(vtkIdType tupleIdx) VTK_EXPECTS(0 <= tupleIdx && tupleIdx < GetNumberOfTuples())
+    VTK_SIZEHINT(9);
   //@}
 
-  void SetTuple(vtkIdType dstTupleIdx, vtkIdType srcTupleIdx,
-                        vtkAbstractArray* source) VTK_OVERRIDE;
+  void SetTuple(vtkIdType dstTupleIdx, vtkIdType srcTupleIdx, vtkAbstractArray* source) override;
 
   //@{
   /**
@@ -130,8 +131,10 @@ public:
    * memory allocation is not performed; use this method in conjunction
    * with SetNumberOfTuples() to allocate space.
    */
-  virtual void SetTuple(vtkIdType tupleIdx, const float * tuple);
-  virtual void SetTuple(vtkIdType tupleIdx, const double * tuple);
+  virtual void SetTuple(vtkIdType tupleIdx, const float* tuple)
+    VTK_EXPECTS(0 <= tupleIdx && tupleIdx < GetNumberOfTuples());
+  virtual void SetTuple(vtkIdType tupleIdx, const double* tuple)
+    VTK_EXPECTS(0 <= tupleIdx && tupleIdx < GetNumberOfTuples());
   //@}
 
   //@{
@@ -140,16 +143,19 @@ public:
    * GetTuple() and SetTuple() which return/take arrays can not be
    * used from wrapped languages. These methods can be used instead.
    */
-  void SetTuple1(vtkIdType tupleIdx, double value);
-  void SetTuple2(vtkIdType tupleIdx, double val0, double val1);
-  void SetTuple3(vtkIdType tupleIdx, double val0, double val1, double val2);
-  void SetTuple4(vtkIdType tupleIdx, double val0, double val1, double val2,
-                 double val3);
-  void SetTuple6(vtkIdType tupleIdx, double val0, double val1, double val2,
-                 double val3, double val4, double val5);
-  void SetTuple9(vtkIdType tupleIdx, double val0, double val1, double val2,
-                 double val3, double val4, double val5, double val6,
-                 double val7, double val8);
+  void SetTuple1(vtkIdType tupleIdx, double value)
+    VTK_EXPECTS(0 <= tupleIdx && tupleIdx < GetNumberOfTuples());
+  void SetTuple2(vtkIdType tupleIdx, double val0, double val1)
+    VTK_EXPECTS(0 <= tupleIdx && tupleIdx < GetNumberOfTuples());
+  void SetTuple3(vtkIdType tupleIdx, double val0, double val1, double val2)
+    VTK_EXPECTS(0 <= tupleIdx && tupleIdx < GetNumberOfTuples());
+  void SetTuple4(vtkIdType tupleIdx, double val0, double val1, double val2, double val3)
+    VTK_EXPECTS(0 <= tupleIdx && tupleIdx < GetNumberOfTuples());
+  void SetTuple6(vtkIdType tupleIdx, double val0, double val1, double val2, double val3,
+    double val4, double val5) VTK_EXPECTS(0 <= tupleIdx && tupleIdx < GetNumberOfTuples());
+  void SetTuple9(vtkIdType tupleIdx, double val0, double val1, double val2, double val3,
+    double val4, double val5, double val6, double val7, double val8)
+    VTK_EXPECTS(0 <= tupleIdx && tupleIdx < GetNumberOfTuples());
   //@}
 
   //@{
@@ -157,8 +163,8 @@ public:
    * Insert the data tuple at tupleIdx. Note that memory allocation
    * is performed as necessary to hold the data.
    */
-  virtual void InsertTuple(vtkIdType tupleIdx, const float * tuple) = 0;
-  virtual void InsertTuple(vtkIdType tupleIdx, const double * tuple) = 0;
+  virtual void InsertTuple(vtkIdType tupleIdx, const float* tuple) VTK_EXPECTS(0 <= tupleIdx) = 0;
+  virtual void InsertTuple(vtkIdType tupleIdx, const double* tuple) VTK_EXPECTS(0 <= tupleIdx) = 0;
   //@}
 
   //@{
@@ -167,16 +173,16 @@ public:
    * InsertTuple() which takes arrays can not be
    * used from wrapped languages. These methods can be used instead.
    */
-  void InsertTuple1(vtkIdType tupleIdx, double value);
-  void InsertTuple2(vtkIdType tupleIdx, double val0, double val1);
-  void InsertTuple3(vtkIdType tupleIdx, double val0, double val1, double val2);
-  void InsertTuple4(vtkIdType tupleIdx, double val0, double val1, double val2,
-                    double val3);
-  void InsertTuple6(vtkIdType tupleIdx, double val0, double val1, double val2,
-                    double val3, double val4, double val5);
-  void InsertTuple9(vtkIdType tupleIdx, double val0, double val1, double val2,
-                    double val3, double val4, double val5, double val6,
-                    double val7, double val8);
+  void InsertTuple1(vtkIdType tupleIdx, double value) VTK_EXPECTS(0 <= tupleIdx);
+  void InsertTuple2(vtkIdType tupleIdx, double val0, double val1) VTK_EXPECTS(0 <= tupleIdx);
+  void InsertTuple3(vtkIdType tupleIdx, double val0, double val1, double val2)
+    VTK_EXPECTS(0 <= tupleIdx);
+  void InsertTuple4(vtkIdType tupleIdx, double val0, double val1, double val2, double val3)
+    VTK_EXPECTS(0 <= tupleIdx);
+  void InsertTuple6(vtkIdType tupleIdx, double val0, double val1, double val2, double val3,
+    double val4, double val5) VTK_EXPECTS(0 <= tupleIdx);
+  void InsertTuple9(vtkIdType tupleIdx, double val0, double val1, double val2, double val3,
+    double val4, double val5, double val6, double val7, double val8) VTK_EXPECTS(0 <= tupleIdx);
   //@}
 
   //@{
@@ -185,8 +191,8 @@ public:
    * which the data was inserted. Memory is allocated as necessary to hold
    * the data.
    */
-  virtual vtkIdType InsertNextTuple(const float * tuple) = 0;
-  virtual vtkIdType InsertNextTuple(const double * tuple) = 0;
+  virtual vtkIdType InsertNextTuple(const float* tuple) = 0;
+  virtual vtkIdType InsertNextTuple(const double* tuple) = 0;
   //@}
 
   //@{
@@ -198,13 +204,11 @@ public:
   void InsertNextTuple1(double value);
   void InsertNextTuple2(double val0, double val1);
   void InsertNextTuple3(double val0, double val1, double val2);
-  void InsertNextTuple4(double val0, double val1, double val2,
-                        double val3);
-  void InsertNextTuple6(double val0, double val1, double val2,
-                        double val3, double val4, double val5);
-  void InsertNextTuple9(double val0, double val1, double val2,
-                        double val3, double val4, double val5, double val6,
-                        double val7, double val8);
+  void InsertNextTuple4(double val0, double val1, double val2, double val3);
+  void InsertNextTuple6(
+    double val0, double val1, double val2, double val3, double val4, double val5);
+  void InsertNextTuple9(double val0, double val1, double val2, double val3, double val4,
+    double val5, double val6, double val7, double val8);
   //@}
 
   //@{
@@ -213,7 +217,8 @@ public:
    * resize array, so the data array is still valid after this operation. Note,
    * this operation is fairly slow.
    */
-  virtual void RemoveTuple(vtkIdType tupleIdx) = 0;
+  virtual void RemoveTuple(vtkIdType tupleIdx)
+    VTK_EXPECTS(0 <= tupleIdx && tupleIdx < GetNumberOfTuples()) = 0;
   virtual void RemoveFirstTuple() { this->RemoveTuple(0); }
   virtual void RemoveLastTuple();
   //@}
@@ -222,7 +227,8 @@ public:
    * Return the data component at the location specified by tupleIdx and
    * compIdx.
    */
-  virtual double GetComponent(vtkIdType tupleIdx, int compIdx);
+  virtual double GetComponent(vtkIdType tupleIdx, int compIdx) VTK_EXPECTS(0 <= tupleIdx &&
+    tupleIdx < GetNumberOfTuples()) VTK_EXPECTS(0 <= compIdx && compIdx < GetNumberOfComponents());
 
   /**
    * Set the data component at the location specified by tupleIdx and compIdx
@@ -231,13 +237,16 @@ public:
    * NumberOfComponents. Make sure enough memory has been allocated
    * (use SetNumberOfTuples() and SetNumberOfComponents()).
    */
-  virtual void SetComponent(vtkIdType tupleIdx, int compIdx, double value);
+  virtual void SetComponent(vtkIdType tupleIdx, int compIdx, double value)
+    VTK_EXPECTS(0 <= tupleIdx && tupleIdx < GetNumberOfTuples())
+      VTK_EXPECTS(0 <= compIdx && compIdx < GetNumberOfComponents());
 
   /**
    * Insert value at the location specified by tupleIdx and compIdx.
    * Note that memory allocation is performed as necessary to hold the data.
    */
-  virtual void InsertComponent(vtkIdType tupleIdx, int compIdx, double value);
+  virtual void InsertComponent(vtkIdType tupleIdx, int compIdx, double value)
+    VTK_EXPECTS(0 <= tupleIdx) VTK_EXPECTS(0 <= compIdx && compIdx < GetNumberOfComponents());
 
   /**
    * Get the data as a double array in the range (tupleMin,tupleMax) and
@@ -247,16 +256,16 @@ public:
    * doubleing point values. This method is provided as a convenience for data
    * exchange, and is not very fast.
    */
-  virtual void GetData(vtkIdType tupleMin, vtkIdType tupleMax, int compMin,
-                       int compMax, vtkDoubleArray* data);
+  virtual void GetData(
+    vtkIdType tupleMin, vtkIdType tupleMax, int compMin, int compMax, vtkDoubleArray* data);
 
   //@{
   /**
    * Deep copy of data. Copies data from different data arrays even if
    * they are different types (using doubleing-point exchange).
    */
-  void DeepCopy(vtkAbstractArray *aa) VTK_OVERRIDE;
-  virtual void DeepCopy(vtkDataArray *da);
+  void DeepCopy(vtkAbstractArray* aa) override;
+  virtual void DeepCopy(vtkDataArray* da);
   //@}
 
   /**
@@ -268,7 +277,7 @@ public:
    * does not.)
    * If a shallow copy is not possible, a deep copy will be performed instead.
    */
-  virtual void ShallowCopy(vtkDataArray *other);
+  virtual void ShallowCopy(vtkDataArray* other);
 
   /**
    * Fill a component of a data array with a specified value. This method
@@ -276,7 +285,13 @@ public:
    * data array.  This methods can be used to initialize or reinitialize a
    * single component of a multi-component array.
    */
-  virtual void FillComponent(int compIdx, double value);
+  virtual void FillComponent(int compIdx, double value)
+    VTK_EXPECTS(0 <= compIdx && compIdx < GetNumberOfComponents());
+
+  /**
+   * Fill all values of a data array with a specified value.
+   */
+  virtual void Fill(double value);
 
   /**
    * Copy a component from one data array into a component on this data array.
@@ -286,8 +301,7 @@ public:
    * a component (column) from one data array and paste that data into
    * a component on this data array.
    */
-  virtual void CopyComponent(int dstComponent, vtkDataArray *src,
-                             int srcComponent);
+  virtual void CopyComponent(int dstComponent, vtkDataArray* src, int srcComponent);
 
   /**
    * Get the address of a particular data index. Make sure data is allocated
@@ -304,7 +318,7 @@ public:
    * information returned is valid only after the pipeline has
    * been updated.
    */
-  unsigned long GetActualMemorySize() VTK_OVERRIDE;
+  unsigned long GetActualMemorySize() const override;
 
   /**
    * Create default lookup table. Generally used to create one when none
@@ -316,8 +330,8 @@ public:
   /**
    * Set/get the lookup table associated with this scalar data, if any.
    */
-  void SetLookupTable(vtkLookupTable *lut);
-  vtkGetObjectMacro(LookupTable,vtkLookupTable);
+  void SetLookupTable(vtkLookupTable* lut);
+  vtkGetObjectMacro(LookupTable, vtkLookupTable);
   //@}
 
   /**
@@ -329,10 +343,7 @@ public:
    * requested component changes.
    * THIS METHOD IS NOT THREAD SAFE.
    */
-  void GetRange(double range[2], int comp)
-  {
-    this->ComputeRange(range, comp);
-  }
+  void GetRange(double range[2], int comp) { this->ComputeRange(range, comp); }
 
   //@{
   /**
@@ -343,7 +354,7 @@ public:
    * modified or the requested component changes.
    * THIS METHOD IS NOT THREAD SAFE.
    */
-  double* GetRange(int comp)
+  double* GetRange(int comp) VTK_SIZEHINT(2)
   {
     this->GetRange(this->Range, comp);
     return this->Range;
@@ -357,23 +368,63 @@ public:
    * on subsequent calls to GetRange() unless the array is modified.
    * THIS METHOD IS NOT THREAD SAFE.
    */
-  double* GetRange()
-  {
-    return this->GetRange(0);
-  }
+  double* GetRange() VTK_SIZEHINT(2) { return this->GetRange(0); }
 
   /**
-   * The the range of the data array values will be returned in the provided
+   * The range of the data array values will be returned in the provided
    * range array argument. If the data array has multiple components, then
    * this will return the range of only the first component (component zero).
    * The range is computend and then cached, and will not be re-computed on
    * subsequent calls to GetRange() unless the array is modified.
    * THIS METHOD IS NOT THREAD SAFE.
    */
-  void GetRange(double range[2])
+  void GetRange(double range[2]) { this->GetRange(range, 0); }
+
+  /**
+   * The range of the data array values for the given component will be
+   * returned in the provided range array argument. If comp is -1, the range
+   * of the magnitude (L2 norm) over all components will be provided. The
+   * range is computed and then cached, and will not be re-computed on
+   * subsequent calls to GetRange() unless the array is modified or the
+   * requested component changes.
+   * THIS METHOD IS NOT THREAD SAFE.
+   */
+  void GetFiniteRange(double range[2], int comp) { this->ComputeFiniteRange(range, comp); }
+
+  //@{
+  /**
+   * Return the range of the data array values for the given component. If
+   * comp is -1, return the range of the magnitude (L2 norm) over all
+   * components.The range is computed and then cached, and will not be
+   * re-computed on subsequent calls to GetRange() unless the array is
+   * modified or the requested component changes.
+   * THIS METHOD IS NOT THREAD SAFE.
+   */
+  double* GetFiniteRange(int comp) VTK_SIZEHINT(2)
   {
-    this->GetRange(range,0);
+    this->GetFiniteRange(this->FiniteRange, comp);
+    return this->FiniteRange;
   }
+  //@}
+
+  /**
+   * Return the range of the data array. If the array has multiple components,
+   * then this will return the range of only the first component (component
+   * zero). The range is computed and then cached, and will not be re-computed
+   * on subsequent calls to GetRange() unless the array is modified.
+   * THIS METHOD IS NOT THREAD SAFE.
+   */
+  double* GetFiniteRange() VTK_SIZEHINT(2) { return this->GetFiniteRange(0); }
+
+  /**
+   * The range of the data array values will be returned in the provided
+   * range array argument. If the data array has multiple components, then
+   * this will return the range of only the first component (component zero).
+   * The range is computend and then cached, and will not be re-computed on
+   * subsequent calls to GetRange() unless the array is modified.
+   * THIS METHOD IS NOT THREAD SAFE.
+   */
+  void GetFiniteRange(double range[2]) { this->GetFiniteRange(range, 0); }
 
   //@{
   /**
@@ -414,6 +465,7 @@ public:
    * this value is set to { VTK_DOUBLE_MAX, VTK_DOUBLE_MIN }.
    */
   static vtkInformationDoubleVectorKey* COMPONENT_RANGE();
+
   /**
    * This key is used to hold tight bounds on the $L_2$ norm
    * of tuples in the array.
@@ -423,27 +475,40 @@ public:
    */
   static vtkInformationDoubleVectorKey* L2_NORM_RANGE();
 
+  /**
+   * This key is used to hold tight bounds on the $L_2$ norm
+   * of tuples in the array.
+   * Two values (a minimum and maximum) are stored for each component.
+   * When GetFiniteRange() is called when no tuples are present in the array
+   * this value is set to { VTK_DOUBLE_MAX, VTK_DOUBLE_MIN }.
+   */
+  static vtkInformationDoubleVectorKey* L2_NORM_FINITE_RANGE();
+
+  /**
+   * Removes out-of-date L2_NORM_RANGE() and L2_NORM_FINITE_RANGE() values.
+   */
+  void Modified() override;
+
   /**
    * A human-readable string indicating the units for the array data.
    */
-  static vtkInformationStringKey *UNITS_LABEL();
+  static vtkInformationStringKey* UNITS_LABEL();
 
   /**
    * Copy information instance. Arrays use information objects
    * in a variety of ways. It is important to have flexibility in
-   * this regard because certain keys should not be coppied, while
-   * others must be. NOTE: Up to the implmeneter to make sure that
-   * keys not inteneded to be coppied are excluded here.
+   * this regard because certain keys should not be copied, while
+   * others must be. NOTE: Up to the implmenter to make sure that
+   * keys not intended to be copied are excluded here.
    */
-  int CopyInformation(vtkInformation *infoFrom, int deep=1) VTK_OVERRIDE;
+  int CopyInformation(vtkInformation* infoFrom, int deep = 1) override;
 
   /**
    * Method for type-checking in FastDownCast implementations.
    */
-  int GetArrayType() VTK_OVERRIDE { return DataArray; }
+  int GetArrayType() const override { return DataArray; }
 
 protected:
-
   friend class vtkPoints;
 
   /**
@@ -455,6 +520,15 @@ protected:
    */
   virtual void ComputeRange(double range[2], int comp);
 
+  /**
+   * Compute the range for a specific component. If comp is set -1
+   * then L2 norm is computed on all components. Call ClearRange
+   * to force a recomputation if it is needed. The range is copied
+   * to the range argument.
+   * THIS METHOD IS NOT THREAD SAFE.
+   */
+  virtual void ComputeFiniteRange(double range[2], int comp);
+
   /**
    * Computes the range for each component of an array, the length
    * of \a ranges must be two times the number of components.
@@ -463,27 +537,44 @@ protected:
    */
   virtual bool ComputeScalarRange(double* ranges);
 
-  // Returns true if the range was computed. Will return false
-  // if you try to compute the range of an array of length zero.
+  /**
+   * Returns true if the range was computed. Will return false
+   * if you try to compute the range of an array of length zero.
+   */
   virtual bool ComputeVectorRange(double range[2]);
 
+  /**
+   * Computes the range for each component of an array, the length
+   * of \a ranges must be two times the number of components.
+   * Returns true if the range was computed. Will return false
+   * if you try to compute the range of an array of length zero.
+   */
+  virtual bool ComputeFiniteScalarRange(double* ranges);
+
+  /**
+   * Returns true if the range was computed. Will return false
+   * if you try to compute the range of an array of length zero.
+   */
+  virtual bool ComputeFiniteVectorRange(double range[2]);
+
   // Construct object with default tuple dimension (number of components) of 1.
   vtkDataArray();
-  ~vtkDataArray() VTK_OVERRIDE;
+  ~vtkDataArray() override;
 
-  vtkLookupTable *LookupTable;
+  vtkLookupTable* LookupTable;
   double Range[2];
+  double FiniteRange[2];
 
 private:
   double* GetTupleN(vtkIdType i, int n);
 
 private:
-  vtkDataArray(const vtkDataArray&) VTK_DELETE_FUNCTION;
-  void operator=(const vtkDataArray&) VTK_DELETE_FUNCTION;
+  vtkDataArray(const vtkDataArray&) = delete;
+  void operator=(const vtkDataArray&) = delete;
 };
 
 //------------------------------------------------------------------------------
-inline vtkDataArray* vtkDataArray::FastDownCast(vtkAbstractArray *source)
+inline vtkDataArray* vtkDataArray::FastDownCast(vtkAbstractArray* source)
 {
   if (source)
   {
@@ -499,9 +590,21 @@ inline vtkDataArray* vtkDataArray::FastDownCast(vtkAbstractArray *source)
         break;
     }
   }
-  return NULL;
+  return nullptr;
 }
 
-vtkArrayDownCast_FastCastMacro(vtkDataArray)
+vtkArrayDownCast_FastCastMacro(vtkDataArray);
+
+// These are used by vtkDataArrayPrivate.txx, but need to be available to
+// vtkGenericDataArray.h as well.
+namespace vtkDataArrayPrivate
+{
+struct AllValues
+{
+};
+struct FiniteValues
+{
+};
+}
 
 #endif
