@@ -25,17 +25,13 @@ VTK_AOS_DATA_ARRAY_TEMPLATE_INSTANTIATE(long long);
 vtkStandardNewMacro(vtkLongLongArray);
 
 //----------------------------------------------------------------------------
-vtkLongLongArray::vtkLongLongArray()
-{
-}
+vtkLongLongArray::vtkLongLongArray() = default;
 
 //----------------------------------------------------------------------------
-vtkLongLongArray::~vtkLongLongArray()
-{
-}
+vtkLongLongArray::~vtkLongLongArray() = default;
 
 //----------------------------------------------------------------------------
 void vtkLongLongArray::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->RealSuperclass::PrintSelf(os,indent);
+  this->RealSuperclass::PrintSelf(os, indent);
 }
