@@ -17,6 +17,7 @@
 #include "vtkCommand.h"
 #include "vtkDebugLeaks.h"
 #include "vtkGarbageCollector.h"
+#include "vtkObjectFactory.h"
 #include "vtkTimeStamp.h"
 #include "vtkWeakPointer.h"
 
@@ -26,18 +27,17 @@
 // Initialize static member that controls warning display
 static int vtkObjectGlobalWarningDisplay = 1;
 
-
 //----------------------------------------------------------------------------
 // avoid dll boundary problems
 #ifdef _WIN32
 void* vtkObject::operator new(size_t nSize)
 {
-  void* p=malloc(nSize);
+  void* p = malloc(nSize);
   return p;
 }
 
 //----------------------------------------------------------------------------
-void vtkObject::operator delete( void *p )
+void vtkObject::operator delete(void* p)
 {
   free(p);
 }
@@ -62,15 +62,22 @@ int vtkObject::GetGlobalWarningDisplay()
 //
 class vtkObserver
 {
- public:
-  vtkObserver():Command(0),Event(0),Tag(0),Next(0),Priority(0.0) {}
+public:
+  vtkObserver()
+    : Command(nullptr)
+    , Event(0)
+    , Tag(0)
+    , Next(nullptr)
+    , Priority(0.0)
+  {
+  }
   ~vtkObserver();
   void PrintSelf(ostream& os, vtkIndent indent);
 
-  vtkCommand *Command;
+  vtkCommand* Command;
   unsigned long Event;
   unsigned long Tag;
-  vtkObserver *Next;
+  vtkObserver* Next;
   float Priority;
 };
 
@@ -94,52 +101,65 @@ void vtkObserver::PrintSelf(ostream& os, vtkIndent indent)
 class vtkSubjectHelper
 {
 public:
-  vtkSubjectHelper():ListModified(0),Focus1(0),Focus2(0),Start(0),Count(1) {}
+  vtkSubjectHelper()
+    : ListModified(0)
+    , Focus1(nullptr)
+    , Focus2(nullptr)
+    , Start(nullptr)
+    , Count(1)
+  {
+  }
   ~vtkSubjectHelper();
 
-  unsigned long AddObserver(unsigned long event, vtkCommand *cmd, float p);
+  unsigned long AddObserver(unsigned long event, vtkCommand* cmd, float p);
   void RemoveObserver(unsigned long tag);
   void RemoveObservers(unsigned long event);
-  void RemoveObservers(unsigned long event, vtkCommand *cmd);
+  void RemoveObservers(unsigned long event, vtkCommand* cmd);
   void RemoveAllObservers();
-  int InvokeEvent(unsigned long event, void *callData, vtkObject *self);
-  vtkCommand *GetCommand(unsigned long tag);
+  int InvokeEvent(unsigned long event, void* callData, vtkObject* self);
+  vtkCommand* GetCommand(unsigned long tag);
   unsigned long GetTag(vtkCommand*);
-  int HasObserver(unsigned long event);
-  int HasObserver(unsigned long event, vtkCommand *cmd);
-  void GrabFocus(vtkCommand *c1, vtkCommand *c2) {this->Focus1 = c1; this->Focus2 = c2;}
-  void ReleaseFocus() {this->Focus1 = NULL; this->Focus2 = NULL;}
+  vtkTypeBool HasObserver(unsigned long event);
+  vtkTypeBool HasObserver(unsigned long event, vtkCommand* cmd);
+  void GrabFocus(vtkCommand* c1, vtkCommand* c2)
+  {
+    this->Focus1 = c1;
+    this->Focus2 = c2;
+  }
+  void ReleaseFocus()
+  {
+    this->Focus1 = nullptr;
+    this->Focus2 = nullptr;
+  }
   void PrintSelf(ostream& os, vtkIndent indent);
 
-  int         ListModified;
+  int ListModified;
 
   // This is to support the GrabFocus() methods found in vtkInteractorObserver.
-  vtkCommand *Focus1;
-  vtkCommand *Focus2;
+  vtkCommand* Focus1;
+  vtkCommand* Focus2;
 
 protected:
-  vtkObserver  *Start;
+  vtkObserver* Start;
   unsigned long Count;
 };
 
 // ------------------------------------vtkObject----------------------
 
-vtkObject *vtkObject::New()
+vtkObject* vtkObject::New()
 {
-#ifdef VTK_DEBUG_LEAKS
-  vtkDebugLeaks::ConstructClass("vtkObject");
-#endif
-  return new vtkObject;
+  vtkObject* ret = new vtkObject;
+  ret->InitializeObjectBase();
+  return ret;
 }
 
-
 //----------------------------------------------------------------------------
 // Create an object with Debug turned off and modified time initialized
 // to zero.
 vtkObject::vtkObject()
 {
-  this->Debug = 0;
-  this->SubjectHelper = NULL;
+  this->Debug = false;
+  this->SubjectHelper = nullptr;
   this->Modified(); // Insures modified time > than any other time
   // initial reference count = 1 and reference counting on.
 }
@@ -151,17 +171,17 @@ vtkObject::~vtkObject()
 
   // warn user if reference counting is on and the object is being referenced
   // by another object
-  if ( this->ReferenceCount > 0)
-    {
+  if (this->ReferenceCount > 0)
+  {
     vtkErrorMacro(<< "Trying to delete object with non-zero reference count.");
-    }
+  }
   delete this->SubjectHelper;
-  this->SubjectHelper = NULL;
+  this->SubjectHelper = nullptr;
 }
 
 //----------------------------------------------------------------------------
 // Return the modification for this object.
-unsigned long int vtkObject::GetMTime()
+vtkMTimeType vtkObject::GetMTime()
 {
   return this->MTime.GetMTime();
 }
@@ -174,15 +194,15 @@ void vtkObject::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Modified Time: " << this->GetMTime() << "\n";
   this->Superclass::PrintSelf(os, indent);
   os << indent << "Registered Events: ";
-  if ( this->SubjectHelper )
-    {
+  if (this->SubjectHelper)
+  {
     os << endl;
-    this->SubjectHelper->PrintSelf(os,indent.GetNextIndent());
-    }
+    this->SubjectHelper->PrintSelf(os, indent.GetNextIndent());
+  }
   else
-    {
+  {
     os << "(none)\n";
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -191,37 +211,34 @@ void vtkObject::PrintSelf(ostream& os, vtkIndent indent)
 // the modification time when enabling debug output.
 void vtkObject::DebugOn()
 {
-  this->Debug = 1;
+  this->Debug = true;
 }
 
 //----------------------------------------------------------------------------
 // Turn debugging output off.
 void vtkObject::DebugOff()
 {
-  this->Debug = 0;
+  this->Debug = false;
 }
 
 //----------------------------------------------------------------------------
 // Get the value of the debug flag.
-unsigned char vtkObject::GetDebug()
+bool vtkObject::GetDebug()
 {
   return this->Debug;
 }
 
 //----------------------------------------------------------------------------
-// Set the value of the debug flag. A non-zero value turns debugging on.
-void vtkObject::SetDebug(unsigned char debugFlag)
+// Set the value of the debug flag. A true value turns debugging on.
+void vtkObject::SetDebug(bool debugFlag)
 {
   this->Debug = debugFlag;
 }
 
-
 //----------------------------------------------------------------------------
 // This method is called when vtkErrorMacro executes. It allows
 // the debugger to break on error.
-void vtkObject::BreakOnError()
-{
-}
+void vtkObject::BreakOnError() {}
 
 //----------------------------------Command/Observer stuff-------------------
 //
@@ -229,112 +246,110 @@ void vtkObject::BreakOnError()
 //----------------------------------------------------------------------------
 vtkObserver::~vtkObserver()
 {
-  this->Command->UnRegister(0);
+  this->Command->UnRegister(nullptr);
 }
 
 //----------------------------------------------------------------------------
 vtkSubjectHelper::~vtkSubjectHelper()
 {
-  vtkObserver *elem = this->Start;
-  vtkObserver *next;
+  vtkObserver* elem = this->Start;
+  vtkObserver* next;
   while (elem)
-    {
+  {
     next = elem->Next;
     delete elem;
     elem = next;
-    }
-  this->Start = NULL;
-  this->Focus1 = NULL;
-  this->Focus2 = NULL;
+  }
+  this->Start = nullptr;
+  this->Focus1 = nullptr;
+  this->Focus2 = nullptr;
 }
 
-
 //----------------------------------------------------------------------------
-unsigned long vtkSubjectHelper::
-AddObserver(unsigned long event, vtkCommand *cmd, float p)
+unsigned long vtkSubjectHelper::AddObserver(unsigned long event, vtkCommand* cmd, float p)
 {
-  vtkObserver *elem;
+  vtkObserver* elem;
 
   // initialize the new observer element
   elem = new vtkObserver;
   elem->Priority = p;
-  elem->Next = NULL;
+  elem->Next = nullptr;
   elem->Event = event;
   elem->Command = cmd;
-  cmd->Register(0);
+  cmd->Register(nullptr);
   elem->Tag = this->Count;
   this->Count++;
 
   // now insert into the list
   // if no other elements in the list then this is Start
   if (!this->Start)
-    {
+  {
     this->Start = elem;
-    }
+  }
   else
-    {
+  {
     // insert high priority first
-    vtkObserver* prev = 0;
+    vtkObserver* prev = nullptr;
     vtkObserver* pos = this->Start;
-    while(pos->Priority >= elem->Priority && pos->Next)
-      {
+    while (pos->Priority >= elem->Priority && pos->Next)
+    {
       prev = pos;
       pos = pos->Next;
-      }
+    }
     // pos is Start and elem should not be start
-    if(pos->Priority > elem->Priority)
-      {
+    if (pos->Priority > elem->Priority)
+    {
       pos->Next = elem;
-      }
+    }
     else
+    {
+      if (prev)
       {
-      if(prev)
-        {
         prev->Next = elem;
-        }
+      }
       elem->Next = pos;
       // check to see if the new element is the start
-      if(pos == this->Start)
-        {
+      if (pos == this->Start)
+      {
         this->Start = elem;
-        }
       }
     }
+  }
   return elem->Tag;
 }
 
 //----------------------------------------------------------------------------
 void vtkSubjectHelper::RemoveObserver(unsigned long tag)
 {
-  vtkObserver *elem;
-  vtkObserver *prev;
-  vtkObserver *next;
+  vtkObserver* elem;
+  vtkObserver* prev;
+  vtkObserver* next;
 
   elem = this->Start;
-  prev = NULL;
+  prev = nullptr;
   while (elem)
-    {
+  {
     if (elem->Tag == tag)
-      {
+    {
       if (prev)
-        {
+      {
         prev->Next = elem->Next;
         next = prev->Next;
-        }
+      }
       else
-        {
+      {
         this->Start = elem->Next;
         next = this->Start;
-        }
+      }
       delete elem;
       elem = next;
-      }
+    }
     else
-      {
+    {
       prev = elem;
       elem = elem->Next;
-      }
     }
+  }
 
   this->ListModified = 1;
 }
@@ -342,71 +357,71 @@ void vtkSubjectHelper::RemoveObserver(unsigned long tag)
 //----------------------------------------------------------------------------
 void vtkSubjectHelper::RemoveObservers(unsigned long event)
 {
-  vtkObserver *elem;
-  vtkObserver *prev;
-  vtkObserver *next;
+  vtkObserver* elem;
+  vtkObserver* prev;
+  vtkObserver* next;
 
   elem = this->Start;
-  prev = NULL;
+  prev = nullptr;
   while (elem)
-    {
+  {
     if (elem->Event == event)
-      {
+    {
       if (prev)
-        {
+      {
         prev->Next = elem->Next;
         next = prev->Next;
-        }
+      }
       else
-        {
+      {
         this->Start = elem->Next;
         next = this->Start;
-        }
+      }
       delete elem;
       elem = next;
-      }
+    }
     else
-      {
+    {
       prev = elem;
       elem = elem->Next;
-      }
     }
+  }
 
   this->ListModified = 1;
 }
 
 //----------------------------------------------------------------------------
-void vtkSubjectHelper::RemoveObservers(unsigned long event, vtkCommand *cmd)
+void vtkSubjectHelper::RemoveObservers(unsigned long event, vtkCommand* cmd)
 {
-  vtkObserver *elem;
-  vtkObserver *prev;
-  vtkObserver *next;
+  vtkObserver* elem;
+  vtkObserver* prev;
+  vtkObserver* next;
 
   elem = this->Start;
-  prev = NULL;
+  prev = nullptr;
   while (elem)
-    {
+  {
     if (elem->Event == event && elem->Command == cmd)
-      {
+    {
       if (prev)
-        {
+      {
         prev->Next = elem->Next;
         next = prev->Next;
-        }
+      }
       else
-        {
+      {
         this->Start = elem->Next;
         next = this->Start;
-        }
+      }
       delete elem;
       elem = next;
-      }
+    }
     else
-      {
+    {
       prev = elem;
       elem = elem->Next;
-      }
     }
+  }
 
   this->ListModified = 1;
 }
@@ -414,51 +429,49 @@ void vtkSubjectHelper::RemoveObservers(unsigned long event, vtkCommand *cmd)
 //----------------------------------------------------------------------------
 void vtkSubjectHelper::RemoveAllObservers()
 {
-  vtkObserver *elem = this->Start;
-  vtkObserver *next;
+  vtkObserver* elem = this->Start;
+  vtkObserver* next;
   while (elem)
-    {
+  {
     next = elem->Next;
     delete elem;
     elem = next;
-    }
-  this->Start = NULL;
+  }
+  this->Start = nullptr;
 }
 
 //----------------------------------------------------------------------------
-int vtkSubjectHelper::HasObserver(unsigned long event)
+vtkTypeBool vtkSubjectHelper::HasObserver(unsigned long event)
 {
-  vtkObserver *elem = this->Start;
+  vtkObserver* elem = this->Start;
   while (elem)
-    {
+  {
     if (elem->Event == event || elem->Event == vtkCommand::AnyEvent)
-      {
-      return 1;
-      }
-    elem = elem->Next;
-    }
-  return 0;
-}
-
-//----------------------------------------------------------------------------
-int vtkSubjectHelper::HasObserver(unsigned long event, vtkCommand *cmd)
-{
-  vtkObserver *elem = this->Start;
-  while (elem)
     {
-    if ((elem->Event == event || elem->Event == vtkCommand::AnyEvent) &&
-        elem->Command == cmd)
-      {
       return 1;
-      }
-    elem = elem->Next;
     }
+    elem = elem->Next;
+  }
   return 0;
 }
 
 //----------------------------------------------------------------------------
-int vtkSubjectHelper::InvokeEvent(unsigned long event, void *callData,
-                                   vtkObject *self)
+vtkTypeBool vtkSubjectHelper::HasObserver(unsigned long event, vtkCommand* cmd)
+{
+  vtkObserver* elem = this->Start;
+  while (elem)
+  {
+    if ((elem->Event == event || elem->Event == vtkCommand::AnyEvent) && elem->Command == cmd)
+    {
+      return 1;
+    }
+    elem = elem->Next;
+  }
+  return 0;
+}
+
+//----------------------------------------------------------------------------
+int vtkSubjectHelper::InvokeEvent(unsigned long event, void* callData, vtkObject* self)
 {
   int focusHandled = 0;
 
@@ -479,7 +492,7 @@ int vtkSubjectHelper::InvokeEvent(unsigned long event, void *callData,
   // invocation.
   typedef std::vector<unsigned long> VisitedListType;
   VisitedListType visited;
-  vtkObserver *elem = this->Start;
+  vtkObserver* elem = this->Start;
   // If an element with a tag greater than maxTag is found, that means it has
   // been added after InvokeEvent is called (as a side effect of calling an
   // element command. In that case, the element is discarded and not executed.
@@ -505,58 +518,56 @@ int vtkSubjectHelper::InvokeEvent(unsigned long event, void *callData,
 
   // 0. Passive observer loop
   //
-  vtkObserver *next;
+  vtkObserver* next;
   while (elem)
-    {
+  {
     // store the next pointer because elem could disappear due to Command
     next = elem->Next;
     if (elem->Command->GetPassiveObserver() &&
-        (elem->Event == event || elem->Event == vtkCommand::AnyEvent) &&
-        elem->Tag < maxTag)
-      {
-      VisitedListType::iterator vIter =
-        std::lower_bound(visited.begin(), visited.end(), elem->Tag);
+      (elem->Event == event || elem->Event == vtkCommand::AnyEvent) && elem->Tag < maxTag)
+    {
+      VisitedListType::iterator vIter = std::lower_bound(visited.begin(), visited.end(), elem->Tag);
       if (vIter == visited.end() || *vIter != elem->Tag)
-        {
+      {
         // Sorted insertion by tag to speed-up future searches at limited
         // insertion cost because it reuses the search iterator already at the
         // correct location
         visited.insert(vIter, elem->Tag);
         vtkCommand* command = elem->Command;
         command->Register(command);
-        elem->Command->Execute(self,event,callData);
+        elem->Command->Execute(self, event, callData);
         command->UnRegister();
-        }
-      }
-    if (this->ListModified)
-      {
-      vtkGenericWarningMacro(<<"Passive observer should not call AddObserver or RemoveObserver in callback.");
-      elem = this->Start;
-      this->ListModified = 0;
-      }
-    else
-      {
-      elem = next;
       }
     }
+    if (this->ListModified)
+    {
+      vtkGenericWarningMacro(
+        << "Passive observer should not call AddObserver or RemoveObserver in callback.");
+      elem = this->Start;
+      this->ListModified = 0;
+    }
+    else
+    {
+      elem = next;
+    }
+  }
 
   // 1. Focus loop
   //
   if (this->Focus1 || this->Focus2)
-    {
+  {
     elem = this->Start;
     while (elem)
-      {
+    {
       // store the next pointer because elem could disappear due to Command
       next = elem->Next;
       if (((this->Focus1 == elem->Command) || (this->Focus2 == elem->Command)) &&
-          (elem->Event == event || elem->Event == vtkCommand::AnyEvent) &&
-          elem->Tag < maxTag)
-        {
+        (elem->Event == event || elem->Event == vtkCommand::AnyEvent) && elem->Tag < maxTag)
+      {
         VisitedListType::iterator vIter =
           std::lower_bound(visited.begin(), visited.end(), elem->Tag);
         if (vIter == visited.end() || *vIter != elem->Tag)
-          {
+        {
           // Don't execute the remainder loop
           focusHandled = 1;
           // Sorted insertion by tag to speed-up future searches at limited
@@ -566,46 +577,45 @@ int vtkSubjectHelper::InvokeEvent(unsigned long event, void *callData,
           vtkCommand* command = elem->Command;
           command->Register(command);
           command->SetAbortFlag(0);
-          elem->Command->Execute(self,event,callData);
+          elem->Command->Execute(self, event, callData);
           // if the command set the abort flag, then stop firing events
           // and return
-          if(command->GetAbortFlag())
-            {
+          if (command->GetAbortFlag())
+          {
             command->UnRegister();
             this->ListModified = saveListModified;
             return 1;
-            }
-          command->UnRegister();
           }
-        }
-      if (this->ListModified)
-        {
-        elem = this->Start;
-        this->ListModified = 0;
-        }
-      else
-        {
-        elem = next;
+          command->UnRegister();
         }
       }
+      if (this->ListModified)
+      {
+        elem = this->Start;
+        this->ListModified = 0;
+      }
+      else
+      {
+        elem = next;
+      }
     }
+  }
 
   // 2. Remainder loop
   //
   if (!focusHandled)
-    {
+  {
     elem = this->Start;
     while (elem)
-      {
+    {
       // store the next pointer because elem could disappear due to Command
       next = elem->Next;
-      if ((elem->Event == event || elem->Event == vtkCommand::AnyEvent) &&
-          elem->Tag < maxTag)
-        {
+      if ((elem->Event == event || elem->Event == vtkCommand::AnyEvent) && elem->Tag < maxTag)
+      {
         VisitedListType::iterator vIter =
           std::lower_bound(visited.begin(), visited.end(), elem->Tag);
         if (vIter == visited.end() || *vIter != elem->Tag)
-          {
+        {
           // Sorted insertion by tag to speed-up future searches at limited
           // insertion cost because it reuses the search iterator already at the
           // correct location
@@ -613,29 +623,29 @@ int vtkSubjectHelper::InvokeEvent(unsigned long event, void *callData,
           vtkCommand* command = elem->Command;
           command->Register(command);
           command->SetAbortFlag(0);
-          elem->Command->Execute(self,event,callData);
+          elem->Command->Execute(self, event, callData);
           // if the command set the abort flag, then stop firing events
           // and return
-          if(command->GetAbortFlag())
-            {
+          if (command->GetAbortFlag())
+          {
             command->UnRegister();
             this->ListModified = saveListModified;
             return 1;
-            }
-          command->UnRegister();
           }
-        }
-      if (this->ListModified)
-        {
-        elem = this->Start;
-        this->ListModified = 0;
-        }
-      else
-        {
-        elem = next;
+          command->UnRegister();
         }
       }
+      if (this->ListModified)
+      {
+        elem = this->Start;
+        this->ListModified = 0;
+      }
+      else
+      {
+        elem = next;
+      }
     }
+  }
 
   this->ListModified = saveListModified;
   return 0;
@@ -644,31 +654,31 @@ int vtkSubjectHelper::InvokeEvent(unsigned long event, void *callData,
 //----------------------------------------------------------------------------
 unsigned long vtkSubjectHelper::GetTag(vtkCommand* cmd)
 {
-  vtkObserver *elem = this->Start;
+  vtkObserver* elem = this->Start;
   while (elem)
-    {
+  {
     if (elem->Command == cmd)
-      {
+    {
       return elem->Tag;
-      }
-    elem = elem->Next;
     }
+    elem = elem->Next;
+  }
   return 0;
 }
 
 //----------------------------------------------------------------------------
-vtkCommand *vtkSubjectHelper::GetCommand(unsigned long tag)
+vtkCommand* vtkSubjectHelper::GetCommand(unsigned long tag)
 {
-  vtkObserver *elem = this->Start;
+  vtkObserver* elem = this->Start;
   while (elem)
-    {
+  {
     if (elem->Tag == tag)
-      {
+    {
       return elem->Command;
-      }
-    elem = elem->Next;
     }
-  return NULL;
+    elem = elem->Next;
+  }
+  return nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -676,94 +686,94 @@ void vtkSubjectHelper::PrintSelf(ostream& os, vtkIndent indent)
 {
   os << indent << "Registered Observers:\n";
   indent = indent.GetNextIndent();
-  vtkObserver *elem = this->Start;
-  if ( !elem )
-    {
+  vtkObserver* elem = this->Start;
+  if (!elem)
+  {
     os << indent << "(none)\n";
     return;
-    }
+  }
 
-  for ( ; elem; elem=elem->Next )
-    {
+  for (; elem; elem = elem->Next)
+  {
     elem->PrintSelf(os, indent);
-    }
+  }
 }
 
 //--------------------------------vtkObject observer-----------------------
-unsigned long vtkObject::AddObserver(unsigned long event, vtkCommand *cmd, float p)
+unsigned long vtkObject::AddObserver(unsigned long event, vtkCommand* cmd, float p)
 {
   if (!this->SubjectHelper)
-    {
+  {
     this->SubjectHelper = new vtkSubjectHelper;
-    }
-  return this->SubjectHelper->AddObserver(event,cmd, p);
+  }
+  return this->SubjectHelper->AddObserver(event, cmd, p);
 }
 
 //----------------------------------------------------------------------------
-unsigned long vtkObject::AddObserver(const char *event,vtkCommand *cmd, float p)
+unsigned long vtkObject::AddObserver(const char* event, vtkCommand* cmd, float p)
 {
   return this->AddObserver(vtkCommand::GetEventIdFromString(event), cmd, p);
 }
 
 //----------------------------------------------------------------------------
-vtkCommand *vtkObject::GetCommand(unsigned long tag)
+vtkCommand* vtkObject::GetCommand(unsigned long tag)
 {
   if (this->SubjectHelper)
-    {
+  {
     return this->SubjectHelper->GetCommand(tag);
-    }
-  return NULL;
+  }
+  return nullptr;
 }
 
 //----------------------------------------------------------------------------
 void vtkObject::RemoveObserver(unsigned long tag)
 {
   if (this->SubjectHelper)
-    {
+  {
     this->SubjectHelper->RemoveObserver(tag);
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
 void vtkObject::RemoveObserver(vtkCommand* c)
 {
   if (this->SubjectHelper)
-    {
+  {
     unsigned long tag = this->SubjectHelper->GetTag(c);
-    while(tag)
-      {
+    while (tag)
+    {
       this->SubjectHelper->RemoveObserver(tag);
       tag = this->SubjectHelper->GetTag(c);
-      }
     }
+  }
 }
 
 //----------------------------------------------------------------------------
 void vtkObject::RemoveObservers(unsigned long event)
 {
   if (this->SubjectHelper)
-    {
+  {
     this->SubjectHelper->RemoveObservers(event);
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
-void vtkObject::RemoveObservers(const char *event)
+void vtkObject::RemoveObservers(const char* event)
 {
   this->RemoveObservers(vtkCommand::GetEventIdFromString(event));
 }
 
 //----------------------------------------------------------------------------
-void vtkObject::RemoveObservers(unsigned long event, vtkCommand *cmd)
+void vtkObject::RemoveObservers(unsigned long event, vtkCommand* cmd)
 {
   if (this->SubjectHelper)
-    {
+  {
     this->SubjectHelper->RemoveObservers(event, cmd);
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
-void vtkObject::RemoveObservers(const char *event, vtkCommand *cmd)
+void vtkObject::RemoveObservers(const char* event, vtkCommand* cmd)
 {
   this->RemoveObservers(vtkCommand::GetEventIdFromString(event), cmd);
 }
@@ -771,130 +781,126 @@ void vtkObject::RemoveObservers(const char *event, vtkCommand *cmd)
 //----------------------------------------------------------------------------
 void vtkObject::RemoveAllObservers()
 {
-  if ( this->SubjectHelper )
-    {
+  if (this->SubjectHelper)
+  {
     this->SubjectHelper->RemoveAllObservers();
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
-int vtkObject::InvokeEvent(unsigned long event, void *callData)
+int vtkObject::InvokeEvent(unsigned long event, void* callData)
 {
   if (this->SubjectHelper)
-    {
-    return this->SubjectHelper->InvokeEvent(event,callData, this);
-    }
+  {
+    return this->SubjectHelper->InvokeEvent(event, callData, this);
+  }
   return 0;
 }
 
 //----------------------------------------------------------------------------
-int vtkObject::InvokeEvent(const char *event, void *callData)
+int vtkObject::InvokeEvent(const char* event, void* callData)
 {
   return this->InvokeEvent(vtkCommand::GetEventIdFromString(event), callData);
 }
 
 //----------------------------------------------------------------------------
-int vtkObject::HasObserver(unsigned long event)
+vtkTypeBool vtkObject::HasObserver(unsigned long event)
 {
   if (this->SubjectHelper)
-    {
+  {
     return this->SubjectHelper->HasObserver(event);
-    }
+  }
   return 0;
 }
 
 //----------------------------------------------------------------------------
-int vtkObject::HasObserver(const char *event)
+vtkTypeBool vtkObject::HasObserver(const char* event)
 {
   return this->HasObserver(vtkCommand::GetEventIdFromString(event));
 }
 
 //----------------------------------------------------------------------------
-int vtkObject::HasObserver(unsigned long event, vtkCommand *cmd)
+vtkTypeBool vtkObject::HasObserver(unsigned long event, vtkCommand* cmd)
 {
   if (this->SubjectHelper)
-    {
+  {
     return this->SubjectHelper->HasObserver(event, cmd);
-    }
+  }
   return 0;
 }
 
 //----------------------------------------------------------------------------
-int vtkObject::HasObserver(const char *event, vtkCommand *cmd)
+vtkTypeBool vtkObject::HasObserver(const char* event, vtkCommand* cmd)
 {
   return this->HasObserver(vtkCommand::GetEventIdFromString(event), cmd);
 }
 
 //----------------------------------------------------------------------------
-void vtkObject::InternalGrabFocus(vtkCommand *mouseEvents, vtkCommand *keypressEvents)
+void vtkObject::InternalGrabFocus(vtkCommand* mouseEvents, vtkCommand* keypressEvents)
 {
   if (this->SubjectHelper)
-    {
-    this->SubjectHelper->GrabFocus(mouseEvents,keypressEvents);
-    }
+  {
+    this->SubjectHelper->GrabFocus(mouseEvents, keypressEvents);
+  }
 }
 
 //----------------------------------------------------------------------------
 void vtkObject::InternalReleaseFocus()
 {
   if (this->SubjectHelper)
-    {
+  {
     this->SubjectHelper->ReleaseFocus();
-    }
+  }
 }
 
-
 //----------------------------------------------------------------------------
 void vtkObject::Modified()
 {
   this->MTime.Modified();
-  this->InvokeEvent(vtkCommand::ModifiedEvent,NULL);
+  this->InvokeEvent(vtkCommand::ModifiedEvent, nullptr);
 }
 
 //----------------------------------------------------------------------------
-void vtkObject::RegisterInternal(vtkObjectBase* o, int check)
+void vtkObject::RegisterInternal(vtkObjectBase* o, vtkTypeBool check)
 {
   // Print debugging messages.
-  if(o)
-    {
+  if (o)
+  {
     vtkDebugMacro(<< "Registered by " << o->GetClassName() << " (" << o
-                  << "), ReferenceCount = " << this->ReferenceCount+1);
-    }
+                  << "), ReferenceCount = " << this->ReferenceCount + 1);
+  }
   else
-    {
-    vtkDebugMacro(<< "Registered by NULL, ReferenceCount = "
-                  << this->ReferenceCount+1);
-    }
+  {
+    vtkDebugMacro(<< "Registered by nullptr, ReferenceCount = " << this->ReferenceCount + 1);
+  }
 
   // Increment the reference count.
   this->Superclass::RegisterInternal(o, check);
 }
 
 //----------------------------------------------------------------------------
-void vtkObject::UnRegisterInternal(vtkObjectBase* o, int check)
+void vtkObject::UnRegisterInternal(vtkObjectBase* o, vtkTypeBool check)
 {
   // Print debugging messages.
-  if(o)
-    {
-    vtkDebugMacro(<< "UnRegistered by "
-                  << o->GetClassName() << " (" << o << "), ReferenceCount = "
-                  << (this->ReferenceCount-1));
-    }
+  if (o)
+  {
+    vtkDebugMacro(<< "UnRegistered by " << o->GetClassName() << " (" << o
+                  << "), ReferenceCount = " << (this->ReferenceCount - 1));
+  }
   else
-    {
-    vtkDebugMacro(<< "UnRegistered by NULL, ReferenceCount = "
-                  << (this->ReferenceCount-1));
-    }
+  {
+    vtkDebugMacro(<< "UnRegistered by nullptr, ReferenceCount = " << (this->ReferenceCount - 1));
+  }
 
-  if(this->ReferenceCount == 1)
-    {
+  if (this->ReferenceCount == 1)
+  {
     // The reference count is 1, so the object is about to be deleted.
     // Invoke the delete event.
-    this->InvokeEvent(vtkCommand::DeleteEvent, 0);
+    this->InvokeEvent(vtkCommand::DeleteEvent, nullptr);
 
     // Clean out observers prior to entering destructor
     this->RemoveAllObservers();
-    }
+  }
 
   // Decrement the reference count.
   this->Superclass::UnRegisterInternal(o, check);
@@ -906,40 +912,33 @@ void vtkObject::UnRegisterInternal(vtkObjectBase* o, int check)
 class vtkObjectCommandInternal : public vtkCommand
 {
   vtkObject::vtkClassMemberCallbackBase* Callable;
+
 public:
-  static vtkObjectCommandInternal* New()
-    { return new vtkObjectCommandInternal(); }
+  static vtkObjectCommandInternal* New() { return new vtkObjectCommandInternal(); }
 
   vtkTypeMacro(vtkObjectCommandInternal, vtkCommand);
-  virtual void Execute(
-    vtkObject *caller, unsigned long eventId, void *callData)
-    {
+  void Execute(vtkObject* caller, unsigned long eventId, void* callData) override
+  {
     if (this->Callable)
-      {
+    {
       this->AbortFlagOff();
-      if((*this->Callable)(caller, eventId, callData))
-        {
+      if ((*this->Callable)(caller, eventId, callData))
+      {
         this->AbortFlagOn();
-        }
       }
     }
+  }
 
   // Takes over the ownership of \c callable.
   void SetCallable(vtkObject::vtkClassMemberCallbackBase* callable)
-    {
+  {
     delete this->Callable;
     this->Callable = callable;
-    }
+  }
 
 protected:
-  vtkObjectCommandInternal()
-    {
-    this->Callable = NULL;
-    }
-  ~vtkObjectCommandInternal()
-    {
-    delete this->Callable;
-    }
+  vtkObjectCommandInternal() { this->Callable = nullptr; }
+  ~vtkObjectCommandInternal() override { delete this->Callable; }
 };
 
 //----------------------------------------------------------------------------
