@@ -15,16 +15,11 @@
 
 #include <cassert>
 
+// ----------------------------------------------------------------------------
+vtkRandomSequence::vtkRandomSequence() = default;
 
 // ----------------------------------------------------------------------------
-vtkRandomSequence::vtkRandomSequence()
-{
-}
-
-// ----------------------------------------------------------------------------
-vtkRandomSequence::~vtkRandomSequence()
-{
-}
+vtkRandomSequence::~vtkRandomSequence() = default;
 
 // ----------------------------------------------------------------------------
 void vtkRandomSequence::PrintSelf(ostream& os, vtkIndent indent)
