@@ -41,14 +41,14 @@
  *
  * @sa
  * vtkLookupTable vtkColorTransferFunction
-*/
+ */
 
 #ifndef vtkScalarsToColors_h
 #define vtkScalarsToColors_h
 
 #include "vtkCommonCoreModule.h" // For export macro
-#include "vtkVariant.h" // Set/get annotation methods require variants.
 #include "vtkObject.h"
+#include "vtkVariant.h" // Set/get annotation methods require variants.
 
 class vtkAbstractArray;
 class vtkDataArray;
@@ -56,19 +56,22 @@ class vtkUnsignedCharArray;
 class vtkAbstractArray;
 class vtkStringArray;
 
-
 class VTKCOMMONCORE_EXPORT vtkScalarsToColors : public vtkObject
 {
 public:
-  vtkTypeMacro(vtkScalarsToColors,vtkObject);
-  void PrintSelf(ostream& os, vtkIndent indent) VTK_OVERRIDE;
-  static vtkScalarsToColors *New();
+  vtkTypeMacro(vtkScalarsToColors, vtkObject);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
+  static vtkScalarsToColors* New();
 
+  //@{
   /**
    * Return true if all of the values defining the mapping have an opacity
-   * equal to 1. Default implementation return true.
+   * equal to 1. Default implementation returns true. The more complex
+   * signature will yield more accurate results.
    */
   virtual int IsOpaque();
+  virtual int IsOpaque(vtkAbstractArray* scalars, int colorMode, int component);
+  //@}
 
   /**
    * Perform any processing required (if any) before processing
@@ -80,17 +83,16 @@ public:
   /**
    * Sets/Gets the range of scalars that will be mapped.
    */
-  virtual double *GetRange();
+  virtual double* GetRange() VTK_SIZEHINT(2);
   virtual void SetRange(double min, double max);
-  void SetRange(double rng[2])
-    {this->SetRange(rng[0],rng[1]);}
+  virtual void SetRange(const double rng[2]) { this->SetRange(rng[0], rng[1]); }
   //@}
 
   /**
    * Map one value through the lookup table and return a color defined
-   * as a RGBA unsigned char tuple (4 bytes).
+   * as an RGBA unsigned char tuple (4 bytes).
    */
-  virtual unsigned char *MapValue(double v);
+  virtual const unsigned char* MapValue(double v);
 
   /**
    * Map one value through the lookup table and store the color as
@@ -102,8 +104,11 @@ public:
    * Map one value through the lookup table and return the color as
    * an RGB array of doubles between 0 and 1.
    */
-  double *GetColor(double v)
-    {this->GetColor(v,this->RGB); return this->RGB;}
+  double* GetColor(double v) VTK_SIZEHINT(3)
+  {
+    this->GetColor(v, this->RGB);
+    return this->RGB;
+  }
 
   /**
    * Map one value through the lookup table and return the alpha value
@@ -118,8 +123,11 @@ public:
    * Returns the luminance value for the specified scalar value.
    */
   double GetLuminance(double x)
-    {double rgb[3]; this->GetColor(x,rgb);
-    return static_cast<double>(rgb[0]*0.30 + rgb[1]*0.59 + rgb[2]*0.11);}
+  {
+    double rgb[3];
+    this->GetColor(x, rgb);
+    return static_cast<double>(rgb[0] * 0.30 + rgb[1] * 0.59 + rgb[2] * 0.11);
+  }
 
   //@{
   /**
@@ -129,31 +137,33 @@ public:
    * blend its opacity. Value is clamped between 0 and 1.
    */
   virtual void SetAlpha(double alpha);
-  vtkGetMacro(Alpha,double);
+  vtkGetMacro(Alpha, double);
   //@}
 
   //@{
   /**
-   * Internal methods that map a data array into a 4-component,
-   * unsigned char RGBA array. The color mode determines the behavior
-   * of mapping. If VTK_COLOR_MODE_DEFAULT is set, then unsigned char
-   * data arrays are treated as colors (and converted to RGBA if
-   * necessary); If VTK_COLOR_MODE_DIRECT_SCALARS is set, then all arrays
-   * are treated as colors (integer types are clamped in the range 0-255,
-   * floating point arrays are clamped in the range 0.0-1.0. Note 'char' does
-   * not have enough values to represent a color so mapping this type is
-   * considered an error);
-   * otherwise, the data is mapped through this instance
-   * of ScalarsToColors. The component argument is used for data
-   * arrays with more than one component; it indicates which component
-   * to use to do the blending.  When the component argument is -1,
-   * then the this object uses its own selected technique to change a
-   * vector into a scalar to map.
+   * Internal methods that map a data array into an unsigned char array.
+   * The output format can be set to VTK_RGBA (4 components),
+   * VTK_RGB (3 components), VTK_LUMINANCE (1 component, greyscale),
+   * or VTK_LUMINANCE_ALPHA (2 components).
+   * If not supplied, the output format defaults to RGBA.
+   * The color mode determines the behavior of mapping.
+   * If VTK_COLOR_MODE_DEFAULT is set, then unsigned char data arrays are
+   * treated as colors (and converted to RGBA if necessary);
+   * If VTK_COLOR_MODE_DIRECT_SCALARS is set, then all arrays are treated as
+   * colors (integer types are clamped in the range 0-255, floating point
+   * arrays are clamped in the range 0.0-1.0. Note 'char' does not have enough
+   * values to represent a color so mapping this type is considered an error);
+   * otherwise, the data is mapped through this instance of ScalarsToColors.
+   * The component argument is used for data arrays with more than one
+   * component; it indicates which component to use to do the blending.
+   * When the component argument is -1, then the this object uses its own
+   * selected technique to change a vector into a scalar to map.
    */
-  virtual vtkUnsignedCharArray *MapScalars(vtkDataArray *scalars, int colorMode,
-                                           int component);
-  virtual vtkUnsignedCharArray *MapScalars(vtkAbstractArray *scalars, int colorMode,
-                                           int component);
+  virtual vtkUnsignedCharArray* MapScalars(
+    vtkDataArray* scalars, int colorMode, int component, int outputFormat = VTK_RGBA);
+  virtual vtkUnsignedCharArray* MapScalars(
+    vtkAbstractArray* scalars, int colorMode, int component, int outputFormat = VTK_RGBA);
   //@}
 
   //@{
@@ -169,10 +179,11 @@ public:
   void SetVectorModeToRGBColors();
   //@}
 
-  enum VectorModes {
-    MAGNITUDE=0,
-    COMPONENT=1,
-    RGBCOLORS=2
+  enum VectorModes
+  {
+    MAGNITUDE = 0,
+    COMPONENT = 1,
+    RGBCOLORS = 2
   };
 
   //@{
@@ -203,15 +214,14 @@ public:
    * VTK_RGB (3 components), VTK_LUMINANCE (1 component, greyscale),
    * or VTK_LUMINANCE_ALPHA (2 components)
    */
-  void MapVectorsThroughTable(void *input, unsigned char *output,
-                              int inputDataType, int numberOfValues,
-                              int inputIncrement, int outputFormat,
-                              int vectorComponent, int vectorSize);
-  void MapVectorsThroughTable(void *input, unsigned char *output,
-                              int inputDataType, int numberOfValues,
-                              int inputIncrement, int outputFormat)
-    { this->MapVectorsThroughTable(input, output, inputDataType, numberOfValues,
-                                   inputIncrement, outputFormat, -1, -1); }
+  void MapVectorsThroughTable(void* input, unsigned char* output, int inputDataType,
+    int numberOfValues, int inputIncrement, int outputFormat, int vectorComponent, int vectorSize);
+  void MapVectorsThroughTable(void* input, unsigned char* output, int inputDataType,
+    int numberOfValues, int inputIncrement, int outputFormat)
+  {
+    this->MapVectorsThroughTable(
+      input, output, inputDataType, numberOfValues, inputIncrement, outputFormat, -1, -1);
+  }
 
   /**
    * Map a set of scalars through the lookup table in a single operation.
@@ -221,40 +231,36 @@ public:
    * or VTK_LUMINANCE_ALPHA (2 components)
    * If not supplied, the output format defaults to RGBA.
    */
-  void MapScalarsThroughTable(vtkDataArray *scalars,
-                              unsigned char *output,
-                              int outputFormat);
-  void MapScalarsThroughTable(vtkDataArray *scalars,
-                              unsigned char *output)
-    {this->MapScalarsThroughTable(scalars,output,VTK_RGBA);}
-  void MapScalarsThroughTable(void *input, unsigned char *output,
-                              int inputDataType, int numberOfValues,
-                              int inputIncrement,
-                              int outputFormat)
-    {this->MapScalarsThroughTable2(input, output, inputDataType,
-       numberOfValues, inputIncrement, outputFormat);}
+  void MapScalarsThroughTable(vtkDataArray* scalars, unsigned char* output, int outputFormat);
+  void MapScalarsThroughTable(vtkDataArray* scalars, unsigned char* output)
+  {
+    this->MapScalarsThroughTable(scalars, output, VTK_RGBA);
+  }
+  void MapScalarsThroughTable(void* input, unsigned char* output, int inputDataType,
+    int numberOfValues, int inputIncrement, int outputFormat)
+  {
+    this->MapScalarsThroughTable2(
+      input, output, inputDataType, numberOfValues, inputIncrement, outputFormat);
+  }
 
   /**
    * An internal method typically not used in applications.  This should
    * be a protected function, but it must be kept public for backwards
    * compatibility.  Never call this method directly.
    */
-  virtual void MapScalarsThroughTable2(void *input, unsigned char *output,
-                                       int inputDataType, int numberOfValues,
-                                       int inputIncrement,
-                                       int outputFormat);
+  virtual void MapScalarsThroughTable2(void* input, unsigned char* output, int inputDataType,
+    int numberOfValues, int inputIncrement, int outputFormat);
 
   /**
    * Copy the contents from another object.
    */
-  virtual void DeepCopy(vtkScalarsToColors *o);
+  virtual void DeepCopy(vtkScalarsToColors* o);
 
   /**
    * This should return 1 is the subclass is using log scale for mapping scalars
    * to colors. Default implementation always returns 0.
    */
-  virtual int UsingLogScale()
-    { return 0; }
+  virtual int UsingLogScale() { return 0; }
 
   /**
    * Get the number of available colors for mapping to.
@@ -266,7 +272,7 @@ public:
    * Set a list of discrete values, either
    * as a categorical set of values (when IndexedLookup is true) or
    * as a set of annotations to add to a scalar array (when IndexedLookup is false).
-   * The two arrays must both either be NULL or of the same length or
+   * The two arrays must both either be nullptr or of the same length or
    * the call will be ignored.
 
    * Note that these arrays are deep copied rather than being used directly
@@ -275,9 +281,9 @@ public:
    * call to map scalar values to colors would require us to check the MTime
    * of the arrays.
    */
-  virtual void SetAnnotations( vtkAbstractArray* values, vtkStringArray* annotations );
-  vtkGetObjectMacro(AnnotatedValues,vtkAbstractArray);
-  vtkGetObjectMacro(Annotations,vtkStringArray);
+  virtual void SetAnnotations(vtkAbstractArray* values, vtkStringArray* annotations);
+  vtkGetObjectMacro(AnnotatedValues, vtkAbstractArray);
+  vtkGetObjectMacro(Annotations, vtkStringArray);
   //@}
 
   /**
@@ -315,14 +321,14 @@ public:
   /**
    * Return the index of the given value in the list of annotated values (or -1 if not present).
    */
-  vtkIdType GetAnnotatedValueIndex( vtkVariant val );
+  vtkIdType GetAnnotatedValueIndex(vtkVariant val);
 
   /**
    * Look up an index into the array of annotations given a
    * value. Does no pointer checks. Returns -1 when \p val not
    * present.
    */
-  vtkIdType GetAnnotatedValueIndexInternal(vtkVariant& val);
+  vtkIdType GetAnnotatedValueIndexInternal(const vtkVariant& val);
 
   /**
    * Get the "indexed color" assigned to an index.
@@ -331,7 +337,7 @@ public:
    * the annotations were set).
    * Subclasses must implement this and interpret how to treat the index.
    * vtkLookupTable simply returns GetTableValue(\a index % \a this->GetNumberOfTableValues()).
-   * vtkColorTransferFunction returns the color assocated with node \a index % \a this->GetSize().
+   * vtkColorTransferFunction returns the color associated with node \a index % \a this->GetSize().
 
    * Note that implementations *must* set the opacity (alpha) component of the color, even if they
    * do not provide opacity values in their colormaps. In that case, alpha = 1 should be used.
@@ -360,35 +366,32 @@ public:
    * When categorical data is present, only values in the lookup table will be
    * considered valid; all other values will be assigned \a NanColor.
    */
-  vtkSetMacro(IndexedLookup,int);
-  vtkGetMacro(IndexedLookup,int);
-  vtkBooleanMacro(IndexedLookup,int);
+  vtkSetMacro(IndexedLookup, vtkTypeBool);
+  vtkGetMacro(IndexedLookup, vtkTypeBool);
+  vtkBooleanMacro(IndexedLookup, vtkTypeBool);
   //@}
 
-
   //@{
   /**
    * Converts a color from numeric type T to uchar. We assume the integral type
-   * is already in the range 0-255. If it is not, it is going to be truncated.
+   * is already in the range 0-255. If it is not, behavior is undefined.
    * Floating point types are assumed to be in interval 0.0-1.0
    */
-  template<typename T> static
-    unsigned char ColorToUChar(T t)
+  template <typename T>
+  static unsigned char ColorToUChar(T t)
   {
-    return t;
+    return static_cast<unsigned char>(t);
   }
-  template<typename T> static
-    void ColorToUChar(T t, unsigned char* dest)
+  template <typename T>
+  static void ColorToUChar(T t, unsigned char* dest)
   {
     *dest = ColorToUChar(t);
   }
   //@}
 
-
-
 protected:
   vtkScalarsToColors();
-  ~vtkScalarsToColors() VTK_OVERRIDE;
+  ~vtkScalarsToColors() override;
 
   /**
    * An internal method that assumes that the input already has the right
@@ -401,33 +404,28 @@ protected:
    * then the components will be combined to compute the luminance.
    * Any components past the fourth component will be ignored.
    */
-  void MapColorsToColors(void *input, unsigned char *output,
-                         int inputDataType, int numberOfValues,
-                         int numberOfComponents, int vectorSize,
-                         int outputFormat);
+  void MapColorsToColors(void* input, unsigned char* output, int inputDataType, int numberOfValues,
+    int numberOfComponents, int vectorSize, int outputFormat);
 
   /**
    * An internal method used to convert a color array to RGBA. The
    * method instantiates a vtkUnsignedCharArray and returns it. The user is
    * responsible for managing the memory.
    */
-  vtkUnsignedCharArray *ConvertToRGBA(
-    vtkDataArray *colors, int numComp, int numTuples);
-
+  vtkUnsignedCharArray* ConvertToRGBA(vtkDataArray* colors, int numComp, int numTuples);
 
   /**
    * An internal method for converting vectors to magnitudes, used as
    * a preliminary step before doing magnitude mapping.
    */
-  void MapVectorsToMagnitude(void *input, double *output,
-                             int inputDataType, int numberOfValues,
-                             int numberOfComponents, int vectorSize);
+  void MapVectorsToMagnitude(void* input, double* output, int inputDataType, int numberOfValues,
+    int numberOfComponents, int vectorSize);
 
   /**
    * Allocate annotation arrays if needed, then return the index of
    * the given \a value or -1 if not present.
    */
-  virtual vtkIdType CheckForAnnotatedValue( vtkVariant value );
+  virtual vtkIdType CheckForAnnotatedValue(vtkVariant value);
 
   /**
    * Update the map from annotated values to indices in the array of
@@ -437,12 +435,12 @@ protected:
 
   // Annotations of specific values.
   vtkAbstractArray* AnnotatedValues;
-  vtkStringArray*   Annotations;
+  vtkStringArray* Annotations;
 
   class vtkInternalAnnotatedValueMap;
   vtkInternalAnnotatedValueMap* AnnotatedValueMap;
 
-  int IndexedLookup;
+  vtkTypeBool IndexedLookup;
 
   double Alpha;
 
@@ -460,8 +458,8 @@ private:
   double RGB[3];
   double InputRange[2];
 
-  vtkScalarsToColors(const vtkScalarsToColors&) VTK_DELETE_FUNCTION;
-  void operator=(const vtkScalarsToColors&) VTK_DELETE_FUNCTION;
+  vtkScalarsToColors(const vtkScalarsToColors&) = delete;
+  void operator=(const vtkScalarsToColors&) = delete;
 };
 
 //@{
@@ -470,17 +468,16 @@ private:
  * Converts from a color in a floating point type in range 0.0-1.0 to a uchar
  * in range 0-255.
  */
-template<> inline
-unsigned char vtkScalarsToColors::ColorToUChar(double t)
+template <>
+inline unsigned char vtkScalarsToColors::ColorToUChar(double t)
 {
-  return static_cast<unsigned char>(t*255 + 0.5);
+  return static_cast<unsigned char>(t * 255 + 0.5);
 }
-template<> inline
-unsigned char vtkScalarsToColors::ColorToUChar(float t)
+template <>
+inline unsigned char vtkScalarsToColors::ColorToUChar(float t)
 {
-  return static_cast<unsigned char>(t*255 + 0.5);
+  return static_cast<unsigned char>(t * 255 + 0.5);
 }
 //@}
 
-
 #endif
