@@ -25,17 +25,13 @@ VTK_AOS_DATA_ARRAY_TEMPLATE_INSTANTIATE(unsigned long);
 vtkStandardNewMacro(vtkUnsignedLongArray);
 
 //----------------------------------------------------------------------------
-vtkUnsignedLongArray::vtkUnsignedLongArray()
-{
-}
+vtkUnsignedLongArray::vtkUnsignedLongArray() = default;
 
 //----------------------------------------------------------------------------
-vtkUnsignedLongArray::~vtkUnsignedLongArray()
-{
-}
+vtkUnsignedLongArray::~vtkUnsignedLongArray() = default;
 
 //----------------------------------------------------------------------------
 void vtkUnsignedLongArray::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->RealSuperclass::PrintSelf(os,indent);
+  this->RealSuperclass::PrintSelf(os, indent);
 }
