@@ -23,14 +23,14 @@
  * This class should not be used directly, as it only exists on systems
  * where the unsigned long long type is defined.  If you need an unsigned
  * 64 bit integer data array, use vtkTypeUInt64Array instead.
-*/
+ */
 
 #ifndef vtkUnsignedLongLongArray_h
 #define vtkUnsignedLongLongArray_h
 
-#include "vtkCommonCoreModule.h" // For export macro
-#include "vtkDataArray.h"
 #include "vtkAOSDataArrayTemplate.h" // Real Superclass
+#include "vtkCommonCoreModule.h"     // For export macro
+#include "vtkDataArray.h"
 
 // Fake the superclass for the wrappers.
 #ifndef __VTK_WRAP__
@@ -39,52 +39,50 @@
 class VTKCOMMONCORE_EXPORT vtkUnsignedLongLongArray : public vtkDataArray
 {
 public:
-  vtkTypeMacro(vtkUnsignedLongLongArray, vtkDataArray)
+  vtkTypeMacro(vtkUnsignedLongLongArray, vtkDataArray);
 #ifndef __VTK_WRAP__
 #undef vtkDataArray
 #endif
   static vtkUnsignedLongLongArray* New();
-  void PrintSelf(ostream& os, vtkIndent indent) VTK_OVERRIDE;
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
   // This macro expands to the set of method declarations that
   // make up the interface of vtkAOSDataArrayTemplate, which is ignored
   // by the wrappers.
-#if defined(__VTK_WRAP__) || defined (__WRAP_GCCXML__)
+#if defined(__VTK_WRAP__) || defined(__WRAP_GCCXML__)
   vtkCreateWrappedArrayInterface(unsigned long long);
 #endif
 
   /**
    * A faster alternative to SafeDownCast for downcasting vtkAbstractArrays.
    */
-  static vtkUnsignedLongLongArray* FastDownCast(vtkAbstractArray *source)
+  static vtkUnsignedLongLongArray* FastDownCast(vtkAbstractArray* source)
   {
-    return static_cast<vtkUnsignedLongLongArray*>(
-          Superclass::FastDownCast(source));
+    return static_cast<vtkUnsignedLongLongArray*>(Superclass::FastDownCast(source));
   }
 
   /**
    * Get the minimum data value in its native type.
    */
-  static unsigned long long GetDataTypeValueMin() {return VTK_UNSIGNED_LONG_LONG_MIN;}
+  static unsigned long long GetDataTypeValueMin() { return VTK_UNSIGNED_LONG_LONG_MIN; }
 
   /**
    * Get the maximum data value in its native type.
    */
-  static unsigned long long GetDataTypeValueMax() {return VTK_UNSIGNED_LONG_LONG_MAX;}
+  static unsigned long long GetDataTypeValueMax() { return VTK_UNSIGNED_LONG_LONG_MAX; }
 
 protected:
   vtkUnsignedLongLongArray();
-  ~vtkUnsignedLongLongArray() VTK_OVERRIDE;
+  ~vtkUnsignedLongLongArray() override;
 
 private:
-
   typedef vtkAOSDataArrayTemplate<unsigned long long> RealSuperclass;
 
-  vtkUnsignedLongLongArray(const vtkUnsignedLongLongArray&) VTK_DELETE_FUNCTION;
-  void operator=(const vtkUnsignedLongLongArray&) VTK_DELETE_FUNCTION;
+  vtkUnsignedLongLongArray(const vtkUnsignedLongLongArray&) = delete;
+  void operator=(const vtkUnsignedLongLongArray&) = delete;
 };
 
 // Define vtkArrayDownCast implementation:
-vtkArrayDownCast_FastCastMacro(vtkUnsignedLongLongArray)
+vtkArrayDownCast_FastCastMacro(vtkUnsignedLongLongArray);
 
 #endif
