@@ -19,78 +19,27 @@ vtkStandardNewMacro(vtkCellTypes);
 
 // This list should contain the cell class names in
 // the same order as the enums in vtkCellType.h. Make sure
-// this list is NULL terminated.
-static const char* vtkCellTypesStrings[] = {
-  "vtkEmptyCell",
-  "vtkVertex",
-  "vtkPolyVertex",
-  "vtkLine",
-  "vtkPolyLine",
-  "vtkTriangle",
-  "vtkTriangleStrip",
-  "vtkPolygon",
-  "vtkPixel",
-  "vtkQuad",
-  "vtkTetra",
-  "vtkVoxel",
-  "vtkHexahedron",
-  "vtkWedge",
-  "vtkPyramid",
-  "vtkPentagonalPrism",
-  "vtkHexagonalPrism",
-  "UnknownClass",
-  "UnknownClass",
-  "UnknownClass",
-  "UnknownClass",
-  "vtkQuadraticEdge",
-  "vtkQuadraticTriangle",
-  "vtkQuadraticQuad",
-  "vtkQuadraticTetra",
-  "vtkQuadraticHexahedron",
-  "vtkQuadraticWedge",
-  "vtkQuadraticPyramid",
-  "vtkBiQuadraticQuad",
-  "vtkTriQuadraticHexahedron",
-  "vtkQuadraticLinearQuad",
-  "vtkQuadraticLinearWedge",
-  "vtkBiQuadraticQuadraticWedge",
-  "vtkBiQuadraticQuadraticHexahedron",
-  "vtkBiQuadraticTriangle",
-  "vtkCubicLine",
-  "vtkQuadraticPolygon",
-  "UnknownClass",
-  "UnknownClass",
-  "UnknownClass",
-  "UnknownClass",
-  "vtkConvexPointSet",
-  "UnknownClass",
-  "UnknownClass",
-  "UnknownClass",
-  "UnknownClass",
-  "UnknownClass",
-  "UnknownClass",
-  "UnknownClass",
-  "UnknownClass",
-  "UnknownClass",
-  "vtkParametricCurve",
-  "vtkParametricSurface",
-  "vtkParametricTriSurface",
-  "vtkParametricQuadSurface",
-  "vtkParametricTetraRegion",
-  "vtkParametricHexRegion",
-  "UnknownClass",
-  "UnknownClass",
-  "UnknownClass",
-  "vtkHigherOrderEdge",
-  "vtkHigherOrderTriangle",
-  "vtkHigherOrderQuad",
-  "vtkHigherOrderPolygon",
-  "vtkHigherOrderTetrahedron",
-  "vtkHigherOrderWedge",
-  "vtkHigherOrderPyramid",
-  "vtkHigherOrderHexahedron",
-  NULL
-};
+// this list is nullptr terminated.
+static const char* vtkCellTypesStrings[] = { "vtkEmptyCell", "vtkVertex", "vtkPolyVertex",
+  "vtkLine", "vtkPolyLine", "vtkTriangle", "vtkTriangleStrip", "vtkPolygon", "vtkPixel", "vtkQuad",
+  "vtkTetra", "vtkVoxel", "vtkHexahedron", "vtkWedge", "vtkPyramid", "vtkPentagonalPrism",
+  "vtkHexagonalPrism", "UnknownClass", "UnknownClass", "UnknownClass", "UnknownClass",
+  "vtkQuadraticEdge", "vtkQuadraticTriangle", "vtkQuadraticQuad", "vtkQuadraticTetra",
+  "vtkQuadraticHexahedron", "vtkQuadraticWedge", "vtkQuadraticPyramid", "vtkBiQuadraticQuad",
+  "vtkTriQuadraticHexahedron", "vtkQuadraticLinearQuad", "vtkQuadraticLinearWedge",
+  "vtkBiQuadraticQuadraticWedge", "vtkBiQuadraticQuadraticHexahedron", "vtkBiQuadraticTriangle",
+  "vtkCubicLine", "vtkQuadraticPolygon", "UnknownClass", "UnknownClass", "UnknownClass",
+  "UnknownClass", "vtkConvexPointSet", "vtkPolyhedron", "UnknownClass", "UnknownClass",
+  "UnknownClass", "UnknownClass", "UnknownClass", "UnknownClass", "UnknownClass", "UnknownClass",
+  "vtkParametricCurve", "vtkParametricSurface", "vtkParametricTriSurface",
+  "vtkParametricQuadSurface", "vtkParametricTetraRegion", "vtkParametricHexRegion", "UnknownClass",
+  "UnknownClass", "UnknownClass", "vtkHigherOrderEdge", "vtkHigherOrderTriangle",
+  "vtkHigherOrderQuad", "vtkHigherOrderPolygon", "vtkHigherOrderTetrahedron", "vtkHigherOrderWedge",
+  "vtkHigherOrderPyramid", "vtkHigherOrderHexahedron", "vtkLagrangeCurve",
+  "vtkLagrangeQuadrilateral", "vtkLagrangeTriangle", "vtkLagrangeTetra", "vtkLagrangeHexahedron",
+  "vtkLagrangeWedge", "vtkLagrangePyramid", "vtkBezierCurve", "vtkBezierQuadrilateral",
+  "vtkBezierTriangle", "vtkBezierTetra", "vtkBezierHexahedron", "vtkBezierWedge",
+  "vtkBezierPyramid", nullptr };
 
 //----------------------------------------------------------------------------
 const char* vtkCellTypes::GetClassNameFromTypeId(int type)
@@ -100,7 +49,7 @@ const char* vtkCellTypes::GetClassNameFromTypeId(int type)
   // find length of table
   if (numClasses == 0)
   {
-    while (vtkCellTypesStrings[numClasses] != NULL)
+    while (vtkCellTypesStrings[numClasses] != nullptr)
     {
       numClasses++;
     }
@@ -114,7 +63,6 @@ const char* vtkCellTypes::GetClassNameFromTypeId(int type)
   {
     return "UnknownClass";
   }
-
 }
 
 //----------------------------------------------------------------------------
@@ -125,7 +73,7 @@ int vtkCellTypes::GetTypeIdFromClassName(const char* classname)
     return -1;
   }
 
-  for(int idx=0; vtkCellTypesStrings[idx] != NULL; idx++)
+  for (int idx = 0; vtkCellTypesStrings[idx] != nullptr; idx++)
   {
     if (strcmp(vtkCellTypesStrings[idx], classname) == 0)
     {
@@ -137,9 +85,12 @@ int vtkCellTypes::GetTypeIdFromClassName(const char* classname)
 }
 
 //----------------------------------------------------------------------------
-vtkCellTypes::vtkCellTypes () :
-  TypeArray(vtkUnsignedCharArray::New()), LocationArray(vtkIntArray::New()),
-  Size(0), MaxId(-1), Extend(1000)
+vtkCellTypes::vtkCellTypes()
+  : TypeArray(vtkUnsignedCharArray::New())
+  , LocationArray(vtkIdTypeArray::New())
+  , Size(0)
+  , MaxId(-1)
+  , Extend(1000)
 {
   this->TypeArray->Register(this);
   this->TypeArray->Delete();
@@ -151,12 +102,12 @@ vtkCellTypes::vtkCellTypes () :
 //----------------------------------------------------------------------------
 vtkCellTypes::~vtkCellTypes()
 {
-  if ( this->TypeArray )
+  if (this->TypeArray)
   {
     this->TypeArray->UnRegister(this);
   }
 
-  if ( this->LocationArray )
+  if (this->LocationArray)
   {
     this->LocationArray->UnRegister(this);
   }
@@ -164,28 +115,28 @@ vtkCellTypes::~vtkCellTypes()
 
 //----------------------------------------------------------------------------
 // Allocate memory for this array. Delete old storage only if necessary.
-int vtkCellTypes::Allocate(int sz, int ext)
+int vtkCellTypes::Allocate(vtkIdType sz, vtkIdType ext)
 {
 
-  this->Size = ( sz > 0 ? sz : 1);
-  this->Extend = ( ext > 0 ? ext : 1);
+  this->Size = (sz > 0 ? sz : 1);
+  this->Extend = (ext > 0 ? ext : 1);
   this->MaxId = -1;
 
-  if ( this->TypeArray )
+  if (this->TypeArray)
   {
     this->TypeArray->UnRegister(this);
   }
   this->TypeArray = vtkUnsignedCharArray::New();
-  this->TypeArray->Allocate(sz,ext);
+  this->TypeArray->Allocate(sz, ext);
   this->TypeArray->Register(this);
   this->TypeArray->Delete();
 
-  if ( this->LocationArray )
+  if (this->LocationArray)
   {
     this->LocationArray->UnRegister(this);
   }
-  this->LocationArray = vtkIntArray::New();
-  this->LocationArray->Allocate(sz,ext);
+  this->LocationArray = vtkIdTypeArray::New();
+  this->LocationArray->Allocate(sz, ext);
   this->LocationArray->Register(this);
   this->LocationArray->Delete();
 
@@ -194,33 +145,49 @@ int vtkCellTypes::Allocate(int sz, int ext)
 
 //----------------------------------------------------------------------------
 // Add a cell at specified id.
-void vtkCellTypes::InsertCell(int cellId, unsigned char type, int loc)
+void vtkCellTypes::InsertCell(vtkIdType cellId, unsigned char type, vtkIdType loc)
 {
-  vtkDebugMacro(<<"Insert Cell id: " << cellId << " at location " << loc);
+  vtkDebugMacro(<< "Insert Cell id: " << cellId << " at location " << loc);
   TypeArray->InsertValue(cellId, type);
 
   LocationArray->InsertValue(cellId, loc);
 
-  if ( cellId > this->MaxId )
+  if (cellId > this->MaxId)
   {
     this->MaxId = cellId;
   }
-  return;
 }
 
 //----------------------------------------------------------------------------
 // Add a cell to the object in the next available slot.
-vtkIdType vtkCellTypes::InsertNextCell(unsigned char type, int loc)
+vtkIdType vtkCellTypes::InsertNextCell(unsigned char type, vtkIdType loc)
 {
-  vtkDebugMacro(<<"Insert Next Cell " << type << " location " << loc);
-  this->InsertCell (++this->MaxId,type,loc);
+  vtkDebugMacro(<< "Insert Next Cell " << type << " location " << loc);
+  this->InsertCell(++this->MaxId, type, loc);
   return this->MaxId;
 }
 
 //----------------------------------------------------------------------------
 // Specify a group of cell types.
-void vtkCellTypes::SetCellTypes(int ncells,
-    vtkUnsignedCharArray *cellTypes, vtkIntArray *cellLocations)
+void vtkCellTypes::SetCellTypes(
+  vtkIdType ncells, vtkUnsignedCharArray* cellTypes, vtkIntArray* cellLocations)
+{
+  vtkIdTypeArray* cellLocations64 = vtkIdTypeArray::New();
+  cellLocations64->SetName(cellLocations->GetName());
+  cellLocations64->SetNumberOfComponents(cellLocations->GetNumberOfComponents());
+  cellLocations64->SetNumberOfTuples(cellLocations->GetNumberOfTuples());
+  for (vtkIdType i = 0, iend = cellLocations->GetNumberOfValues(); i < iend; ++i)
+  {
+    cellLocations64->SetValue(i, cellLocations->GetValue(i));
+  }
+  this->SetCellTypes(ncells, cellTypes, cellLocations64);
+  cellLocations64->Delete();
+}
+
+//----------------------------------------------------------------------------
+// Specify a group of cell types.
+void vtkCellTypes::SetCellTypes(
+  vtkIdType ncells, vtkUnsignedCharArray* cellTypes, vtkIdTypeArray* cellLocations)
 {
   this->Size = ncells;
 
@@ -260,64 +227,63 @@ void vtkCellTypes::Reset()
 //----------------------------------------------------------------------------
 unsigned long vtkCellTypes::GetActualMemorySize()
 {
-  unsigned long size=0;
+  unsigned long size = 0;
 
-  if ( this->TypeArray )
+  if (this->TypeArray)
   {
     size += this->TypeArray->GetActualMemorySize();
   }
 
-  if ( this->LocationArray )
+  if (this->LocationArray)
   {
     size += this->LocationArray->GetActualMemorySize();
   }
 
-  return static_cast<unsigned long>(ceil(size/1024.0)); // kibibytes
+  return static_cast<unsigned long>(ceil(size / 1024.0)); // kibibytes
 }
 
-
 //----------------------------------------------------------------------------
-void vtkCellTypes::DeepCopy(vtkCellTypes *src)
+void vtkCellTypes::DeepCopy(vtkCellTypes* src)
 {
   if (this->TypeArray)
   {
-      this->TypeArray->UnRegister(this);
-      this->TypeArray = NULL;
+    this->TypeArray->UnRegister(this);
+    this->TypeArray = nullptr;
   }
   if (src->TypeArray)
   {
-      this->TypeArray = vtkUnsignedCharArray::New();
-      this->TypeArray->DeepCopy(src->TypeArray);
-      this->TypeArray->Register(this);
-      this->TypeArray->Delete();
+    this->TypeArray = vtkUnsignedCharArray::New();
+    this->TypeArray->DeepCopy(src->TypeArray);
+    this->TypeArray->Register(this);
+    this->TypeArray->Delete();
   }
 
   if (this->LocationArray)
   {
-      this->LocationArray->UnRegister(this);
-      this->LocationArray = NULL;
+    this->LocationArray->UnRegister(this);
+    this->LocationArray = nullptr;
   }
   if (src->LocationArray)
   {
-      this->LocationArray = vtkIntArray::New();
-      this->LocationArray->DeepCopy(src->LocationArray);
-      this->LocationArray->Register(this);
-      this->LocationArray->Delete();
+    this->LocationArray = vtkIdTypeArray::New();
+    this->LocationArray->DeepCopy(src->LocationArray);
+    this->LocationArray->Register(this);
+    this->LocationArray->Delete();
   }
-
-  this->Allocate(src->Size, src->Extend);
+  this->Size = src->Size;
+  this->Extend = src->Extend;
   this->MaxId = src->MaxId;
 }
 
 //----------------------------------------------------------------------------
 void vtkCellTypes::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 
   os << indent << "TypeArray:\n";
-  this->TypeArray->PrintSelf(os,indent.GetNextIndent());
+  this->TypeArray->PrintSelf(os, indent.GetNextIndent());
   os << indent << "LocationArray:\n";
-  this->LocationArray->PrintSelf(os,indent.GetNextIndent());
+  this->LocationArray->PrintSelf(os, indent.GetNextIndent());
 
   os << indent << "Size: " << this->Size << "\n";
   os << indent << "MaxId: " << this->MaxId << "\n";
