@@ -18,7 +18,6 @@
 #include "vtkDataObjectTreeInternals.h"
 #include "vtkObjectFactory.h"
 
-
 class vtkDataObjectTreeIterator::vtkInternals
 {
 public:
@@ -44,19 +43,17 @@ public:
       {
         this->ChildIterator = new vtkIterator(this->Parent);
       }
-      this->ChildIterator->Initialize(this->Reverse, 0);
+      this->ChildIterator->Initialize(this->Reverse, nullptr);
 
       if (this->Reverse &&
         this->ReverseIter != this->GetInternals(this->CompositeDataSet)->Children.rend())
       {
-        this->ChildIterator->Initialize(this->Reverse,
-          this->ReverseIter->DataObject);
+        this->ChildIterator->Initialize(this->Reverse, this->ReverseIter->DataObject);
       }
       else if (!this->Reverse &&
         this->Iter != this->GetInternals(this->CompositeDataSet)->Children.end())
       {
-        this->ChildIterator->Initialize(this->Reverse,
-          this->Iter->DataObject);
+        this->ChildIterator->Initialize(this->Reverse, this->Iter->DataObject);
       }
     }
 
@@ -64,21 +61,20 @@ public:
     {
       return this->Parent->GetInternals(cd);
     }
+
   public:
     vtkIterator(vtkInternals* parent)
     {
-      this->ChildIterator = 0;
+      this->ChildIterator = nullptr;
       this->Parent = parent;
     }
 
     ~vtkIterator()
     {
       delete this->ChildIterator;
-      this->ChildIterator = 0;
+      this->ChildIterator = nullptr;
     }
 
-
-
     void Initialize(bool reverse, vtkDataObject* dataObj)
     {
       vtkDataObjectTree* compositeData = vtkDataObjectTree::SafeDownCast(dataObj);
@@ -89,7 +85,7 @@ public:
       this->PassSelf = true;
 
       delete this->ChildIterator;
-      this->ChildIterator = NULL;
+      this->ChildIterator = nullptr;
 
       if (compositeData)
       {
@@ -119,7 +115,6 @@ public:
       return true;
     }
 
-
     bool IsDoneWithTraversal()
     {
       if (!this->DataObject)
@@ -158,22 +153,21 @@ public:
       {
         return this->DataObject;
       }
-      return this->ChildIterator?
-        this->ChildIterator->GetCurrentDataObject() : 0;
+      return this->ChildIterator ? this->ChildIterator->GetCurrentDataObject() : nullptr;
     }
 
     vtkInformation* GetCurrentMetaData()
     {
       if (this->PassSelf || !this->ChildIterator)
       {
-        return NULL;
+        return nullptr;
       }
 
       if (this->ChildIterator->PassSelf)
       {
         if (this->Reverse)
         {
-          if (!this->ReverseIter->MetaData.GetPointer())
+          if (!this->ReverseIter->MetaData)
           {
             this->ReverseIter->MetaData.TakeReference(vtkInformation::New());
           }
@@ -181,7 +175,7 @@ public:
         }
         else
         {
-          if (!this->Iter->MetaData.GetPointer())
+          if (!this->Iter->MetaData)
           {
             this->Iter->MetaData.TakeReference(vtkInformation::New());
           }
@@ -200,9 +194,8 @@ public:
 
       if (this->ChildIterator->PassSelf)
       {
-        return this->Reverse?
-          (this->ReverseIter->MetaData.GetPointer() != 0):
-          (this->Iter->MetaData.GetPointer() != 0);
+        return this->Reverse ? (this->ReverseIter->MetaData != nullptr)
+                             : (this->Iter->MetaData != nullptr);
       }
 
       return this->ChildIterator->HasCurrentMetaData();
@@ -223,11 +216,11 @@ public:
           this->ChildIndex++;
           if (this->Reverse)
           {
-            this->ReverseIter++;
+            ++this->ReverseIter;
           }
           else
           {
-            this->Iter++;
+            ++this->Iter;
           }
           this->InitChildIterator();
         }
@@ -247,7 +240,6 @@ public:
       index.insert(index.end(), childIndex.begin(), childIndex.end());
       return index;
     }
-
   };
 
   // Description:
@@ -258,17 +250,14 @@ public:
     return this->CompositeDataIterator->GetInternals(cd);
   }
 
-  vtkInternals()
-  {
-    this->Iterator = new vtkIterator(this);
-  }
+  vtkInternals() { this->Iterator = new vtkIterator(this); }
   ~vtkInternals()
   {
     delete this->Iterator;
-    this->Iterator = 0;
+    this->Iterator = nullptr;
   }
 
-  vtkIterator *Iterator;
+  vtkIterator* Iterator;
   vtkDataObjectTreeIterator* CompositeDataIterator;
 };
 
@@ -298,8 +287,8 @@ int vtkDataObjectTreeIterator::IsDoneWithTraversal()
 //----------------------------------------------------------------------------
 void vtkDataObjectTreeIterator::GoToFirstItem()
 {
-  this->CurrentFlatIndex = 0;
-  this->Internals->Iterator->Initialize(this->Reverse !=0, this->DataSet);
+  this->SetCurrentFlatIndex(0);
+  this->Internals->Iterator->Initialize(this->Reverse != 0, this->DataSet);
   this->NextInternal();
 
   while (!this->Internals->Iterator->IsDoneWithTraversal())
@@ -347,8 +336,9 @@ void vtkDataObjectTreeIterator::NextInternal()
   {
     this->CurrentFlatIndex++;
     this->Internals->Iterator->Next();
-  }
-  while (!this->TraverseSubTree && this->Internals->Iterator->InSubTree());
+  } while (!this->TraverseSubTree && this->Internals->Iterator->InSubTree());
+
+  this->Modified();
 }
 
 //----------------------------------------------------------------------------
@@ -359,7 +349,7 @@ vtkDataObject* vtkDataObjectTreeIterator::GetCurrentDataObject()
     return this->Internals->Iterator->GetCurrentDataObject();
   }
 
-  return 0;
+  return nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -370,7 +360,7 @@ vtkInformation* vtkDataObjectTreeIterator::GetCurrentMetaData()
     return this->Internals->Iterator->GetCurrentMetaData();
   }
 
-  return 0;
+  return nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -395,36 +385,30 @@ unsigned int vtkDataObjectTreeIterator::GetCurrentFlatIndex()
 {
   if (this->Reverse)
   {
-    vtkErrorMacro(
-      "FlatIndex cannot be obtained when iterating in reverse order.");
+    vtkErrorMacro("FlatIndex cannot be obtained when iterating in reverse order.");
     return 0;
   }
   return this->CurrentFlatIndex;
 }
 
 //----------------------------------------------------------------------------
-vtkDataObjectTreeInternals* vtkDataObjectTreeIterator::GetInternals(
-  vtkDataObjectTree* cd)
+vtkDataObjectTreeInternals* vtkDataObjectTreeIterator::GetInternals(vtkDataObjectTree* cd)
 {
   if (cd)
   {
     return cd->Internals;
   }
 
-  return 0;
+  return nullptr;
 }
 
 //----------------------------------------------------------------------------
 void vtkDataObjectTreeIterator::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
-  os << indent << "VisitOnlyLeaves: "
-    << (this->VisitOnlyLeaves? "On" : "Off") << endl;
-  os << indent << "Reverse: "
-    << (this->Reverse? "On" : "Off") << endl;
-  os << indent << "TraverseSubTree: "
-    << (this->TraverseSubTree? "On" : "Off") << endl;
-  os << indent << "SkipEmptyNodes: "
-    << (this->SkipEmptyNodes? "On" : "Off") << endl;
+  os << indent << "VisitOnlyLeaves: " << (this->VisitOnlyLeaves ? "On" : "Off") << endl;
+  os << indent << "Reverse: " << (this->Reverse ? "On" : "Off") << endl;
+  os << indent << "TraverseSubTree: " << (this->TraverseSubTree ? "On" : "Off") << endl;
+  os << indent << "SkipEmptyNodes: " << (this->SkipEmptyNodes ? "On" : "Off") << endl;
   os << indent << "CurrentFlatIndex: " << this->CurrentFlatIndex << endl;
 }
