@@ -54,12 +54,11 @@
  *
  * @sa
  * vtkGenericDataSet
-*/
+ */
 
 #ifndef vtkGenericAdaptorCell_h
 #define vtkGenericAdaptorCell_h
 
-
 #include "vtkCommonDataModelModule.h" // For export macro
 #include "vtkObject.h"
 
@@ -92,8 +91,8 @@ class vtkPyramid;
 class VTKCOMMONDATAMODEL_EXPORT vtkGenericAdaptorCell : public vtkObject
 {
 public:
-  vtkTypeMacro(vtkGenericAdaptorCell,vtkObject);
-  void PrintSelf(ostream& os, vtkIndent indent) VTK_OVERRIDE;
+  vtkTypeMacro(vtkGenericAdaptorCell, vtkObject);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
   /**
    * Unique identification number of the cell over the whole
@@ -104,7 +103,7 @@ public:
   /**
    * Does `this' a cell of a dataset? (otherwise, it is a boundary cell)
    */
-  virtual int IsInDataSet()=0;
+  virtual int IsInDataSet() = 0;
 
   /**
    * Return the type of the current cell.
@@ -112,7 +111,7 @@ public:
    * (result==VTK_HIGHER_ORDER_TRIANGLE)||
    * (result==VTK_HIGHER_ORDER_TETRAHEDRON)
    */
-  virtual int GetType()=0;
+  virtual int GetType() = 0;
 
   /**
    * Return the topological dimension of the current cell.
@@ -124,7 +123,7 @@ public:
    * Return the interpolation order of the geometry.
    * \post positive_result: result>=0
    */
-  virtual int GetGeometryOrder()=0;
+  virtual int GetGeometryOrder() = 0;
 
   /**
    * Does the cell have a non-linear interpolation for the geometry?
@@ -138,7 +137,7 @@ public:
    * \pre a_exists: a!=0
    * \post positive_result: result>=0
    */
-  virtual int GetAttributeOrder(vtkGenericAttribute *a)=0;
+  virtual int GetAttributeOrder(vtkGenericAttribute* a) = 0;
 
   /**
    * Return the index of the first point centered attribute with the highest
@@ -146,25 +145,25 @@ public:
    * \pre ac_exists: ac!=0
    * \post valid_result: result>=-1 && result<ac->GetNumberOfAttributes()
    */
-  virtual int GetHighestOrderAttribute(vtkGenericAttributeCollection *ac);
+  virtual int GetHighestOrderAttribute(vtkGenericAttributeCollection* ac);
 
   /**
    * Does the attribute `a' have a non-linear interpolation?
    * \pre a_exists: a!=0
    * \post definition: result==(GetAttributeOrder()==1)
    */
-  int IsAttributeLinear(vtkGenericAttribute *a);
+  vtkTypeBool IsAttributeLinear(vtkGenericAttribute* a);
 
   /**
    * Is the cell primary (i.e. not composite) ?
    */
-  virtual int IsPrimary()=0;
+  virtual int IsPrimary() = 0;
 
   /**
    * Return the number of corner points that compose the cell.
    * \post positive_result: result>=0
    */
-  virtual int GetNumberOfPoints()=0;
+  virtual int GetNumberOfPoints() = 0;
 
   /**
    * Return the number of boundaries of dimension `dim' (or all dimensions
@@ -176,7 +175,7 @@ public:
    * \pre valid_dim_range: (dim==-1) || ((dim>=0)&&(dim<GetDimension()))
    * \post positive_result: result>=0
    */
-  virtual int GetNumberOfBoundaries(int dim=-1)=0;
+  virtual int GetNumberOfBoundaries(int dim = -1) = 0;
 
   /**
    * Accumulated number of DOF nodes of the current cell. A DOF node is
@@ -190,19 +189,20 @@ public:
    * an arbitrary number of field values associated with them.
    * \post valid_result: result==GetNumberOfBoundaries(-1)+1
    */
-  virtual int GetNumberOfDOFNodes()=0;
+  virtual int GetNumberOfDOFNodes() = 0;
 
   /**
    * Return the points of cell into `it'.
    * \pre it_exists: it!=0
    */
-  virtual void GetPointIterator(vtkGenericPointIterator *it)=0;
+  virtual void GetPointIterator(vtkGenericPointIterator* it) = 0;
 
   /**
    * Create an empty cell iterator. The user is responsible for deleting it.
    * \post result_exists: result!=0
    */
-  virtual vtkGenericCellIterator *NewCellIterator()=0;
+  VTK_NEWINSTANCE
+  virtual vtkGenericCellIterator* NewCellIterator() = 0;
 
   /**
    * Return the `boundaries' cells of dimension `dim' (or all dimensions
@@ -210,8 +210,7 @@ public:
    * \pre valid_dim_range: (dim==-1) || ((dim>=0)&&(dim<GetDimension()))
    * \pre boundaries_exist: boundaries!=0
    */
-  virtual void GetBoundaryIterator(vtkGenericCellIterator *boundaries,
-                                   int dim=-1)=0;
+  virtual void GetBoundaryIterator(vtkGenericCellIterator* boundaries, int dim = -1) = 0;
 
   //@{
   /**
@@ -224,8 +223,8 @@ public:
    * \pre boundary: HasBoundary(boundary)
    * \post positive_result: result>=0
    */
-  virtual int CountNeighbors(vtkGenericAdaptorCell *boundary)=0;
-  virtual void CountEdgeNeighbors( int* sharing ) = 0;
+  virtual int CountNeighbors(vtkGenericAdaptorCell* boundary) = 0;
+  virtual void CountEdgeNeighbors(int* sharing) = 0;
   //@}
 
   /**
@@ -238,8 +237,7 @@ public:
    * \pre boundary: HasBoundary(boundary)
    * \pre neighbors_exist: neighbors!=0
    */
-  virtual void GetNeighbors(vtkGenericAdaptorCell *boundary,
-                            vtkGenericCellIterator *neighbors)=0;
+  virtual void GetNeighbors(vtkGenericAdaptorCell* boundary, vtkGenericCellIterator* neighbors) = 0;
 
   /**
    * Compute the closest boundary of the current sub-cell `subId' for point
@@ -248,9 +246,8 @@ public:
    * GetDimension()-1.
    * \pre positive_subId: subId>=0
    */
-  virtual int FindClosestBoundary(int subId,
-                                  double pcoords[3],
-                                  vtkGenericCellIterator* &boundary)=0;
+  virtual int FindClosestBoundary(
+    int subId, double pcoords[3], vtkGenericCellIterator*& boundary) = 0;
 
   /**
    * Is `x' inside the current cell? It also evaluates parametric coordinates
@@ -263,11 +260,8 @@ public:
    * \post positive_distance: result!=-1 implies (closestPoint!=0 implies
    * dist2>=0)
    */
-  virtual int EvaluatePosition(double x[3],
-                               double *closestPoint,
-                               int &subId,
-                               double pcoords[3],
-                               double &dist2)=0;
+  virtual int EvaluatePosition(
+    const double x[3], double* closestPoint, int& subId, double pcoords[3], double& dist2) = 0;
 
   /**
    * Determine the global coordinates `x' from sub-cell `subId' and parametric
@@ -276,9 +270,7 @@ public:
    * \pre clamped_pcoords: (0<=pcoords[0])&&(pcoords[0]<=1)&&(0<=pcoords[1])
    * &&(pcoords[1]<=1)&&(0<=pcoords[2])&&(pcoords[2]<=1)
    */
-  virtual void EvaluateLocation(int subId,
-                                double pcoords[3],
-                                double x[3])=0;
+  virtual void EvaluateLocation(int subId, double pcoords[3], double x[3]) = 0;
 
   /**
    * Interpolate the attribute `a' at local position `pcoords' of the cell into
@@ -290,8 +282,7 @@ public:
    * \pre val_exists: val!=0
    * \pre valid_size: sizeof(val)==a->GetNumberOfComponents()
    */
-  virtual void InterpolateTuple(vtkGenericAttribute *a, double pcoords[3],
-                                double *val) = 0;
+  virtual void InterpolateTuple(vtkGenericAttribute* a, double pcoords[3], double* val) = 0;
 
   /**
    * Interpolate the whole collection of attributes `c' at local position
@@ -303,9 +294,8 @@ public:
    * \pre val_exists: val!=0
    * \pre valid_size: sizeof(val)==c->GetNumberOfPointCenteredComponents()
    */
-  virtual void InterpolateTuple(vtkGenericAttributeCollection *c,
-                                double pcoords[3],
-                                double *val) = 0;
+  virtual void InterpolateTuple(
+    vtkGenericAttributeCollection* c, double pcoords[3], double* val) = 0;
 
   /**
    * Generate a contour (contouring primitives) for each `values' or with
@@ -322,9 +312,9 @@ public:
    * - `lines' is an array of generated lines
    * - `polys' is an array of generated polygons
    * - `outPd' is an array of interpolated point data along the edge (if
-   * not-NULL)
+   * not-nullptr)
    * - `outCd' is an array of copied cell data of the current cell (if
-   * not-NULL)
+   * not-nullptr)
    * `internalPd', `secondaryPd' and `secondaryCd' are initialized by the
    * filter that call it from `attributes'.
    * - `internalPd' stores the result of the tessellation pass: the
@@ -348,19 +338,11 @@ public:
    * \pre secondaryPd_exists: secondaryPd!=0
    * \pre secondaryCd_exists: secondaryCd!=0
    */
-  virtual void Contour(vtkContourValues *values,
-                       vtkImplicitFunction *f,
-                       vtkGenericAttributeCollection *attributes,
-                       vtkGenericCellTessellator *tess,
-                       vtkIncrementalPointLocator *locator,
-                       vtkCellArray *verts,
-                       vtkCellArray *lines,
-                       vtkCellArray *polys,
-                       vtkPointData *outPd,
-                       vtkCellData *outCd,
-                       vtkPointData *internalPd,
-                       vtkPointData *secondaryPd,
-                       vtkCellData *secondaryCd);
+  virtual void Contour(vtkContourValues* values, vtkImplicitFunction* f,
+    vtkGenericAttributeCollection* attributes, vtkGenericCellTessellator* tess,
+    vtkIncrementalPointLocator* locator, vtkCellArray* verts, vtkCellArray* lines,
+    vtkCellArray* polys, vtkPointData* outPd, vtkCellData* outCd, vtkPointData* internalPd,
+    vtkPointData* secondaryPd, vtkCellData* secondaryCd);
 
   /**
    * Cut (or clip) the current cell with respect to the contour defined by
@@ -379,9 +361,9 @@ public:
    * (i.e., prevents duplicates).
    * - `connectivity' is an array of generated cells
    * - `outPd' is an array of interpolated point data along the edge (if
-   * not-NULL)
+   * not-nullptr)
    * - `outCd' is an array of copied cell data of the current cell (if
-   * not-NULL)
+   * not-nullptr)
    * `internalPd', `secondaryPd' and `secondaryCd' are initialized by the
    * filter that call it from `attributes'.
    * - `internalPd' stores the result of the tessellation pass: the
@@ -402,18 +384,10 @@ public:
    * \pre secondaryPd_exists: secondaryPd!=0
    * \pre secondaryCd_exists: secondaryCd!=0
    */
-  virtual void Clip(double value,
-                    vtkImplicitFunction *f,
-                    vtkGenericAttributeCollection *attributes,
-                    vtkGenericCellTessellator *tess,
-                    int insideOut,
-                    vtkIncrementalPointLocator *locator,
-                    vtkCellArray *connectivity,
-                    vtkPointData *outPd,
-                    vtkCellData *outCd,
-                    vtkPointData *internalPd,
-                    vtkPointData *secondaryPd,
-                    vtkCellData *secondaryCd);
+  virtual void Clip(double value, vtkImplicitFunction* f, vtkGenericAttributeCollection* attributes,
+    vtkGenericCellTessellator* tess, int insideOut, vtkIncrementalPointLocator* locator,
+    vtkCellArray* connectivity, vtkPointData* outPd, vtkCellData* outCd, vtkPointData* internalPd,
+    vtkPointData* secondaryPd, vtkCellData* secondaryCd);
 
   /**
    * Is there an intersection between the current cell and the ray (`p1',`p2')
@@ -423,13 +397,8 @@ public:
    * the intersection occurs.
    * \pre positive_tolerance: tol>0
    */
-  virtual int IntersectWithLine(double p1[3],
-                                double p2[3],
-                                double tol,
-                                double &t,
-                                double x[3],
-                                double pcoords[3],
-                                int &subId)=0;
+  virtual int IntersectWithLine(double p1[3], double p2[3], double tol, double& t, double x[3],
+    double pcoords[3], int& subId) = 0;
 
   /**
    * Compute derivatives `derivs' of the attribute `attribute' (from its
@@ -443,17 +412,15 @@ public:
    * \pre derivs_exists: derivs!=0
    * \pre valid_size: sizeof(derivs)>=attribute->GetNumberOfComponents()*3
    */
-  virtual void Derivatives(int subId,
-                           double pcoords[3],
-                           vtkGenericAttribute *attribute,
-                           double *derivs)=0;
+  virtual void Derivatives(
+    int subId, double pcoords[3], vtkGenericAttribute* attribute, double* derivs) = 0;
 
   /**
    * Compute the bounding box of the current cell in `bounds' in global
    * coordinates.
    * THREAD SAFE
    */
-  virtual void GetBounds(double bounds[6])=0;
+  virtual void GetBounds(double bounds[6]) = 0;
 
   /**
    * Return the bounding box of the current cell in global coordinates.
@@ -461,7 +428,7 @@ public:
    * \post result_exists: result!=0
    * \post valid_size: sizeof(result)>=6
    */
-  virtual double *GetBounds();
+  virtual double* GetBounds();
 
   /**
    * Return the bounding box diagonal squared of the current cell.
@@ -475,7 +442,7 @@ public:
    * is the sub-cell id that the center is in.  \post valid_result:
    * (result>=0) && (IsPrimary() implies result==0)
    */
-  virtual int GetParametricCenter(double pcoords[3])=0;
+  virtual int GetParametricCenter(double pcoords[3]) = 0;
 
   /**
    * Return the distance of the parametric coordinate `pcoords' to the
@@ -484,7 +451,7 @@ public:
    * will occasionally allow cells to be picked who are not really
    * intersected "inside" the cell.)  \post positive_result: result>=0
    */
-  virtual double GetParametricDistance(double pcoords[3])=0;
+  virtual double GetParametricDistance(const double pcoords[3]) = 0;
 
   /**
    * Return a contiguous array of parametric coordinates of the corrner points
@@ -496,7 +463,7 @@ public:
    * ((!IsPrimary()) && (result==0))
    * result!=0 implies sizeof(result)==GetNumberOfPoints()
    */
-  virtual double *GetParametricCoords()=0;
+  virtual double* GetParametricCoords() = 0;
 
   /**
    * Tessellate the cell if it is not linear or if at least one attribute of
@@ -518,16 +485,12 @@ public:
    * \pre pd_exist: pd!=0
    * \pre cd_exists: cd!=0
    */
-  virtual void Tessellate(vtkGenericAttributeCollection *attributes,
-                          vtkGenericCellTessellator *tess,
-                          vtkPoints *points,
-                          vtkIncrementalPointLocator *locator,
-                          vtkCellArray* cellArray,
-                          vtkPointData *internalPd,
-                          vtkPointData *pd, vtkCellData* cd,
-                          vtkUnsignedCharArray *types);
+  virtual void Tessellate(vtkGenericAttributeCollection* attributes,
+    vtkGenericCellTessellator* tess, vtkPoints* points, vtkIncrementalPointLocator* locator,
+    vtkCellArray* cellArray, vtkPointData* internalPd, vtkPointData* pd, vtkCellData* cd,
+    vtkUnsignedCharArray* types);
 
-  // The following methods are for the internals of the tesselation algorithm
+  // The following methods are for the internals of the tessellation algorithm
   // (the hash table in particular)
 
   /**
@@ -549,7 +512,7 @@ public:
    * \pre id_exists: id!=0
    * \pre valid_size: sizeof(id)==GetNumberOfPoints();
    */
-  virtual void GetPointIds(vtkIdType *id) = 0;
+  virtual void GetPointIds(vtkIdType* id) = 0;
 
   /**
    * Tessellate face `index' of the cell. See Tessellate() for further
@@ -564,13 +527,10 @@ public:
    * \pre pd_exist: pd!=0
    * \pre cd_exists: cd!=0
    */
-  virtual void TriangulateFace(vtkGenericAttributeCollection *attributes,
-                               vtkGenericCellTessellator *tess, int index,
-                               vtkPoints *points,
-                               vtkIncrementalPointLocator *locator,
-                               vtkCellArray *cellArray,
-                               vtkPointData *internalPd,
-                               vtkPointData *pd, vtkCellData *cd );
+  virtual void TriangulateFace(vtkGenericAttributeCollection* attributes,
+    vtkGenericCellTessellator* tess, int index, vtkPoints* points,
+    vtkIncrementalPointLocator* locator, vtkCellArray* cellArray, vtkPointData* internalPd,
+    vtkPointData* pd, vtkCellData* cd);
 
   /**
    * Return the ids of the vertices defining face `faceId'.
@@ -579,8 +539,12 @@ public:
    * \pre valid_faceId_range: faceId>=0 && faceId<this->GetNumberOfBoundaries(2)
    * \post result_exists: result!=0
    * \post valid_size: sizeof(result)>=GetNumberOfVerticesOnFace(faceId)
+   *
+   * @note The return type changed. It used to be int*, it is now const vtkIdType*.
+   * This is so ids are unified between vtkCell and vtkPoints, and so vtkCell ids
+   * can be used as inputs in algorithms such as vtkPolygon::ComputeNormal.
    */
-  virtual int *GetFaceArray(int faceId)=0;
+  virtual const vtkIdType* GetFaceArray(vtkIdType faceId) = 0;
 
   /**
    * Return the number of vertices defining face `faceId'.
@@ -588,7 +552,7 @@ public:
    * \pre valid_faceId_range: faceId>=0 && faceId<this->GetNumberOfBoundaries(2)
    * \post positive_result: && result>0
    */
-  virtual int GetNumberOfVerticesOnFace(int faceId)=0;
+  virtual int GetNumberOfVerticesOnFace(int faceId) = 0;
 
   /**
    * Return the ids of the vertices defining edge `edgeId'.
@@ -597,12 +561,15 @@ public:
    * \pre valid_edgeId_range: edgeId>=0 && edgeId<this->GetNumberOfBoundaries(1)
    * \post result_exists: result!=0
    * \post valid_size: sizeof(result)==2
+   *
+   * @note The return type changed. It used to be int*, it is now const vtkIdType*.
+   * This is so ids are unified between vtkCell and vtkPoints.
    */
-  virtual int *GetEdgeArray(int edgeId)=0;
+  virtual const vtkIdType* GetEdgeArray(vtkIdType edgeId) = 0;
 
 protected:
   vtkGenericAdaptorCell();
-  ~vtkGenericAdaptorCell() VTK_OVERRIDE;
+  ~vtkGenericAdaptorCell() override;
 
   /**
    * Reset internal structures.
@@ -615,44 +582,44 @@ protected:
    */
   void AllocateTuples(int size);
 
-  //Internal tetra used for the contouring/clipping algorithm
-  vtkTetra       *Tetra;
-  vtkTriangle    *Triangle;
-  vtkLine        *Line;
-  vtkVertex      *Vertex; //is it used ?
-  vtkQuad *Quad;
-  vtkHexahedron *Hexa;
-  vtkWedge *Wedge;
-  vtkPyramid *Pyramid;
+  // Internal tetra used for the contouring/clipping algorithm
+  vtkTetra* Tetra;
+  vtkTriangle* Triangle;
+  vtkLine* Line;
+  vtkVertex* Vertex; // is it used ?
+  vtkQuad* Quad;
+  vtkHexahedron* Hexa;
+  vtkWedge* Wedge;
+  vtkPyramid* Pyramid;
 
   // Internal locator when tessellating on a cell basis, this is different
   // from the main locator used in contour/clip filter, this locator is used for
   // points for
   // Be careful the use of a vtkLocator in conjunction with the table fast
   // tessellator is very sensitive, we need to keep all the points we used
-  vtkDoubleArray  *InternalPoints;
-  vtkCellArray    *InternalCellArray;
-  vtkDoubleArray  *InternalScalars;
-  vtkDoubleArray  *PointDataScalars;
+  vtkDoubleArray* InternalPoints;
+  vtkCellArray* InternalCellArray;
+  vtkDoubleArray* InternalScalars;
+  vtkDoubleArray* PointDataScalars;
 
-  vtkIdList        *InternalIds; // used by Tessellate() and TriangulateFace()
+  vtkIdList* InternalIds; // used by Tessellate() and TriangulateFace()
 
-  //Attributes to mimic the vtk cell look and feel, internal use only
-  vtkDoubleArray  *Scalars;
-  vtkPointData    *PointData;
-  vtkCellData     *CellData;
+  // Attributes to mimic the vtk cell look and feel, internal use only
+  vtkDoubleArray* Scalars;
+  vtkPointData* PointData;
+  vtkCellData* CellData;
 
   // Scalar buffer to store the attributes values at some location
   // There are variable members to reduce memory allocations.
-  double *Tuples;
+  double* Tuples;
   int TuplesCapacity;
 
   // Cached Bounds.
   double Bounds[6];
 
 private:
-  vtkGenericAdaptorCell(const vtkGenericAdaptorCell&) VTK_DELETE_FUNCTION;
-  void operator=(const vtkGenericAdaptorCell&) VTK_DELETE_FUNCTION;
+  vtkGenericAdaptorCell(const vtkGenericAdaptorCell&) = delete;
+  void operator=(const vtkGenericAdaptorCell&) = delete;
 };
 
 #endif
