@@ -14,21 +14,14 @@
 =========================================================================*/
 #include "vtkGenericCellIterator.h"
 
+//----------------------------------------------------------------------------
+vtkGenericCellIterator::vtkGenericCellIterator() = default;
 
 //----------------------------------------------------------------------------
-vtkGenericCellIterator::vtkGenericCellIterator()
-{
-}
-
-//----------------------------------------------------------------------------
-vtkGenericCellIterator::~vtkGenericCellIterator()
-{
-}
+vtkGenericCellIterator::~vtkGenericCellIterator() = default;
 
 //----------------------------------------------------------------------------
 void vtkGenericCellIterator::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
-
+  this->Superclass::PrintSelf(os, indent);
 }
-
