@@ -18,11 +18,12 @@
 #include "vtkInformationVector.h"
 #include "vtkObjectFactory.h"
 
-#include <cassert>
-#include <vector>
-#include <set>
 #include <algorithm>
+#include <cassert>
+#include <cmath>
 #include <iterator>
+#include <set>
+#include <vector>
 
 vtkStandardNewMacro(vtkPiecewiseFunction);
 
@@ -40,10 +41,9 @@ public:
 class vtkPiecewiseFunctionCompareNodes
 {
 public:
-  bool operator () ( const vtkPiecewiseFunctionNode *node1,
-                     const vtkPiecewiseFunctionNode *node2 )
+  bool operator()(const vtkPiecewiseFunctionNode* node1, const vtkPiecewiseFunctionNode* node2)
   {
-      return node1->X < node2->X;
+    return node1->X < node2->X;
   }
 };
 
@@ -52,10 +52,7 @@ class vtkPiecewiseFunctionFindNodeEqual
 {
 public:
   double X;
-  bool operator () ( const vtkPiecewiseFunctionNode *node )
-  {
-      return node->X == this->X;
-  }
+  bool operator()(const vtkPiecewiseFunctionNode* node) { return node->X == this->X; }
 };
 
 // A find method for finding nodes inside a specified range
@@ -64,10 +61,9 @@ class vtkPiecewiseFunctionFindNodeInRange
 public:
   double X1;
   double X2;
-  bool operator () ( const vtkPiecewiseFunctionNode *node )
+  bool operator()(const vtkPiecewiseFunctionNode* node)
   {
-      return ( node->X >= this->X1 &&
-               node->X <= this->X2 );
+    return (node->X >= this->X1 && node->X <= this->X2);
   }
 };
 
@@ -77,10 +73,9 @@ class vtkPiecewiseFunctionFindNodeOutOfRange
 public:
   double X1;
   double X2;
-  bool operator () ( const vtkPiecewiseFunctionNode *node )
+  bool operator()(const vtkPiecewiseFunctionNode* node)
   {
-      return ( node->X < this->X1 ||
-               node->X > this->X2 );
+    return (node->X < this->X1 || node->X > this->X2);
   }
 };
 
@@ -89,10 +84,10 @@ class vtkPiecewiseFunctionInternals
 {
 public:
   std::vector<vtkPiecewiseFunctionNode*> Nodes;
-  vtkPiecewiseFunctionCompareNodes        CompareNodes;
-  vtkPiecewiseFunctionFindNodeEqual       FindNodeEqual;
-  vtkPiecewiseFunctionFindNodeInRange     FindNodeInRange;
-  vtkPiecewiseFunctionFindNodeOutOfRange  FindNodeOutOfRange;
+  vtkPiecewiseFunctionCompareNodes CompareNodes;
+  vtkPiecewiseFunctionFindNodeEqual FindNodeEqual;
+  vtkPiecewiseFunctionFindNodeInRange FindNodeInRange;
+  vtkPiecewiseFunctionFindNodeOutOfRange FindNodeOutOfRange;
 };
 
 // Construct a new vtkPiecewiseFunction with default values
@@ -102,9 +97,10 @@ vtkPiecewiseFunction::vtkPiecewiseFunction()
   this->Range[0] = 0;
   this->Range[1] = 0;
 
-  this->Function = NULL;
+  this->Function = nullptr;
 
   this->AllowDuplicateScalars = 0;
+  this->UseLogScale = false;
 
   this->Internal = new vtkPiecewiseFunctionInternals;
 }
@@ -112,9 +108,9 @@ vtkPiecewiseFunction::vtkPiecewiseFunction()
 // Destruct a vtkPiecewiseFunction
 vtkPiecewiseFunction::~vtkPiecewiseFunction()
 {
-  delete [] this->Function;
+  delete[] this->Function;
 
-  for(unsigned int i=0;i<this->Internal->Nodes.size();i++)
+  for (unsigned int i = 0; i < this->Internal->Nodes.size(); i++)
   {
     delete this->Internal->Nodes[i];
   }
@@ -122,20 +118,21 @@ vtkPiecewiseFunction::~vtkPiecewiseFunction()
   delete this->Internal;
 }
 
-void vtkPiecewiseFunction::DeepCopy( vtkDataObject *o )
+void vtkPiecewiseFunction::DeepCopy(vtkDataObject* o)
 {
-  vtkPiecewiseFunction *f = vtkPiecewiseFunction::SafeDownCast(o);
+  vtkPiecewiseFunction* f = vtkPiecewiseFunction::SafeDownCast(o);
 
-  if (f != NULL)
+  if (f != nullptr)
   {
-    this->Clamping     = f->Clamping;
+    this->Clamping = f->Clamping;
     int i;
     this->RemoveAllPoints();
-    for ( i = 0; i < f->GetSize(); i++ )
+    for (i = 0; i < f->GetSize(); i++)
     {
       double val[4];
       int isInRange = f->GetNodeValue(i, val);
-      assert(isInRange == 1); (void)isInRange;
+      assert(isInRange == 1);
+      (void)isInRange;
       this->AddPoint(val[0], val[1], val[2], val[3]);
     }
     this->Modified();
@@ -145,20 +142,21 @@ void vtkPiecewiseFunction::DeepCopy( vtkDataObject *o )
   this->Superclass::DeepCopy(o);
 }
 
-void vtkPiecewiseFunction::ShallowCopy( vtkDataObject *o )
+void vtkPiecewiseFunction::ShallowCopy(vtkDataObject* o)
 {
-  vtkPiecewiseFunction *f = vtkPiecewiseFunction::SafeDownCast(o);
+  vtkPiecewiseFunction* f = vtkPiecewiseFunction::SafeDownCast(o);
 
-  if (f != NULL)
+  if (f != nullptr)
   {
-    this->Clamping     = f->Clamping;
+    this->Clamping = f->Clamping;
     int i;
     this->RemoveAllPoints();
-    for ( i = 0; i < f->GetSize(); i++ )
+    for (i = 0; i < f->GetSize(); i++)
     {
       double val[4];
       int isInRange = f->GetNodeValue(i, val);
-      assert(isInRange == 1); (void)isInRange;
+      assert(isInRange == 1);
+      (void)isInRange;
       this->AddPoint(val[0], val[1], val[2], val[3]);
     }
     this->Modified();
@@ -174,7 +172,6 @@ void vtkPiecewiseFunction::Initialize()
   this->RemoveAllPoints();
 }
 
-
 // Return the number of points which specify this function
 int vtkPiecewiseFunction::GetSize()
 {
@@ -189,50 +186,50 @@ int vtkPiecewiseFunction::GetSize()
 //    3 : Varied          (Contains both decreasing and increasing slopes)
 //    4 : Unknown         (Error condition)
 //
-const char *vtkPiecewiseFunction::GetType()
+const char* vtkPiecewiseFunction::GetType()
 {
-  unsigned int   i;
+  unsigned int i;
   double value;
   double prev_value = 0.0;
-  int   function_type;
+  int function_type;
 
   function_type = 0;
 
-  if( this->Internal->Nodes.size() )
+  if (!this->Internal->Nodes.empty())
   {
     prev_value = this->Internal->Nodes[0]->Y;
   }
 
-  for( i=1; i < this->Internal->Nodes.size(); i++ )
+  for (i = 1; i < this->Internal->Nodes.size(); i++)
   {
     value = this->Internal->Nodes[i]->Y;
 
     // Do not change the function type if equal
-    if( value != prev_value )
+    if (value != prev_value)
     {
-      if( value > prev_value )
+      if (value > prev_value)
       {
-        switch( function_type )
+        switch (function_type)
         {
           case 0:
           case 1:
-            function_type = 1;  // NonDecreasing
+            function_type = 1; // NonDecreasing
             break;
           case 2:
-            function_type = 3;  // Varied
+            function_type = 3; // Varied
             break;
         }
       }
       else // value < prev_value
       {
-        switch( function_type )
+        switch (function_type)
         {
           case 0:
           case 2:
-            function_type = 2;  // NonIncreasing
+            function_type = 2; // NonIncreasing
             break;
           case 1:
-            function_type = 3;  // Varied
+            function_type = 3; // Varied
             break;
         }
       }
@@ -241,13 +238,13 @@ const char *vtkPiecewiseFunction::GetType()
     prev_value = value;
 
     // Exit loop if we find a Varied function
-    if( function_type == 3 )
+    if (function_type == 3)
     {
       break;
     }
   }
 
-  switch( function_type )
+  switch (function_type)
   {
     case 0:
       return "Constant";
@@ -265,20 +262,20 @@ const char *vtkPiecewiseFunction::GetType()
 // Since we no longer store the data in an array, we must
 // copy out of the vector into an array. No modified check -
 // could be added if performance is a problem
-double *vtkPiecewiseFunction::GetDataPointer()
+double* vtkPiecewiseFunction::GetDataPointer()
 {
   int size = static_cast<int>(this->Internal->Nodes.size());
 
-  delete [] this->Function;
-  this->Function = NULL;
+  delete[] this->Function;
+  this->Function = nullptr;
 
-  if ( size > 0 )
+  if (size > 0)
   {
-    this->Function = new double[size*2];
-    for ( int i = 0; i < size; i++ )
+    this->Function = new double[size * 2];
+    for (int i = 0; i < size; i++)
     {
-      this->Function[2*i  ] = this->Internal->Nodes[i]->X;
-      this->Function[2*i+1] = this->Internal->Nodes[i]->Y;
+      this->Function[2 * i] = this->Internal->Nodes[i]->X;
+      this->Function[2 * i + 1] = this->Internal->Nodes[i]->Y;
     }
   }
 
@@ -290,17 +287,17 @@ double *vtkPiecewiseFunction::GetDataPointer()
 double vtkPiecewiseFunction::GetFirstNonZeroValue()
 {
   // Check if no points specified
-  if( this->Internal->Nodes.size() == 0 )
+  if (this->Internal->Nodes.empty())
   {
     return 0;
   }
 
-  unsigned int   i;
-  int   all_zero = 1;
+  unsigned int i;
+  int all_zero = 1;
   double x = 0.0;
-  for( i=0; i < this->Internal->Nodes.size(); i++ )
+  for (i = 0; i < this->Internal->Nodes.size(); i++)
   {
-    if( this->Internal->Nodes[i]->Y != 0.0 )
+    if (this->Internal->Nodes[i]->Y != 0.0)
     {
       all_zero = 0;
       break;
@@ -309,23 +306,23 @@ double vtkPiecewiseFunction::GetFirstNonZeroValue()
 
   // If every specified point has a zero value then return
   // a large value
-  if( all_zero )
+  if (all_zero)
   {
     x = VTK_DOUBLE_MAX;
   }
-  else  // A point was found with a non-zero value
+  else // A point was found with a non-zero value
   {
-    if( i > 0 )
-      // Return the value of the point that precedes this one
+    if (i > 0)
+    // Return the value of the point that precedes this one
     {
-      x = this->Internal->Nodes[i-1]->X;
+      x = this->Internal->Nodes[i - 1]->X;
     }
     else
-      // If this is the first point in the function, return its
-      // value is clamping is off, otherwise VTK_DOUBLE_MIN if
-      // clamping is on.
+    // If this is the first point in the function, return its
+    // value is clamping is off, otherwise VTK_DOUBLE_MIN if
+    // clamping is on.
     {
-      if ( this->Clamping )
+      if (this->Clamping)
       {
         x = VTK_DOUBLE_MIN;
       }
@@ -340,11 +337,11 @@ double vtkPiecewiseFunction::GetFirstNonZeroValue()
 }
 
 // For a specified index value, get the node parameters
-int vtkPiecewiseFunction::GetNodeValue( int index, double val[4] )
+int vtkPiecewiseFunction::GetNodeValue(int index, double val[4])
 {
   int size = static_cast<int>(this->Internal->Nodes.size());
 
-  if ( index < 0 || index >= size )
+  if (index < 0 || index >= size)
   {
     vtkErrorMacro("Index out of range!");
     return -1;
@@ -359,11 +356,11 @@ int vtkPiecewiseFunction::GetNodeValue( int index, double val[4] )
 }
 
 // For a specified index value, get the node parameters
-int vtkPiecewiseFunction::SetNodeValue( int index, double val[4] )
+int vtkPiecewiseFunction::SetNodeValue(int index, double val[4])
 {
   int size = static_cast<int>(this->Internal->Nodes.size());
 
-  if ( index < 0 || index >= size )
+  if (index < 0 || index >= size)
   {
     vtkErrorMacro("Index out of range!");
     return -1;
@@ -395,23 +392,22 @@ int vtkPiecewiseFunction::SetNodeValue( int index, double val[4] )
 // then the function value at that location is set to the new value.
 // This is the legacy version that assumes midpoint = 0.5 and
 // sharpness = 0.0
-int vtkPiecewiseFunction::AddPoint( double x, double y )
+int vtkPiecewiseFunction::AddPoint(double x, double y)
 {
-  return this->AddPoint( x, y, 0.5, 0.0 );
+  return this->AddPoint(x, y, 0.5, 0.0);
 }
 
 // Adds a point to the function and returns the array index of the point.
-int vtkPiecewiseFunction::AddPoint( double x, double y,
-                                    double midpoint, double sharpness )
+int vtkPiecewiseFunction::AddPoint(double x, double y, double midpoint, double sharpness)
 {
   // Error check
-  if ( midpoint < 0.0 || midpoint > 1.0 )
+  if (midpoint < 0.0 || midpoint > 1.0)
   {
     vtkErrorMacro("Midpoint outside range [0.0, 1.0]");
     return -1;
   }
 
-  if ( sharpness < 0.0 || sharpness > 1.0 )
+  if (sharpness < 0.0 || sharpness > 1.0)
   {
     vtkErrorMacro("Sharpness outside range [0.0, 1.0]");
     return -1;
@@ -420,15 +416,15 @@ int vtkPiecewiseFunction::AddPoint( double x, double y,
   // remove any node already at this X location
   if (!this->AllowDuplicateScalars)
   {
-    this->RemovePoint( x );
+    this->RemovePoint(x);
   }
 
   // Create the new node
-  vtkPiecewiseFunctionNode *node = new vtkPiecewiseFunctionNode;
-  node->X         = x;
-  node->Y         = y;
+  vtkPiecewiseFunctionNode* node = new vtkPiecewiseFunctionNode;
+  node->X = x;
+  node->Y = y;
   node->Sharpness = sharpness;
-  node->Midpoint  = midpoint;
+  node->Midpoint = midpoint;
 
   // Add it, then sort to get everything in order
   this->Internal->Nodes.push_back(node);
@@ -436,9 +432,9 @@ int vtkPiecewiseFunction::AddPoint( double x, double y,
 
   // Now find this node so we can return the index
   unsigned int i;
-  for ( i = 0; i < this->Internal->Nodes.size(); i++ )
+  for (i = 0; i < this->Internal->Nodes.size(); i++)
   {
-    if ( this->Internal->Nodes[i]->X == x )
+    if (this->Internal->Nodes[i]->X == x)
     {
       break;
     }
@@ -448,7 +444,7 @@ int vtkPiecewiseFunction::AddPoint( double x, double y,
 
   // If we didn't find it, something went horribly wrong so
   // return -1
-  if ( i < this->Internal->Nodes.size() )
+  if (i < this->Internal->Nodes.size())
   {
     retVal = i;
   }
@@ -464,9 +460,8 @@ int vtkPiecewiseFunction::AddPoint( double x, double y,
 // the Range
 void vtkPiecewiseFunction::SortAndUpdateRange()
 {
-  std::sort( this->Internal->Nodes.begin(),
-                this->Internal->Nodes.end(),
-                this->Internal->CompareNodes );
+  std::sort(
+    this->Internal->Nodes.begin(), this->Internal->Nodes.end(), this->Internal->CompareNodes);
   bool modifiedInvoked = this->UpdateRange();
   // If range is updated, Modified() has been called, don't call it again.
   if (!modifiedInvoked)
@@ -483,10 +478,10 @@ bool vtkPiecewiseFunction::UpdateRange()
   oldRange[1] = this->Range[1];
 
   int size = static_cast<int>(this->Internal->Nodes.size());
-  if ( size )
+  if (size)
   {
     this->Range[0] = this->Internal->Nodes[0]->X;
-    this->Range[1] = this->Internal->Nodes[size-1]->X;
+    this->Range[1] = this->Internal->Nodes[size - 1]->X;
   }
   else
   {
@@ -505,14 +500,14 @@ bool vtkPiecewiseFunction::UpdateRange()
 
 // Removes a point from the function. If no point is found then function
 // remains the same.
-int vtkPiecewiseFunction::RemovePoint( double x )
+int vtkPiecewiseFunction::RemovePoint(double x)
 {
   // First find the node since we need to know its
   // index as our return value
   unsigned int i;
-  for ( i = 0; i < this->Internal->Nodes.size(); i++ )
+  for (i = 0; i < this->Internal->Nodes.size(); i++)
   {
-    if ( this->Internal->Nodes[i]->X == x )
+    if (this->Internal->Nodes[i]->X == x)
     {
       break;
     }
@@ -521,7 +516,7 @@ int vtkPiecewiseFunction::RemovePoint( double x )
   int retVal;
 
   // If the node doesn't exist, we return -1
-  if ( i < this->Internal->Nodes.size() )
+  if (i < this->Internal->Nodes.size())
   {
     retVal = i;
   }
@@ -533,13 +528,11 @@ int vtkPiecewiseFunction::RemovePoint( double x )
   // Now use STL to find it, so that we can remove it
   this->Internal->FindNodeEqual.X = x;
 
-  std::vector<vtkPiecewiseFunctionNode*>::iterator iter =
-    std::find_if(this->Internal->Nodes.begin(),
-                    this->Internal->Nodes.end(),
-                    this->Internal->FindNodeEqual );
+  std::vector<vtkPiecewiseFunctionNode*>::iterator iter = std::find_if(
+    this->Internal->Nodes.begin(), this->Internal->Nodes.end(), this->Internal->FindNodeEqual);
 
   // Actually delete it
-  if ( iter != this->Internal->Nodes.end() )
+  if (iter != this->Internal->Nodes.end())
   {
     delete *iter;
     this->Internal->Nodes.erase(iter);
@@ -557,19 +550,18 @@ int vtkPiecewiseFunction::RemovePoint( double x )
   }
   else
   {
-     // This should never happen - we already returned if the node
-     // didn't exist...
-     return -1;
+    // This should never happen - we already returned if the node
+    // didn't exist...
+    return -1;
   }
 
-
   return retVal;
 }
 
 // Removes all points from the function.
 void vtkPiecewiseFunction::RemoveAllPoints()
 {
-  for(unsigned int i=0;i<this->Internal->Nodes.size();i++)
+  for (unsigned int i = 0; i < this->Internal->Nodes.size(); i++)
   {
     delete this->Internal->Nodes[i];
   }
@@ -580,26 +572,23 @@ void vtkPiecewiseFunction::RemoveAllPoints()
 
 // Add in end points of line and remove any points between them
 // Legacy method with no way to specify midpoint and sharpness
-void vtkPiecewiseFunction::AddSegment( double x1, double y1,
-                                       double x2, double y2 )
+void vtkPiecewiseFunction::AddSegment(double x1, double y1, double x2, double y2)
 {
   int done;
 
   // First, find all points in this range and remove them
   done = 0;
-  while ( !done )
+  while (!done)
   {
     done = 1;
 
     this->Internal->FindNodeInRange.X1 = x1;
     this->Internal->FindNodeInRange.X2 = x2;
 
-    std::vector<vtkPiecewiseFunctionNode*>::iterator iter =
-      std::find_if(this->Internal->Nodes.begin(),
-                      this->Internal->Nodes.end(),
-                      this->Internal->FindNodeInRange );
+    std::vector<vtkPiecewiseFunctionNode*>::iterator iter = std::find_if(
+      this->Internal->Nodes.begin(), this->Internal->Nodes.end(), this->Internal->FindNodeInRange);
 
-    if ( iter != this->Internal->Nodes.end() )
+    if (iter != this->Internal->Nodes.end())
     {
       delete *iter;
       this->Internal->Nodes.erase(iter);
@@ -609,15 +598,15 @@ void vtkPiecewiseFunction::AddSegment( double x1, double y1,
   }
 
   // Now add the points
-  this->AddPoint( x1, y1, 0.5, 0.0 );
-  this->AddPoint( x2, y2, 0.5, 0.0 );
+  this->AddPoint(x1, y1, 0.5, 0.0);
+  this->AddPoint(x2, y2, 0.5, 0.0);
 }
 
 // Return the value of the function at a position
-double vtkPiecewiseFunction::GetValue( double x )
+double vtkPiecewiseFunction::GetValue(double x)
 {
   double table[1];
-  this->GetTable( x, x, 1, table );
+  this->GetTable(x, x, 1, table);
   return table[0];
 }
 
@@ -631,7 +620,7 @@ int vtkPiecewiseFunction::AdjustRange(double range[2])
     return 0;
   }
 
-  double *function_range = this->GetRange();
+  double* function_range = this->GetRange();
 
   // Make sure we have points at each end of the range
 
@@ -657,7 +646,7 @@ int vtkPiecewiseFunction::AdjustRange(double range[2])
   int done;
 
   done = 0;
-  while ( !done )
+  while (!done)
   {
     done = 1;
 
@@ -665,11 +654,10 @@ int vtkPiecewiseFunction::AdjustRange(double range[2])
     this->Internal->FindNodeOutOfRange.X2 = range[1];
 
     std::vector<vtkPiecewiseFunctionNode*>::iterator iter =
-      std::find_if(this->Internal->Nodes.begin(),
-                      this->Internal->Nodes.end(),
-                      this->Internal->FindNodeOutOfRange );
+      std::find_if(this->Internal->Nodes.begin(), this->Internal->Nodes.end(),
+        this->Internal->FindNodeOutOfRange);
 
-    if ( iter != this->Internal->Nodes.end() )
+    if (iter != this->Internal->Nodes.end())
     {
       delete *iter;
       this->Internal->Nodes.erase(iter);
@@ -683,8 +671,7 @@ int vtkPiecewiseFunction::AdjustRange(double range[2])
 }
 
 //--------------------------------------------------------------------------
-int vtkPiecewiseFunction::EstimateMinNumberOfSamples(double const & x1,
-  double const & x2)
+int vtkPiecewiseFunction::EstimateMinNumberOfSamples(double const& x1, double const& x2)
 {
   double const d = this->FindMinimumXDistance();
   int idealWidth = static_cast<int>(ceil((x2 - x1) / d));
@@ -695,7 +682,7 @@ int vtkPiecewiseFunction::EstimateMinNumberOfSamples(double const & x1,
 //----------------------------------------------------------------------------
 double vtkPiecewiseFunction::FindMinimumXDistance()
 {
-  std::vector<vtkPiecewiseFunctionNode*> const & nodes = this->Internal->Nodes;
+  std::vector<vtkPiecewiseFunctionNode*> const& nodes = this->Internal->Nodes;
   size_t const size = nodes.size();
   if (size < 2)
     return -1.0;
@@ -714,9 +701,8 @@ double vtkPiecewiseFunction::FindMinimumXDistance()
 }
 
 // Returns a table of function values evaluated at regular intervals
-void vtkPiecewiseFunction::GetTable( double xStart, double xEnd,
-                                     int size, double* table,
-                                     int stride )
+void vtkPiecewiseFunction::GetTable(
+  double start, double end, int size, double* table, int stride, int logIncrements)
 {
   int i;
   int idx = 0;
@@ -726,68 +712,81 @@ void vtkPiecewiseFunction::GetTable( double xStart, double xEnd,
   // we can fill in table locations past this with
   // this value if Clamping is On.
   double lastValue = 0.0;
-  if ( numNodes != 0 )
+  if (numNodes != 0)
   {
-    lastValue = this->Internal->Nodes[numNodes-1]->Y;
+    lastValue = this->Internal->Nodes[numNodes - 1]->Y;
   }
 
-  double *tptr     = NULL;
-  double x         = 0.0;
-  double x1        = 0.0;
-  double x2        = 0.0;
-  double y1        = 0.0;
-  double y2        = 0.0;
-  double midpoint  = 0.0;
+  double* tptr = nullptr;
+  double x = 0.0;
+  double x1 = 0.0;
+  double x2 = 0.0;
+  double y1 = 0.0;
+  double y2 = 0.0;
+  double midpoint = 0.0;
   double sharpness = 0.0;
+  double xStart = start;
+  double xEnd = end;
+
+  if (logIncrements)
+  {
+    xStart = std::log10(xStart);
+    xEnd = std::log10(xEnd);
+  }
 
   // For each table entry
-  for ( i = 0; i < size; i++ )
+  for (i = 0; i < size; i++)
   {
     // Find our location in the table
-    tptr = table + stride*i;
+    tptr = table + stride * i;
 
     // Find our X location. If we are taking only 1 sample, make
     // it halfway between start and end (usually start and end will
     // be the same in this case)
-    if ( size > 1 )
+    if (size > 1)
     {
-      x = xStart + (double(i)/double(size-1))*(xEnd-xStart);
+      x = xStart + (double(i) / double(size - 1)) * (xEnd - xStart);
     }
     else
     {
-      x = 0.5*(xStart+xEnd);
+      x = 0.5 * (xStart + xEnd);
+    }
+
+    // Convert back into data space if xStart and xEnd are defined in log space:
+    if (logIncrements)
+    {
+      x = std::pow(10., x);
     }
 
     // Do we need to move to the next node?
-    while ( idx < numNodes &&
-            x > this->Internal->Nodes[idx]->X )
+    while (idx < numNodes && x > this->Internal->Nodes[idx]->X)
     {
       idx++;
       // If we are at a valid point index, fill in
       // the value at this node, and the one before (the
       // two that surround our current sample location)
       // idx cannot be 0 since we just incremented it.
-      if ( idx < numNodes )
+      if (idx < numNodes)
       {
-        x1 = this->Internal->Nodes[idx-1]->X;
-        x2 = this->Internal->Nodes[idx  ]->X;
+        x1 = this->Internal->Nodes[idx - 1]->X;
+        x2 = this->Internal->Nodes[idx]->X;
 
-        y1 = this->Internal->Nodes[idx-1]->Y;
-        y2 = this->Internal->Nodes[idx  ]->Y;
+        y1 = this->Internal->Nodes[idx - 1]->Y;
+        y2 = this->Internal->Nodes[idx]->Y;
 
         // We only need the previous midpoint and sharpness
         // since these control this region
-        midpoint  = this->Internal->Nodes[idx-1]->Midpoint;
-        sharpness = this->Internal->Nodes[idx-1]->Sharpness;
+        midpoint = this->Internal->Nodes[idx - 1]->Midpoint;
+        sharpness = this->Internal->Nodes[idx - 1]->Sharpness;
 
         // Move midpoint away from extreme ends of range to avoid
         // degenerate math
-        if ( midpoint < 0.00001 )
+        if (midpoint < 0.00001)
         {
           midpoint = 0.00001;
         }
 
-        if ( midpoint > 0.99999 )
+        if (midpoint > 0.99999)
         {
           midpoint = 0.99999;
         }
@@ -795,14 +794,14 @@ void vtkPiecewiseFunction::GetTable( double xStart, double xEnd,
     }
 
     // Are we at the end? If so, just use the last value
-    if ( idx >= numNodes )
+    if (idx >= numNodes)
     {
-      *tptr = (this->Clamping)?(lastValue):(0.0);
+      *tptr = (this->Clamping) ? (lastValue) : (0.0);
     }
     // Are we before the first node? If so, duplicate this nodes values
-    else if ( idx == 0 )
+    else if (idx == 0)
     {
-      *tptr = (this->Clamping)?(this->Internal->Nodes[0]->Y):(0.0);
+      *tptr = (this->Clamping) ? (this->Internal->Nodes[0]->Y) : (0.0);
     }
     // Otherwise, we are between two nodes - interpolate
     else
@@ -811,24 +810,36 @@ void vtkPiecewiseFunction::GetTable( double xStart, double xEnd,
       // we will be modifying this based on midpoint and
       // sharpness to get the curve shape we want and to have
       // it pass through (y1+y2)/2 at the midpoint.
-      double s = (x - x1) / (x2 - x1);
+      double s;
+      if (this->UseLogScale)
+      {
+        // Don't modify x1/x2 -- these are not reset on each iteration.
+        double xLog = std::log10(x);
+        double x1Log = std::log10(x1);
+        double x2Log = std::log10(x2);
+        s = (xLog - x1Log) / (x2Log - x1Log);
+      }
+      else
+      {
+        s = (x - x1) / (x2 - x1);
+      }
 
       // Readjust based on the midpoint - linear adjustment
-      if ( s < midpoint )
+      if (s < midpoint)
       {
         s = 0.5 * s / midpoint;
       }
       else
       {
-        s = 0.5 + 0.5*(s-midpoint)/(1.0-midpoint);
+        s = 0.5 + 0.5 * (s - midpoint) / (1.0 - midpoint);
       }
 
       // override for sharpness > 0.99
       // In this case we just want piecewise constant
-      if ( sharpness > 0.99 )
+      if (sharpness > 0.99)
       {
         // Use the first value since we are below the midpoint
-        if ( s < 0.5 )
+        if (s < 0.5)
         {
           *tptr = y1;
           continue;
@@ -843,10 +854,10 @@ void vtkPiecewiseFunction::GetTable( double xStart, double xEnd,
 
       // Override for sharpness < 0.01
       // In this case we want piecewise linear
-      if ( sharpness < 0.01 )
+      if (sharpness < 0.01)
       {
         // Simple linear interpolation
-        *tptr = (1-s)*y1 + s*y2;
+        *tptr = (1 - s) * y1 + s * y2;
         continue;
       }
 
@@ -857,63 +868,61 @@ void vtkPiecewiseFunction::GetTable( double xStart, double xEnd,
 
       // First, we will adjust our position based on sharpness in
       // order to make the curve sharper (closer to piecewise constant)
-      if ( s < .5 )
+      if (s < .5)
       {
-        s = 0.5 * pow(s*2,1.0 + 10*sharpness);
+        s = 0.5 * pow(s * 2, 1.0 + 10 * sharpness);
       }
-      else if ( s > .5 )
+      else if (s > .5)
       {
-        s = 1.0 - 0.5 * pow((1.0-s)*2,1+10*sharpness);
+        s = 1.0 - 0.5 * pow((1.0 - s) * 2, 1 + 10 * sharpness);
       }
 
       // Compute some coefficients we will need for the hermite curve
-      double ss = s*s;
-      double sss = ss*s;
+      double ss = s * s;
+      double sss = ss * s;
 
-      double h1 =  2*sss - 3*ss + 1;
-      double h2 = -2*sss + 3*ss;
-      double h3 =    sss - 2*ss + s;
-      double h4 =    sss -   ss;
+      double h1 = 2 * sss - 3 * ss + 1;
+      double h2 = -2 * sss + 3 * ss;
+      double h3 = sss - 2 * ss + s;
+      double h4 = sss - ss;
 
       double slope;
       double t;
 
       // Use one slope for both end points
       slope = y2 - y1;
-      t = (1.0 - sharpness)*slope;
+      t = (1.0 - sharpness) * slope;
 
       // Compute the value
-      *tptr = h1*y1 + h2*y2 + h3*t + h4*t;
+      *tptr = h1 * y1 + h2 * y2 + h3 * t + h4 * t;
 
       // Final error check to make sure we don't go outside
       // the Y range
-      double min = (y1<y2)?(y1):(y2);
-      double max = (y1>y2)?(y1):(y2);
-
-      *tptr = (*tptr < min)?(min):(*tptr);
-      *tptr = (*tptr > max)?(max):(*tptr);
+      double min = (y1 < y2) ? (y1) : (y2);
+      double max = (y1 > y2) ? (y1) : (y2);
 
+      *tptr = (*tptr < min) ? (min) : (*tptr);
+      *tptr = (*tptr > max) ? (max) : (*tptr);
     }
   }
 }
 
 // Copy from double table to float
-void vtkPiecewiseFunction::GetTable( double xStart, double xEnd,
-                                     int size, float* table,
-                                     int stride )
+void vtkPiecewiseFunction::GetTable(
+  double xStart, double xEnd, int size, float* table, int stride, int logIncrements)
 {
-  double *tmpTable = new double [size];
+  double* tmpTable = new double[size];
 
-  this->GetTable( xStart, xEnd, size, tmpTable, 1 );
+  this->GetTable(xStart, xEnd, size, tmpTable, 1, logIncrements);
 
-  double *tmpPtr = tmpTable;
-  float *tPtr = table;
+  double* tmpPtr = tmpTable;
+  float* tPtr = table;
 
-  for ( int i = 0; i < size; i++ )
+  for (int i = 0; i < size; i++)
   {
     *tPtr = static_cast<float>(*tmpPtr);
-    tPtr   += stride;
-    tmpPtr ++;
+    tPtr += stride;
+    tmpPtr++;
   }
 
   delete[] tmpTable;
@@ -921,29 +930,27 @@ void vtkPiecewiseFunction::GetTable( double xStart, double xEnd,
 
 // Given a table of values, build the piecewise function. Legacy method
 // that does not allow for midpoint and sharpness control
-void vtkPiecewiseFunction::BuildFunctionFromTable( double xStart, double xEnd,
-                                                   int size, double* table,
-                                                   int stride )
+void vtkPiecewiseFunction::BuildFunctionFromTable(
+  double xStart, double xEnd, int size, double* table, int stride)
 {
   double inc = 0.0;
-  double *tptr = table;
+  double* tptr = table;
 
   this->RemoveAllPoints();
 
-
-  if( size > 1 )
+  if (size > 1)
   {
-    inc = (xEnd-xStart)/static_cast<double>(size-1);
+    inc = (xEnd - xStart) / static_cast<double>(size - 1);
   }
 
   int i;
-  for (i=0; i < size; i++)
+  for (i = 0; i < size; i++)
   {
-    vtkPiecewiseFunctionNode *node = new vtkPiecewiseFunctionNode;
-    node->X    = xStart + inc*i;
-    node->Y   = *tptr;
+    vtkPiecewiseFunctionNode* node = new vtkPiecewiseFunctionNode;
+    node->X = xStart + inc * i;
+    node->Y = *tptr;
     node->Sharpness = 0.0;
-    node->Midpoint  = 0.5;
+    node->Midpoint = 0.5;
 
     this->Internal->Nodes.push_back(node);
     tptr += stride;
@@ -954,7 +961,7 @@ void vtkPiecewiseFunction::BuildFunctionFromTable( double xStart, double xEnd,
 
 // Given a pointer to an array of values, build the piecewise function.
 // Legacy method that does not allow for midpoint and sharpness control
-void vtkPiecewiseFunction::FillFromDataPointer(int nb, double *ptr)
+void vtkPiecewiseFunction::FillFromDataPointer(int nb, double* ptr)
 {
   if (nb <= 0 || !ptr)
   {
@@ -963,16 +970,16 @@ void vtkPiecewiseFunction::FillFromDataPointer(int nb, double *ptr)
 
   this->RemoveAllPoints();
 
-  double *inPtr = ptr;
+  double* inPtr = ptr;
 
   int i;
-  for (i=0; i < nb; i++)
+  for (i = 0; i < nb; i++)
   {
-    vtkPiecewiseFunctionNode *node = new vtkPiecewiseFunctionNode;
-    node->X  = inPtr[0];
-    node->Y  = inPtr[1];
+    vtkPiecewiseFunctionNode* node = new vtkPiecewiseFunctionNode;
+    node->X = inPtr[0];
+    node->Y = inPtr[1];
     node->Sharpness = 0.0;
-    node->Midpoint  = 0.5;
+    node->Midpoint = 0.5;
 
     this->Internal->Nodes.push_back(node);
     inPtr += 2;
@@ -984,13 +991,11 @@ void vtkPiecewiseFunction::FillFromDataPointer(int nb, double *ptr)
 //----------------------------------------------------------------------------
 vtkPiecewiseFunction* vtkPiecewiseFunction::GetData(vtkInformation* info)
 {
-  return
-    info? vtkPiecewiseFunction::SafeDownCast(info->Get(DATA_OBJECT())) : 0;
+  return info ? vtkPiecewiseFunction::SafeDownCast(info->Get(DATA_OBJECT())) : nullptr;
 }
 
 //----------------------------------------------------------------------------
-vtkPiecewiseFunction* vtkPiecewiseFunction::GetData(vtkInformationVector* v,
-                                                    int i)
+vtkPiecewiseFunction* vtkPiecewiseFunction::GetData(vtkInformationVector* v, int i)
 {
   return vtkPiecewiseFunction::GetData(v->GetInformationObject(i));
 }
@@ -1003,18 +1008,15 @@ void vtkPiecewiseFunction::PrintSelf(ostream& os, vtkIndent indent)
   unsigned int i;
 
   os << indent << "Clamping: " << this->Clamping << endl;
-  os << indent << "Range: [" << this->Range[0] << ","
-     << this->Range[1] << "]" << endl;
+  os << indent << "Range: [" << this->Range[0] << "," << this->Range[1] << "]" << endl;
   os << indent << "Function Points: " << this->Internal->Nodes.size() << endl;
-  for( i = 0; i < this->Internal->Nodes.size(); i++ )
+  for (i = 0; i < this->Internal->Nodes.size(); i++)
   {
-    os << indent << "  " << i << " X: "
-       << this->Internal->Nodes[i]->X << " Y: "
-       << this->Internal->Nodes[i]->Y << " Sharpness: "
-       << this->Internal->Nodes[i]->Sharpness << " Midpoint: "
-       << this->Internal->Nodes[i]->Midpoint << endl;
+    os << indent << "  " << i << " X: " << this->Internal->Nodes[i]->X
+       << " Y: " << this->Internal->Nodes[i]->Y
+       << " Sharpness: " << this->Internal->Nodes[i]->Sharpness
+       << " Midpoint: " << this->Internal->Nodes[i]->Midpoint << endl;
   }
-  os << indent << "AllowDuplicateScalars: " << this->AllowDuplicateScalars
-     << endl;
+  os << indent << "AllowDuplicateScalars: " << this->AllowDuplicateScalars << endl;
+  os << indent << "UseLogScale: " << this->UseLogScale << endl;
 }
-
