@@ -64,9 +64,9 @@
  * vtkBiQuadraticQuad
  *
  * @par Thanks:
- * Thanks to Soeren Gebbert  who developed this class and
+ * Thanks to Soeren Gebbert who developed this class and
  * integrated it into VTK 5.0.
-*/
+ */
 
 #ifndef vtkTriQuadraticHexahedron_h
 #define vtkTriQuadraticHexahedron_h
@@ -82,85 +82,77 @@ class vtkDoubleArray;
 class VTKCOMMONDATAMODEL_EXPORT vtkTriQuadraticHexahedron : public vtkNonLinearCell
 {
 public:
-  static vtkTriQuadraticHexahedron *New ();
-  vtkTypeMacro(vtkTriQuadraticHexahedron,vtkNonLinearCell);
-  void PrintSelf (ostream & os, vtkIndent indent) VTK_OVERRIDE;
+  static vtkTriQuadraticHexahedron* New();
+  vtkTypeMacro(vtkTriQuadraticHexahedron, vtkNonLinearCell);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
   //@{
   /**
    * Implement the vtkCell API. See the vtkCell API for descriptions
    * of these methods.
    */
-  int GetCellType() VTK_OVERRIDE { return VTK_TRIQUADRATIC_HEXAHEDRON; }
-  int GetCellDimension() VTK_OVERRIDE { return 3; }
-  int GetNumberOfEdges() VTK_OVERRIDE { return 12; }
-  int GetNumberOfFaces() VTK_OVERRIDE { return 6; }
-  vtkCell *GetEdge (int) VTK_OVERRIDE;
-  vtkCell *GetFace (int) VTK_OVERRIDE;
+  int GetCellType() override { return VTK_TRIQUADRATIC_HEXAHEDRON; }
+  int GetCellDimension() override { return 3; }
+  int GetNumberOfEdges() override { return 12; }
+  int GetNumberOfFaces() override { return 6; }
+  vtkCell* GetEdge(int) override;
+  vtkCell* GetFace(int) override;
   //@}
 
-  int CellBoundary (int subId, double pcoords[3], vtkIdList * pts) VTK_OVERRIDE;
-  void Contour (double value, vtkDataArray * cellScalars,
-    vtkIncrementalPointLocator * locator, vtkCellArray * verts,
-    vtkCellArray * lines, vtkCellArray * polys,
-    vtkPointData * inPd, vtkPointData * outPd, vtkCellData * inCd,
-    vtkIdType cellId, vtkCellData * outCd) VTK_OVERRIDE;
-  int EvaluatePosition (double x[3], double *closestPoint,
-    int &subId, double pcoords[3], double &dist2, double *weights) VTK_OVERRIDE;
-  void EvaluateLocation (int &subId, double pcoords[3],
-                         double x[3], double *weights) VTK_OVERRIDE;
-  int Triangulate (int index, vtkIdList * ptIds, vtkPoints * pts) VTK_OVERRIDE;
-  void Derivatives (int subId, double pcoords[3], double *values,
-                    int dim, double *derivs) VTK_OVERRIDE;
-  double *GetParametricCoords () VTK_OVERRIDE;
+  int CellBoundary(int subId, const double pcoords[3], vtkIdList* pts) override;
+  void Contour(double value, vtkDataArray* cellScalars, vtkIncrementalPointLocator* locator,
+    vtkCellArray* verts, vtkCellArray* lines, vtkCellArray* polys, vtkPointData* inPd,
+    vtkPointData* outPd, vtkCellData* inCd, vtkIdType cellId, vtkCellData* outCd) override;
+  int EvaluatePosition(const double x[3], double* closestPoint, int& subId, double pcoords[3],
+    double& dist2, double* weights) override;
+  void EvaluateLocation(int& subId, const double pcoords[3], double x[3], double* weights) override;
+  int Triangulate(int index, vtkIdList* ptIds, vtkPoints* pts) override;
+  void Derivatives(
+    int subId, const double pcoords[3], const double* values, int dim, double* derivs) override;
+  double* GetParametricCoords() override;
 
   /**
    * Clip this triquadratic hexahedron using scalar value provided. Like
    * contouring, except that it cuts the hex to produce linear
    * tetrahedron.
    */
-  void Clip (double value, vtkDataArray * cellScalars,
-       vtkIncrementalPointLocator * locator, vtkCellArray * tetras,
-       vtkPointData * inPd, vtkPointData * outPd,
-       vtkCellData * inCd, vtkIdType cellId, vtkCellData * outCd,
-       int insideOut) VTK_OVERRIDE;
+  void Clip(double value, vtkDataArray* cellScalars, vtkIncrementalPointLocator* locator,
+    vtkCellArray* tetras, vtkPointData* inPd, vtkPointData* outPd, vtkCellData* inCd,
+    vtkIdType cellId, vtkCellData* outCd, int insideOut) override;
 
   /**
    * Line-edge intersection. Intersection has to occur within [0,1] parametric
    * coordinates and with specified tolerance.
    */
-  int IntersectWithLine (double p1[3], double p2[3], double tol, double &t,
-    double x[3], double pcoords[3], int &subId) VTK_OVERRIDE;
+  int IntersectWithLine(const double p1[3], const double p2[3], double tol, double& t, double x[3],
+    double pcoords[3], int& subId) override;
 
-  /**
-   * @deprecated Replaced by vtkTriQuadraticHexahedron::InterpolateFunctions as of VTK 5.2
-   */
-  static void InterpolationFunctions (double pcoords[3], double weights[27]);
-  /**
-   * @deprecated Replaced by vtkTriQuadraticHexahedron::InterpolateDerivs as of VTK 5.2
-   */
-  static void InterpolationDerivs (double pcoords[3], double derivs[81]);
+  static void InterpolationFunctions(const double pcoords[3], double weights[27]);
+  static void InterpolationDerivs(const double pcoords[3], double derivs[81]);
   //@{
   /**
    * Compute the interpolation functions/derivatives
    * (aka shape functions/derivatives)
    */
-  void InterpolateFunctions (double pcoords[3], double weights[27]) VTK_OVERRIDE
+  void InterpolateFunctions(const double pcoords[3], double weights[27]) override
   {
-    vtkTriQuadraticHexahedron::InterpolationFunctions(pcoords,weights);
+    vtkTriQuadraticHexahedron::InterpolationFunctions(pcoords, weights);
   }
-  void InterpolateDerivs (double pcoords[3], double derivs[81]) VTK_OVERRIDE
+  void InterpolateDerivs(const double pcoords[3], double derivs[81]) override
   {
-    vtkTriQuadraticHexahedron::InterpolationDerivs(pcoords,derivs);
+    vtkTriQuadraticHexahedron::InterpolationDerivs(pcoords, derivs);
   }
   //@}
   //@{
   /**
    * Return the ids of the vertices defining edge/face (`edgeId`/`faceId').
    * Ids are related to the cell, not to the dataset.
+   *
+   * @note The return type changed. It used to be int*, it is now const vtkIdType*.
+   * This is so ids are unified between vtkCell and vtkPoints.
    */
-  static int *GetEdgeArray(int edgeId);
-  static int *GetFaceArray(int faceId);
+  static const vtkIdType* GetEdgeArray(vtkIdType edgeId);
+  static const vtkIdType* GetFaceArray(vtkIdType faceId);
   //@}
 
   /**
@@ -168,20 +160,20 @@ public:
    * matrix. Returns 9 elements of 3x3 inverse Jacobian plus interpolation
    * function derivatives.
    */
-  void JacobianInverse (double pcoords[3], double **inverse, double derivs[81]);
+  void JacobianInverse(const double pcoords[3], double** inverse, double derivs[81]);
 
 protected:
-  vtkTriQuadraticHexahedron ();
-  ~vtkTriQuadraticHexahedron () VTK_OVERRIDE;
+  vtkTriQuadraticHexahedron();
+  ~vtkTriQuadraticHexahedron() override;
 
-  vtkQuadraticEdge *Edge;
-  vtkBiQuadraticQuad *Face;
-  vtkHexahedron *Hex;
-  vtkDoubleArray *Scalars;
+  vtkQuadraticEdge* Edge;
+  vtkBiQuadraticQuad* Face;
+  vtkHexahedron* Hex;
+  vtkDoubleArray* Scalars;
 
 private:
-  vtkTriQuadraticHexahedron (const vtkTriQuadraticHexahedron &) VTK_DELETE_FUNCTION;
-  void operator = (const vtkTriQuadraticHexahedron &) VTK_DELETE_FUNCTION;
+  vtkTriQuadraticHexahedron(const vtkTriQuadraticHexahedron&) = delete;
+  void operator=(const vtkTriQuadraticHexahedron&) = delete;
 };
 
 #endif
