@@ -22,13 +22,13 @@
  * as well as accept a pipeline request using the UPDATE_MEMBER key.
  * Note that it is expected that all ensemble members produce data of the
  * same type.
-*/
+ */
 
 #ifndef vtkEnsembleSource_h
 #define vtkEnsembleSource_h
 
-#include "vtkCommonExecutionModelModule.h" // For export macro
 #include "vtkAlgorithm.h"
+#include "vtkCommonExecutionModelModule.h" // For export macro
 
 struct vtkEnsembleSourceInternal;
 class vtkTable;
@@ -39,9 +39,9 @@ class vtkInformationIntegerKey;
 class VTKCOMMONEXECUTIONMODEL_EXPORT vtkEnsembleSource : public vtkAlgorithm
 {
 public:
-  static vtkEnsembleSource *New();
-  vtkTypeMacro(vtkEnsembleSource,vtkAlgorithm);
-  void PrintSelf(ostream& os, vtkIndent indent) VTK_OVERRIDE;
+  static vtkEnsembleSource* New();
+  vtkTypeMacro(vtkEnsembleSource, vtkAlgorithm);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
   /**
    * Add an algorithm (source) that will produce the next ensemble member.
@@ -90,16 +90,15 @@ public:
 
 protected:
   vtkEnsembleSource();
-  ~vtkEnsembleSource() VTK_OVERRIDE;
+  ~vtkEnsembleSource() override;
 
   static vtkInformationIntegerKey* DATA_MEMBER();
 
   friend class vtkInformationEnsembleMemberRequestKey;
 
-  int ProcessRequest(vtkInformation *request,
-                             vtkInformationVector **inputVector,
-                             vtkInformationVector *outputVector) VTK_OVERRIDE;
-  int FillOutputPortInformation(int, vtkInformation*) VTK_OVERRIDE;
+  vtkTypeBool ProcessRequest(vtkInformation* request, vtkInformationVector** inputVector,
+    vtkInformationVector* outputVector) override;
+  int FillOutputPortInformation(int, vtkInformation*) override;
 
   vtkAlgorithm* GetCurrentReader(vtkInformation*);
 
@@ -109,8 +108,8 @@ protected:
   vtkTable* MetaData;
 
 private:
-  vtkEnsembleSource(const vtkEnsembleSource&) VTK_DELETE_FUNCTION;
-  void operator=(const vtkEnsembleSource&) VTK_DELETE_FUNCTION;
+  vtkEnsembleSource(const vtkEnsembleSource&) = delete;
+  void operator=(const vtkEnsembleSource&) = delete;
 };
 
 #endif
