@@ -15,22 +15,22 @@
 #include "vtkAmoebaMinimizer.h"
 #include "vtkObjectFactory.h"
 
-#define  N_STEPS_NO_VALUE_IMPROVEMENT  2
-#define  N_STEPS_NO_PARAM_IMPROVEMENT  18
+#define N_STEPS_NO_VALUE_IMPROVEMENT 2
+#define N_STEPS_NO_PARAM_IMPROVEMENT 18
 
 vtkStandardNewMacro(vtkAmoebaMinimizer);
 
 //----------------------------------------------------------------------------
 vtkAmoebaMinimizer::vtkAmoebaMinimizer()
 {
-  this->Function = NULL;
-  this->FunctionArg = NULL;
-  this->FunctionArgDelete = NULL;
+  this->Function = nullptr;
+  this->FunctionArg = nullptr;
+  this->FunctionArgDelete = nullptr;
 
   this->NumberOfParameters = 0;
-  this->ParameterNames = NULL;
-  this->ParameterValues = NULL;
-  this->ParameterScales = NULL;
+  this->ParameterNames = nullptr;
+  this->ParameterValues = nullptr;
+  this->ParameterScales = nullptr;
 
   this->FunctionValue = 0.0;
 
@@ -44,9 +44,9 @@ vtkAmoebaMinimizer::vtkAmoebaMinimizer()
   this->FunctionEvaluations = 0;
 
   // specific to the amoeba
-  this->AmoebaVertices = NULL;
-  this->AmoebaValues = NULL;
-  this->AmoebaSum = NULL;
+  this->AmoebaVertices = nullptr;
+  this->AmoebaValues = nullptr;
+  this->AmoebaSum = nullptr;
   this->AmoebaSize = 0;
   this->AmoebaHighValue = 0;
   this->AmoebaNStepsNoImprovement = 0;
@@ -61,23 +61,23 @@ vtkAmoebaMinimizer::~vtkAmoebaMinimizer()
   {
     (*this->FunctionArgDelete)(this->FunctionArg);
   }
-  this->FunctionArg = NULL;
-  this->FunctionArgDelete = NULL;
-  this->Function = NULL;
+  this->FunctionArg = nullptr;
+  this->FunctionArgDelete = nullptr;
+  this->Function = nullptr;
 
   if (this->ParameterNames)
   {
     for (int i = 0; i < this->NumberOfParameters; i++)
     {
-      delete [] this->ParameterNames[i];
+      delete[] this->ParameterNames[i];
     }
-    delete [] this->ParameterNames;
-    this->ParameterNames = NULL;
+    delete[] this->ParameterNames;
+    this->ParameterNames = nullptr;
   }
-  delete [] this->ParameterValues;
-  this->ParameterValues = NULL;
-  delete [] this->ParameterScales;
-  this->ParameterScales = NULL;
+  delete[] this->ParameterValues;
+  this->ParameterValues = nullptr;
+  delete[] this->ParameterScales;
+  this->ParameterScales = nullptr;
 
   this->NumberOfParameters = 0;
 }
@@ -94,7 +94,7 @@ void vtkAmoebaMinimizer::PrintSelf(ostream& os, vtkIndent indent)
     os << indent << "ParameterValues: \n";
     for (i = 0; i < this->NumberOfParameters; i++)
     {
-      const char *name = this->GetParameterName(i);
+      const char* name = this->GetParameterName(i);
       os << indent << "  ";
       if (name)
       {
@@ -110,7 +110,7 @@ void vtkAmoebaMinimizer::PrintSelf(ostream& os, vtkIndent indent)
     os << indent << "ParameterScales: \n";
     for (i = 0; i < this->NumberOfParameters; i++)
     {
-      const char *name = this->GetParameterName(i);
+      const char* name = this->GetParameterName(i);
       os << indent << "  ";
       if (name)
       {
@@ -125,8 +125,7 @@ void vtkAmoebaMinimizer::PrintSelf(ostream& os, vtkIndent indent)
   }
 
   os << indent << "FunctionValue: " << this->GetFunctionValue() << "\n";
-  os << indent << "FunctionEvaluations: " << this->GetFunctionEvaluations()
-     << "\n";
+  os << indent << "FunctionEvaluations: " << this->GetFunctionEvaluations() << "\n";
   os << indent << "Iterations: " << this->GetIterations() << "\n";
   os << indent << "MaxIterations: " << this->GetMaxIterations() << "\n";
   os << indent << "Tolerance: " << this->GetTolerance() << "\n";
@@ -136,9 +135,9 @@ void vtkAmoebaMinimizer::PrintSelf(ostream& os, vtkIndent indent)
 }
 
 //----------------------------------------------------------------------------
-void vtkAmoebaMinimizer::SetFunction(void (*f)(void *), void *arg)
+void vtkAmoebaMinimizer::SetFunction(void (*f)(void*), void* arg)
 {
-  if ( f != this->Function || arg != this->FunctionArg )
+  if (f != this->Function || arg != this->FunctionArg)
   {
     // delete the current arg if there is one and a delete meth
     if ((this->FunctionArg) && (this->FunctionArgDelete))
@@ -152,9 +151,9 @@ void vtkAmoebaMinimizer::SetFunction(void (*f)(void *), void *arg)
 }
 
 //----------------------------------------------------------------------------
-void vtkAmoebaMinimizer::SetFunctionArgDelete(void (*f)(void *))
+void vtkAmoebaMinimizer::SetFunctionArgDelete(void (*f)(void*))
 {
-  if ( f != this->FunctionArgDelete)
+  if (f != this->FunctionArgDelete)
   {
     this->FunctionArgDelete = f;
     this->Modified();
@@ -162,11 +161,11 @@ void vtkAmoebaMinimizer::SetFunctionArgDelete(void (*f)(void *))
 }
 
 //----------------------------------------------------------------------------
-double vtkAmoebaMinimizer::GetParameterValue(const char *name)
+double vtkAmoebaMinimizer::GetParameterValue(const char* name)
 {
   for (int i = 0; i < this->NumberOfParameters; i++)
   {
-    if (this->ParameterNames[i] && strcmp(name,this->ParameterNames[i]) == 0)
+    if (this->ParameterNames[i] && strcmp(name, this->ParameterNames[i]) == 0)
     {
       return this->ParameterValues[i];
     }
@@ -176,13 +175,13 @@ double vtkAmoebaMinimizer::GetParameterValue(const char *name)
 }
 
 //----------------------------------------------------------------------------
-void vtkAmoebaMinimizer::SetParameterValue(const char *name, double val)
+void vtkAmoebaMinimizer::SetParameterValue(const char* name, double val)
 {
   int i;
 
   for (i = 0; i < this->NumberOfParameters; i++)
   {
-    if (this->ParameterNames[i] && strcmp(name,this->ParameterNames[i]) == 0)
+    if (this->ParameterNames[i] && strcmp(name, this->ParameterNames[i]) == 0)
     {
       break;
     }
@@ -192,8 +191,8 @@ void vtkAmoebaMinimizer::SetParameterValue(const char *name, double val)
 
   if (!this->ParameterNames[i])
   {
-    char *cp = new char[strlen(name)+8];
-    strcpy(cp,name);
+    char* cp = new char[strlen(name) + 8];
+    strcpy(cp, name);
     this->ParameterNames[i] = cp;
   }
 }
@@ -215,21 +214,21 @@ void vtkAmoebaMinimizer::SetParameterValue(int i, double val)
 
   int n = this->NumberOfParameters + 1;
 
-  char **newParameterNames = new char *[n];
-  double *newParameterValues = new double[n];
-  double *newParameterScales = new double[n];
+  char** newParameterNames = new char*[n];
+  double* newParameterValues = new double[n];
+  double* newParameterScales = new double[n];
 
   for (int j = 0; j < this->NumberOfParameters; j++)
   {
     newParameterNames[j] = this->ParameterNames[j];
-    this->ParameterNames[j] = NULL; // or else it will be deleted in Initialize
+    this->ParameterNames[j] = nullptr; // or else it will be deleted in Initialize
     newParameterValues[j] = this->ParameterValues[j];
     newParameterScales[j] = this->ParameterScales[j];
   }
 
-  newParameterNames[n-1] = 0;
-  newParameterValues[n-1] = val;
-  newParameterScales[n-1] = 1.0;
+  newParameterNames[n - 1] = nullptr;
+  newParameterValues[n - 1] = val;
+  newParameterScales[n - 1] = 1.0;
 
   this->Initialize();
 
@@ -243,11 +242,11 @@ void vtkAmoebaMinimizer::SetParameterValue(int i, double val)
 }
 
 //----------------------------------------------------------------------------
-double vtkAmoebaMinimizer::GetParameterScale(const char *name)
+double vtkAmoebaMinimizer::GetParameterScale(const char* name)
 {
   for (int i = 0; i < this->NumberOfParameters; i++)
   {
-    if (this->ParameterNames[i] && strcmp(name,this->ParameterNames[i]) == 0)
+    if (this->ParameterNames[i] && strcmp(name, this->ParameterNames[i]) == 0)
     {
       return this->ParameterScales[i];
     }
@@ -257,11 +256,11 @@ double vtkAmoebaMinimizer::GetParameterScale(const char *name)
 }
 
 //----------------------------------------------------------------------------
-void vtkAmoebaMinimizer::SetParameterScale(const char *name, double scale)
+void vtkAmoebaMinimizer::SetParameterScale(const char* name, double scale)
 {
   for (int i = 0; i < this->NumberOfParameters; i++)
   {
-    if (this->ParameterNames[i] && strcmp(name,this->ParameterNames[i]) == 0)
+    if (this->ParameterNames[i] && strcmp(name, this->ParameterNames[i]) == 0)
     {
       this->SetParameterScale(i, scale);
       return;
@@ -294,15 +293,15 @@ void vtkAmoebaMinimizer::Initialize()
   {
     for (int i = 0; i < this->NumberOfParameters; i++)
     {
-      delete [] this->ParameterNames[i];
+      delete[] this->ParameterNames[i];
     }
-    delete [] this->ParameterNames;
-    this->ParameterNames = 0;
+    delete[] this->ParameterNames;
+    this->ParameterNames = nullptr;
   }
-  delete [] this->ParameterValues;
-  this->ParameterValues = 0;
-  delete [] this->ParameterScales;
-  this->ParameterScales = 0;
+  delete[] this->ParameterValues;
+  this->ParameterValues = nullptr;
+  delete[] this->ParameterScales;
+  this->ParameterScales = nullptr;
 
   this->NumberOfParameters = 0;
   this->Iterations = 0;
@@ -327,28 +326,28 @@ int vtkAmoebaMinimizer::CheckParameterTolerance()
 {
   int n = this->NumberOfParameters;
 
-  double *vertex0 = this->AmoebaVertices[0];
-  double *scales = this->ParameterScales;
+  double* vertex0 = this->AmoebaVertices[0];
+  double* scales = this->ParameterScales;
   double size = 0;
 
   for (int i = 1; i <= n; i++)
   {
-    double *vertex = this->AmoebaVertices[i];
+    double* vertex = this->AmoebaVertices[i];
     for (int j = 0; j < n; j++)
     {
-      double d = fabs((vertex[j] - vertex0[j])/scales[j]);
+      double d = fabs((vertex[j] - vertex0[j]) / scales[j]);
       size = ((d < size) ? size : d);
     }
   }
 
   if (size != this->AmoebaSize)
   {
-    this->AmoebaNStepsNoImprovement = N_STEPS_NO_VALUE_IMPROVEMENT-1;
+    this->AmoebaNStepsNoImprovement = N_STEPS_NO_VALUE_IMPROVEMENT - 1;
   }
   this->AmoebaSize = size;
   // if amoeba is static, only make a set number of tries
   if (this->AmoebaNStepsNoImprovement >
-      (N_STEPS_NO_VALUE_IMPROVEMENT + N_STEPS_NO_PARAM_IMPROVEMENT))
+    (N_STEPS_NO_VALUE_IMPROVEMENT + N_STEPS_NO_PARAM_IMPROVEMENT))
   {
     return 1;
   }
@@ -363,7 +362,7 @@ int vtkAmoebaMinimizer::Iterate()
   {
     if (!this->Function)
     {
-      vtkErrorMacro("Iterate: Function is NULL");
+      vtkErrorMacro("Iterate: Function is nullptr");
       return 0;
     }
     this->InitializeAmoeba();
@@ -388,7 +387,7 @@ void vtkAmoebaMinimizer::Minimize()
   {
     if (!this->Function)
     {
-      vtkErrorMacro("Minimize: Function is NULL");
+      vtkErrorMacro("Minimize: Function is nullptr");
       return;
     }
     this->InitializeAmoeba();
@@ -444,16 +443,14 @@ void vtkAmoebaMinimizer::Minimize()
 @MODIFIED   :         2002    David Gobbi
 ---------------------------------------------------------------------------- */
 
-#define  VTK_AMOEBA_SMALLEST  1.0e-20
+#define VTK_AMOEBA_SMALLEST 1.0e-20
 
-static  int  vtkAmoebaNumericallyClose(double  n1,
-                                       double  n2,
-                                       double  threshold_ratio )
+static int vtkAmoebaNumericallyClose(double n1, double n2, double threshold_ratio)
 {
-  double  avg, diff, abs_n1, abs_n2;
+  double avg, diff, abs_n1, abs_n2;
 
   diff = n1 - n2;
-  if( diff < 0.0 )
+  if (diff < 0.0)
   {
     diff = -diff;
   }
@@ -461,24 +458,24 @@ static  int  vtkAmoebaNumericallyClose(double  n1,
   abs_n1 = (n1 < 0.0 ? -n1 : n1);
   abs_n2 = (n2 < 0.0 ? -n2 : n2);
 
-  if( abs_n1 < VTK_AMOEBA_SMALLEST || abs_n2 < VTK_AMOEBA_SMALLEST )
+  if (abs_n1 < VTK_AMOEBA_SMALLEST || abs_n2 < VTK_AMOEBA_SMALLEST)
   {
-    return( abs_n1 < threshold_ratio && abs_n2 < threshold_ratio );
+    return (abs_n1 < threshold_ratio && abs_n2 < threshold_ratio);
   }
 
   avg = (n1 + n2) / 2.0;
 
-  if( avg == 0.0 )
+  if (avg == 0.0)
   {
-    return( diff <= threshold_ratio );
+    return (diff <= threshold_ratio);
   }
 
-  if( avg < 0.0 )
+  if (avg < 0.0)
   {
     avg = -avg;
   }
 
-  return( (diff / avg) <= threshold_ratio );
+  return ((diff / avg) <= threshold_ratio);
 }
 
 /* ----------------------------- MNI Header -----------------------------------
@@ -494,23 +491,23 @@ static  int  vtkAmoebaNumericallyClose(double  n1,
 @MODIFIED   :         2002    David Gobbi
 ---------------------------------------------------------------------------- */
 
-void  vtkAmoebaMinimizer::InitializeAmoeba()
+void vtkAmoebaMinimizer::InitializeAmoeba()
 {
-  int    i, j;
+  int i, j;
 
   this->TerminateAmoeba();
 
   int n_parameters = this->NumberOfParameters;
   this->AmoebaNStepsNoImprovement = 0;
-  this->AmoebaVertices = new double *[n_parameters+1];
-  this->AmoebaVertices[0] = new double[n_parameters*(n_parameters+1)];
+  this->AmoebaVertices = new double*[n_parameters + 1];
+  this->AmoebaVertices[0] = new double[n_parameters * (n_parameters + 1)];
 
-  for( i = 1 ; i < n_parameters+1 ; i++)
+  for (i = 1; i < n_parameters + 1; i++)
   {
-    this->AmoebaVertices[i] = this->AmoebaVertices[i-1] + n_parameters;
+    this->AmoebaVertices[i] = this->AmoebaVertices[i - 1] + n_parameters;
   }
 
-  this->AmoebaValues = new double[n_parameters+1];
+  this->AmoebaValues = new double[n_parameters + 1];
 
   this->AmoebaSum = new double[n_parameters];
 
@@ -519,22 +516,21 @@ void  vtkAmoebaMinimizer::InitializeAmoeba()
     this->AmoebaSum[j] = 0.0;
   }
 
-  for( i = 0 ; i < n_parameters+1 ; i++ )
+  for (i = 0; i < n_parameters + 1; i++)
   {
-    for( j = 0; j < n_parameters ; j++ )
+    for (j = 0; j < n_parameters; j++)
     {
       this->AmoebaVertices[i][j] = this->ParameterValues[j];
-      if( i > 0 && j == i - 1 )
+      if (i > 0 && j == i - 1)
       {
-        this->AmoebaVertices[i][j] =
-          this->ParameterValues[j] + this->ParameterScales[j];
+        this->AmoebaVertices[i][j] = this->ParameterValues[j] + this->ParameterScales[j];
       }
       this->AmoebaSum[j] += this->ParameterValues[j];
     }
   }
-  for( i = 0 ; i < n_parameters+1 ; i++ )
+  for (i = 0; i < n_parameters + 1; i++)
   {
-    for( j = 0; j < n_parameters; j++ )
+    for (j = 0; j < n_parameters; j++)
     {
       this->ParameterValues[j] = this->AmoebaVertices[i][j];
     }
@@ -542,7 +538,7 @@ void  vtkAmoebaMinimizer::InitializeAmoeba()
     this->AmoebaValues[i] = this->FunctionValue;
   }
 
-  for ( j = 0 ; j < n_parameters ; j++ )
+  for (j = 0; j < n_parameters; j++)
   {
     this->ParameterValues[j] = this->AmoebaVertices[0][j];
   }
@@ -564,18 +560,18 @@ void  vtkAmoebaMinimizer::InitializeAmoeba()
 
 void vtkAmoebaMinimizer::GetAmoebaParameterValues()
 {
-  int   i, j, low;
+  int i, j, low;
 
   low = 0;
-  for( i = 1 ; i < this->NumberOfParameters+1 ; i++ )
+  for (i = 1; i < this->NumberOfParameters + 1; i++)
   {
-    if( this->AmoebaValues[i] < this->AmoebaValues[low] )
+    if (this->AmoebaValues[i] < this->AmoebaValues[low])
     {
       low = i;
     }
   }
 
-  for( j = 0 ; j < this->NumberOfParameters ; j++ )
+  for (j = 0; j < this->NumberOfParameters; j++)
   {
     this->ParameterValues[j] = this->AmoebaVertices[low][j];
   }
@@ -596,18 +592,18 @@ void vtkAmoebaMinimizer::GetAmoebaParameterValues()
 @MODIFIED   :         2002    David Gobbi
 ---------------------------------------------------------------------------- */
 
-void  vtkAmoebaMinimizer::TerminateAmoeba()
+void vtkAmoebaMinimizer::TerminateAmoeba()
 {
   if (this->AmoebaVertices)
   {
-    delete [] this->AmoebaVertices[0];
-    delete [] this->AmoebaVertices;
-    this->AmoebaVertices = NULL;
+    delete[] this->AmoebaVertices[0];
+    delete[] this->AmoebaVertices;
+    this->AmoebaVertices = nullptr;
   }
-  delete [] this->AmoebaValues;
-  this->AmoebaValues = NULL;
-  delete [] this->AmoebaSum;
-  this->AmoebaSum = NULL;
+  delete[] this->AmoebaValues;
+  this->AmoebaValues = nullptr;
+  delete[] this->AmoebaSum;
+  this->AmoebaSum = nullptr;
 }
 
 /* ----------------------------- MNI Header -----------------------------------
@@ -628,20 +624,18 @@ void  vtkAmoebaMinimizer::TerminateAmoeba()
 @MODIFIED   :         2002    David Gobbi
 ---------------------------------------------------------------------------- */
 
-double  vtkAmoebaMinimizer::TryAmoeba(double  sum[],
-                                      int     high,
-                                      double  fac )
+double vtkAmoebaMinimizer::TryAmoeba(double sum[], int high, double fac)
 {
-  int    j;
+  int j;
   double y_try, fac1, fac2;
-  double  *parameters;
+  double* parameters;
 
   parameters = this->ParameterValues;
 
   fac1 = (1.0 - fac) / this->NumberOfParameters;
   fac2 = fac - fac1;
 
-  for( j = 0 ; j < this->NumberOfParameters ; j++ )
+  for (j = 0; j < this->NumberOfParameters; j++)
   {
     parameters[j] = (sum[j] * fac1 + this->AmoebaVertices[high][j] * fac2);
   }
@@ -649,17 +643,17 @@ double  vtkAmoebaMinimizer::TryAmoeba(double  sum[],
   this->EvaluateFunction();
   y_try = this->FunctionValue;
 
-  if( y_try < this->AmoebaValues[high] )
+  if (y_try < this->AmoebaValues[high])
   {
     this->AmoebaValues[high] = y_try;
-    for( j = 0 ; j < this->NumberOfParameters ; j++ )
+    for (j = 0; j < this->NumberOfParameters; j++)
     {
       sum[j] += parameters[j] - this->AmoebaVertices[high][j];
       this->AmoebaVertices[high][j] = parameters[j];
     }
   }
 
-  return( y_try );
+  return (y_try);
 }
 
 /* ----------------------------- MNI Header -----------------------------------
@@ -672,7 +666,7 @@ double  vtkAmoebaMinimizer::TryAmoeba(double  sum[],
               numerically significant improvement has been found recently.
               Even if it returns 0, you can keep calling this function,
               since it may be contracting with no improvement, but will
-              eventually shrink small enough to get an improvment.
+              eventually shrink small enough to get an improvement.
 @METHOD     :
 @GLOBALS    :
 @CALLS      :
@@ -682,13 +676,13 @@ double  vtkAmoebaMinimizer::TryAmoeba(double  sum[],
 
 int vtkAmoebaMinimizer::PerformAmoeba()
 {
-  int      i, j, low, high, next_high;
-  double   y_try, y_save;
-  int      improvement_found;
+  int i, j, low, high, next_high;
+  double y_try, y_save;
+  int improvement_found;
 
   improvement_found = 1;
 
-  if( this->AmoebaValues[0] > this->AmoebaValues[1] )
+  if (this->AmoebaValues[0] > this->AmoebaValues[1])
   {
     high = 0;
     next_high = 1;
@@ -701,30 +695,28 @@ int vtkAmoebaMinimizer::PerformAmoeba()
 
   low = next_high;
 
-  for( i = 2 ; i < this->NumberOfParameters+1 ; i++ )
+  for (i = 2; i < this->NumberOfParameters + 1; i++)
   {
-    if( this->AmoebaValues[i] < this->AmoebaValues[low] )
+    if (this->AmoebaValues[i] < this->AmoebaValues[low])
     {
       low = i;
     }
-    else if( this->AmoebaValues[i] > this->AmoebaValues[high] )
+    else if (this->AmoebaValues[i] > this->AmoebaValues[high])
     {
       next_high = high;
       high = i;
     }
-    else if( this->AmoebaValues[i] > this->AmoebaValues[next_high] )
+    else if (this->AmoebaValues[i] > this->AmoebaValues[next_high])
     {
       next_high = i;
     }
   }
 
-  if( this->AmoebaValues[high] == this->AmoebaHighValue ||
-      vtkAmoebaNumericallyClose( this->AmoebaValues[low],
-                                 this->AmoebaValues[high],
-                                 this->Tolerance ) )
+  if (this->AmoebaValues[high] == this->AmoebaHighValue ||
+    vtkAmoebaNumericallyClose(this->AmoebaValues[low], this->AmoebaValues[high], this->Tolerance))
   {
     ++this->AmoebaNStepsNoImprovement;
-    if( this->AmoebaNStepsNoImprovement >= N_STEPS_NO_VALUE_IMPROVEMENT )
+    if (this->AmoebaNStepsNoImprovement >= N_STEPS_NO_VALUE_IMPROVEMENT)
     {
       improvement_found = 0;
     }
@@ -736,27 +728,27 @@ int vtkAmoebaMinimizer::PerformAmoeba()
 
   this->AmoebaHighValue = this->AmoebaValues[high];
 
-  y_try = this->TryAmoeba( this->AmoebaSum, high, -1.0 );
+  y_try = this->TryAmoeba(this->AmoebaSum, high, -1.0);
 
-  if( y_try <= this->AmoebaValues[low] )
+  if (y_try <= this->AmoebaValues[low])
   {
-    TryAmoeba( this->AmoebaSum, high, this->ExpansionRatio );
+    TryAmoeba(this->AmoebaSum, high, this->ExpansionRatio);
   }
-  else if( y_try >= this->AmoebaValues[next_high] )
+  else if (y_try >= this->AmoebaValues[next_high])
   {
     y_save = this->AmoebaValues[high];
-    y_try = TryAmoeba( this->AmoebaSum, high, this->ContractionRatio );
+    y_try = TryAmoeba(this->AmoebaSum, high, this->ContractionRatio);
 
-    if( y_try >= y_save )
+    if (y_try >= y_save)
     {
-      for( i = 0 ; i < this->NumberOfParameters+1 ; i++)
+      for (i = 0; i < this->NumberOfParameters + 1; i++)
       {
-        if( i != low )
+        if (i != low)
         {
-          for( j = 0 ; j < this->NumberOfParameters ; j++ )
+          for (j = 0; j < this->NumberOfParameters; j++)
           {
-            this->ParameterValues[j] = (this->AmoebaVertices[i][j] +
-                                        this->AmoebaVertices[low][j]) / 2.0;
+            this->ParameterValues[j] =
+              (this->AmoebaVertices[i][j] + this->AmoebaVertices[low][j]) / 2.0;
             this->AmoebaVertices[i][j] = this->ParameterValues[j];
           }
 
@@ -765,10 +757,10 @@ int vtkAmoebaMinimizer::PerformAmoeba()
         }
       }
 
-      for( j = 0 ; j < this->NumberOfParameters ; j++ )
+      for (j = 0; j < this->NumberOfParameters; j++)
       {
         this->AmoebaSum[j] = 0.0;
-        for( i = 0 ; i < this->NumberOfParameters+1 ; i++ )
+        for (i = 0; i < this->NumberOfParameters + 1; i++)
         {
           this->AmoebaSum[j] += this->AmoebaVertices[i][j];
         }
@@ -776,6 +768,5 @@ int vtkAmoebaMinimizer::PerformAmoeba()
     }
   }
 
-  return( improvement_found );
+  return (improvement_found);
 }
-
