@@ -16,10 +16,6 @@
 
 #include "vtkObjectFactory.h"
 
-#if defined(__BORLANDC__)
-# pragma warn -8012 /* signed/unsigned comparison */
-#endif
-
 // The VTK_SOCKET_FAKE_API definition is given to the compiler
 // command line by CMakeLists.txt if there is no real sockets
 // interface available.  When this macro is defined we simply make
@@ -30,86 +26,75 @@
 
 #ifndef VTK_SOCKET_FAKE_API
 #if defined(_WIN32) && !defined(__CYGWIN__)
-  #define VTK_WINDOWS_FULL
-  #include "vtkWindows.h"
+#define VTK_WINDOWS_FULL
+#include "vtkWindows.h"
 #else
-  #include <sys/types.h>
-  #include <sys/socket.h>
-  #include <netinet/in.h>
-  #include <netinet/tcp.h>
-  #include <arpa/inet.h>
-  #include <netdb.h>
-  #include <unistd.h>
-  #include <sys/time.h>
-  #include <errno.h>
-  #include <cstring>
-  #include <cstdio>
+#include <arpa/inet.h>
+#include <cerrno>
+#include <cstdio>
+#include <cstring>
+#include <netdb.h>
+#include <netinet/in.h>
+#include <netinet/tcp.h>
+#include <sys/socket.h>
+#include <sys/time.h>
+#include <sys/types.h>
+#include <unistd.h>
 #endif
 #endif
 
 #if defined(_WIN32) && !defined(__CYGWIN__)
 
 // TODO : document why we restrict to v1.1
-#define WSA_VERSION MAKEWORD(1,1)
+#define WSA_VERSION MAKEWORD(1, 1)
 
-#define vtkCloseSocketMacro(sock)      (closesocket(sock))
-#define vtkErrnoMacro                  (WSAGetLastError())
-#define vtkStrerrorMacro(_num)         (wsaStrerror(_num))
-#define vtkSocketErrorIdMacro(_id)     (WSA##_id)
-#define vtkSocketErrorReturnMacro      (SOCKET_ERROR)
+#define vtkCloseSocketMacro(sock) (closesocket(sock))
+#define vtkErrnoMacro (WSAGetLastError())
+#define vtkStrerrorMacro(_num) (wsaStrerror(_num))
+#define vtkSocketErrorIdMacro(_id) (WSA##_id)
+#define vtkSocketErrorReturnMacro (SOCKET_ERROR)
 
 #else
 
-#define vtkCloseSocketMacro(sock)      (close(sock))
-#define vtkErrnoMacro                  (errno)
-#define vtkStrerrorMacro(_num)         (strerror(_num))
-#define vtkSocketErrorIdMacro(_id)     (_id)
-#define vtkSocketErrorReturnMacro      (-1)
+#define vtkCloseSocketMacro(sock) (close(sock))
+#define vtkErrnoMacro (errno)
+#define vtkStrerrorMacro(_num) (strerror(_num))
+#define vtkSocketErrorIdMacro(_id) (_id)
+#define vtkSocketErrorReturnMacro (-1)
 
 #endif
 
 // This macro wraps a system function call(_call),
 // restarting the call in case it was interrupted
 // by a signal (EINTR).
-#define vtkRestartInterruptedSystemCallMacro(_call,_ret)\
-  do                                                    \
-  {                                                   \
-    (_ret)=(_call);                                     \
-  }                                                   \
-  while (((_ret)==vtkSocketErrorReturnMacro)            \
-    && (vtkErrnoMacro==vtkSocketErrorIdMacro(EINTR)));
+#define vtkRestartInterruptedSystemCallMacro(_call, _ret)                                          \
+  do                                                                                               \
+  {                                                                                                \
+    (_ret) = (_call);                                                                              \
+  } while (                                                                                        \
+    ((_ret) == vtkSocketErrorReturnMacro) && (vtkErrnoMacro == vtkSocketErrorIdMacro(EINTR)));
 
 // use when _str may be a null pointer but _fallback is not.
-#define vtkSafeStrMacro(_str,_fallback) ((_str)?(_str):(_fallback))
+#define vtkSafeStrMacro(_str, _fallback) ((_str) ? (_str) : (_fallback))
 
 // convert error number to string and report via vtkErrorMacro.
-#define vtkSocketErrorMacro(_eno, _message)             \
-  vtkErrorMacro(                                        \
-    << (_message)                                       \
-    << " "                                              \
-    << vtkSafeStrMacro(                                 \
-         vtkStrerrorMacro(_eno),                        \
-         "unknown error")                               \
-    << ".");
+#define vtkSocketErrorMacro(_eno, _message)                                                        \
+  vtkErrorMacro(<< (_message) << " " << vtkSafeStrMacro(vtkStrerrorMacro(_eno), "unknown error")   \
+                << ".");
 
 // convert error number to string and report via vtkGenericWarningMacro
-#define vtkSocketGenericErrorMacro(_message)            \
-  vtkGenericWarningMacro(                                 \
-    << (_message)                                       \
-    << " "                                              \
-    << vtkSafeStrMacro(                                 \
-         vtkStrerrorMacro(vtkErrnoMacro),               \
-         "unknown error")                               \
-    << ".");
+#define vtkSocketGenericErrorMacro(_message)                                                       \
+  vtkGenericWarningMacro(<< (_message) << " "                                                      \
+                         << vtkSafeStrMacro(vtkStrerrorMacro(vtkErrnoMacro), "unknown error")      \
+                         << ".");
 
 // on windows strerror doesn't handle socket error codes
 #if defined(_WIN32) && !defined(__CYGWIN__)
-static
-const char *wsaStrerror(int wsaeid)
+static const char* wsaStrerror(int wsaeid)
 {
-  static char buf[256]={'\0'};
+  static char buf[256] = { '\0' };
   int ok;
-  ok=FormatMessage(FORMAT_MESSAGE_FROM_SYSTEM,0,wsaeid,0,buf,256,0);
+  ok = FormatMessage(FORMAT_MESSAGE_FROM_SYSTEM, 0, wsaeid, 0, buf, 256, 0);
   if (!ok)
   {
     return 0;
@@ -139,7 +124,7 @@ int vtkSocket::CreateSocket()
 {
 #ifndef VTK_SOCKET_FAKE_API
   int sock;
-  vtkRestartInterruptedSystemCallMacro(socket(AF_INET,SOCK_STREAM, 0), sock);
+  vtkRestartInterruptedSystemCallMacro(socket(AF_INET, SOCK_STREAM, 0), sock);
   if (sock == vtkSocketErrorReturnMacro)
   {
     vtkSocketErrorMacro(vtkErrnoMacro, "Socket error in call to socket.");
@@ -150,8 +135,7 @@ int vtkSocket::CreateSocket()
   int on = 1;
   int iErr;
   vtkRestartInterruptedSystemCallMacro(
-    setsockopt(sock, IPPROTO_TCP, TCP_NODELAY, (char*)&on, sizeof(on)),
-    iErr);
+    setsockopt(sock, IPPROTO_TCP, TCP_NODELAY, (char*)&on, sizeof(on)), iErr);
   if (iErr == vtkSocketErrorReturnMacro)
   {
     vtkSocketErrorMacro(vtkErrnoMacro, "Socket error in call to setsockopt.");
@@ -181,16 +165,14 @@ int vtkSocket::BindSocket(int socketdescriptor, int port)
   server.sin_addr.s_addr = INADDR_ANY;
   server.sin_port = htons(port);
   // Allow the socket to be bound to an address that is already in use
-  int opt=1;
-  int iErr=~vtkSocketErrorReturnMacro;
+  int opt = 1;
+  int iErr = ~vtkSocketErrorReturnMacro;
 #ifdef _WIN32
   vtkRestartInterruptedSystemCallMacro(
-    setsockopt(socketdescriptor,SOL_SOCKET,SO_REUSEADDR,(char*)&opt,sizeof(int)),
-    iErr);
+    setsockopt(socketdescriptor, SOL_SOCKET, SO_REUSEADDR, (char*)&opt, sizeof(int)), iErr);
 #elif defined(VTK_HAVE_SO_REUSEADDR)
   vtkRestartInterruptedSystemCallMacro(
-    setsockopt(socketdescriptor,SOL_SOCKET,SO_REUSEADDR,(char*)&opt,sizeof(int)),
-    iErr);
+    setsockopt(socketdescriptor, SOL_SOCKET, SO_REUSEADDR, (char*)&opt, sizeof(int)), iErr);
 #endif
   if (iErr == vtkSocketErrorReturnMacro)
   {
@@ -199,8 +181,7 @@ int vtkSocket::BindSocket(int socketdescriptor, int port)
   }
 
   vtkRestartInterruptedSystemCallMacro(
-    bind(socketdescriptor,reinterpret_cast<sockaddr*>(&server),sizeof(server)),
-    iErr);
+    bind(socketdescriptor, reinterpret_cast<sockaddr*>(&server), sizeof(server)), iErr);
   if (iErr == vtkSocketErrorReturnMacro)
   {
     vtkSocketErrorMacro(vtkErrnoMacro, "Socket error in call to bind.");
@@ -226,8 +207,7 @@ int vtkSocket::Accept(int socketdescriptor)
   }
 
   int newDescriptor;
-  vtkRestartInterruptedSystemCallMacro(
-    accept(socketdescriptor, 0, 0), newDescriptor);
+  vtkRestartInterruptedSystemCallMacro(accept(socketdescriptor, nullptr, nullptr), newDescriptor);
   if (newDescriptor == vtkSocketErrorReturnMacro)
   {
     vtkSocketErrorMacro(vtkErrnoMacro, "Socket error in call to accept.");
@@ -270,7 +250,7 @@ int vtkSocket::Listen(int socketdescriptor)
 int vtkSocket::SelectSocket(int socketdescriptor, unsigned long msec)
 {
 #ifndef VTK_SOCKET_FAKE_API
-  if (socketdescriptor < 0 )
+  if (socketdescriptor < 0)
   {
     vtkErrorMacro("Invalid descriptor.");
     return -1;
@@ -281,11 +261,11 @@ int vtkSocket::SelectSocket(int socketdescriptor, unsigned long msec)
   do
   {
     struct timeval tval;
-    struct timeval* tvalptr = 0;
-    if (msec>0)
+    struct timeval* tvalptr = nullptr;
+    if (msec > 0)
     {
       tval.tv_sec = msec / 1000;
-      tval.tv_usec = (msec % 1000)*1000;
+      tval.tv_usec = (msec % 1000) * 1000;
       tvalptr = &tval;
     }
 
@@ -293,28 +273,24 @@ int vtkSocket::SelectSocket(int socketdescriptor, unsigned long msec)
     FD_SET(socketdescriptor, &rset);
 
     // block until socket is readable.
-    res = select(socketdescriptor+1, &rset, 0, 0, tvalptr);
-  }
-  while ((res == vtkSocketErrorReturnMacro)
-    && (vtkErrnoMacro == vtkSocketErrorIdMacro(EINTR)));
+    res = select(socketdescriptor + 1, &rset, nullptr, nullptr, tvalptr);
+  } while ((res == vtkSocketErrorReturnMacro) && (vtkErrnoMacro == vtkSocketErrorIdMacro(EINTR)));
 
   if (res == 0)
   {
     // time out
     return 0;
   }
-  else
-  if (res == vtkSocketErrorReturnMacro)
+  else if (res == vtkSocketErrorReturnMacro)
   {
     // error in the call
     vtkSocketErrorMacro(vtkErrnoMacro, "Socket error in call to select.");
     return -1;
   }
-  else
-  if (!FD_ISSET(socketdescriptor, &rset))
+  else if (!FD_ISSET(socketdescriptor, &rset))
   {
-     vtkErrorMacro("Socket error in select. Descriptor not selected.");
-     return -1;
+    vtkErrorMacro("Socket error in select. Descriptor not selected.");
+    return -1;
   }
 
   // NOTE: not checking for pending errors,these will be handled
@@ -330,8 +306,8 @@ int vtkSocket::SelectSocket(int socketdescriptor, unsigned long msec)
 }
 
 //-----------------------------------------------------------------------------
-int vtkSocket::SelectSockets(const int* sockets_to_select, int size,
-    unsigned long msec, int* selected_index)
+int vtkSocket::SelectSockets(
+  const int* sockets_to_select, int size, unsigned long msec, int* selected_index)
 {
 #ifndef VTK_SOCKET_FAKE_API
 
@@ -348,35 +324,32 @@ int vtkSocket::SelectSockets(const int* sockets_to_select, int size,
   do
   {
     struct timeval tval;
-    struct timeval* tvalptr = 0;
-    if (msec>0)
+    struct timeval* tvalptr = nullptr;
+    if (msec > 0)
     {
       tval.tv_sec = msec / 1000;
-      tval.tv_usec = msec % 1000;
+      tval.tv_usec = (msec % 1000) * 1000;
       tvalptr = &tval;
     }
 
     FD_ZERO(&rset);
     int max_fd = -1;
-    for (int i=0; i<size; i++)
+    for (int i = 0; i < size; i++)
     {
-      FD_SET(sockets_to_select[i],&rset);
+      FD_SET(sockets_to_select[i], &rset);
       max_fd = (sockets_to_select[i] > max_fd ? sockets_to_select[i] : max_fd);
     }
 
     // block until one socket is ready to read.
-    res = select(max_fd + 1, &rset, 0, 0, tvalptr);
-  }
-  while ((res == vtkSocketErrorReturnMacro)
-    && (vtkErrnoMacro == vtkSocketErrorIdMacro(EINTR)));
+    res = select(max_fd + 1, &rset, nullptr, nullptr, tvalptr);
+  } while ((res == vtkSocketErrorReturnMacro) && (vtkErrnoMacro == vtkSocketErrorIdMacro(EINTR)));
 
-  if (res==0)
+  if (res == 0)
   {
     // time out
     return 0;
   }
-  else
-  if (res == vtkSocketErrorReturnMacro)
+  else if (res == vtkSocketErrorReturnMacro)
   {
     // error in the call
     vtkSocketGenericErrorMacro("Socket error in call to select.");
@@ -384,9 +357,9 @@ int vtkSocket::SelectSockets(const int* sockets_to_select, int size,
   }
 
   // find the first socket which has some activity.
-  for (int i=0; i<size; i++)
+  for (int i = 0; i < size; i++)
   {
-    if ( FD_ISSET(sockets_to_select[i],&rset) )
+    if (FD_ISSET(sockets_to_select[i], &rset))
     {
       // NOTE: not checking for pending errors, these
       // will be handled in the next call to read/recv
@@ -423,7 +396,7 @@ int vtkSocket::Connect(int socketdescriptor, const char* hostName, int port)
   if (!hp)
   {
     unsigned long addr = inet_addr(hostName);
-    hp = gethostbyaddr((char *)&addr, sizeof(addr), AF_INET);
+    hp = gethostbyaddr((char*)&addr, sizeof(addr), AF_INET);
   }
   if (!hp)
   {
@@ -436,16 +409,14 @@ int vtkSocket::Connect(int socketdescriptor, const char* hostName, int port)
   memcpy(&name.sin_addr, hp->h_addr, hp->h_length);
   name.sin_port = htons(port);
 
-  int iErr
-    = connect(socketdescriptor, reinterpret_cast<sockaddr*>(&name),sizeof(name));
-  if ( (iErr == vtkSocketErrorReturnMacro )
-    && (vtkErrnoMacro == vtkSocketErrorIdMacro(EINTR)) )
+  int iErr = connect(socketdescriptor, reinterpret_cast<sockaddr*>(&name), sizeof(name));
+  if ((iErr == vtkSocketErrorReturnMacro) && (vtkErrnoMacro == vtkSocketErrorIdMacro(EINTR)))
   {
     // Restarting an interrupted connect call only works on linux,
     // other unix require a call to select which blocks until the
     // connection is complete.
     // See Stevens 2d ed, 15.4 p413, "interrupted connect"
-    iErr = this->SelectSocket(socketdescriptor,0);
+    iErr = this->SelectSocket(socketdescriptor, 0);
     if (iErr == -1)
     {
       // SelectSocket doesn't test for pending errors.
@@ -457,28 +428,23 @@ int vtkSocket::Connect(int socketdescriptor, const char* hostName, int port)
 #endif
 
       vtkRestartInterruptedSystemCallMacro(
-        getsockopt(socketdescriptor, SOL_SOCKET, SO_ERROR, (char *)&pendingErr, &pendingErrLen),
+        getsockopt(socketdescriptor, SOL_SOCKET, SO_ERROR, (char*)&pendingErr, &pendingErrLen),
         iErr);
       if (iErr == vtkSocketErrorReturnMacro)
       {
-        vtkSocketErrorMacro(
-          vtkErrnoMacro, "Socket error in call to getsockopt.");
+        vtkSocketErrorMacro(vtkErrnoMacro, "Socket error in call to getsockopt.");
         return -1;
       }
-      else
-      if (pendingErr)
+      else if (pendingErr)
       {
-        vtkSocketErrorMacro(
-          pendingErr, "Socket error pending from call to connect.");
+        vtkSocketErrorMacro(pendingErr, "Socket error pending from call to connect.");
         return -1;
       }
     }
   }
-  else
-  if (iErr == vtkSocketErrorReturnMacro)
+  else if (iErr == vtkSocketErrorReturnMacro)
   {
-    vtkSocketErrorMacro(
-      vtkErrnoMacro, "Socket error in call to connect.");
+    vtkSocketErrorMacro(vtkErrnoMacro, "Socket error in call to connect.");
     return -1;
   }
 
@@ -505,12 +471,10 @@ int vtkSocket::GetPort(int sock)
 
   int iErr;
   vtkRestartInterruptedSystemCallMacro(
-    getsockname(sock, reinterpret_cast<sockaddr*>(&sockinfo), &sizebuf),
-    iErr);
+    getsockname(sock, reinterpret_cast<sockaddr*>(&sockinfo), &sizebuf), iErr);
   if (iErr == vtkSocketErrorReturnMacro)
   {
-    vtkSocketErrorMacro(
-      vtkErrnoMacro, "Socket error in call to getsockname.");
+    vtkSocketErrorMacro(vtkErrnoMacro, "Socket error in call to getsockname.");
     return 0;
   }
   return ntohs(sockinfo.sin_port);
@@ -530,13 +494,10 @@ void vtkSocket::CloseSocket(int socketdescriptor)
     return;
   }
   int iErr;
-  vtkRestartInterruptedSystemCallMacro(
-    vtkCloseSocketMacro(socketdescriptor),
-    iErr);
+  vtkRestartInterruptedSystemCallMacro(vtkCloseSocketMacro(socketdescriptor), iErr);
   if (iErr == vtkSocketErrorReturnMacro)
   {
-    vtkSocketErrorMacro(
-      vtkErrnoMacro, "Socket error in call to close/closesocket.");
+    vtkSocketErrorMacro(vtkErrnoMacro, "Socket error in call to close/closesocket.");
   }
 #else
   static_cast<void>(socketdescriptor);
@@ -562,18 +523,17 @@ int vtkSocket::Send(const void* data, int length)
   int total = 0;
   do
   {
-    int flags=0;
+    int flags = 0;
     int nSent;
     vtkRestartInterruptedSystemCallMacro(
-      send(this->SocketDescriptor, buffer+total, length-total, flags),
-      nSent);
+      send(this->SocketDescriptor, buffer + total, length - total, flags), nSent);
     if (nSent == vtkSocketErrorReturnMacro)
     {
       vtkSocketErrorMacro(vtkErrnoMacro, "Socket error in call to send.");
       return 0;
     }
     total += nSent;
-  } while(total < length);
+  } while (total < length);
 
   return 1;
 #else
@@ -584,7 +544,7 @@ int vtkSocket::Send(const void* data, int length)
 }
 
 //-----------------------------------------------------------------------------
-int vtkSocket::Receive(void* data, int length, int readFully/*=1*/)
+int vtkSocket::Receive(void* data, int length, int readFully /*=1*/)
 {
 #ifndef VTK_SOCKET_FAKE_API
   if (!this->GetConnected())
@@ -594,7 +554,7 @@ int vtkSocket::Receive(void* data, int length, int readFully/*=1*/)
   }
 
 #if defined(_WIN32) && !defined(__CYGWIN__)
-  int trys = 0;
+  int tries = 0;
 #endif
 
   char* buffer = reinterpret_cast<char*>(data);
@@ -603,8 +563,7 @@ int vtkSocket::Receive(void* data, int length, int readFully/*=1*/)
   {
     int nRecvd;
     vtkRestartInterruptedSystemCallMacro(
-      recv(this->SocketDescriptor, buffer+total, length-total, 0),
-      nRecvd);
+      recv(this->SocketDescriptor, buffer + total, length - total, 0), nRecvd);
 
     if (nRecvd == 0)
     {
@@ -613,12 +572,11 @@ int vtkSocket::Receive(void* data, int length, int readFully/*=1*/)
     }
 
 #if defined(_WIN32) && !defined(__CYGWIN__)
-    if ((nRecvd == vtkSocketErrorReturnMacro)
-      && (WSAGetLastError() == WSAENOBUFS))
+    if ((nRecvd == vtkSocketErrorReturnMacro) && (WSAGetLastError() == WSAENOBUFS))
     {
       // On long messages, Windows recv sometimes fails with WSAENOBUFS, but
       // will work if you try again.
-      if ((trys++ < 1000))
+      if ((tries++ < 1000))
       {
         Sleep(1);
         continue;
@@ -629,8 +587,7 @@ int vtkSocket::Receive(void* data, int length, int readFully/*=1*/)
 #endif
 
     total += nRecvd;
-  }
-  while( readFully && (total < length));
+  } while (readFully && (total < length));
 
   return total;
 #else
