@@ -19,12 +19,14 @@
 #include "vtkCellArray.h"
 #include "vtkCellData.h"
 #include "vtkContourGrid.h"
+#include "vtkContourHelper.h"
 #include "vtkContourValues.h"
 #include "vtkCutter.h"
 #include "vtkGarbageCollector.h"
 #include "vtkGenericCell.h"
 #include "vtkGridSynchronizedTemplates3D.h"
 #include "vtkImageData.h"
+#include "vtkIncrementalPointLocator.h"
 #include "vtkInformation.h"
 #include "vtkInformationVector.h"
 #include "vtkMergePoints.h"
@@ -42,13 +44,11 @@
 #include "vtkSynchronizedTemplates3D.h"
 #include "vtkTimerLog.h"
 #include "vtkUniformGrid.h"
-#include "vtkIncrementalPointLocator.h"
-#include "vtkContourHelper.h"
 
 #include <cmath>
 
 vtkStandardNewMacro(vtkContourFilter);
-vtkCxxSetObjectMacro(vtkContourFilter,ScalarTree,vtkScalarTree);
+vtkCxxSetObjectMacro(vtkContourFilter, ScalarTree, vtkScalarTree);
 
 //-----------------------------------------------------------------------------
 // Construct object with initial range (0,1) and single contour value
@@ -64,10 +64,10 @@ vtkContourFilter::vtkContourFilter()
   this->ComputeGradients = 0;
   this->ComputeScalars = 1;
 
-  this->Locator = NULL;
+  this->Locator = nullptr;
 
   this->UseScalarTree = 0;
-  this->ScalarTree = NULL;
+  this->ScalarTree = nullptr;
 
   this->OutputPointsPrecision = DEFAULT_PRECISION;
 
@@ -83,33 +83,33 @@ vtkContourFilter::vtkContourFilter()
     &vtkContourFilter::InternalProgressCallbackFunction);
   this->InternalProgressCallbackCommand->SetClientData(this);
 
-  this->SynchronizedTemplates2D->AddObserver(vtkCommand::ProgressEvent,
-                                             this->InternalProgressCallbackCommand);
-  this->SynchronizedTemplates3D->AddObserver(vtkCommand::ProgressEvent,
-                                             this->InternalProgressCallbackCommand);
-  this->GridSynchronizedTemplates->AddObserver(vtkCommand::ProgressEvent,
-                                               this->InternalProgressCallbackCommand);
-  this->RectilinearSynchronizedTemplates->AddObserver(vtkCommand::ProgressEvent,
-                                                      this->InternalProgressCallbackCommand);
+  this->SynchronizedTemplates2D->AddObserver(
+    vtkCommand::ProgressEvent, this->InternalProgressCallbackCommand);
+  this->SynchronizedTemplates3D->AddObserver(
+    vtkCommand::ProgressEvent, this->InternalProgressCallbackCommand);
+  this->GridSynchronizedTemplates->AddObserver(
+    vtkCommand::ProgressEvent, this->InternalProgressCallbackCommand);
+  this->RectilinearSynchronizedTemplates->AddObserver(
+    vtkCommand::ProgressEvent, this->InternalProgressCallbackCommand);
 
   // by default process active point scalars
-  this->SetInputArrayToProcess(0,0,0,vtkDataObject::FIELD_ASSOCIATION_POINTS,
-                               vtkDataSetAttributes::SCALARS);
+  this->SetInputArrayToProcess(
+    0, 0, 0, vtkDataObject::FIELD_ASSOCIATION_POINTS, vtkDataSetAttributes::SCALARS);
 }
 
 //-----------------------------------------------------------------------------
 vtkContourFilter::~vtkContourFilter()
 {
   this->ContourValues->Delete();
-  if ( this->Locator )
+  if (this->Locator)
   {
     this->Locator->UnRegister(this);
-    this->Locator = NULL;
+    this->Locator = nullptr;
   }
-  if ( this->ScalarTree )
+  if (this->ScalarTree)
   {
     this->ScalarTree->Delete();
-    this->ScalarTree = NULL;
+    this->ScalarTree = nullptr;
   }
   this->SynchronizedTemplates2D->Delete();
   this->SynchronizedTemplates3D->Delete();
@@ -123,39 +123,35 @@ vtkContourFilter::~vtkContourFilter()
 // then this object is modified as well.
 vtkMTimeType vtkContourFilter::GetMTime()
 {
-  vtkMTimeType mTime=this->Superclass::GetMTime();
+  vtkMTimeType mTime = this->Superclass::GetMTime();
   vtkMTimeType time;
 
   if (this->ContourValues)
   {
     time = this->ContourValues->GetMTime();
-    mTime = ( time > mTime ? time : mTime );
+    mTime = (time > mTime ? time : mTime);
   }
   if (this->Locator)
   {
     time = this->Locator->GetMTime();
-    mTime = ( time > mTime ? time : mTime );
+    mTime = (time > mTime ? time : mTime);
   }
 
   return mTime;
 }
 
 //-----------------------------------------------------------------------------
-int vtkContourFilter::RequestUpdateExtent(vtkInformation* request,
-                                          vtkInformationVector** inputVector,
-                                          vtkInformationVector* outputVector)
+int vtkContourFilter::RequestUpdateExtent(
+  vtkInformation* request, vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
   vtkInformation* inInfo = inputVector[0]->GetInformationObject(0);
-  vtkDataSet *input =
-    vtkDataSet::SafeDownCast(inInfo->Get(vtkDataObject::DATA_OBJECT()));
+  vtkDataSet* input = vtkDataSet::SafeDownCast(inInfo->Get(vtkDataObject::DATA_OBJECT()));
 
-  int numContours=this->ContourValues->GetNumberOfContours();
-  double *values=this->ContourValues->GetValues();
+  vtkIdType numContours = this->ContourValues->GetNumberOfContours();
+  double* values = this->ContourValues->GetValues();
 
-  vtkInformation *fInfo =
-    vtkDataObject::GetActiveFieldInformation(inInfo,
-                                             vtkDataObject::FIELD_ASSOCIATION_POINTS,
-                                             vtkDataSetAttributes::SCALARS);
+  vtkInformation* fInfo = vtkDataObject::GetActiveFieldInformation(
+    inInfo, vtkDataObject::FIELD_ASSOCIATION_POINTS, vtkDataSetAttributes::SCALARS);
   int sType = VTK_DOUBLE;
   if (fInfo)
   {
@@ -164,11 +160,10 @@ int vtkContourFilter::RequestUpdateExtent(vtkInformation* request,
 
   // handle 2D images
   int i;
-  if (vtkImageData::SafeDownCast(input) && sType != VTK_BIT &&
-      !vtkUniformGrid::SafeDownCast(input))
+  if (vtkImageData::SafeDownCast(input) && sType != VTK_BIT && !vtkUniformGrid::SafeDownCast(input))
   {
     int dim = 3;
-    int *uExt = inInfo->Get(vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT());
+    int* uExt = inInfo->Get(vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT());
     if (uExt[0] == uExt[1])
     {
       --dim;
@@ -182,75 +177,72 @@ int vtkContourFilter::RequestUpdateExtent(vtkInformation* request,
       --dim;
     }
 
-    if ( dim == 2 )
+    if (dim == 2)
     {
       this->SynchronizedTemplates2D->SetNumberOfContours(numContours);
-      for (i=0; i < numContours; i++)
+      for (i = 0; i < numContours; i++)
       {
-        this->SynchronizedTemplates2D->SetValue(i,values[i]);
+        this->SynchronizedTemplates2D->SetValue(i, values[i]);
       }
       this->SynchronizedTemplates2D->SetComputeScalars(this->ComputeScalars);
-      return this->SynchronizedTemplates2D->
-        ProcessRequest(request,inputVector,outputVector);
+      return this->SynchronizedTemplates2D->ProcessRequest(request, inputVector, outputVector);
     }
     else if (dim == 3)
     {
       this->SynchronizedTemplates3D->SetNumberOfContours(numContours);
-      for (i=0; i < numContours; i++)
+      for (i = 0; i < numContours; i++)
       {
-        this->SynchronizedTemplates3D->SetValue(i,values[i]);
+        this->SynchronizedTemplates3D->SetValue(i, values[i]);
       }
       this->SynchronizedTemplates3D->SetComputeNormals(this->ComputeNormals);
       this->SynchronizedTemplates3D->SetComputeGradients(this->ComputeGradients);
       this->SynchronizedTemplates3D->SetComputeScalars(this->ComputeScalars);
       this->SynchronizedTemplates3D->SetGenerateTriangles(this->GenerateTriangles);
-      return this->SynchronizedTemplates3D->
-        ProcessRequest(request,inputVector,outputVector);
+      return this->SynchronizedTemplates3D->ProcessRequest(request, inputVector, outputVector);
     }
-  } //if image data
+  } // if image data
 
   // handle 3D RGrids
   if (vtkRectilinearGrid::SafeDownCast(input) && sType != VTK_BIT)
   {
-    int *uExt = inInfo->Get(vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT());
+    int* uExt = inInfo->Get(vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT());
     // if 3D
     if (uExt[0] < uExt[1] && uExt[2] < uExt[3] && uExt[4] < uExt[5])
     {
       this->RectilinearSynchronizedTemplates->SetNumberOfContours(numContours);
-      for (i=0; i < numContours; i++)
+      for (i = 0; i < numContours; i++)
       {
-        this->RectilinearSynchronizedTemplates->SetValue(i,values[i]);
+        this->RectilinearSynchronizedTemplates->SetValue(i, values[i]);
       }
       this->RectilinearSynchronizedTemplates->SetComputeNormals(this->ComputeNormals);
       this->RectilinearSynchronizedTemplates->SetComputeGradients(this->ComputeGradients);
       this->RectilinearSynchronizedTemplates->SetComputeScalars(this->ComputeScalars);
       this->RectilinearSynchronizedTemplates->SetGenerateTriangles(this->GenerateTriangles);
-      return this->RectilinearSynchronizedTemplates->
-        ProcessRequest(request,inputVector,outputVector);
+      return this->RectilinearSynchronizedTemplates->ProcessRequest(
+        request, inputVector, outputVector);
     }
-  } //if 3D RGrid
+  } // if 3D RGrid
 
   // handle 3D SGrids
   if (vtkStructuredGrid::SafeDownCast(input) && sType != VTK_BIT)
   {
-    int *uExt = inInfo->Get(vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT());
+    int* uExt = inInfo->Get(vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT());
     // if 3D
     if (uExt[0] < uExt[1] && uExt[2] < uExt[3] && uExt[4] < uExt[5])
     {
       this->GridSynchronizedTemplates->SetNumberOfContours(numContours);
-      for (i=0; i < numContours; i++)
+      for (i = 0; i < numContours; i++)
       {
-        this->GridSynchronizedTemplates->SetValue(i,values[i]);
+        this->GridSynchronizedTemplates->SetValue(i, values[i]);
       }
       this->GridSynchronizedTemplates->SetComputeNormals(this->ComputeNormals);
       this->GridSynchronizedTemplates->SetComputeGradients(this->ComputeGradients);
       this->GridSynchronizedTemplates->SetComputeScalars(this->ComputeScalars);
       this->GridSynchronizedTemplates->SetOutputPointsPrecision(this->OutputPointsPrecision);
       this->GridSynchronizedTemplates->SetGenerateTriangles(this->GenerateTriangles);
-      return this->GridSynchronizedTemplates->
-        ProcessRequest(request,inputVector,outputVector);
+      return this->GridSynchronizedTemplates->ProcessRequest(request, inputVector, outputVector);
     }
-  } //if 3D SGrid
+  } // if 3D SGrid
 
   inInfo->Set(vtkStreamingDemandDrivenPipeline::EXACT_EXTENT(), 1);
   return 1;
@@ -260,26 +252,23 @@ int vtkContourFilter::RequestUpdateExtent(vtkInformation* request,
 // General contouring filter.  Handles arbitrary input.
 //
 int vtkContourFilter::RequestData(
-  vtkInformation* request,
-  vtkInformationVector** inputVector,
-  vtkInformationVector* outputVector)
+  vtkInformation* request, vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
   // get the input
   vtkInformation* inInfo = inputVector[0]->GetInformationObject(0);
-  vtkDataSet *input = vtkDataSet::SafeDownCast(
-    inInfo->Get(vtkDataObject::DATA_OBJECT()));
+  vtkDataSet* input = vtkDataSet::SafeDownCast(inInfo->Get(vtkDataObject::DATA_OBJECT()));
   if (!input)
   {
     return 0;
   }
 
   // get the contours
-  int numContours = this->ContourValues->GetNumberOfContours();
-  double *values = this->ContourValues->GetValues();
+  vtkIdType numContours = this->ContourValues->GetNumberOfContours();
+  double* values = this->ContourValues->GetValues();
   int i;
 
   // is there data to process?
-  vtkDataArray *inScalars = this->GetInputArrayToProcess(0, inputVector);
+  vtkDataArray* inScalars = this->GetInputArrayToProcess(0, inputVector);
   if (!inScalars)
   {
     return 1;
@@ -288,11 +277,10 @@ int vtkContourFilter::RequestData(
   int sType = inScalars->GetDataType();
 
   // handle 2D images
-  if (vtkImageData::SafeDownCast(input) && sType != VTK_BIT &&
-      !vtkUniformGrid::SafeDownCast(input))
+  if (vtkImageData::SafeDownCast(input) && sType != VTK_BIT && !vtkUniformGrid::SafeDownCast(input))
   {
     int dim = 3;
-    int *uExt = inInfo->Get(vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT());
+    int* uExt = inInfo->Get(vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT());
     if (uExt[0] == uExt[1])
     {
       --dim;
@@ -306,97 +294,94 @@ int vtkContourFilter::RequestData(
       --dim;
     }
 
-    if ( dim == 2 )
+    if (dim == 2)
     {
       this->SynchronizedTemplates2D->SetNumberOfContours(numContours);
-      for (i=0; i < numContours; i++)
+      for (i = 0; i < numContours; i++)
       {
-        this->SynchronizedTemplates2D->SetValue(i,values[i]);
+        this->SynchronizedTemplates2D->SetValue(i, values[i]);
       }
-      this->SynchronizedTemplates2D->
-        SetInputArrayToProcess(0,this->GetInputArrayInformation(0));
-      return
-        this->SynchronizedTemplates2D->ProcessRequest(request,inputVector,outputVector);
+      this->SynchronizedTemplates2D->SetInputArrayToProcess(0, this->GetInputArrayInformation(0));
+      return this->SynchronizedTemplates2D->ProcessRequest(request, inputVector, outputVector);
     }
-    else if ( dim == 3 )
+    else if (dim == 3)
     {
       this->SynchronizedTemplates3D->SetNumberOfContours(numContours);
-      for (i=0; i < numContours; i++)
+      for (i = 0; i < numContours; i++)
       {
-        this->SynchronizedTemplates3D->SetValue(i,values[i]);
+        this->SynchronizedTemplates3D->SetValue(i, values[i]);
       }
       this->SynchronizedTemplates3D->SetComputeNormals(this->ComputeNormals);
       this->SynchronizedTemplates3D->SetComputeGradients(this->ComputeGradients);
       this->SynchronizedTemplates3D->SetComputeScalars(this->ComputeScalars);
       this->SynchronizedTemplates3D->SetGenerateTriangles(this->GenerateTriangles);
-      this->SynchronizedTemplates3D->
-        SetInputArrayToProcess(0,this->GetInputArrayInformation(0));
+      this->SynchronizedTemplates3D->SetInputArrayToProcess(0, this->GetInputArrayInformation(0));
 
-      return this->SynchronizedTemplates3D->ProcessRequest(request,inputVector,outputVector);
+      return this->SynchronizedTemplates3D->ProcessRequest(request, inputVector, outputVector);
     }
-  } //if image data
+  } // if image data
 
   // handle 3D RGrids
   if (vtkRectilinearGrid::SafeDownCast(input) && sType != VTK_BIT)
   {
-    int *uExt = inInfo->Get(vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT());
+    int* uExt = inInfo->Get(vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT());
     // if 3D
     if (uExt[0] < uExt[1] && uExt[2] < uExt[3] && uExt[4] < uExt[5])
     {
       this->RectilinearSynchronizedTemplates->SetNumberOfContours(numContours);
-      for (i=0; i < numContours; i++)
+      for (i = 0; i < numContours; i++)
       {
-        this->RectilinearSynchronizedTemplates->SetValue(i,values[i]);
+        this->RectilinearSynchronizedTemplates->SetValue(i, values[i]);
       }
       this->RectilinearSynchronizedTemplates->SetComputeNormals(this->ComputeNormals);
       this->RectilinearSynchronizedTemplates->SetComputeGradients(this->ComputeGradients);
       this->RectilinearSynchronizedTemplates->SetComputeScalars(this->ComputeScalars);
       this->RectilinearSynchronizedTemplates->SetGenerateTriangles(this->GenerateTriangles);
-      this->RectilinearSynchronizedTemplates->
-        SetInputArrayToProcess(0,this->GetInputArrayInformation(0));
-      return this->RectilinearSynchronizedTemplates->
-        ProcessRequest(request,inputVector,outputVector);
+      this->RectilinearSynchronizedTemplates->SetInputArrayToProcess(
+        0, this->GetInputArrayInformation(0));
+      return this->RectilinearSynchronizedTemplates->ProcessRequest(
+        request, inputVector, outputVector);
     }
   } // if 3D Rgrid
 
   // handle 3D SGrids
   if (vtkStructuredGrid::SafeDownCast(input) && sType != VTK_BIT)
   {
-    int *uExt = inInfo->Get(vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT());
+    int* uExt = inInfo->Get(vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT());
     // if 3D
     if (uExt[0] < uExt[1] && uExt[2] < uExt[3] && uExt[4] < uExt[5])
     {
       this->GridSynchronizedTemplates->SetNumberOfContours(numContours);
-      for (i=0; i < numContours; i++)
+      for (i = 0; i < numContours; i++)
       {
-        this->GridSynchronizedTemplates->SetValue(i,values[i]);
+        this->GridSynchronizedTemplates->SetValue(i, values[i]);
       }
       this->GridSynchronizedTemplates->SetComputeNormals(this->ComputeNormals);
       this->GridSynchronizedTemplates->SetComputeGradients(this->ComputeGradients);
       this->GridSynchronizedTemplates->SetComputeScalars(this->ComputeScalars);
       this->GridSynchronizedTemplates->SetOutputPointsPrecision(this->OutputPointsPrecision);
       this->GridSynchronizedTemplates->SetGenerateTriangles(this->GenerateTriangles);
-      this->GridSynchronizedTemplates->
-        SetInputArrayToProcess(0,this->GetInputArrayInformation(0));
-      return this->GridSynchronizedTemplates->
-        ProcessRequest(request,inputVector,outputVector);
+      this->GridSynchronizedTemplates->SetInputArrayToProcess(0, this->GetInputArrayInformation(0));
+      return this->GridSynchronizedTemplates->ProcessRequest(request, inputVector, outputVector);
     }
-  } //if 3D SGrid
+  } // if 3D SGrid
 
   vtkIdType cellId;
-  int abortExecute=0;
-  vtkIdList *cellPts;
+  int abortExecute = 0;
+  vtkIdList* cellPts;
   vtkCellArray *newVerts, *newLines, *newPolys;
-  vtkPoints *newPts;
+  vtkPoints* newPts;
   vtkIdType numCells, estimatedSize;
-  vtkDataArray *cellScalars;
+  vtkDataArray* cellScalars;
 
   vtkInformation* info = outputVector->GetInformationObject(0);
-  vtkPolyData *output = vtkPolyData::SafeDownCast(
-    info->Get(vtkDataObject::DATA_OBJECT()));
-  if (!output) {return 0;}
+  vtkPolyData* output = vtkPolyData::SafeDownCast(info->Get(vtkDataObject::DATA_OBJECT()));
+  if (!output)
+  {
+    return 0;
+  }
 
-  vtkPointData *inPdOriginal = input->GetPointData();
+  vtkPointData* inPdOriginal = input->GetPointData();
 
   // We don't want to change the active scalars in the input, but we
   // need to set the active scalars to match the input array to
@@ -415,16 +400,16 @@ int vtkContourFilter::RequestData(
   {
     inPd->AddArray(oldScalars);
   }
-  vtkPointData *outPd = output->GetPointData();
+  vtkPointData* outPd = output->GetPointData();
 
-  vtkCellData *inCd = input->GetCellData();
-  vtkCellData *outCd = output->GetCellData();
+  vtkCellData* inCd = input->GetCellData();
+  vtkCellData* outCd = output->GetCellData();
 
   vtkDebugMacro(<< "Executing contour filter");
   if (input->IsA("vtkUnstructuredGridBase"))
   {
     vtkDebugMacro(<< "Processing unstructured grid");
-    vtkContourGrid *cgrid;
+    vtkContourGrid* cgrid;
 
     cgrid = vtkContourGrid::New();
     cgrid->SetInputData(input);
@@ -435,50 +420,48 @@ int vtkContourFilter::RequestData(
     cgrid->SetOutputPointsPrecision(this->OutputPointsPrecision);
     cgrid->SetGenerateTriangles(this->GenerateTriangles);
     cgrid->SetUseScalarTree(this->UseScalarTree);
-    if ( this->UseScalarTree ) //special treatment to reuse it
+    if (this->UseScalarTree) // special treatment to reuse it
     {
-      if ( this->ScalarTree == NULL )
+      if (this->ScalarTree == nullptr)
       {
         this->ScalarTree = vtkSpanSpace::New();
       }
       this->ScalarTree->SetDataSet(input);
       cgrid->SetScalarTree(this->ScalarTree);
     }
-    if ( this->Locator )
+    if (this->Locator)
     {
-      cgrid->SetLocator( this->Locator );
+      cgrid->SetLocator(this->Locator);
     }
 
     for (i = 0; i < numContours; i++)
     {
       cgrid->SetValue(i, values[i]);
     }
-    cgrid->SetInputArrayToProcess(0,this->GetInputArrayInformation(0));
-    cgrid->UpdatePiece(
-      info->Get(vtkStreamingDemandDrivenPipeline::UPDATE_PIECE_NUMBER()),
-      info->Get(vtkStreamingDemandDrivenPipeline:: UPDATE_NUMBER_OF_PIECES()),
+    cgrid->SetInputArrayToProcess(0, this->GetInputArrayInformation(0));
+    cgrid->UpdatePiece(info->Get(vtkStreamingDemandDrivenPipeline::UPDATE_PIECE_NUMBER()),
+      info->Get(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_PIECES()),
       info->Get(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_GHOST_LEVELS()));
 
     output->ShallowCopy(cgrid->GetOutput());
     cgrid->Delete();
-  } //if type VTK_UNSTRUCTURED_GRID
+  } // if type VTK_UNSTRUCTURED_GRID
   else
   {
     numCells = input->GetNumberOfCells();
-    inScalars = this->GetInputArrayToProcess(0,inputVector);
-    if ( ! inScalars || numCells < 1 )
+    inScalars = this->GetInputArrayToProcess(0, inputVector);
+    if (!inScalars || numCells < 1)
     {
-      vtkDebugMacro(<<"No data to contour");
+      vtkDebugMacro(<< "No data to contour");
       return 1;
     }
 
     // Create objects to hold output of contour operation. First estimate
     // allocation size.
     //
-    estimatedSize=
-      static_cast<vtkIdType>(pow(static_cast<double>(numCells),.75));
+    estimatedSize = static_cast<vtkIdType>(pow(static_cast<double>(numCells), .75));
     estimatedSize *= numContours;
-    estimatedSize = estimatedSize / 1024 * 1024; //multiple of 1024
+    estimatedSize = estimatedSize / 1024 * 1024; // multiple of 1024
     if (estimatedSize < 1024)
     {
       estimatedSize = 1024;
@@ -486,10 +469,10 @@ int vtkContourFilter::RequestData(
 
     newPts = vtkPoints::New();
     // set precision for the points in the output
-    if(this->OutputPointsPrecision == vtkAlgorithm::DEFAULT_PRECISION)
+    if (this->OutputPointsPrecision == vtkAlgorithm::DEFAULT_PRECISION)
     {
-      vtkPointSet *inputPointSet = vtkPointSet::SafeDownCast(input);
-      if(inputPointSet)
+      vtkPointSet* inputPointSet = vtkPointSet::SafeDownCast(input);
+      if (inputPointSet)
       {
         newPts->SetDataType(inputPointSet->GetPoints()->GetDataType());
       }
@@ -498,33 +481,31 @@ int vtkContourFilter::RequestData(
         newPts->SetDataType(VTK_FLOAT);
       }
     }
-    else if(this->OutputPointsPrecision == vtkAlgorithm::SINGLE_PRECISION)
+    else if (this->OutputPointsPrecision == vtkAlgorithm::SINGLE_PRECISION)
     {
       newPts->SetDataType(VTK_FLOAT);
     }
-    else if(this->OutputPointsPrecision == vtkAlgorithm::DOUBLE_PRECISION)
+    else if (this->OutputPointsPrecision == vtkAlgorithm::DOUBLE_PRECISION)
     {
       newPts->SetDataType(VTK_DOUBLE);
     }
-    newPts->Allocate(estimatedSize,estimatedSize);
+    newPts->Allocate(estimatedSize, estimatedSize);
     newVerts = vtkCellArray::New();
-    newVerts->Allocate(estimatedSize,estimatedSize);
+    newVerts->AllocateEstimate(estimatedSize, 1);
     newLines = vtkCellArray::New();
-    newLines->Allocate(estimatedSize,estimatedSize);
+    newLines->AllocateEstimate(estimatedSize, 2);
     newPolys = vtkCellArray::New();
-    newPolys->Allocate(estimatedSize,estimatedSize);
+    newPolys->AllocateEstimate(estimatedSize, 4);
     cellScalars = inScalars->NewInstance();
     cellScalars->SetNumberOfComponents(inScalars->GetNumberOfComponents());
-    cellScalars->Allocate(cellScalars->GetNumberOfComponents()*VTK_CELL_SIZE);
+    cellScalars->Allocate(cellScalars->GetNumberOfComponents() * VTK_CELL_SIZE);
 
     // locator used to merge potentially duplicate points
-    if ( this->Locator == NULL )
+    if (this->Locator == nullptr)
     {
       this->CreateDefaultLocator();
     }
-    this->Locator->InitPointInsertion (newPts,
-                                       input->GetBounds(),
-                                       input->GetNumberOfPoints());
+    this->Locator->InitPointInsertion(newPts, input->GetBounds(), input->GetNumberOfPoints());
 
     // interpolate data along edge
     // if we did not ask for scalars to be computed, don't copy them
@@ -532,15 +513,16 @@ int vtkContourFilter::RequestData(
     {
       outPd->CopyScalarsOff();
     }
-    outPd->InterpolateAllocate(inPd,estimatedSize,estimatedSize);
-    outCd->CopyAllocate(inCd,estimatedSize,estimatedSize);
+    outPd->InterpolateAllocate(inPd, estimatedSize, estimatedSize);
+    outCd->CopyAllocate(inCd, estimatedSize, estimatedSize);
 
-    vtkContourHelper helper(this->Locator, newVerts, newLines, newPolys, inPd, inCd, outPd,outCd, estimatedSize, this->GenerateTriangles!=0);
+    vtkContourHelper helper(this->Locator, newVerts, newLines, newPolys, inPd, inCd, outPd, outCd,
+      estimatedSize, this->GenerateTriangles != 0);
     // If enabled, build a scalar tree to accelerate search
     //
-    if ( !this->UseScalarTree )
+    if (!this->UseScalarTree)
     {
-      vtkGenericCell *cell = vtkGenericCell::New();
+      vtkGenericCell* cell = vtkGenericCell::New();
       // Three passes over the cells to process lower dimensional cells first.
       // For poly data output cells need to be added in the order:
       // verts, lines and then polys, or cell data gets mixed up.
@@ -564,7 +546,7 @@ int vtkContourFilter::RequestData(
         // Loop over all cells; get scalar values for all cell points
         // and process each cell.
         //
-        for (cellId=0; cellId < numCells && !abortExecute; cellId++)
+        for (cellId = 0; cellId < numCells && !abortExecute; cellId++)
         {
           // I assume that "GetCellType" is fast.
           cellType = input->GetCellType(cellId);
@@ -577,34 +559,33 @@ int vtkContourFilter::RequestData(
           {
             continue;
           }
-          input->GetCell(cellId,cell);
+          input->GetCell(cellId, cell);
           cellPts = cell->GetPointIds();
-          if (cellScalars->GetSize()/cellScalars->GetNumberOfComponents() <
+          if (cellScalars->GetSize() / cellScalars->GetNumberOfComponents() <
             cellPts->GetNumberOfIds())
           {
-            cellScalars->Allocate(
-              cellScalars->GetNumberOfComponents()*cellPts->GetNumberOfIds());
+            cellScalars->Allocate(cellScalars->GetNumberOfComponents() * cellPts->GetNumberOfIds());
           }
-          inScalars->GetTuples(cellPts,cellScalars);
+          inScalars->GetTuples(cellPts, cellScalars);
 
-          if (dimensionality == 3 &&  ! (cellId % 5000) )
+          if (dimensionality == 3 && !(cellId % 5000))
           {
-            vtkDebugMacro(<<"Contouring #" << cellId);
-            this->UpdateProgress (static_cast<double>(cellId)/numCells);
+            vtkDebugMacro(<< "Contouring #" << cellId);
+            this->UpdateProgress(static_cast<double>(cellId) / numCells);
             abortExecute = this->GetAbortExecute();
           }
 
-          for (i=0; i < numContours; i++)
+          for (i = 0; i < numContours; i++)
           {
-            helper.Contour(cell,values[i],cellScalars,cellId);
+            helper.Contour(cell, values[i], cellScalars, cellId);
           } // for all contour values
-        } // for all cells
-      } // for all dimensions
+        }   // for all cells
+      }     // for all dimensions
       cell->Delete();
-    } //if using scalar tree
+    } // if using scalar tree
     else
     {
-      vtkCell *cell;
+      vtkCell* cell;
       // Note: This will have problems when input contains 2D and 3D cells.
       // CellData will get scrabled because of the implicit ordering of
       // verts, lines and polys in vtkPolyData.  The solution
@@ -613,21 +594,19 @@ int vtkContourFilter::RequestData(
       // Loop over all contour values.  Then for each contour value,
       // loop over all cells.
       //
-      for (i=0; i < numContours; i++)
+      for (i = 0; i < numContours; i++)
       {
-        for ( this->ScalarTree->InitTraversal(values[i]);
-              (cell=this->ScalarTree->GetNextCell(cellId,cellPts,cellScalars)) != NULL; )
+        for (this->ScalarTree->InitTraversal(values[i]);
+             (cell = this->ScalarTree->GetNextCell(cellId, cellPts, cellScalars)) != nullptr;)
         {
-          helper.Contour(cell,values[i],cellScalars,cellId);
-        } //for all cells
-      } //for all contour values
-    } //using scalar tree
+          helper.Contour(cell, values[i], cellScalars, cellId);
+        } // for all cells
+      }   // for all contour values
+    }     // using scalar tree
 
-    vtkDebugMacro(<<"Created: "
-                  << newPts->GetNumberOfPoints() << " points, "
-                  << newVerts->GetNumberOfCells() << " verts, "
-                  << newLines->GetNumberOfCells() << " lines, "
-                  << newPolys->GetNumberOfCells() << " triangles");
+    vtkDebugMacro(<< "Created: " << newPts->GetNumberOfPoints() << " points, "
+                  << newVerts->GetNumberOfCells() << " verts, " << newLines->GetNumberOfCells()
+                  << " lines, " << newPolys->GetNumberOfCells() << " triangles");
 
     // Update ourselves.  Because we don't know up front how many verts, lines,
     // polys we've created, take care to reclaim memory.
@@ -663,19 +642,17 @@ int vtkContourFilter::RequestData(
       normalsFilter->SetOutputPointsPrecision(this->OutputPointsPrecision);
       vtkNew<vtkPolyData> tempInput;
       tempInput->ShallowCopy(output);
-      normalsFilter->SetInputData(tempInput.GetPointer());
+      normalsFilter->SetInputData(tempInput);
       normalsFilter->SetFeatureAngle(180.);
-      normalsFilter->UpdatePiece(
-        info->Get(vtkStreamingDemandDrivenPipeline::UPDATE_PIECE_NUMBER()),
+      normalsFilter->UpdatePiece(info->Get(vtkStreamingDemandDrivenPipeline::UPDATE_PIECE_NUMBER()),
         info->Get(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_PIECES()),
-        info->Get(vtkStreamingDemandDrivenPipeline::
-                  UPDATE_NUMBER_OF_GHOST_LEVELS()));
+        info->Get(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_GHOST_LEVELS()));
       output->ShallowCopy(normalsFilter->GetOutput());
     }
 
-    this->Locator->Initialize();//releases leftover memory
+    this->Locator->Initialize(); // releases leftover memory
     output->Squeeze();
-  } //else if not vtkUnstructuredGrid
+  } // else if not vtkUnstructuredGrid
 
   return 1;
 }
@@ -683,18 +660,18 @@ int vtkContourFilter::RequestData(
 //-----------------------------------------------------------------------------
 // Specify a spatial locator for merging points. By default,
 // an instance of vtkMergePoints is used.
-void vtkContourFilter::SetLocator(vtkIncrementalPointLocator *locator)
+void vtkContourFilter::SetLocator(vtkIncrementalPointLocator* locator)
 {
-  if ( this->Locator == locator )
+  if (this->Locator == locator)
   {
     return;
   }
-  if ( this->Locator )
+  if (this->Locator)
   {
     this->Locator->UnRegister(this);
-    this->Locator = NULL;
+    this->Locator = nullptr;
   }
-  if ( locator )
+  if (locator)
   {
     locator->Register(this);
   }
@@ -705,7 +682,7 @@ void vtkContourFilter::SetLocator(vtkIncrementalPointLocator *locator)
 //-----------------------------------------------------------------------------
 void vtkContourFilter::CreateDefaultLocator()
 {
-  if ( this->Locator == NULL )
+  if (this->Locator == nullptr)
   {
     this->Locator = vtkMergePoints::New();
     this->Locator->Register(this);
@@ -714,17 +691,17 @@ void vtkContourFilter::CreateDefaultLocator()
 }
 
 //-----------------------------------------------------------------------------
-void vtkContourFilter::SetArrayComponent( int comp )
+void vtkContourFilter::SetArrayComponent(int comp)
 {
-  this->SynchronizedTemplates2D->SetArrayComponent( comp );
-  this->SynchronizedTemplates3D->SetArrayComponent( comp );
-  this->RectilinearSynchronizedTemplates->SetArrayComponent( comp );
+  this->SynchronizedTemplates2D->SetArrayComponent(comp);
+  this->SynchronizedTemplates3D->SetArrayComponent(comp);
+  this->RectilinearSynchronizedTemplates->SetArrayComponent(comp);
 }
 
 //-----------------------------------------------------------------------------
 int vtkContourFilter::GetArrayComponent()
 {
-  return( this->SynchronizedTemplates2D->GetArrayComponent() );
+  return (this->SynchronizedTemplates2D->GetArrayComponent());
 }
 
 //-----------------------------------------------------------------------------
@@ -741,7 +718,7 @@ int vtkContourFilter::GetOutputPointsPrecision() const
 }
 
 //-----------------------------------------------------------------------------
-int vtkContourFilter::FillInputPortInformation(int, vtkInformation *info)
+int vtkContourFilter::FillInputPortInformation(int, vtkInformation* info)
 {
   info->Set(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkDataSet");
   return 1;
@@ -749,20 +726,16 @@ int vtkContourFilter::FillInputPortInformation(int, vtkInformation *info)
 
 void vtkContourFilter::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 
-  os << indent << "Compute Gradients: "
-     << (this->ComputeGradients ? "On\n" : "Off\n");
-  os << indent << "Compute Normals: "
-     << (this->ComputeNormals ? "On\n" : "Off\n");
-  os << indent << "Compute Scalars: "
-     << (this->ComputeScalars ? "On\n" : "Off\n");
+  os << indent << "Compute Gradients: " << (this->ComputeGradients ? "On\n" : "Off\n");
+  os << indent << "Compute Normals: " << (this->ComputeNormals ? "On\n" : "Off\n");
+  os << indent << "Compute Scalars: " << (this->ComputeScalars ? "On\n" : "Off\n");
 
-  this->ContourValues->PrintSelf(os,indent.GetNextIndent());
+  this->ContourValues->PrintSelf(os, indent.GetNextIndent());
 
-  os << indent << "Use Scalar Tree: "
-     << (this->UseScalarTree ? "On\n" : "Off\n");
-  if ( this->ScalarTree )
+  os << indent << "Use Scalar Tree: " << (this->UseScalarTree ? "On\n" : "Off\n");
+  if (this->ScalarTree)
   {
     os << indent << "Scalar Tree: " << this->ScalarTree << "\n";
   }
@@ -771,7 +744,7 @@ void vtkContourFilter::PrintSelf(ostream& os, vtkIndent indent)
     os << indent << "Scalar Tree: (none)\n";
   }
 
-  if ( this->Locator )
+  if (this->Locator)
   {
     os << indent << "Locator: " << this->Locator << "\n";
   }
@@ -780,8 +753,7 @@ void vtkContourFilter::PrintSelf(ostream& os, vtkIndent indent)
     os << indent << "Locator: (none)\n";
   }
 
-  os << indent << "Precision of the output points: "
-     << this->OutputPointsPrecision << "\n";
+  os << indent << "Precision of the output points: " << this->OutputPointsPrecision << "\n";
 }
 
 //----------------------------------------------------------------------------
@@ -794,12 +766,10 @@ void vtkContourFilter::ReportReferences(vtkGarbageCollector* collector)
 }
 
 //----------------------------------------------------------------------------
-void vtkContourFilter::InternalProgressCallbackFunction(vtkObject *vtkNotUsed(caller),
-                                                        unsigned long vtkNotUsed(eid),
-                                                        void *clientData,
-                                                        void *callData)
+void vtkContourFilter::InternalProgressCallbackFunction(
+  vtkObject* vtkNotUsed(caller), unsigned long vtkNotUsed(eid), void* clientData, void* callData)
 {
-  vtkContourFilter *contourFilter = static_cast<vtkContourFilter *>(clientData);
-  double progress = *static_cast<double *>(callData);
+  vtkContourFilter* contourFilter = static_cast<vtkContourFilter*>(clientData);
+  double progress = *static_cast<double*>(callData);
   contourFilter->UpdateProgress(progress);
 }
