@@ -15,48 +15,44 @@
 #include "vtkStructuredGridAppend.h"
 
 #include "vtkAlgorithmOutput.h"
+#include "vtkArrayDispatch.h"
 #include "vtkCellData.h"
 #include "vtkDataArray.h"
-#include "vtkNew.h"
-#include "vtkStructuredGrid.h"
+#include "vtkDataArrayRange.h"
 #include "vtkInformation.h"
 #include "vtkInformationVector.h"
+#include "vtkNew.h"
 #include "vtkObjectFactory.h"
 #include "vtkPointData.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
+#include "vtkStructuredGrid.h"
 #include "vtkUnsignedCharArray.h"
 #include <cassert>
 
 vtkStandardNewMacro(vtkStructuredGridAppend);
 
 //----------------------------------------------------------------------------
-vtkStructuredGridAppend::vtkStructuredGridAppend()
-{
-}
+vtkStructuredGridAppend::vtkStructuredGridAppend() = default;
 
 //----------------------------------------------------------------------------
-vtkStructuredGridAppend::~vtkStructuredGridAppend()
-{
-}
+vtkStructuredGridAppend::~vtkStructuredGridAppend() = default;
 
 //----------------------------------------------------------------------------
-void vtkStructuredGridAppend::ReplaceNthInputConnection(
-  int idx, vtkAlgorithmOutput *input)
+void vtkStructuredGridAppend::ReplaceNthInputConnection(int idx, vtkAlgorithmOutput* input)
 {
   if (idx < 0 || idx >= this->GetNumberOfInputConnections(0))
   {
-    vtkErrorMacro("Attempt to replace connection idx " << idx
-                  << " of input port " << 0 << ", which has only "
-                  << this->GetNumberOfInputConnections(0)
-                  << " connections.");
+    vtkErrorMacro("Attempt to replace connection idx "
+      << idx << " of input port " << 0 << ", which has only "
+      << this->GetNumberOfInputConnections(0) << " connections.");
     return;
   }
 
   if (!input || !input->GetProducer())
   {
-    vtkErrorMacro("Attempt to replace connection index " << idx
-                  << " for input port " << 0 << " with " <<
-                  (!input ? "a null input." : "an input with no producer."));
+    vtkErrorMacro("Attempt to replace connection index "
+      << idx << " for input port " << 0 << " with "
+      << (!input ? "a null input." : "an input with no producer."));
     return;
   }
 
@@ -67,28 +63,25 @@ void vtkStructuredGridAppend::ReplaceNthInputConnection(
 // The default vtkStructuredGridAlgorithm semantics are that SetInput() puts
 // each input on a different port, we want all the structured grid inputs to
 // go on the first port.
-void vtkStructuredGridAppend::SetInputData(int idx, vtkDataObject *input)
+void vtkStructuredGridAppend::SetInputData(int idx, vtkDataObject* input)
 {
   this->SetInputDataInternal(idx, input);
 }
 
 //----------------------------------------------------------------------------
-vtkDataObject *vtkStructuredGridAppend::GetInput(int idx)
+vtkDataObject* vtkStructuredGridAppend::GetInput(int idx)
 {
   if (this->GetNumberOfInputConnections(0) <= idx)
   {
-    return 0;
+    return nullptr;
   }
-  return vtkStructuredGrid::SafeDownCast(
-    this->GetExecutive()->GetInputData(0, idx));
+  return vtkStructuredGrid::SafeDownCast(this->GetExecutive()->GetInputData(0, idx));
 }
 
 //----------------------------------------------------------------------------
 // This method tells the output it will have more components
-int vtkStructuredGridAppend::RequestInformation (
-  vtkInformation * vtkNotUsed(request),
-  vtkInformationVector **inputVector,
-  vtkInformationVector *outputVector)
+int vtkStructuredGridAppend::RequestInformation(vtkInformation* vtkNotUsed(request),
+  vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
   // get the info objects
   vtkInformation* outInfo = outputVector->GetInformationObject(0);
@@ -96,12 +89,12 @@ int vtkStructuredGridAppend::RequestInformation (
   int unionExt[6];
 
   // Find the outMin/max of the appended axis for this input.
-  vtkInformation * inInfo = inputVector[0]->GetInformationObject(0);
+  vtkInformation* inInfo = inputVector[0]->GetInformationObject(0);
   inInfo->Get(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT(), unionExt);
   for (int idx = 0; idx < this->GetNumberOfInputConnections(0); ++idx)
   {
     inInfo = inputVector[0]->GetInformationObject(idx);
-    int * inExt = inInfo->Get(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT());
+    int* inExt = inInfo->Get(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT());
 
     // Compute union for preserving extents.
     if (inExt[0] < unionExt[0])
@@ -130,28 +123,25 @@ int vtkStructuredGridAppend::RequestInformation (
     }
   }
 
-  outInfo->Set(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT(),unionExt,6);
+  outInfo->Set(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT(), unionExt, 6);
 
   return 1;
 }
 
 //----------------------------------------------------------------------------
-int vtkStructuredGridAppend::RequestUpdateExtent(
-  vtkInformation * vtkNotUsed(request),
-  vtkInformationVector **inputVector,
-  vtkInformationVector *vtkNotUsed(outputVector))
+int vtkStructuredGridAppend::RequestUpdateExtent(vtkInformation* vtkNotUsed(request),
+  vtkInformationVector** inputVector, vtkInformationVector* vtkNotUsed(outputVector))
 {
   // default input extent will be that of output extent
-  for (int whichInput = 0; whichInput < this->GetNumberOfInputConnections(0);
-       whichInput++)
+  for (int whichInput = 0; whichInput < this->GetNumberOfInputConnections(0); whichInput++)
   {
-    int *inWextent;
+    int* inWextent;
 
     // Find the outMin/max of the appended axis for this input.
-    vtkInformation *inInfo = inputVector[0]->GetInformationObject(whichInput);
+    vtkInformation* inInfo = inputVector[0]->GetInformationObject(whichInput);
     inWextent = inInfo->Get(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT());
 
-    inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT(),inWextent, 6);
+    inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT(), inWextent, 6);
   }
 
   return 1;
@@ -160,69 +150,78 @@ int vtkStructuredGridAppend::RequestUpdateExtent(
 namespace
 {
 //----------------------------------------------------------------------------
-// This templated function executes the filter for any type of data.
-  template <class T>
-  void vtkStructuredGridAppendExecute(int inExt[6], vtkStructuredGrid *inData,
-                                      T *inPtr, int outExt[6], T *outPtr,
-                                      vtkIdType numComp, bool forCells,
-                                      std::vector<int>& validValues,
-                                      vtkUnsignedCharArray* ghosts)
+// This templated implementation executes the filter for any type of data.
+struct AppendWorker
+{
+  template <typename InArrayT, typename OutArrayT>
+  void operator()(InArrayT *inArray,
+                  OutArrayT *outArray,
+                  int inExt[6],
+                  int outExt[6],
+                  vtkStructuredGrid *inData,
+                  std::vector<int> &validValues,
+                  vtkUnsignedCharArray *ghosts,
+                  bool forCells)
   {
-    int forPoints = forCells?0:1;
+    const auto inTuples = vtk::DataArrayTupleRange(inArray);
+    auto outTuples = vtk::DataArrayTupleRange(outArray);
+
+    const int forPoints = forCells ? 0 : 1;
     vtkIdType inCounter = 0;
-    for(int k=inExt[4];k<inExt[5]+forPoints;k++)
+
+    for (int k = inExt[4]; k < inExt[5] + forPoints; k++)
     {
-      for(int j=inExt[2];j<inExt[3]+forPoints;j++)
+      for (int j = inExt[2]; j < inExt[3] + forPoints; j++)
       {
-        for(int i=inExt[0];i<inExt[1]+forPoints;i++)
+        for (int i = inExt[0]; i < inExt[1] + forPoints; i++)
         {
-          bool skipValue = !(forCells?
-                             inData->IsCellVisible(inCounter):inData->IsPointVisible(inCounter));
-          int ijk[3] = {i, j, k};
-          vtkIdType outputIndex = forCells?
-            vtkStructuredData::ComputeCellIdForExtent(outExt, ijk) :
-            vtkStructuredData::ComputePointIdForExtent(outExt, ijk);
+          const int ijk[3] = {i, j, k};
+          bool skipValue = forCells
+              ? !inData->IsCellVisible(inCounter)
+              : !inData->IsPointVisible(inCounter);
+
+          const vtkIdType outputIndex = forCells
+              ? vtkStructuredData::ComputeCellIdForExtent(outExt, ijk)
+              : vtkStructuredData::ComputePointIdForExtent(outExt, ijk);
           assert(static_cast<size_t>(outputIndex) < validValues.size());
-          if(skipValue && validValues[outputIndex] <= 1)
+          int &validValue = validValues[static_cast<std::size_t>(outputIndex)];
+
+          if (skipValue && validValue <= 1)
           { // current output value for this is not set
             skipValue = false;
-            validValues[outputIndex] = 1; // value is from a blanked entity
+            validValue = 1; // value is from a blanked entity
           }
           else if(
             ghosts &&
             (ghosts->GetValue(inCounter) & vtkDataSetAttributes::DUPLICATECELL) &&
-            validValues[outputIndex] <= 2)
+            validValue <= 2)
           {
-            validValues[outputIndex] = 2; // value is a ghost
+            validValue = 2; // value is a ghost
             skipValue = false;
           }
-          else if(validValues[outputIndex] <= 3)
+          else if(validValue <= 3)
           {
-            validValues[outputIndex] = 3; // value is valid
+            validValue = 3; // value is valid
             skipValue = false;
           }
+
           if(!skipValue)
           {
-            for(vtkIdType nc=0;nc<numComp;nc++)
-            {
-              outPtr[outputIndex*numComp+nc] = inPtr[inCounter*numComp+nc];
-            }
+            outTuples[outputIndex] = inTuples[inCounter];
           }
           inCounter++;
         }
       }
     }
   }
-}
+};
+} // end anon namespace
 
 //----------------------------------------------------------------------------
 int vtkStructuredGridAppend::RequestData(
-  vtkInformation *,
-  vtkInformationVector **inputVector, vtkInformationVector *outputVector)
+  vtkInformation*, vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
   int outExt[6];
-  void *inPtr;
-  void *outPtr;
 
   vtkStructuredGrid* output = vtkStructuredGrid::GetData(outputVector, 0);
   vtkInformation* outInfo = outputVector->GetInformationObject(0);
@@ -239,46 +238,45 @@ int vtkStructuredGridAppend::RequestData(
   std::vector<int> validValues;
   validValues.reserve(numPoints);
 
+  // Dispatcher and worker implementation for append
+  using Dispatcher = vtkArrayDispatch::Dispatch2SameValueType;
+  AppendWorker worker;
+
   for (int idx1 = 0; idx1 < this->GetNumberOfInputConnections(0); ++idx1)
   {
     vtkStructuredGrid* input = vtkStructuredGrid::GetData(inputVector[0], idx1);
-    if (input != NULL)
+    if (input != nullptr)
     {
       // Get the input extent and output extent
       // the real out extent for this input may be clipped.
-      vtkInformation *inInfo =
-        inputVector[0]->GetInformationObject(idx1);
+      vtkInformation* inInfo = inputVector[0]->GetInformationObject(idx1);
 
       int inExt[6];
-      inInfo->Get(vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT(),inExt);
+      inInfo->Get(vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT(), inExt);
       // do a quick check to see if the input is used at all.
-      if (inExt[0] <= inExt[1] &&
-          inExt[2] <= inExt[3] &&
-          inExt[4] <= inExt[5])
+      if (inExt[0] <= inExt[1] && inExt[2] <= inExt[3] && inExt[4] <= inExt[5])
       {
-        vtkDataArray *inArray;
-        vtkDataArray *outArray;
+        vtkDataArray* inArray;
+        vtkDataArray* outArray;
         vtkIdType numComp;
 
         vtkUnsignedCharArray* ghosts = input->GetPointGhostArray();
 
-        if(input->GetPointData()->GetNumberOfArrays())
+        if (input->GetPointData()->GetNumberOfArrays())
         { // only zero out the array if we have point arrays
           validValues.resize(numPoints);
-          for(vtkIdType i=0;i<numPoints;i++)
+          for (vtkIdType i = 0; i < numPoints; i++)
           {
             validValues[i] = 0;
           }
         }
 
-        //do point associated arrays
-        for (vtkIdType ai = 0;
-             ai < input->GetPointData()->GetNumberOfArrays();
-             ai++)
+        // do point associated arrays
+        for (vtkIdType ai = 0; ai < input->GetPointData()->GetNumberOfArrays(); ai++)
         {
           inArray = input->GetPointData()->GetArray(ai);
           outArray = output->GetPointData()->GetArray(ai);
-          if(outArray == NULL)
+          if (outArray == nullptr)
           {
             outArray = inArray->NewInstance();
             outArray->SetName(inArray->GetName());
@@ -298,84 +296,64 @@ int vtkStructuredGridAppend::RequestData(
           // this filter expects that input is the same type as output.
           if (inArray->GetDataType() != outArray->GetDataType())
           {
-            vtkErrorMacro(<< "Execute: input" << idx1 << " ScalarType ("
-                          << inArray->GetDataType()
-                          << "), must match output ScalarType ("
-                          << outArray->GetDataType() << ")");
+            vtkErrorMacro(<< "Execute: input" << idx1 << " ScalarType (" << inArray->GetDataType()
+                          << "), must match output ScalarType (" << outArray->GetDataType() << ")");
             return 0;
           }
-          if (strcmp(inArray->GetName(), outArray->GetName()) )
+          if (strcmp(inArray->GetName(), outArray->GetName()))
           {
-            vtkErrorMacro(<< "Execute: input" << idx1 << " Name ("
-                          << inArray->GetName()
-                          << "), must match output Name ("
-                          << outArray->GetName() << ")");
+            vtkErrorMacro(<< "Execute: input" << idx1 << " Name (" << inArray->GetName()
+                          << "), must match output Name (" << outArray->GetName() << ")");
             return 0;
           }
 
-          inPtr = inArray->GetVoidPointer(0);
-          outPtr = outArray->GetVoidPointer(0);
-
-          switch (inArray->GetDataType())
-          {
-            vtkTemplateMacro(
-              vtkStructuredGridAppendExecute(inExt, input,
-                                             static_cast<VTK_TT *>(inPtr),
-                                             outExt,
-                                             static_cast<VTK_TT *>(outPtr),
-                                             numComp,
-                                             false, validValues, ghosts));
-            default:
-              vtkErrorMacro(<< "Execute: Unknown ScalarType");
-              return 0;
+          if (!Dispatcher::Execute(inArray, outArray,
+                                   worker, inExt, outExt, input,
+                                   validValues, ghosts, false))
+          { // Fallback for unknown array types:
+            worker(inArray, outArray, inExt, outExt, input, validValues,
+                   ghosts, false);
           }
+
         }
 
         // do the point locations array
         inArray = input->GetPoints()->GetData();
-        if(output->GetPoints() == NULL)
+        if (output->GetPoints() == nullptr)
         {
           vtkNew<vtkPoints> points;
           points->SetDataType(inArray->GetDataType());
           points->SetNumberOfPoints(vtkStructuredData::GetNumberOfPoints(outExt));
-          output->SetPoints(points.GetPointer());
+          output->SetPoints(points);
         }
         outArray = output->GetPoints()->GetData();
-        inPtr = inArray->GetVoidPointer(0);
-        outPtr = outArray->GetVoidPointer(0);
-        switch (inArray->GetDataType())
-        {
-          vtkTemplateMacro(
-            vtkStructuredGridAppendExecute(inExt, input,
-                                           static_cast<VTK_TT *>(inPtr),
-                                           outExt,
-                                           static_cast<VTK_TT *>(outPtr),
-                                           3, false, validValues, ghosts));
-          default:
-            vtkErrorMacro(<< "Execute: Unknown ScalarType");
-            return 0;
+
+        if (!Dispatcher::Execute(inArray, outArray,
+                                 worker, inExt, outExt, input,
+                                 validValues, ghosts, false))
+        { // Fallback for unknown array types:
+          worker(inArray, outArray, inExt, outExt, input, validValues,
+                 ghosts, false);
         }
 
         // note that we are still using validValues but only for the
         // cells now so there are less of them than points.
-        if(input->GetCellData()->GetNumberOfArrays())
+        if (input->GetCellData()->GetNumberOfArrays())
         { // only zero out values if we have cell arrays to compute
           validValues.resize(numCells);
-          for(vtkIdType i=0;i<numCells;i++)
+          for (vtkIdType i = 0; i < numCells; i++)
           {
             validValues[i] = 0;
           }
         }
         ghosts = input->GetCellGhostArray();
 
-        //do cell associated arrays
-        for (vtkIdType ai = 0;
-             ai < input->GetCellData()->GetNumberOfArrays();
-             ai++)
+        // do cell associated arrays
+        for (vtkIdType ai = 0; ai < input->GetCellData()->GetNumberOfArrays(); ai++)
         {
           inArray = input->GetCellData()->GetArray(ai);
           outArray = output->GetCellData()->GetArray(ai);
-          if(outArray == NULL)
+          if (outArray == nullptr)
           {
             outArray = inArray->NewInstance();
             outArray->SetName(inArray->GetName());
@@ -395,35 +373,23 @@ int vtkStructuredGridAppend::RequestData(
           // this filter expects that input is the same type as output.
           if (inArray->GetDataType() != outArray->GetDataType())
           {
-            vtkErrorMacro(<< "Execute: input" << idx1 << " ScalarType ("
-                          << inArray->GetDataType()
-                          << "), must match output ScalarType ("
-                          << outArray->GetDataType() << ")");
+            vtkErrorMacro(<< "Execute: input" << idx1 << " ScalarType (" << inArray->GetDataType()
+                          << "), must match output ScalarType (" << outArray->GetDataType() << ")");
             return 0;
           }
-          if (strcmp(inArray->GetName(), outArray->GetName()) )
+          if (strcmp(inArray->GetName(), outArray->GetName()))
           {
-            vtkErrorMacro(<< "Execute: input" << idx1 << " Name ("
-                          << inArray->GetName()
-                          << "), must match output Name ("
-                          << outArray->GetName() << ")");
+            vtkErrorMacro(<< "Execute: input" << idx1 << " Name (" << inArray->GetName()
+                          << "), must match output Name (" << outArray->GetName() << ")");
             return 0;
           }
 
-          inPtr = inArray->GetVoidPointer(0);
-          outPtr = outArray->GetVoidPointer(0);
-
-          switch (inArray->GetDataType())
-          {
-            vtkTemplateMacro(
-              vtkStructuredGridAppendExecute(inExt, input,
-                                             static_cast<VTK_TT *>(inPtr),
-                                             outExt,
-                                             static_cast<VTK_TT *>(outPtr),
-                                             numComp, true, validValues, ghosts));
-            default:
-              vtkErrorMacro(<< "Execute: Unknown ScalarType");
-              return 0;
+          if (!Dispatcher::Execute(inArray, outArray,
+                                   worker, inExt, outExt, input,
+                                   validValues, ghosts, true))
+          { // Fallback for unknown array types:
+            worker(inArray, outArray, inExt, outExt, input, validValues,
+                   ghosts, true);
           }
         }
       }
@@ -437,7 +403,7 @@ int vtkStructuredGridAppend::RequestData(
 int vtkStructuredGridAppend::FillInputPortInformation(int i, vtkInformation* info)
 {
   info->Set(vtkAlgorithm::INPUT_IS_REPEATABLE(), 1);
-  return this->Superclass::FillInputPortInformation(i,info);
+  return this->Superclass::FillInputPortInformation(i, info);
 }
 
 //----------------------------------------------------------------------------
