@@ -19,6 +19,8 @@
 #include "vtkCharArray.h"
 #include "vtkDoubleArray.h"
 #include "vtkFloatArray.h"
+#include "vtkIdList.h"
+#include "vtkIdListCollection.h"
 #include "vtkImplicitFunction.h"
 #include "vtkInformation.h"
 #include "vtkInformationVector.h"
@@ -28,22 +30,20 @@
 #include "vtkObjectFactory.h"
 #include "vtkPointData.h"
 #include "vtkPolyData.h"
+#include "vtkPolygonBuilder.h"
 #include "vtkShortArray.h"
+#include "vtkSmartPointer.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
 #include "vtkStructuredPoints.h"
 #include "vtkUnsignedCharArray.h"
 #include "vtkUnsignedIntArray.h"
 #include "vtkUnsignedLongArray.h"
 #include "vtkUnsignedShortArray.h"
-#include "vtkPolygonBuilder.h"
-#include "vtkIdList.h"
-#include "vtkIdListCollection.h"
-#include "vtkSmartPointer.h"
 
 #include <cmath>
 
 vtkStandardNewMacro(vtkSynchronizedTemplatesCutter3D);
-vtkCxxSetObjectMacro(vtkSynchronizedTemplatesCutter3D,CutFunction,vtkImplicitFunction);
+vtkCxxSetObjectMacro(vtkSynchronizedTemplatesCutter3D, CutFunction, vtkImplicitFunction);
 
 //----------------------------------------------------------------------------
 // Description:
@@ -51,26 +51,26 @@ vtkCxxSetObjectMacro(vtkSynchronizedTemplatesCutter3D,CutFunction,vtkImplicitFun
 // of 0.0. The ImageRange are set to extract the first k-plane.
 vtkSynchronizedTemplatesCutter3D::vtkSynchronizedTemplatesCutter3D()
 {
-  this->CutFunction = 0;
+  this->CutFunction = nullptr;
   this->OutputPointsPrecision = vtkAlgorithm::DEFAULT_PRECISION;
 }
 
 //----------------------------------------------------------------------------
 vtkSynchronizedTemplatesCutter3D::~vtkSynchronizedTemplatesCutter3D()
 {
-  this->SetCutFunction(NULL);
+  this->SetCutFunction(nullptr);
 }
 
 //----------------------------------------------------------------------------
 static void vtkSynchronizedTemplatesCutter3DInitializeOutput(
-  int *ext, int precision, vtkImageData *input, vtkPolyData *o)
+  int* ext, int precision, vtkImageData* input, vtkPolyData* o)
 {
-  vtkPoints *newPts;
-  vtkCellArray *newPolys;
+  vtkPoints* newPts;
+  vtkCellArray* newPolys;
   long estimatedSize;
 
-  estimatedSize = (int) pow ((double)
-      ((ext[1]-ext[0]+1)*(ext[3]-ext[2]+1)*(ext[5]-ext[4]+1)), .75);
+  estimatedSize =
+    (int)pow((double)((ext[1] - ext[0] + 1) * (ext[3] - ext[2] + 1) * (ext[5] - ext[4] + 1)), .75);
   if (estimatedSize < 1024)
   {
     estimatedSize = 1024;
@@ -78,10 +78,10 @@ static void vtkSynchronizedTemplatesCutter3DInitializeOutput(
   newPts = vtkPoints::New();
 
   // set precision for the points in the output
-  if(precision == vtkAlgorithm::DEFAULT_PRECISION)
+  if (precision == vtkAlgorithm::DEFAULT_PRECISION)
   {
-    vtkPointSet *inputPointSet = vtkPointSet::SafeDownCast(input);
-    if(inputPointSet)
+    vtkPointSet* inputPointSet = vtkPointSet::SafeDownCast(input);
+    if (inputPointSet)
     {
       newPts->SetDataType(inputPointSet->GetPoints()->GetDataType());
     }
@@ -90,25 +90,23 @@ static void vtkSynchronizedTemplatesCutter3DInitializeOutput(
       newPts->SetDataType(VTK_FLOAT);
     }
   }
-  else if(precision == vtkAlgorithm::SINGLE_PRECISION)
+  else if (precision == vtkAlgorithm::SINGLE_PRECISION)
   {
     newPts->SetDataType(VTK_FLOAT);
   }
-  else if(precision == vtkAlgorithm::DOUBLE_PRECISION)
+  else if (precision == vtkAlgorithm::DOUBLE_PRECISION)
   {
     newPts->SetDataType(VTK_DOUBLE);
   }
 
-  newPts->Allocate(estimatedSize,estimatedSize);
+  newPts->Allocate(estimatedSize, estimatedSize);
   newPolys = vtkCellArray::New();
-  newPolys->Allocate(newPolys->EstimateSize(estimatedSize,3));
+  newPolys->AllocateEstimate(estimatedSize, 3);
 
   o->GetPointData()->CopyAllOn();
 
-  o->GetPointData()->InterpolateAllocate(input->GetPointData(),
-                                         estimatedSize,estimatedSize/2);
-  o->GetCellData()->CopyAllocate(input->GetCellData(),
-                                 estimatedSize,estimatedSize/2);
+  o->GetPointData()->InterpolateAllocate(input->GetPointData(), estimatedSize, estimatedSize / 2);
+  o->GetCellData()->CopyAllocate(input->GetCellData(), estimatedSize, estimatedSize / 2);
 
   o->SetPoints(newPts);
   newPts->Delete();
@@ -122,27 +120,27 @@ static void vtkSynchronizedTemplatesCutter3DInitializeOutput(
 // Contouring filter specialized for images
 //
 template <class T>
-void ContourImage(vtkSynchronizedTemplatesCutter3D *self, int *exExt,
-                  vtkImageData *data, vtkPolyData *output, T *ptr, bool outputTriangles)
+void ContourImage(vtkSynchronizedTemplatesCutter3D* self, int* exExt, vtkImageData* data,
+  vtkPolyData* output, T* ptr, bool outputTriangles)
 {
-  int *inExt = data->GetExtent();
+  int* inExt = data->GetExtent();
   vtkIdType xdim = exExt[1] - exExt[0] + 1;
   vtkIdType ydim = exExt[3] - exExt[2] + 1;
-  double *values = self->GetValues();
-  int numContours = self->GetNumberOfContours();
+  double* values = self->GetValues();
+  vtkIdType numContours = self->GetNumberOfContours();
   T *inPtrX, *inPtrY, *inPtrZ;
   T *s0, *s1, *s2, *s3;
   int xMin, xMax, yMin, yMax, zMin, zMax;
   vtkIdType xInc, yInc, zInc;
   int xIncFunc, yIncFunc, zIncFunc, scalarZIncFunc;
-  double *origin = data->GetOrigin();
-  double *spacing = data->GetSpacing();
+  double* origin = data->GetOrigin();
+  double* spacing = data->GetSpacing();
   vtkIdType *isect1Ptr, *isect2Ptr;
   double y, z, t;
   int i, j, k;
   vtkIdType zstep, yisectstep;
   vtkIdType offsets[12];
-  int *tablePtr;
+  int* tablePtr;
   vtkIdType idx;
   int vidx;
   double x[3], xz[3];
@@ -151,19 +149,19 @@ void ContourImage(vtkSynchronizedTemplatesCutter3D *self, int *exExt,
   double value;
   // We need to know the edgePointId's for interpolating attributes.
   vtkIdType edgePtId, inCellId, outCellId;
-  vtkPointData *inPD = data->GetPointData();
-  vtkCellData *inCD = data->GetCellData();
-  vtkPointData *outPD = output->GetPointData();
-  vtkCellData *outCD = output->GetCellData();
+  vtkPointData* inPD = data->GetPointData();
+  vtkCellData* inCD = data->GetCellData();
+  vtkPointData* outPD = output->GetPointData();
+  vtkCellData* outCD = output->GetCellData();
   // Use to be arguments
-  vtkPoints *newPts;
-  vtkCellArray *newPolys;
+  vtkPoints* newPts;
+  vtkCellArray* newPolys;
   ptr += self->GetArrayComponent();
   vtkPolygonBuilder polyBuilder;
-  vtkSmartPointer<vtkIdListCollection> polys =
-    vtkSmartPointer<vtkIdListCollection>::New();
+  vtkSmartPointer<vtkIdListCollection> polys = vtkSmartPointer<vtkIdListCollection>::New();
 
-  vtkSynchronizedTemplatesCutter3DInitializeOutput(exExt, self->GetOutputPointsPrecision(), data, output);
+  vtkSynchronizedTemplatesCutter3DInitializeOutput(
+    exExt, self->GetOutputPointsPrecision(), data, output);
   newPts = output->GetPoints();
   newPolys = output->GetPolys();
 
@@ -174,61 +172,58 @@ void ContourImage(vtkSynchronizedTemplatesCutter3D *self, int *exExt,
   zMin = exExt[4];
   zMax = exExt[5];
 
-  vtkImplicitFunction *func = self->GetCutFunction();
+  vtkImplicitFunction* func = self->GetCutFunction();
   if (!func)
   {
     return;
   }
 
   xInc = 1;
-  yInc = xInc*(inExt[1]-inExt[0]+1);
-  zInc = yInc*(inExt[3]-inExt[2]+1);
+  yInc = xInc * (inExt[1] - inExt[0] + 1);
+  zInc = yInc * (inExt[3] - inExt[2] + 1);
 
   // Note that the implicit functions are specified
-  //over exExt so we need to compute the steps differently
+  // over exExt so we need to compute the steps differently
   xIncFunc = 1;
-  yIncFunc = xIncFunc*xdim;
-  zIncFunc = yIncFunc*ydim;
+  yIncFunc = xIncFunc * xdim;
+  zIncFunc = yIncFunc * ydim;
   scalarZIncFunc = zIncFunc;
 
   // Kens increments, probably to do with edge array
-  zstep = xdim*ydim;
-  yisectstep = xdim*3;
+  zstep = xdim * ydim;
+  yisectstep = xdim * 3;
   // compute offsets probably how to get to the edges in the edge array.
-  offsets[0] = -xdim*3;
-  offsets[1] = -xdim*3 + 1;
-  offsets[2] = -xdim*3 + 2;
-  offsets[3] = -xdim*3 + 4;
-  offsets[4] = -xdim*3 + 5;
+  offsets[0] = -xdim * 3;
+  offsets[1] = -xdim * 3 + 1;
+  offsets[2] = -xdim * 3 + 2;
+  offsets[3] = -xdim * 3 + 4;
+  offsets[4] = -xdim * 3 + 5;
   offsets[5] = 0;
   offsets[6] = 2;
   offsets[7] = 5;
-  offsets[8] = (zstep - xdim)*3;
-  offsets[9] = (zstep - xdim)*3 + 1;
-  offsets[10] = (zstep - xdim)*3 + 4;
-  offsets[11] = zstep*3;
+  offsets[8] = (zstep - xdim) * 3;
+  offsets[9] = (zstep - xdim) * 3 + 1;
+  offsets[10] = (zstep - xdim) * 3 + 4;
+  offsets[11] = zstep * 3;
 
   // allocate storage array
-  vtkIdType *isect1 = new vtkIdType [xdim*ydim*3*2];
+  vtkIdType* isect1 = new vtkIdType[xdim * ydim * 3 * 2];
   // set impossible edges to -1
   for (i = 0; i < ydim; i++)
   {
-    isect1[(i+1)*xdim*3-3] = -1;
-    isect1[(i+1)*xdim*3*2-3] = -1;
+    isect1[(i + 1) * xdim * 3 - 3] = -1;
+    isect1[(i + 1) * xdim * 3 * 2 - 3] = -1;
   }
   for (i = 0; i < xdim; i++)
   {
-    isect1[((ydim-1)*xdim + i)*3 + 1] = -1;
-    isect1[((ydim-1)*xdim + i)*3*2 + 1] = -1;
+    isect1[((ydim - 1) * xdim + i) * 3 + 1] = -1;
+    isect1[((ydim - 1) * xdim + i) * 3 * 2 + 1] = -1;
   }
 
   // allocate scalar storage for two slices
-  T *scalars = 0;
-  T *scalars1 = 0;
-  T *scalars2 = 0;
-  scalars = new T [xdim*ydim*2];
-  scalars1 = scalars;
-  scalars2 = scalars + xdim*ydim;
+  T* scalars = new T[xdim * ydim * 2];
+  T* scalars1 = scalars;
+  T* scalars2 = scalars + xdim * ydim;
 
   // for each contour
   for (vidx = 0; vidx < numContours; vidx++)
@@ -237,17 +232,17 @@ void ContourImage(vtkSynchronizedTemplatesCutter3D *self, int *exExt,
     inPtrZ = ptr;
 
     // fill the first slice
-    z = origin[2] + spacing[2]*zMin;
+    z = origin[2] + spacing[2] * zMin;
     x[2] = z;
-    T *scalarsTmp = scalars1;
+    T* scalarsTmp = scalars1;
     scalars1 = scalars2;
     scalars2 = scalarsTmp;
     for (j = yMin; j <= yMax; j++)
     {
-      x[1] = origin[1] + spacing[1]*j;
+      x[1] = origin[1] + spacing[1] * j;
       for (i = xMin; i <= xMax; i++)
       {
-        x[0] = origin[0] + spacing[0]*i;
+        x[0] = origin[0] + spacing[0] * i;
         *scalarsTmp = func->FunctionValue(x);
         scalarsTmp++;
       }
@@ -257,12 +252,12 @@ void ContourImage(vtkSynchronizedTemplatesCutter3D *self, int *exExt,
     //==================================================================
     for (k = zMin; k <= zMax; k++)
     {
-      self->UpdateProgress((double)vidx/numContours +
-                           (k-zMin)/((zMax - zMin+1.0)*numContours));
+      self->UpdateProgress(
+        (double)vidx / numContours + (k - zMin) / ((zMax - zMin + 1.0) * numContours));
       inPtrY = inPtrZ;
 
       // for each slice compute the scalars
-      z = origin[2] + spacing[2]*(k+1);
+      z = origin[2] + spacing[2] * (k + 1);
       x[2] = z;
       scalarsTmp = scalars1;
       scalars1 = scalars2;
@@ -272,10 +267,10 @@ void ContourImage(vtkSynchronizedTemplatesCutter3D *self, int *exExt,
       {
         for (j = yMin; j <= yMax; j++)
         {
-          x[1] = origin[1] + spacing[1]*j;
+          x[1] = origin[1] + spacing[1] * j;
           for (i = xMin; i <= xMax; i++)
           {
-            x[0] = origin[0] + spacing[0]*i;
+            x[0] = origin[0] + spacing[0] * i;
             *scalarsTmp = func->FunctionValue(x);
             scalarsTmp++;
           }
@@ -284,42 +279,41 @@ void ContourImage(vtkSynchronizedTemplatesCutter3D *self, int *exExt,
       inPtrY = scalars1;
       scalarZIncFunc = -scalarZIncFunc;
 
-      z = origin[2] + spacing[2]*k;
+      z = origin[2] + spacing[2] * k;
       x[2] = z;
 
       // swap the buffers
-      if (k%2)
+      if (k % 2)
       {
-        offsets[8] = (zstep - xdim)*3;
-        offsets[9] = (zstep - xdim)*3 + 1;
-        offsets[10] = (zstep - xdim)*3 + 4;
-        offsets[11] = zstep*3;
+        offsets[8] = (zstep - xdim) * 3;
+        offsets[9] = (zstep - xdim) * 3 + 1;
+        offsets[10] = (zstep - xdim) * 3 + 4;
+        offsets[11] = zstep * 3;
         isect1Ptr = isect1;
-        isect2Ptr = isect1 + xdim*ydim*3;
+        isect2Ptr = isect1 + xdim * ydim * 3;
       }
       else
       {
-        offsets[8] = (-zstep - xdim)*3;
-        offsets[9] = (-zstep - xdim)*3 + 1;
-        offsets[10] = (-zstep - xdim)*3 + 4;
-        offsets[11] = -zstep*3;
-        isect1Ptr = isect1 + xdim*ydim*3;
+        offsets[8] = (-zstep - xdim) * 3;
+        offsets[9] = (-zstep - xdim) * 3 + 1;
+        offsets[10] = (-zstep - xdim) * 3 + 4;
+        offsets[11] = -zstep * 3;
+        isect1Ptr = isect1 + xdim * ydim * 3;
         isect2Ptr = isect1;
       }
 
       for (j = yMin; j <= yMax; j++)
       {
         // Should not impact performance here/
-        edgePtId = (xMin-inExt[0])*xInc + (j-inExt[2])*yInc + (k-inExt[4])*zInc;
+        edgePtId = (xMin - inExt[0]) * xInc + (j - inExt[2]) * yInc + (k - inExt[4]) * zInc;
 
         // Increments are different for cells.  Since the cells are not
         // contoured until the second row of templates, subtract 1 from
         // i,j,and k.  Note: first cube is formed when i=0, j=1, and k=1.
-        inCellId =
-          (xMin-inExt[0]) + (inExt[1]-inExt[0])*
-          ( (j-inExt[2]-1) + (k-inExt[4]-1)*(inExt[3]-inExt[2]) );
+        inCellId = (xMin - inExt[0]) +
+          (inExt[1] - inExt[0]) * ((j - inExt[2] - 1) + (k - inExt[4] - 1) * (inExt[3] - inExt[2]));
 
-        y = origin[1] + j*spacing[1];
+        y = origin[1] + j * spacing[1];
         xz[1] = y;
 
         s1 = inPtrY;
@@ -342,26 +336,26 @@ void ContourImage(vtkSynchronizedTemplatesCutter3D *self, int *exExt,
               // watch for degenerate points
               if (*s0 == value)
               {
-                if (i > xMin && *(isect2Ptr-3) > -1)
+                if (i > xMin && *(isect2Ptr - 3) > -1)
                 {
-                  *isect2Ptr = *(isect2Ptr-3);
+                  *isect2Ptr = *(isect2Ptr - 3);
                 }
                 else if (j > yMin && *(isect2Ptr - yisectstep + 1) > -1)
                 {
                   *isect2Ptr = *(isect2Ptr - yisectstep + 1);
                 }
-                else if (k > zMin && *(isect1Ptr+2) > -1)
+                else if (k > zMin && *(isect1Ptr + 2) > -1)
                 {
-                  *isect2Ptr = *(isect1Ptr+2);
+                  *isect2Ptr = *(isect1Ptr + 2);
                 }
               }
               else if (*s1 == value)
               {
-                if (j > yMin && *(isect2Ptr - yisectstep +4) > -1)
+                if (j > yMin && *(isect2Ptr - yisectstep + 4) > -1)
                 {
                   *isect2Ptr = *(isect2Ptr - yisectstep + 4);
                 }
-                else if (k > zMin && i < xMax && *(isect1Ptr + 5) > -1)
+                else if (k > zMin && i<xMax&&*(isect1Ptr + 5)> - 1)
                 {
                   *isect2Ptr = *(isect1Ptr + 5);
                 }
@@ -370,10 +364,10 @@ void ContourImage(vtkSynchronizedTemplatesCutter3D *self, int *exExt,
               if (*isect2Ptr == -1)
               {
                 t = (value - (double)(*s0)) / ((double)(*s1) - (double)(*s0));
-                x[0] = origin[0] + spacing[0]*(i+t);
+                x[0] = origin[0] + spacing[0] * (i + t);
                 x[1] = y;
                 *isect2Ptr = newPts->InsertNextPoint(x);
-                outPD->InterpolateEdge(inPD, *isect2Ptr, edgePtId, edgePtId+1, t);
+                outPD->InterpolateEdge(inPD, *isect2Ptr, edgePtId, edgePtId + 1, t);
               }
             }
           }
@@ -389,31 +383,31 @@ void ContourImage(vtkSynchronizedTemplatesCutter3D *self, int *exExt,
                 {
                   *(isect2Ptr + 1) = *isect2Ptr;
                 }
-                else if (i > xMin && *(isect2Ptr-3) > -1)
+                else if (i > xMin && *(isect2Ptr - 3) > -1)
                 {
-                  *(isect2Ptr + 1) = *(isect2Ptr-3);
+                  *(isect2Ptr + 1) = *(isect2Ptr - 3);
                 }
                 else if (j > yMin && *(isect2Ptr - yisectstep + 1) > -1)
                 {
                   *(isect2Ptr + 1) = *(isect2Ptr - yisectstep + 1);
                 }
-                else if (k > zMin && *(isect1Ptr+2) > -1)
+                else if (k > zMin && *(isect1Ptr + 2) > -1)
                 {
-                  *(isect2Ptr + 1) = *(isect1Ptr+2);
+                  *(isect2Ptr + 1) = *(isect1Ptr + 2);
                 }
               }
               else if (*s2 == value && k > zMin && *(isect1Ptr + yisectstep + 2) > -1)
               {
-                *(isect2Ptr+1) = *(isect1Ptr + yisectstep + 2);
+                *(isect2Ptr + 1) = *(isect1Ptr + yisectstep + 2);
               }
               // if the edge has not been set yet then it is a new point
               if (*(isect2Ptr + 1) == -1)
               {
                 t = (value - (double)(*s0)) / ((double)(*s2) - (double)(*s0));
-                x[0] = origin[0] + spacing[0]*i;
-                x[1] = y + spacing[1]*t;
+                x[0] = origin[0] + spacing[0] * i;
+                x[1] = y + spacing[1] * t;
                 *(isect2Ptr + 1) = newPts->InsertNextPoint(x);
-                outPD->InterpolateEdge(inPD, *(isect2Ptr+1), edgePtId, edgePtId+yInc, t);
+                outPD->InterpolateEdge(inPD, *(isect2Ptr + 1), edgePtId, edgePtId + yInc, t);
               }
             }
           }
@@ -429,30 +423,30 @@ void ContourImage(vtkSynchronizedTemplatesCutter3D *self, int *exExt,
                 {
                   *(isect2Ptr + 2) = *isect2Ptr;
                 }
-                else if (*(isect2Ptr+1) > -1)
+                else if (*(isect2Ptr + 1) > -1)
                 {
-                  *(isect2Ptr + 2) = *(isect2Ptr+1);
+                  *(isect2Ptr + 2) = *(isect2Ptr + 1);
                 }
-                else if (i > xMin && *(isect2Ptr-3) > -1)
+                else if (i > xMin && *(isect2Ptr - 3) > -1)
                 {
-                  *(isect2Ptr + 2) = *(isect2Ptr-3);
+                  *(isect2Ptr + 2) = *(isect2Ptr - 3);
                 }
                 else if (j > yMin && *(isect2Ptr - yisectstep + 1) > -1)
                 {
                   *(isect2Ptr + 2) = *(isect2Ptr - yisectstep + 1);
                 }
-                else if (k > zMin && *(isect1Ptr+2) > -1)
+                else if (k > zMin && *(isect1Ptr + 2) > -1)
                 {
-                  *(isect2Ptr + 2) = *(isect1Ptr+2);
+                  *(isect2Ptr + 2) = *(isect1Ptr + 2);
                 }
               }
               if (*(isect2Ptr + 2) == -1)
               {
                 t = (value - (double)(*s0)) / ((double)(*s3) - (double)(*s0));
-                xz[0] = origin[0] + spacing[0]*i;
-                xz[2] = z + spacing[2]*t;
+                xz[0] = origin[0] + spacing[0] * i;
+                xz[2] = z + spacing[2] * t;
                 *(isect2Ptr + 2) = newPts->InsertNextPoint(xz);
-                outPD->InterpolateEdge(inPD, *(isect2Ptr+2), edgePtId, edgePtId+zInc, t);
+                outPD->InterpolateEdge(inPD, *(isect2Ptr + 2), edgePtId, edgePtId + zInc, t);
               }
             }
           }
@@ -466,20 +460,20 @@ void ContourImage(vtkSynchronizedTemplatesCutter3D *self, int *exExt,
           {
             idx = (v0 ? 4096 : 0);
             idx = idx + (*(isect1Ptr - yisectstep) > -1 ? 2048 : 0);
-            idx = idx + (*(isect1Ptr -yisectstep +1) > -1 ? 1024 : 0);
-            idx = idx + (*(isect1Ptr -yisectstep +2) > -1 ? 512 : 0);
-            idx = idx + (*(isect1Ptr -yisectstep +4) > -1 ? 256 : 0);
-            idx = idx + (*(isect1Ptr -yisectstep +5) > -1 ? 128 : 0);
+            idx = idx + (*(isect1Ptr - yisectstep + 1) > -1 ? 1024 : 0);
+            idx = idx + (*(isect1Ptr - yisectstep + 2) > -1 ? 512 : 0);
+            idx = idx + (*(isect1Ptr - yisectstep + 4) > -1 ? 256 : 0);
+            idx = idx + (*(isect1Ptr - yisectstep + 5) > -1 ? 128 : 0);
             idx = idx + (*(isect1Ptr) > -1 ? 64 : 0);
             idx = idx + (*(isect1Ptr + 2) > -1 ? 32 : 0);
             idx = idx + (*(isect1Ptr + 5) > -1 ? 16 : 0);
-            idx = idx + (*(isect2Ptr -yisectstep) > -1 ? 8 : 0);
-            idx = idx + (*(isect2Ptr -yisectstep +1) > -1 ? 4 : 0);
-            idx = idx + (*(isect2Ptr -yisectstep +4) > -1 ? 2 : 0);
+            idx = idx + (*(isect2Ptr - yisectstep) > -1 ? 8 : 0);
+            idx = idx + (*(isect2Ptr - yisectstep + 1) > -1 ? 4 : 0);
+            idx = idx + (*(isect2Ptr - yisectstep + 4) > -1 ? 2 : 0);
             idx = idx + (*(isect2Ptr) > -1 ? 1 : 0);
 
-            tablePtr = VTK_SYNCHRONIZED_TEMPLATES_3D_TABLE_2
-              + VTK_SYNCHRONIZED_TEMPLATES_3D_TABLE_1[idx];
+            tablePtr =
+              VTK_SYNCHRONIZED_TEMPLATES_3D_TABLE_2 + VTK_SYNCHRONIZED_TEMPLATES_3D_TABLE_1[idx];
 
             if (!outputTriangles)
             {
@@ -493,13 +487,11 @@ void ContourImage(vtkSynchronizedTemplatesCutter3D *self, int *exExt,
               tablePtr++;
               ptIds[2] = *(isect1Ptr + offsets[*tablePtr]);
               tablePtr++;
-              if (ptIds[0] != ptIds[1] &&
-                  ptIds[0] != ptIds[2] &&
-                  ptIds[1] != ptIds[2])
+              if (ptIds[0] != ptIds[1] && ptIds[0] != ptIds[2] && ptIds[1] != ptIds[2])
               {
-                if(outputTriangles)
+                if (outputTriangles)
                 {
-                  outCellId = newPolys->InsertNextCell(3,ptIds);
+                  outCellId = newPolys->InsertNextCell(3, ptIds);
                   outCD->CopyData(inCD, inCellId, outCellId);
                 }
                 else
@@ -508,14 +500,14 @@ void ContourImage(vtkSynchronizedTemplatesCutter3D *self, int *exExt,
                 }
               }
             }
-            if(!outputTriangles)
+            if (!outputTriangles)
             {
               polyBuilder.GetPolygons(polys);
               int nPolys = polys->GetNumberOfItems();
               for (int polyId = 0; polyId < nPolys; ++polyId)
               {
                 vtkIdList* poly = polys->GetItem(polyId);
-                if(poly->GetNumberOfIds()!=0)
+                if (poly->GetNumberOfIds() != 0)
                 {
                   outCellId = newPolys->InsertNextCell(poly);
                   outCD->CopyData(inCD, inCellId, outCellId);
@@ -536,52 +528,46 @@ void ContourImage(vtkSynchronizedTemplatesCutter3D *self, int *exExt,
       inPtrZ += zIncFunc;
     }
   }
-  delete [] isect1;
+  delete[] isect1;
 
-  delete [] scalars;
+  delete[] scalars;
 }
 
 //----------------------------------------------------------------------------
 //
 // Contouring filter specialized for images (or slices from images)
 //
-void vtkSynchronizedTemplatesCutter3D::ThreadedExecute(vtkImageData *data,
-                                                       vtkInformation *outInfo,
-                                                       int)
+void vtkSynchronizedTemplatesCutter3D::ThreadedExecute(
+  vtkImageData* data, vtkInformation* outInfo, int)
 {
-  vtkPolyData *output;
+  vtkPolyData* output;
 
   vtkDebugMacro(<< "Executing Cutter3D structured contour");
 
   output = vtkPolyData::SafeDownCast(outInfo->Get(vtkDataObject::DATA_OBJECT()));
 
   int* exExt = data->GetExtent();
-  if ( exExt[0] >= exExt[1] || exExt[2] >= exExt[3] || exExt[4] >= exExt[5] )
+  if (exExt[0] >= exExt[1] || exExt[2] >= exExt[3] || exExt[4] >= exExt[5])
   {
-    vtkDebugMacro(<<"Cutter3D structured contours requires Cutter3D data");
+    vtkDebugMacro(<< "Cutter3D structured contours requires Cutter3D data");
     return;
   }
 
-
   // Check data type and execute appropriate function
-  ContourImage(this, exExt, data, output, (double *)0, this->GenerateTriangles!=0);
+  ContourImage(this, exExt, data, output, (double*)nullptr, this->GenerateTriangles != 0);
 }
 
 //----------------------------------------------------------------------------
-int vtkSynchronizedTemplatesCutter3D::RequestData(
-  vtkInformation *vtkNotUsed(request),
-  vtkInformationVector **inputVector,
-  vtkInformationVector *outputVector)
+int vtkSynchronizedTemplatesCutter3D::RequestData(vtkInformation* vtkNotUsed(request),
+  vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
   // get the info objects
-  vtkInformation *inInfo = inputVector[0]->GetInformationObject(0);
-  vtkInformation *outInfo = outputVector->GetInformationObject(0);
+  vtkInformation* inInfo = inputVector[0]->GetInformationObject(0);
+  vtkInformation* outInfo = outputVector->GetInformationObject(0);
 
   // get the input and output
-  vtkImageData *input = vtkImageData::SafeDownCast(
-    inInfo->Get(vtkDataObject::DATA_OBJECT()));
-  vtkPolyData *output = vtkPolyData::SafeDownCast(
-    outInfo->Get(vtkDataObject::DATA_OBJECT()));
+  vtkImageData* input = vtkImageData::SafeDownCast(inInfo->Get(vtkDataObject::DATA_OBJECT()));
+  vtkPolyData* output = vtkPolyData::SafeDownCast(outInfo->Get(vtkDataObject::DATA_OBJECT()));
 
   // Just call the threaded execute directly.
   this->ThreadedExecute(input, outInfo, 0);
@@ -591,13 +577,10 @@ int vtkSynchronizedTemplatesCutter3D::RequestData(
   return 1;
 }
 
-
 //----------------------------------------------------------------------------
 void vtkSynchronizedTemplatesCutter3D::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
   os << indent << "Cut Function: " << this->CutFunction << "\n";
-  os << indent << "Precision of the output points: "
-     << this->OutputPointsPrecision << "\n";
+  os << indent << "Precision of the output points: " << this->OutputPointsPrecision << "\n";
 }
-
