@@ -14,14 +14,14 @@
   =========================================================================*/
 #include "vtkTemporalInterpolatedVelocityField.h"
 
+#include "vtkAbstractCellLocator.h"
+#include "vtkCachingInterpolatedVelocityField.h"
 #include "vtkDataArray.h"
-#include "vtkDoubleArray.h"
 #include "vtkDataSet.h"
+#include "vtkDoubleArray.h"
 #include "vtkGenericCell.h"
 #include "vtkObjectFactory.h"
 #include "vtkPointData.h"
-#include "vtkCachingInterpolatedVelocityField.h"
-#include "vtkAbstractCellLocator.h"
 
 #include <vector>
 //---------------------------------------------------------------------------
@@ -29,16 +29,16 @@ vtkStandardNewMacro(vtkTemporalInterpolatedVelocityField);
 //---------------------------------------------------------------------------
 vtkTemporalInterpolatedVelocityField::vtkTemporalInterpolatedVelocityField()
 {
-  this->NumFuncs         = 3; // u, v, w
-  this->NumIndepVars     = 4; // x, y, z, t
+  this->NumFuncs = 3;     // u, v, w
+  this->NumIndepVars = 4; // x, y, z, t
   this->IVF[0] = vtkSmartPointer<vtkCachingInterpolatedVelocityField>::New();
   this->IVF[1] = vtkSmartPointer<vtkCachingInterpolatedVelocityField>::New();
-  this->LastGoodVelocity[0]=0.0;
-  this->LastGoodVelocity[1]=0.0;
-  this->LastGoodVelocity[2]=0.0;
-  this->CurrentWeight=0.0;
-  this->OneMinusWeight=1.0;
-  this->ScaleCoeff=1.0;
+  this->LastGoodVelocity[0] = 0.0;
+  this->LastGoodVelocity[1] = 0.0;
+  this->LastGoodVelocity[2] = 0.0;
+  this->CurrentWeight = 0.0;
+  this->OneMinusWeight = 1.0;
+  this->ScaleCoeff = 1.0;
 
   this->Vals1[0] = this->Vals1[1] = this->Vals1[2] = 0.0;
   this->Vals2[0] = this->Vals2[1] = this->Vals2[2] = 0.0;
@@ -50,29 +50,30 @@ vtkTemporalInterpolatedVelocityField::~vtkTemporalInterpolatedVelocityField()
 {
   this->NumFuncs = 0;
   this->NumIndepVars = 0;
-  this->SetVectorsSelection(0);
-  this->IVF[0] = NULL;
-  this->IVF[1] = NULL;
+  this->SetVectorsSelection(nullptr);
+  this->IVF[0] = nullptr;
+  this->IVF[1] = nullptr;
 }
 //---------------------------------------------------------------------------
-void vtkTemporalInterpolatedVelocityField::SetDataSetAtTime(int I, int N, double T, vtkDataSet* dataset, bool staticdataset)
+void vtkTemporalInterpolatedVelocityField::SetDataSetAtTime(
+  int I, int N, double T, vtkDataSet* dataset, bool staticdataset)
 {
   this->Times[N] = T;
-  if ((this->Times[1]-this->Times[0])>0)
+  if ((this->Times[1] - this->Times[0]) > 0)
   {
-    this->ScaleCoeff = 1.0/(this->Times[1]-this->Times[0]);
+    this->ScaleCoeff = 1.0 / (this->Times[1] - this->Times[0]);
   }
-  if (N==0)
+  if (N == 0)
   {
-    this->IVF[N]->SetDataSet(I, dataset, staticdataset, NULL);
+    this->IVF[N]->SetDataSet(I, dataset, staticdataset, nullptr);
   }
   // when the datasets for the second time set are added, set the static flag
-  if (N==1)
+  if (N == 1)
   {
     bool is_static = staticdataset && this->IVF[0]->CacheList[I].StaticDataSet;
-    if (static_cast<size_t>(I)>=this->StaticDataSets.size())
+    if (static_cast<size_t>(I) >= this->StaticDataSets.size())
     {
-      this->StaticDataSets.resize(I+1,is_static);
+      this->StaticDataSets.resize(I + 1, is_static);
     }
     if (is_static)
     {
@@ -80,7 +81,7 @@ void vtkTemporalInterpolatedVelocityField::SetDataSetAtTime(int I, int N, double
     }
     else
     {
-      this->IVF[N]->SetDataSet(I, dataset, staticdataset, NULL);
+      this->IVF[N]->SetDataSet(I, dataset, staticdataset, nullptr);
     }
   }
 }
@@ -90,7 +91,7 @@ bool vtkTemporalInterpolatedVelocityField::IsStatic(int datasetIndex)
   return this->StaticDataSets[datasetIndex];
 }
 //---------------------------------------------------------------------------
-void vtkTemporalInterpolatedVelocityField::SetVectorsSelection(const char *v)
+void vtkTemporalInterpolatedVelocityField::SetVectorsSelection(const char* v)
 {
   this->IVF[0]->SelectVectors(v);
   this->IVF[1]->SelectVectors(v);
@@ -104,7 +105,7 @@ void vtkTemporalInterpolatedVelocityField::ClearCache()
 //---------------------------------------------------------------------------
 void vtkTemporalInterpolatedVelocityField::SetCachedCellIds(vtkIdType id[2], int ds[2])
 {
-  if (id[0]!=-1)
+  if (id[0] != -1)
   {
     this->IVF[0]->SetLastCellInfo(id[0], ds[0]);
   }
@@ -113,7 +114,7 @@ void vtkTemporalInterpolatedVelocityField::SetCachedCellIds(vtkIdType id[2], int
     this->IVF[0]->SetLastCellInfo(-1, 0);
   }
   //
-  if (id[1]!=-1)
+  if (id[1] != -1)
   {
     this->IVF[1]->SetLastCellInfo(id[1], ds[1]);
   }
@@ -126,16 +127,16 @@ void vtkTemporalInterpolatedVelocityField::SetCachedCellIds(vtkIdType id[2], int
 bool vtkTemporalInterpolatedVelocityField::GetCachedCellIds(vtkIdType id[2], int ds[2])
 {
   id[0] = this->IVF[0]->LastCellId;
-  ds[0] = (id[0]==-1) ? 0 : this->IVF[0]->LastCacheIndex;
+  ds[0] = (id[0] == -1) ? 0 : this->IVF[0]->LastCacheIndex;
   //
   id[1] = this->IVF[1]->LastCellId;
-  ds[1] = (id[1]==-1) ? 0 : this->IVF[1]->LastCacheIndex;
-  return ((id[0]>=0) && (id[1]>=0));
+  ds[1] = (id[1] == -1) ? 0 : this->IVF[1]->LastCacheIndex;
+  return ((id[0] >= 0) && (id[1] >= 0));
 }
 //---------------------------------------------------------------------------
 void vtkTemporalInterpolatedVelocityField::AdvanceOneTimeStep()
 {
-  for (unsigned int i=0; i<this->IVF[0]->CacheList.size(); i++)
+  for (unsigned int i = 0; i < this->IVF[0]->CacheList.size(); i++)
   {
     if (this->IsStatic(i))
     {
@@ -154,10 +155,10 @@ void vtkTemporalInterpolatedVelocityField::ShowCacheResults()
 {
   vtkErrorMacro(<< ")\n"
                 << "T0 - (cell hit : " << this->IVF[0]->CellCacheHit
-                << "  (dataset hit : " << this->IVF[0]->DataSetCacheHit-this->IVF[0]->CellCacheHit
-                << "         (miss : " << this->IVF[0]->CacheMiss       << ")\n"
+                << "  (dataset hit : " << this->IVF[0]->DataSetCacheHit - this->IVF[0]->CellCacheHit
+                << "         (miss : " << this->IVF[0]->CacheMiss << ")\n"
                 << "T1 - (cell hit : " << this->IVF[1]->CellCacheHit
-                << "  (dataset hit : " << this->IVF[1]->DataSetCacheHit-this->IVF[1]->CellCacheHit
+                << "  (dataset hit : " << this->IVF[1]->DataSetCacheHit - this->IVF[1]->CellCacheHit
                 << "         (miss : " << this->IVF[1]->CacheMiss);
 }
 //---------------------------------------------------------------------------
@@ -165,13 +166,13 @@ static double vtkTIVFWeightTolerance = 1E-3;
 // Evaluate u,v,w at x,y,z,t
 int vtkTemporalInterpolatedVelocityField::TestPoint(double* x)
 {
-  this->CurrentWeight  = (x[3]-this->Times[0])*this->ScaleCoeff;
+  this->CurrentWeight = (x[3] - this->Times[0]) * this->ScaleCoeff;
   this->OneMinusWeight = 1.0 - this->CurrentWeight;
-  if (this->CurrentWeight<(0.0+vtkTIVFWeightTolerance))
+  if (this->CurrentWeight < (0.0 + vtkTIVFWeightTolerance))
   {
     this->CurrentWeight = 0.0;
   }
-  if (this->CurrentWeight>(1.0-vtkTIVFWeightTolerance))
+  if (this->CurrentWeight > (1.0 - vtkTIVFWeightTolerance))
   {
     this->CurrentWeight = 1.0;
   }
@@ -186,9 +187,10 @@ int vtkTemporalInterpolatedVelocityField::TestPoint(double* x)
       // compute using weights from dataset 0 and vectors from dataset 1
       this->IVF[1]->SetLastCellInfo(this->IVF[0]->LastCellId, this->IVF[0]->LastCacheIndex);
       this->IVF[0]->FastCompute(this->IVF[1]->Cache, this->Vals2);
-      for (int i=0; i<this->NumFuncs; i++)
+      for (int i = 0; i < this->NumFuncs; i++)
       {
-        this->LastGoodVelocity[i] = this->OneMinusWeight*this->Vals1[i] + this->CurrentWeight*this->Vals2[i];
+        this->LastGoodVelocity[i] =
+          this->OneMinusWeight * this->Vals1[i] + this->CurrentWeight * this->Vals2[i];
       }
       return ID_INSIDE_ALL;
     }
@@ -196,16 +198,17 @@ int vtkTemporalInterpolatedVelocityField::TestPoint(double* x)
     if (!this->IVF[1]->FunctionValues(x, this->Vals2))
     {
       // inside at T0, but outside at T1, return velocity for T0
-      for (int i=0; i<this->NumFuncs; i++)
+      for (int i = 0; i < this->NumFuncs; i++)
       {
         this->LastGoodVelocity[i] = this->Vals1[i];
       }
       return ID_OUTSIDE_T1;
     }
     // both valid, compute correct value
-    for (int i=0; i<this->NumFuncs; i++)
+    for (int i = 0; i < this->NumFuncs; i++)
     {
-      this->LastGoodVelocity[i] = this->OneMinusWeight*this->Vals1[i] + this->CurrentWeight*this->Vals2[i];
+      this->LastGoodVelocity[i] =
+        this->OneMinusWeight * this->Vals1[i] + this->CurrentWeight * this->Vals2[i];
     }
     return ID_INSIDE_ALL;
   }
@@ -219,7 +222,7 @@ int vtkTemporalInterpolatedVelocityField::TestPoint(double* x)
   if (this->IVF[1]->FunctionValues(x, this->Vals2))
   {
     // inside at T1, but outside at T0, return velocity for T1
-    for (int i=0; i<this->NumFuncs; i++)
+    for (int i = 0; i < this->NumFuncs; i++)
     {
       this->LastGoodVelocity[i] = this->Vals2[i];
     }
@@ -251,11 +254,11 @@ int vtkTemporalInterpolatedVelocityField::QuickTestPoint(double* x)
 // Evaluate u,v,w at x,y,z,t
 int vtkTemporalInterpolatedVelocityField::FunctionValues(double* x, double* u)
 {
-  if (this->TestPoint(x)==ID_OUTSIDE_ALL)
+  if (this->TestPoint(x) == ID_OUTSIDE_ALL)
   {
     return 0;
   }
-  for (int i=0; i<this->NumFuncs; i++)
+  for (int i = 0; i < this->NumFuncs; i++)
   {
     u[i] = this->LastGoodVelocity[i];
   }
@@ -267,13 +270,13 @@ int vtkTemporalInterpolatedVelocityField::FunctionValuesAtT(int T, double* x, do
   //
   // Try velocity at T0
   //
-  if (T==0)
+  if (T == 0)
   {
     if (!this->IVF[0]->FunctionValues(x, this->Vals1))
     {
       return 0;
     }
-    for (int i=0; i<this->NumFuncs; i++)
+    for (int i = 0; i < this->NumFuncs; i++)
     {
       this->LastGoodVelocity[i] = u[i] = this->Vals1[i];
     }
@@ -285,13 +288,13 @@ int vtkTemporalInterpolatedVelocityField::FunctionValuesAtT(int T, double* x, do
   //
   // Try velocity at T1
   //
-  else if (T==1)
+  else if (T == 1)
   {
     if (!this->IVF[1]->FunctionValues(x, this->Vals2))
     {
       return 0;
     }
-    for (int i=0; i<this->NumFuncs; i++)
+    for (int i = 0; i < this->NumFuncs; i++)
     {
       this->LastGoodVelocity[i] = u[i] = this->Vals2[i];
     }
@@ -304,8 +307,7 @@ int vtkTemporalInterpolatedVelocityField::FunctionValuesAtT(int T, double* x, do
 }
 //---------------------------------------------------------------------------
 bool vtkTemporalInterpolatedVelocityField::InterpolatePoint(
-  vtkPointData *outPD1, vtkPointData *outPD2,
-  vtkIdType outIndex)
+  vtkPointData* outPD1, vtkPointData* outPD2, vtkIdType outIndex)
 {
   bool ok1 = this->IVF[0]->InterpolatePoint(outPD1, outIndex);
   bool ok2 = this->IVF[1]->InterpolatePoint(outPD2, outIndex);
@@ -313,35 +315,33 @@ bool vtkTemporalInterpolatedVelocityField::InterpolatePoint(
 }
 //---------------------------------------------------------------------------
 bool vtkTemporalInterpolatedVelocityField::InterpolatePoint(
-  int T, vtkPointData *outPD1, vtkIdType outIndex)
+  int T, vtkPointData* outPD1, vtkIdType outIndex)
 {
   vtkCachingInterpolatedVelocityField* inivf = this->IVF[T];
   // force use of correct weights/etc if static as only T0 are valid
-  if (T==1 && this->IsStatic(this->IVF[T]->LastCacheIndex))
+  if (T == 1 && this->IsStatic(this->IVF[T]->LastCacheIndex))
   {
-    T=0;
+    T = 0;
   }
   //
   return this->IVF[T]->InterpolatePoint(inivf, outPD1, outIndex);
 }
 //---------------------------------------------------------------------------
 bool vtkTemporalInterpolatedVelocityField::GetVorticityData(
-  int T, double pcoords[3], double *weights,
-  vtkGenericCell *&cell, vtkDoubleArray *cellVectors)
+  int T, double pcoords[3], double* weights, vtkGenericCell*& cell, vtkDoubleArray* cellVectors)
 {
   // force use of correct weights/etc if static as only T0 are valid
-  if (T==1 && this->IsStatic(this->IVF[T]->LastCacheIndex))
+  if (T == 1 && this->IsStatic(this->IVF[T]->LastCacheIndex))
   {
-    T=0;
+    T = 0;
   }
   //
-  if (this->IVF[T]->GetLastWeights(weights) &&
-      this->IVF[T]->GetLastLocalCoordinates(pcoords) &&
-      (cell=this->IVF[T]->GetLastCell()) )
+  if (this->IVF[T]->GetLastWeights(weights) && this->IVF[T]->GetLastLocalCoordinates(pcoords) &&
+    (cell = this->IVF[T]->GetLastCell()))
   {
-    vtkDataSet   *ds = this->IVF[T]->Cache->DataSet;
-    vtkPointData *pd = ds->GetPointData();
-    vtkDataArray *da = pd->GetVectors(this->IVF[T]->GetVectorsSelection());
+    vtkDataSet* ds = this->IVF[T]->Cache->DataSet;
+    vtkPointData* pd = ds->GetPointData();
+    vtkDataArray* da = pd->GetVectors(this->IVF[T]->GetVectorsSelection());
     da->GetTuples(cell->PointIds, cellVectors);
     return 1;
   }
@@ -352,10 +352,8 @@ void vtkTemporalInterpolatedVelocityField::PrintSelf(ostream& os, vtkIndent inde
 {
   this->Superclass::PrintSelf(os, indent);
 
-  os << indent << "LastGoodVelocity: "
-     << this->LastGoodVelocity[0] << ", "
-     << this->LastGoodVelocity[1] << ", "
-     << this->LastGoodVelocity[2] << endl;
+  os << indent << "LastGoodVelocity: " << this->LastGoodVelocity[0] << ", "
+     << this->LastGoodVelocity[1] << ", " << this->LastGoodVelocity[2] << endl;
   os << indent << "CurrentWeight: " << this->CurrentWeight << endl;
 }
 //---------------------------------------------------------------------------
