@@ -15,22 +15,22 @@
 #include "vtkClipConvexPolyData.h"
 
 #include "vtkCellArray.h"
-#include "vtkMath.h"
 #include "vtkInformation.h"
 #include "vtkInformationVector.h"
+#include "vtkMath.h"
 #include "vtkObjectFactory.h"
 #include "vtkPlane.h"
 #include "vtkPlaneCollection.h"
 #include "vtkPolyData.h"
 
-#include <vector>
-#include <set>
 #include <algorithm>
 #include <iterator>
+#include <set>
+#include <vector>
 
 vtkStandardNewMacro(vtkClipConvexPolyData);
 
-vtkCxxSetObjectMacro(vtkClipConvexPolyData,Planes,vtkPlaneCollection);
+vtkCxxSetObjectMacro(vtkClipConvexPolyData, Planes, vtkPlaneCollection);
 
 // ----------------------------------------------------------------------------
 class vtkCCPDVertex
@@ -58,16 +58,15 @@ public:
 // Constructor
 vtkClipConvexPolyData::vtkClipConvexPolyData()
 {
-  this->Planes=NULL;
-  this->Internal=new vtkClipConvexPolyDataInternals;
-
+  this->Planes = nullptr;
+  this->Internal = new vtkClipConvexPolyDataInternals;
 }
 
 // ----------------------------------------------------------------------------
 // Destructor
 vtkClipConvexPolyData::~vtkClipConvexPolyData()
 {
-  this->SetPlanes(NULL);
+  this->SetPlanes(nullptr);
   this->ClearInternals();
   delete this->Internal;
 }
@@ -78,13 +77,13 @@ vtkClipConvexPolyData::~vtkClipConvexPolyData()
 // (planes)
 vtkMTimeType vtkClipConvexPolyData::GetMTime()
 {
-  vtkMTimeType result=Superclass::GetMTime();
-  if(this->Planes!=0)
+  vtkMTimeType result = Superclass::GetMTime();
+  if (this->Planes != nullptr)
   {
-    vtkMTimeType planesTime=this->Planes->GetMTime();
-    if(planesTime>result)
+    vtkMTimeType planesTime = this->Planes->GetMTime();
+    if (planesTime > result)
     {
-      result=planesTime;
+      result = planesTime;
     }
   }
   return result;
@@ -94,21 +93,20 @@ vtkMTimeType vtkClipConvexPolyData::GetMTime()
 void vtkClipConvexPolyData::ClearInternals()
 {
   unsigned int j;
-  for(unsigned int i=0; i<this->Internal->Polygons.size(); i++)
+  for (unsigned int i = 0; i < this->Internal->Polygons.size(); i++)
   {
-    for (j=0; j<this->Internal->Polygons[i]->Vertices.size(); j++)
+    for (j = 0; j < this->Internal->Polygons[i]->Vertices.size(); j++)
     {
       delete this->Internal->Polygons[i]->Vertices[j];
     }
     this->Internal->Polygons[i]->Vertices.clear();
 
-    for (j=0; j<this->Internal->Polygons[i]->NewVertices.size(); j++)
+    for (j = 0; j < this->Internal->Polygons[i]->NewVertices.size(); j++)
     {
       delete this->Internal->Polygons[i]->NewVertices[j];
     }
     this->Internal->Polygons[i]->NewVertices.clear();
 
-
     delete this->Internal->Polygons[i];
   }
   this->Internal->Polygons.clear();
@@ -117,10 +115,9 @@ void vtkClipConvexPolyData::ClearInternals()
 // ----------------------------------------------------------------------------
 void vtkClipConvexPolyData::ClearNewVertices()
 {
-  for(unsigned int i=0; i<this->Internal->Polygons.size(); i++)
+  for (unsigned int i = 0; i < this->Internal->Polygons.size(); i++)
   {
-    for(unsigned int j=0; j<this->Internal->Polygons[i]->NewVertices.size();
-        j++)
+    for (unsigned int j = 0; j < this->Internal->Polygons[i]->NewVertices.size(); j++)
     {
       delete this->Internal->Polygons[i]->NewVertices[j];
     }
@@ -133,18 +130,16 @@ void vtkClipConvexPolyData::RemoveEmptyPolygons()
 {
   bool done = false;
 
-  while (!done )
+  while (!done)
   {
     done = true;
-    for(unsigned int i=0; i<this->Internal->Polygons.size(); i++)
+    for (unsigned int i = 0; i < this->Internal->Polygons.size(); i++)
     {
-      if ( this->Internal->Polygons[i]->Vertices.size() == 0 )
+      if (this->Internal->Polygons[i]->Vertices.empty())
       {
-        std::vector<vtkCCPDPolygon*>::iterator where =
-          std::find(this->Internal->Polygons.begin(),
-               this->Internal->Polygons.end(),
-               this->Internal->Polygons[i]);
-        if ( where != this->Internal->Polygons.end() )
+        std::vector<vtkCCPDPolygon*>::iterator where = std::find(this->Internal->Polygons.begin(),
+          this->Internal->Polygons.end(), this->Internal->Polygons[i]);
+        if (where != this->Internal->Polygons.end())
         {
           delete this->Internal->Polygons[i];
           this->Internal->Polygons.erase(where);
@@ -158,65 +153,61 @@ void vtkClipConvexPolyData::RemoveEmptyPolygons()
 
 // ----------------------------------------------------------------------------
 //
-int vtkClipConvexPolyData::RequestData(
-  vtkInformation *vtkNotUsed(request),
-  vtkInformationVector **inputVector,
-  vtkInformationVector *outputVector)
+int vtkClipConvexPolyData::RequestData(vtkInformation* vtkNotUsed(request),
+  vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
   // Pre-conditions
-  if(this->Planes==0)
+  if (this->Planes == nullptr)
   {
     vtkErrorMacro("plane collection is null");
     return 0;
   }
-  if(this->Planes->GetNumberOfItems()==0)
+  if (this->Planes->GetNumberOfItems() == 0)
   {
     vtkErrorMacro("plane collection is empty");
     return 0;
   }
 
   // get the info objects
-  vtkInformation *inInfo = inputVector[0]->GetInformationObject(0);
-  vtkInformation *outInfo = outputVector->GetInformationObject(0);
+  vtkInformation* inInfo = inputVector[0]->GetInformationObject(0);
+  vtkInformation* outInfo = outputVector->GetInformationObject(0);
 
-  // get the input and ouptut
-  vtkPolyData *input = vtkPolyData::SafeDownCast(
-    inInfo->Get(vtkDataObject::DATA_OBJECT()));
-  vtkPolyData *output = vtkPolyData::SafeDownCast(
-    outInfo->Get(vtkDataObject::DATA_OBJECT()));
+  // get the input and output
+  vtkPolyData* input = vtkPolyData::SafeDownCast(inInfo->Get(vtkDataObject::DATA_OBJECT()));
+  vtkPolyData* output = vtkPolyData::SafeDownCast(outInfo->Get(vtkDataObject::DATA_OBJECT()));
 
-  vtkCellArray *polys = input->GetPolys();
-  vtkPoints *points = input->GetPoints();
+  vtkCellArray* polys = input->GetPolys();
+  vtkPoints* points = input->GetPoints();
 
   // Compute tolerance to be 0.00001 of diagonal
-  double min[3] = {VTK_DOUBLE_MAX, VTK_DOUBLE_MAX, VTK_DOUBLE_MAX};
-  double max[3] = {VTK_DOUBLE_MIN, VTK_DOUBLE_MIN, VTK_DOUBLE_MIN};
+  double min[3] = { VTK_DOUBLE_MAX, VTK_DOUBLE_MAX, VTK_DOUBLE_MAX };
+  double max[3] = { VTK_DOUBLE_MIN, VTK_DOUBLE_MIN, VTK_DOUBLE_MIN };
 
   size_t i, j;
   double tolerance;
-  for ( i = 0; i < static_cast<size_t>(points->GetNumberOfPoints()); i++ )
+  for (i = 0; i < static_cast<size_t>(points->GetNumberOfPoints()); i++)
   {
     double pt[3];
     points->GetPoint(static_cast<vtkIdType>(i), pt);
-    for ( j = 0; j < 3; j++ )
+    for (j = 0; j < 3; j++)
     {
-      min[j] = (pt[j] < min[j])?(pt[j]):(min[j]);
-      max[j] = (pt[j] > max[j])?(pt[j]):(max[j]);
+      min[j] = (pt[j] < min[j]) ? (pt[j]) : (min[j]);
+      max[j] = (pt[j] > max[j]) ? (pt[j]) : (max[j]);
     }
   }
-  tolerance = sqrt(vtkMath::Distance2BetweenPoints(min,max))*0.00001;
+  tolerance = sqrt(vtkMath::Distance2BetweenPoints(min, max)) * 0.00001;
 
   // Copy the polygons from the polys array to the internal
   // data structure
   vtkIdType npts;
-  vtkIdType *pts;
+  const vtkIdType* pts;
   polys->InitTraversal();
-  while ( polys->GetNextCell(npts, pts) )
+  while (polys->GetNextCell(npts, pts))
   {
-    vtkCCPDPolygon *polygon = new vtkCCPDPolygon;
-    for ( i = 0; i < static_cast<size_t>(npts); i++ )
+    vtkCCPDPolygon* polygon = new vtkCCPDPolygon;
+    for (i = 0; i < static_cast<size_t>(npts); i++)
     {
-      vtkCCPDVertex *v = new vtkCCPDVertex;
+      vtkCCPDVertex* v = new vtkCCPDVertex;
       points->GetPoint(pts[i], v->Point);
       polygon->Vertices.push_back(v);
     }
@@ -224,33 +215,35 @@ int vtkClipConvexPolyData::RequestData(
   }
 
   this->Planes->InitTraversal();
-  vtkPlane *plane;
+  vtkPlane* plane;
 
   // For each plane in the collection, clip the polygons with the plane.
-  while ( (plane = this->Planes->GetNextItem()) )
+  while ((plane = this->Planes->GetNextItem()))
   {
-    if ( !this->HasDegeneracies( plane ) )
+    if (!this->HasDegeneracies(plane))
     {
-      this->ClipWithPlane( plane, tolerance );
+      this->ClipWithPlane(plane, tolerance);
     }
   }
 
   // Create a new set of points and polygons into which the results will
   // be stored
-  vtkPoints *outPoints = vtkPoints::New();
-  vtkCellArray *outPolys  = vtkCellArray::New();
+  vtkPoints* outPoints = vtkPoints::New();
+  vtkCellArray* outPolys = vtkCellArray::New();
 
-  for ( i = 0; i < this->Internal->Polygons.size(); i++ )
+  std::vector<vtkIdType> polyPts(32);
+  for (i = 0; i < this->Internal->Polygons.size(); i++)
   {
     size_t numPoints = this->Internal->Polygons[i]->Vertices.size();
-    vtkIdType *polyPts = new vtkIdType[numPoints];
-    for ( j = 0; j < numPoints; j++ )
+    if (numPoints > polyPts.size())
     {
-      polyPts[j] = outPoints->InsertNextPoint(
-        this->Internal->Polygons[i]->Vertices[j]->Point );
+      polyPts.resize(numPoints);
     }
-    outPolys->InsertNextCell(static_cast<vtkIdType>(numPoints), polyPts );
-    delete [] polyPts;
+    for (j = 0; j < numPoints; j++)
+    {
+      polyPts[j] = outPoints->InsertNextPoint(this->Internal->Polygons[i]->Vertices[j]->Point);
+    }
+    outPolys->InsertNextCell(static_cast<vtkIdType>(numPoints), polyPts.data());
   }
 
   // Set the output vertices and polygons
@@ -267,30 +260,28 @@ int vtkClipConvexPolyData::RequestData(
 }
 
 // ----------------------------------------------------------------------------
-void vtkClipConvexPolyData::ClipWithPlane( vtkPlane *plane, double tolerance )
+void vtkClipConvexPolyData::ClipWithPlane(vtkPlane* plane, double tolerance)
 {
   double origin[3];
   double normal[4];
 
-  plane->GetOrigin( origin );
-  plane->GetNormal( normal );
+  plane->GetOrigin(origin);
+  plane->GetNormal(normal);
 
   vtkMath::Normalize(normal);
 
-  normal[3] = -(origin[0]*normal[0] +
-                origin[1]*normal[1] +
-                origin[2]*normal[2]);
+  normal[3] = -(origin[0] * normal[0] + origin[1] * normal[1] + origin[2] * normal[2]);
 
   int numNewPoints = 0;
   unsigned int i;
   size_t j;
 
   // For each polygon
-  for ( i = 0; i < this->Internal->Polygons.size(); i++ )
+  for (i = 0; i < this->Internal->Polygons.size(); i++)
   {
     // the new polygon. We are clipping the existing polygon then
     // removing that old polygon and adding this clipped polygon
-    vtkCCPDPolygon *newPoly = new vtkCCPDPolygon;
+    vtkCCPDPolygon* newPoly = new vtkCCPDPolygon;
 
     int somePositive = 0;
     // Look around the polygon - we only want to process it if
@@ -299,55 +290,54 @@ void vtkClipConvexPolyData::ClipWithPlane( vtkPlane *plane, double tolerance )
     // clipped. If they are either negative or 0, then this is a boundary
     // condition and we also don't want to consider it
     size_t numVertices = this->Internal->Polygons[i]->Vertices.size();
-    for ( j = 0; j < numVertices; j++ )
+    for (j = 0; j < numVertices; j++)
     {
-      double *p1=this->Internal->Polygons[i]->Vertices[j]->Point;
-      double p1D=p1[0]*normal[0]+p1[1]*normal[1]+p1[2]*normal[2] + normal[3];
-      if ( p1D < 2.0*tolerance && p1D > -2.0*tolerance )
+      double* p1 = this->Internal->Polygons[i]->Vertices[j]->Point;
+      double p1D = p1[0] * normal[0] + p1[1] * normal[1] + p1[2] * normal[2] + normal[3];
+      if (p1D < 2.0 * tolerance && p1D > -2.0 * tolerance)
       {
         p1D = 0;
       }
-      if ( p1D > 0 )
+      if (p1D > 0)
       {
         somePositive = 1;
         break;
       }
     }
 
-    if ( somePositive )
+    if (somePositive)
     {
       // For each vertex
-      for ( j = 0; j < numVertices; j++ )
+      for (j = 0; j < numVertices; j++)
       {
-        double *p1=this->Internal->Polygons[i]->Vertices[j]->Point;
-        double *p2=
-          this->Internal->Polygons[i]->Vertices[(j+1)%numVertices]->Point;
+        double* p1 = this->Internal->Polygons[i]->Vertices[j]->Point;
+        double* p2 = this->Internal->Polygons[i]->Vertices[(j + 1) % numVertices]->Point;
 
-        double p1D=p1[0]*normal[0]+p1[1]*normal[1]+p1[2]*normal[2] + normal[3];
-        double p2D=p2[0]*normal[0]+p2[1]*normal[1]+p2[2]*normal[2] + normal[3];
+        double p1D = p1[0] * normal[0] + p1[1] * normal[1] + p1[2] * normal[2] + normal[3];
+        double p2D = p2[0] * normal[0] + p2[1] * normal[1] + p2[2] * normal[2] + normal[3];
 
         // We want to avoid the case where we just barely clip a vertex. If we allow
         // that to happen then we wind up with too many candidate points all in
         // approximately the same place when we try to form a loop to close off
         // the cut. So if the point is within a 1/10th of the tolerance factor
         // we've set, we'll just consider it not clipped.
-        if ( p1D < 2*tolerance && p1D > -2.0*tolerance )
+        if (p1D < 2 * tolerance && p1D > -2.0 * tolerance)
         {
           p1D = 0;
         }
 
-        if ( p2D < 2*tolerance && p2D > -2.0*tolerance )
+        if (p2D < 2 * tolerance && p2D > -2.0 * tolerance)
         {
           p2D = 0;
         }
         // Add p1 in if it is not clipped. If the whole polygon is unclipped
         // then we'll just add in each vertex in turn. If the whole polygon
         // is clipped we won't add in any vertices. If the polygon is
-        // clipped, we'll add in two new points corresponding the the
+        // clipped, we'll add in two new points corresponding the
         // crossing location of the plane on two edges of the polygon
-        if ( p1D >= 0 )
+        if (p1D >= 0)
         {
-          vtkCCPDVertex *v = new vtkCCPDVertex;
+          vtkCCPDVertex* v = new vtkCCPDVertex;
           v->Point[0] = p1[0];
           v->Point[1] = p1[1];
           v->Point[2] = p1[2];
@@ -356,9 +346,9 @@ void vtkClipConvexPolyData::ClipWithPlane( vtkPlane *plane, double tolerance )
 
         // If the first point is exactly on the boundary, we need to also count it
         // as a new point
-        if ( p1D == 0 && p2D <= 0)
+        if (p1D == 0 && p2D <= 0)
         {
-          vtkCCPDVertex *v = new vtkCCPDVertex;
+          vtkCCPDVertex* v = new vtkCCPDVertex;
           v->Point[0] = p1[0];
           v->Point[1] = p1[1];
           v->Point[2] = p1[2];
@@ -366,9 +356,9 @@ void vtkClipConvexPolyData::ClipWithPlane( vtkPlane *plane, double tolerance )
           numNewPoints++;
         }
 
-        if ( p2D == 0 && p1D <= 0 )
+        if (p2D == 0 && p1D <= 0)
         {
-          vtkCCPDVertex *v = new vtkCCPDVertex;
+          vtkCCPDVertex* v = new vtkCCPDVertex;
           v->Point[0] = p2[0];
           v->Point[1] = p2[1];
           v->Point[2] = p2[2];
@@ -378,20 +368,20 @@ void vtkClipConvexPolyData::ClipWithPlane( vtkPlane *plane, double tolerance )
 
         // If the plane clips this edge - find the crossing point. We'll need
         // to add this point to the new polygon
-        if ( p1D*p2D < 0 )
+        if (p1D * p2D < 0)
         {
           double w = -p1D / (p2D - p1D);
 
-          vtkCCPDVertex *v = new vtkCCPDVertex;
-          v->Point[0] = p1[0] + w * (p2[0]-p1[0]);
-          v->Point[1] = p1[1] + w * (p2[1]-p1[1]);
-          v->Point[2] = p1[2] + w * (p2[2]-p1[2]);
+          vtkCCPDVertex* v = new vtkCCPDVertex;
+          v->Point[0] = p1[0] + w * (p2[0] - p1[0]);
+          v->Point[1] = p1[1] + w * (p2[1] - p1[1]);
+          v->Point[2] = p1[2] + w * (p2[2] - p1[2]);
           newPoly->Vertices.push_back(v);
 
           v = new vtkCCPDVertex;
-          v->Point[0] = p1[0] + w * (p2[0]-p1[0]);
-          v->Point[1] = p1[1] + w * (p2[1]-p1[1]);
-          v->Point[2] = p1[2] + w * (p2[2]-p1[2]);
+          v->Point[0] = p1[0] + w * (p2[0] - p1[0]);
+          v->Point[1] = p1[1] + w * (p2[1] - p1[1]);
+          v->Point[2] = p1[2] + w * (p2[2] - p1[2]);
           this->Internal->Polygons[i]->NewVertices.push_back(v);
           numNewPoints++;
         }
@@ -399,7 +389,7 @@ void vtkClipConvexPolyData::ClipWithPlane( vtkPlane *plane, double tolerance )
     }
 
     // Remove the current polygon
-    for ( j = 0; j < numVertices; j++ )
+    for (j = 0; j < numVertices; j++)
     {
       delete this->Internal->Polygons[i]->Vertices[j];
     }
@@ -407,9 +397,9 @@ void vtkClipConvexPolyData::ClipWithPlane( vtkPlane *plane, double tolerance )
 
     // copy in the new polygon if it isn't entirely clipped
     numVertices = newPoly->Vertices.size();
-    if ( numVertices > 0 )
+    if (numVertices > 0)
     {
-      for ( j = 0; j < numVertices; j++ )
+      for (j = 0; j < numVertices; j++)
       {
         this->Internal->Polygons[i]->Vertices.push_back(newPoly->Vertices[j]);
       }
@@ -420,49 +410,48 @@ void vtkClipConvexPolyData::ClipWithPlane( vtkPlane *plane, double tolerance )
 
   // If we've added any new points when clipping the polydata then
   // we must have added at least six. Otherwise something is wrong
-  if ( numNewPoints )
+  if (numNewPoints)
   {
-    if ( numNewPoints < 6 )
+    if (numNewPoints < 6)
     {
       vtkErrorMacro(<< "Failure - not enough new points");
       return;
     }
 
     // Check that all new arrays contain exactly 0 or 2 points
-    for ( i = 0; i < this->Internal->Polygons.size(); i++ )
+    for (i = 0; i < this->Internal->Polygons.size(); i++)
     {
-      if ( this->Internal->Polygons[i]->NewVertices.size() != 0 &&
-           this->Internal->Polygons[i]->NewVertices.size() != 2 )
+      if (!this->Internal->Polygons[i]->NewVertices.empty() &&
+        this->Internal->Polygons[i]->NewVertices.size() != 2)
       {
-        vtkErrorMacro( << "Horrible error - we have " <<
-                       this->Internal->Polygons[i]->NewVertices.size()
-                       << " crossing points");
+        vtkErrorMacro(<< "Horrible error - we have "
+                      << this->Internal->Polygons[i]->NewVertices.size() << " crossing points");
         return;
       }
     }
 
     // Find the first polygon with a new point
     size_t idx = 0;
-    bool idxFound=false;
+    bool idxFound = false;
 
-    for ( i = 0; !idxFound && i < this->Internal->Polygons.size(); i++ )
+    for (i = 0; !idxFound && i < this->Internal->Polygons.size(); i++)
     {
-      idxFound=this->Internal->Polygons[i]->NewVertices.size() > 0;
-      if(idxFound)
+      idxFound = !this->Internal->Polygons[i]->NewVertices.empty();
+      if (idxFound)
       {
-        idx=i;
+        idx = i;
       }
     }
 
     if (!idxFound)
     {
-      vtkErrorMacro( << "Couldn't find any new vertices!");
+      vtkErrorMacro(<< "Couldn't find any new vertices!");
       return;
     }
 
     // the new polygon
-    vtkCCPDPolygon *newPoly = new vtkCCPDPolygon;
-    vtkCCPDVertex *v = new vtkCCPDVertex;
+    vtkCCPDPolygon* newPoly = new vtkCCPDPolygon;
+    vtkCCPDVertex* v = new vtkCCPDVertex;
     v->Point[0] = this->Internal->Polygons[idx]->NewVertices[0]->Point[0];
     v->Point[1] = this->Internal->Polygons[idx]->NewVertices[0]->Point[1];
     v->Point[2] = this->Internal->Polygons[idx]->NewVertices[0]->Point[2];
@@ -482,68 +471,59 @@ void vtkClipConvexPolyData::ClipWithPlane( vtkPlane *plane, double tolerance )
     size_t lastPointIdx = idx;
     size_t subIdx;
 
-    while ( static_cast<int>(newPoly->Vertices.size()) < numNewPoints / 2 )
+    while (static_cast<int>(newPoly->Vertices.size()) < numNewPoints / 2)
     {
       // Find the index of the closest new vertex that matches the
       // lastPoint but not the lastPointIdx.
       subIdx = 0;
       float closestDistance = VTK_FLOAT_MAX;
-      bool foundSubIdx=false;
-      for ( i = 0; i < this->Internal->Polygons.size(); i++ )
+      bool foundSubIdx = false;
+      for (i = 0; i < this->Internal->Polygons.size(); i++)
       {
-          if ( i != lastPointIdx &&
-               this->Internal->Polygons[i]->NewVertices.size() > 0 )
+        if (i != lastPointIdx && !this->Internal->Polygons[i]->NewVertices.empty())
+        {
+          for (j = 0; j < 2; j++)
           {
-          for ( j = 0; j < 2; j++ )
-          {
-            float testDistance =
-              vtkMath::Distance2BetweenPoints(lastPoint,
-                  this->Internal->Polygons[i]->NewVertices[j]->Point);
-            if ( testDistance < tolerance && testDistance < closestDistance)
+            float testDistance = vtkMath::Distance2BetweenPoints(
+              lastPoint, this->Internal->Polygons[i]->NewVertices[j]->Point);
+            if (testDistance < tolerance && testDistance < closestDistance)
             {
               closestDistance = testDistance;
               idx = i;
-              subIdx =j;
-              foundSubIdx=true;
+              subIdx = j;
+              foundSubIdx = true;
             }
           }
-          }
+        }
       }
 
-      if ( !foundSubIdx )
+      if (!foundSubIdx)
       {
         vtkErrorMacro("Could not find a match");
       }
 
       v = new vtkCCPDVertex;
-      v->Point[0] =
-        this->Internal->Polygons[idx]->NewVertices[(subIdx+1)%2]->Point[0];
-      v->Point[1] =
-        this->Internal->Polygons[idx]->NewVertices[(subIdx+1)%2]->Point[1];
-      v->Point[2] =
-        this->Internal->Polygons[idx]->NewVertices[(subIdx+1)%2]->Point[2];
+      v->Point[0] = this->Internal->Polygons[idx]->NewVertices[(subIdx + 1) % 2]->Point[0];
+      v->Point[1] = this->Internal->Polygons[idx]->NewVertices[(subIdx + 1) % 2]->Point[1];
+      v->Point[2] = this->Internal->Polygons[idx]->NewVertices[(subIdx + 1) % 2]->Point[2];
       newPoly->Vertices.push_back(v);
 
-      lastPoint[0] =
-        this->Internal->Polygons[idx]->NewVertices[(subIdx+1)%2]->Point[0];
-      lastPoint[1] =
-        this->Internal->Polygons[idx]->NewVertices[(subIdx+1)%2]->Point[1];
-      lastPoint[2] =
-        this->Internal->Polygons[idx]->NewVertices[(subIdx+1)%2]->Point[2];
+      lastPoint[0] = this->Internal->Polygons[idx]->NewVertices[(subIdx + 1) % 2]->Point[0];
+      lastPoint[1] = this->Internal->Polygons[idx]->NewVertices[(subIdx + 1) % 2]->Point[1];
+      lastPoint[2] = this->Internal->Polygons[idx]->NewVertices[(subIdx + 1) % 2]->Point[2];
       lastPointIdx = idx;
     }
 
-
     // check to see that the polygon vertices are in the right order.
     // cross product of p1p2 and p3p2 should point in the same direction
     // as the plane normal. Otherwise, reverse the order
     int flipCount = 0;
     int checkCount = 0;
-    for (size_t startV = 0; startV+2 < newPoly->Vertices.size(); startV++)
+    for (size_t startV = 0; startV + 2 < newPoly->Vertices.size(); startV++)
     {
-      double *p1 = newPoly->Vertices[startV]->Point;
-      double *p2 = newPoly->Vertices[startV+1]->Point;
-      double *p3 = newPoly->Vertices[startV+2]->Point;
+      double* p1 = newPoly->Vertices[startV]->Point;
+      double* p2 = newPoly->Vertices[startV + 1]->Point;
+      double* p3 = newPoly->Vertices[startV + 2]->Point;
       double v1[3];
       double v2[3];
       double cross[3];
@@ -553,15 +533,15 @@ void vtkClipConvexPolyData::ClipWithPlane( vtkPlane *plane, double tolerance )
       v2[0] = p3[0] - p2[0];
       v2[1] = p3[1] - p2[1];
       v2[2] = p3[2] - p2[2];
-      vtkMath::Cross(v1,v2,cross);
+      vtkMath::Cross(v1, v2, cross);
       double nd = vtkMath::Normalize(cross);
       // only check if the length of the cross product is long
       // enough - otherwise we might be working with points that
       // are all too close together and we might wind up with
       // misleading results
-      if ( nd > tolerance )
+      if (nd > tolerance)
       {
-        if ( vtkMath::Dot(cross,normal) < 0 )
+        if (vtkMath::Dot(cross, normal) < 0)
         {
           flipCount++;
         }
@@ -571,7 +551,7 @@ void vtkClipConvexPolyData::ClipWithPlane( vtkPlane *plane, double tolerance )
 
     // As long as more than half the time we checked we got the answer
     // that we should flip, go ahead and flip it
-    if ( flipCount > checkCount/2 )
+    if (flipCount > checkCount / 2)
     {
       std::reverse(newPoly->Vertices.begin(), newPoly->Vertices.end());
     }
@@ -582,50 +562,47 @@ void vtkClipConvexPolyData::ClipWithPlane( vtkPlane *plane, double tolerance )
 }
 
 // ----------------------------------------------------------------------------
-bool vtkClipConvexPolyData::HasDegeneracies(vtkPlane *plane)
+bool vtkClipConvexPolyData::HasDegeneracies(vtkPlane* plane)
 {
   double origin[3];
   double normal[4];
 
-  plane->GetOrigin( origin );
-  plane->GetNormal( normal );
+  plane->GetOrigin(origin);
+  plane->GetNormal(normal);
 
-  normal[3] = -(origin[0]*normal[0] +
-                origin[1]*normal[1] +
-                origin[2]*normal[2]);
+  normal[3] = -(origin[0] * normal[0] + origin[1] * normal[1] + origin[2] * normal[2]);
 
   unsigned int i;
   size_t j;
   // For each polygon
   int totalNumNewVertices = 0;
-  for ( i = 0; i < this->Internal->Polygons.size(); i++ )
+  for (i = 0; i < this->Internal->Polygons.size(); i++)
   {
     // For each vertex
     size_t numVertices = this->Internal->Polygons[i]->Vertices.size();
     int numNewVertices = 0;
-    for ( j = 0; j < numVertices; j++ )
+    for (j = 0; j < numVertices; j++)
     {
-      double *p1 = this->Internal->Polygons[i]->Vertices[j]->Point;
-      double *p2 =
-        this->Internal->Polygons[i]->Vertices[(j+1)%numVertices]->Point;
+      double* p1 = this->Internal->Polygons[i]->Vertices[j]->Point;
+      double* p2 = this->Internal->Polygons[i]->Vertices[(j + 1) % numVertices]->Point;
 
-      double p1D=p1[0]*normal[0]+p1[1]*normal[1]+p1[2]*normal[2]+normal[3];
-      double p2D=p2[0]*normal[0]+p2[1]*normal[1]+p2[2]*normal[2]+normal[3];
+      double p1D = p1[0] * normal[0] + p1[1] * normal[1] + p1[2] * normal[2] + normal[3];
+      double p2D = p2[0] * normal[0] + p2[1] * normal[1] + p2[2] * normal[2] + normal[3];
 
       // If the plane clips this edge - find the crossing point
-      if ( p1D*p2D <= 0 )
+      if (p1D * p2D <= 0)
       {
         numNewVertices++;
       }
     }
-    if ( numNewVertices != 0 && numNewVertices != 2)
+    if (numNewVertices != 0 && numNewVertices != 2)
     {
       return true;
     }
     totalNumNewVertices += numNewVertices;
   }
 
-  if ( totalNumNewVertices < 6 )
+  if (totalNumNewVertices < 6)
   {
     return true;
   }
@@ -635,7 +612,7 @@ bool vtkClipConvexPolyData::HasDegeneracies(vtkPlane *plane)
 // ----------------------------------------------------------------------------
 void vtkClipConvexPolyData::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 
   os << indent << "Planes: " << this->Planes << endl;
 }
