@@ -18,6 +18,7 @@
 #include "vtkCommand.h"
 #include "vtkFloatArray.h"
 #include "vtkImageData.h"
+#include "vtkImageTransform.h"
 #include "vtkInformation.h"
 #include "vtkInformationExecutivePortKey.h"
 #include "vtkInformationVector.h"
@@ -41,8 +42,8 @@ vtkImageMarchingCubes::vtkImageMarchingCubes()
   this->ComputeGradients = 0;
   this->ComputeScalars = 1;
 
-  this->LocatorPointIds = NULL;
-  this->InputMemoryLimit = 10240;  // 10 mega Bytes
+  this->LocatorPointIds = nullptr;
+  this->InputMemoryLimit = 10240; // 10 mega Bytes
 }
 
 vtkImageMarchingCubes::~vtkImageMarchingCubes()
@@ -55,10 +56,10 @@ vtkImageMarchingCubes::~vtkImageMarchingCubes()
 // then this object is modified as well.
 vtkMTimeType vtkImageMarchingCubes::GetMTime()
 {
-  vtkMTimeType mTime=this->Superclass::GetMTime();
-  vtkMTimeType contourValuesMTime=this->ContourValues->GetMTime();
+  vtkMTimeType mTime = this->Superclass::GetMTime();
+  vtkMTimeType contourValuesMTime = this->ContourValues->GetMTime();
 
-  mTime = ( contourValuesMTime > mTime ? contourValuesMTime : mTime );
+  mTime = (contourValuesMTime > mTime ? contourValuesMTime : mTime);
 
   return mTime;
 }
@@ -71,27 +72,34 @@ int vtkImageMarchingCubesGetTypeSize(T*)
 }
 
 //----------------------------------------------------------------------------
-int vtkImageMarchingCubes::RequestData(
-  vtkInformation *vtkNotUsed(request),
-  vtkInformationVector **inputVector,
-  vtkInformationVector *outputVector)
+int vtkImageMarchingCubes::RequestUpdateExtent(vtkInformation* vtkNotUsed(request),
+  vtkInformationVector** inputVector, vtkInformationVector* vtkNotUsed(outputVector))
+{
+  // start with an empty UPDATE_EXTENT to ensure proper streaming
+  // (the UPDATE_EXTENT will be set properly in RequestData()).
+  int extent[6] = { 0, -1, 0, -1, 0, -1 };
+  vtkInformation* inInfo = inputVector[0]->GetInformationObject(0);
+  inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT(), extent, 6);
+  return 1;
+}
+
+//----------------------------------------------------------------------------
+int vtkImageMarchingCubes::RequestData(vtkInformation* vtkNotUsed(request),
+  vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
   // get the info objects
-  vtkInformation *inInfo = inputVector[0]->GetInformationObject(0);
-  vtkInformation *outInfo = outputVector->GetInformationObject(0);
+  vtkInformation* inInfo = inputVector[0]->GetInformationObject(0);
+  vtkInformation* outInfo = outputVector->GetInformationObject(0);
 
   // get the input and output
-  vtkImageData *inData = vtkImageData::SafeDownCast(
-    inInfo->Get(vtkDataObject::DATA_OBJECT()));
-  vtkPolyData *output = vtkPolyData::SafeDownCast(
-    outInfo->Get(vtkDataObject::DATA_OBJECT()));
+  vtkImageData* inData = vtkImageData::SafeDownCast(inInfo->Get(vtkDataObject::DATA_OBJECT()));
+  vtkPolyData* output = vtkPolyData::SafeDownCast(outInfo->Get(vtkDataObject::DATA_OBJECT()));
 
   vtkDemandDrivenPipeline* inputExec =
-    vtkDemandDrivenPipeline::SafeDownCast(
-      vtkExecutive::PRODUCER()->GetExecutive(inInfo));
+    vtkDemandDrivenPipeline::SafeDownCast(vtkExecutive::PRODUCER()->GetExecutive(inInfo));
 
-  int numContours=this->ContourValues->GetNumberOfContours();
-  double *values=this->ContourValues->GetValues();
+  vtkIdType numContours = this->ContourValues->GetNumberOfContours();
+  double* values = this->ContourValues->GetValues();
 
   vtkDebugMacro("Starting Execute Method");
 
@@ -115,31 +123,27 @@ int vtkImageMarchingCubes::RequestData(
   vtkIdType temp;
   switch (inData->GetScalarType())
   {
-    vtkTemplateMacro(
-      temp = vtkImageMarchingCubesGetTypeSize(static_cast<VTK_TT*>(0))
-      );
+    vtkTemplateMacro(temp = vtkImageMarchingCubesGetTypeSize(static_cast<VTK_TT*>(nullptr)));
     default:
       vtkErrorMacro(<< "Could not determine input scalar type.");
       return 1;
   }
 
+  // Get the WHOLE_EXTENT and divide it into chunks
   int extent[6];
   inInfo->Get(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT(), extent);
   // multiply by the area of each slice
   temp *= extent[1] - extent[0] + 1;
   temp *= extent[3] - extent[2] + 1;
   // temp holds memory per image. (+1 to avoid dividing by zero)
-  this->NumberOfSlicesPerChunk =
-    static_cast<int>(this->InputMemoryLimit * 1024 / (temp + 1));
+  this->NumberOfSlicesPerChunk = static_cast<int>(this->InputMemoryLimit * 1024 / (temp + 1));
   if (this->NumberOfSlicesPerChunk < minSlicesPerChunk)
   {
-    vtkWarningMacro("Execute: Need "
-      <<  minSlicesPerChunk*(temp/1024) << " KB to load "
-      << minSlicesPerChunk << " slices.\n");
+    vtkWarningMacro("Execute: Need " << minSlicesPerChunk * (temp / 1024) << " KB to load "
+                                     << minSlicesPerChunk << " slices.\n");
     this->NumberOfSlicesPerChunk = minSlicesPerChunk;
   }
-  vtkDebugMacro("Execute: NumberOfSlicesPerChunk = "
-                << this->NumberOfSlicesPerChunk);
+  vtkDebugMacro("Execute: NumberOfSlicesPerChunk = " << this->NumberOfSlicesPerChunk);
   this->NumberOfSlicesPerChunk -= chunkOverlap;
 
   // Create the points, scalars, normals and Cell arrays for the output.
@@ -147,42 +151,42 @@ int vtkImageMarchingCubes::RequestData(
   vtkIdType estimatedSize = static_cast<vtkIdType>(extent[1] - extent[0] + 1);
   estimatedSize *= static_cast<vtkIdType>(extent[3] - extent[2] + 1);
   estimatedSize *= static_cast<vtkIdType>(extent[5] - extent[4] + 1);
-  estimatedSize = static_cast<vtkIdType>(pow(1.0*estimatedSize, 0.75));
-  estimatedSize = (estimatedSize / 1024) * 1024; //multiple of 1024
+  estimatedSize = static_cast<vtkIdType>(pow(1.0 * estimatedSize, 0.75));
+  estimatedSize = (estimatedSize / 1024) * 1024; // multiple of 1024
   if (estimatedSize < 1024)
   {
     estimatedSize = 1024;
   }
   vtkDebugMacro(<< "Estimated number of points/triangles: " << estimatedSize);
   this->Points = vtkPoints::New();
-  this->Points->Allocate(estimatedSize,estimatedSize/2);
+  this->Points->Allocate(estimatedSize, estimatedSize / 2);
   this->Triangles = vtkCellArray::New();
-  this->Triangles->Allocate(estimatedSize,estimatedSize/2);
+  this->Triangles->AllocateEstimate(estimatedSize, 1);
   if (this->ComputeScalars)
   {
     this->Scalars = vtkFloatArray::New();
-    this->Scalars->Allocate(estimatedSize,estimatedSize/2);
+    this->Scalars->Allocate(estimatedSize, estimatedSize / 2);
   }
   if (this->ComputeNormals)
   {
     this->Normals = vtkFloatArray::New();
     this->Normals->SetNumberOfComponents(3);
-    this->Normals->Allocate(3*estimatedSize,3*estimatedSize/2);
+    this->Normals->Allocate(3 * estimatedSize, 3 * estimatedSize / 2);
   }
   if (this->ComputeGradients)
   {
     this->Gradients = vtkFloatArray::New();
     this->Gradients->SetNumberOfComponents(3);
-    this->Gradients->Allocate(3*estimatedSize,3*estimatedSize/2);
+    this->Gradients->Allocate(3 * estimatedSize, 3 * estimatedSize / 2);
   }
 
-  // Initialize the internal point locator (edge table for oen image of cubes).
+  // Initialize the internal point locator (edge table for one image of cubes).
   this->InitializeLocator(extent[0], extent[1], extent[2], extent[3]);
 
   // Loop through the chunks running marching cubes on each one
   int zMin = extent[4];
   int zMax = extent[5];
-  for(int chunkMin = zMin, chunkMax; chunkMin < zMax; chunkMin = chunkMax)
+  for (int chunkMin = zMin, chunkMax; chunkMin < zMax; chunkMin = chunkMax)
   {
     // Get the chunk from the input
     chunkMax = chunkMin + this->NumberOfSlicesPerChunk;
@@ -208,50 +212,50 @@ int vtkImageMarchingCubes::RequestData(
       extent[5] = zMax;
     }
     // Get the chunk from the input
-    inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT(),
-                extent, 6);
+    inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT(), extent, 6);
     inputExec->Update();
 
     this->March(inData, chunkMin, chunkMax, numContours, values);
-    if ( !this->AbortExecute )
+    if (!this->AbortExecute)
     {
-      this->UpdateProgress(static_cast<double>(chunkMax-zMin)/(zMax-zMin));
+      this->UpdateProgress(static_cast<double>(chunkMax - zMin) / (zMax - zMin));
     }
 
     if (vtkDataObject::GetGlobalReleaseDataFlag() ||
-        inInfo->Has(vtkStreamingDemandDrivenPipeline::RELEASE_DATA()))
+      inInfo->Has(vtkStreamingDemandDrivenPipeline::RELEASE_DATA()))
     {
       inData->ReleaseData();
     }
   }
 
   // Put results in our output
-  vtkDebugMacro(<<"Created: "
-               << this->Points->GetNumberOfPoints() << " points, "
-               << this->Triangles->GetNumberOfCells() << " triangles");
+  vtkDebugMacro(<< "Created: " << this->Points->GetNumberOfPoints() << " points, "
+                << this->Triangles->GetNumberOfCells() << " triangles");
   output->SetPoints(this->Points);
   this->Points->Delete();
-  this->Points = NULL;
+  this->Points = nullptr;
   output->SetPolys(this->Triangles);
   this->Triangles->Delete();
-  this->Triangles = NULL;
+  this->Triangles = nullptr;
   if (this->ComputeScalars)
   {
     int idx = output->GetPointData()->AddArray(this->Scalars);
     output->GetPointData()->SetActiveAttribute(idx, vtkDataSetAttributes::SCALARS);
     this->Scalars->Delete();
-    this->Scalars = NULL;
+    this->Scalars = nullptr;
   }
   if (this->ComputeNormals)
   {
     output->GetPointData()->SetNormals(this->Normals);
     this->Normals->Delete();
-    this->Normals = NULL;
+    this->Normals = nullptr;
   }
 
   // Recover extra space.
   output->Squeeze();
 
+  vtkImageTransform::TransformPointSet(inData, output);
+
   // release the locators memory
   this->DeleteLocator();
 
@@ -267,9 +271,8 @@ int vtkImageMarchingCubes::RequestData(
 // b0 = 0 => no boundary conditions
 // b0 = +1 => pixel is on x axis maximum of region.
 template <class T>
-void vtkImageMarchingCubesComputePointGradient(T *ptr, double *g,
-                                               int inc0, int inc1, int inc2,
-                                               short b0, short b1, short b2)
+void vtkImageMarchingCubesComputePointGradient(
+  T* ptr, double* g, int inc0, int inc1, int inc2, short b0, short b1, short b2)
 {
   if (b0 < 0)
   {
@@ -311,59 +314,55 @@ void vtkImageMarchingCubesComputePointGradient(T *ptr, double *g,
   }
 }
 
-
 //----------------------------------------------------------------------------
 // This method interpolates vertices to make a new point.
 template <class T>
-int vtkImageMarchingCubesMakeNewPoint(vtkImageMarchingCubes *self,
-                                      int idx0, int idx1, int idx2,
-                                      int inc0, int inc1, int inc2,
-                                      T *ptr, int edge,
-                                      int *imageExtent,
-                                      double *spacing, double *origin,
-                                      double value)
+int vtkImageMarchingCubesMakeNewPoint(vtkImageMarchingCubes* self, int idx0, int idx1, int idx2,
+  int inc0, int inc1, int inc2, T* ptr, int edge, int* imageExtent, double value)
 {
   int edgeAxis = 0;
-  T *ptrB = NULL;
+  T* ptrB = nullptr;
   double temp, pt[3];
 
   // decode the edge into starting point and axis direction
   switch (edge)
   {
-    case 0:  // 0,1
+    case 0: // 0,1
       ptrB = ptr + inc0;
       edgeAxis = 0;
       break;
-    case 1:  // 1,2
+    case 1: // 1,2
       ++idx0;
       ptr += inc0;
       ptrB = ptr + inc1;
       edgeAxis = 1;
       break;
-    case 2:  // 3,2
+    case 2: // 3,2
       ++idx1;
       ptr += inc1;
       ptrB = ptr + inc0;
       edgeAxis = 0;
       break;
-    case 3:  // 0,3
+    case 3: // 0,3
       ptrB = ptr + inc1;
       edgeAxis = 1;
       break;
-    case 4:  // 4,5
+    case 4: // 4,5
       ++idx2;
       ptr += inc2;
       ptrB = ptr + inc0;
       edgeAxis = 0;
       break;
-    case 5:  // 5,6
-      ++idx0; ++idx2;
+    case 5: // 5,6
+      ++idx0;
+      ++idx2;
       ptr += inc0 + inc2;
       ptrB = ptr + inc1;
       edgeAxis = 1;
       break;
-    case 6:  // 7,6
-      ++idx1; ++idx2;
+    case 6: // 7,6
+      ++idx1;
+      ++idx2;
       ptr += inc1 + inc2;
       ptrB = ptr + inc0;
       edgeAxis = 0;
@@ -391,7 +390,8 @@ int vtkImageMarchingCubesMakeNewPoint(vtkImageMarchingCubes *self,
       edgeAxis = 2;
       break;
     case 11: // 2,6
-      ++idx0; ++idx1;
+      ++idx0;
+      ++idx1;
       ptr += inc0 + inc1;
       ptrB = ptr + inc2;
       edgeAxis = 2;
@@ -405,19 +405,19 @@ int vtkImageMarchingCubesMakeNewPoint(vtkImageMarchingCubes *self,
   switch (edgeAxis)
   {
     case 0:
-      pt[0] = origin[0] + spacing[0] * ((double)idx0 + temp);
-      pt[1] = origin[1] + spacing[1] * ((double)idx1);
-      pt[2] = origin[2] + spacing[2] * ((double)idx2);
+      pt[0] = (double)idx0 + temp;
+      pt[1] = (double)idx1;
+      pt[2] = (double)idx2;
       break;
     case 1:
-      pt[0] = origin[0] + spacing[0] * ((double)idx0);
-      pt[1] = origin[1] + spacing[1] * ((double)idx1 + temp);
-      pt[2] = origin[2] + spacing[2] * ((double)idx2);
+      pt[0] = (double)idx0;
+      pt[1] = (double)idx1 + temp;
+      pt[2] = (double)idx2;
       break;
     case 2:
-      pt[0] = origin[0] + spacing[0] * ((double)idx0);
-      pt[1] = origin[1] + spacing[1] * ((double)idx1);
-      pt[2] = origin[2] + spacing[2] * ((double)idx2 + temp);
+      pt[0] = (double)idx0;
+      pt[1] = (double)idx1;
+      pt[2] = (double)idx2 + temp;
       break;
   }
 
@@ -448,8 +448,7 @@ int vtkImageMarchingCubesMakeNewPoint(vtkImageMarchingCubes *self,
     {
       b2 = -1;
     }
-    vtkImageMarchingCubesComputePointGradient(ptr, g, inc0, inc1, inc2,
-                                             b0, b1, b2);
+    vtkImageMarchingCubesComputePointGradient(ptr, g, inc0, inc1, inc2, b0, b1, b2);
     // Find boundary conditions and compute gradient (second point)
     switch (edgeAxis)
     {
@@ -466,19 +465,18 @@ int vtkImageMarchingCubesMakeNewPoint(vtkImageMarchingCubes *self,
         b2 = (idx2 == imageExtent[5]);
         break;
     }
-    vtkImageMarchingCubesComputePointGradient(ptrB, gB, inc0, inc1, inc2,
-                                             b0, b1, b2);
+    vtkImageMarchingCubesComputePointGradient(ptrB, gB, inc0, inc1, inc2, b0, b1, b2);
     // Interpolate Gradient
-    g[0] = (g[0] + temp * (gB[0] - g[0])) / spacing[0];
-    g[1] = (g[1] + temp * (gB[1] - g[1])) / spacing[1];
-    g[2] = (g[2] + temp * (gB[2] - g[2])) / spacing[2];
+    g[0] = g[0] + temp * (gB[0] - g[0]);
+    g[1] = g[1] + temp * (gB[1] - g[1]);
+    g[2] = g[2] + temp * (gB[2] - g[2]);
     if (self->ComputeGradients)
     {
       self->Gradients->InsertNextTuple(g);
     }
     if (self->ComputeNormals)
     {
-      temp = -1.0 / sqrt(g[0]*g[0] + g[1]*g[1] + g[2]*g[2]);
+      temp = -1.0 / sqrt(g[0] * g[0] + g[1] * g[1] + g[2] * g[2]);
       g[0] *= temp;
       g[1] *= temp;
       g[2] *= temp;
@@ -492,10 +490,8 @@ int vtkImageMarchingCubesMakeNewPoint(vtkImageMarchingCubes *self,
 //----------------------------------------------------------------------------
 // This method runs marching cubes on one cube.
 template <class T>
-void vtkImageMarchingCubesHandleCube(vtkImageMarchingCubes *self,
-                                     int cellX, int cellY, int cellZ,
-                                     vtkImageData *inData,
-                                     T *ptr, int numContours, double *values)
+void vtkImageMarchingCubesHandleCube(vtkImageMarchingCubes* self, int cellX, int cellY, int cellZ,
+  vtkImageData* inData, T* ptr, int numContours, double* values)
 {
   vtkIdType inc0, inc1, inc2;
   int valueIdx;
@@ -504,9 +500,9 @@ void vtkImageMarchingCubesHandleCube(vtkImageMarchingCubes *self,
   vtkIdType pointIds[3];
   vtkMarchingCubesTriangleCases *triCase, *triCases;
 
-  vtkInformation *inInfo = self->GetExecutive()->GetInputInformation(0, 0);
+  vtkInformation* inInfo = self->GetExecutive()->GetInputInformation(0, 0);
 
-  triCases =  vtkMarchingCubesTriangleCases::GetCases();
+  triCases = vtkMarchingCubesTriangleCases::GetCases();
 
   inData->GetIncrements(inc0, inc1, inc2);
   for (valueIdx = 0; valueIdx < numContours; ++valueIdx)
@@ -551,42 +547,34 @@ void vtkImageMarchingCubesHandleCube(vtkImageMarchingCubes *self,
     {
       // Get edges.
       triCase = triCases + cubeIndex;
-      EDGE_LIST *edge = triCase->edges;
+      EDGE_LIST* edge = triCase->edges;
       // loop over triangles
-      while(*edge > -1)
+      while (*edge > -1)
       {
-        for (ii=0; ii<3; ++ii, ++edge) //insert triangle
+        for (ii = 0; ii < 3; ++ii, ++edge) // insert triangle
         {
           // Get the index of the point
           pointIds[ii] = self->GetLocatorPoint(cellX, cellY, *edge);
           // If the point has not been created yet
           if (pointIds[ii] == -1)
           {
-            double *spacing = inData->GetSpacing();
-            double *origin = inData->GetOrigin();
-            int *extent =
-              inInfo->Get(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT());
+            int* extent = inInfo->Get(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT());
 
-            pointIds[ii] = vtkImageMarchingCubesMakeNewPoint(self,
-                                              cellX, cellY, cellZ,
-                                              inc0, inc1, inc2,
-                                              ptr, *edge, extent,
-                                              spacing, origin, value);
+            pointIds[ii] = vtkImageMarchingCubesMakeNewPoint(
+              self, cellX, cellY, cellZ, inc0, inc1, inc2, ptr, *edge, extent, value);
             self->AddLocatorPoint(cellX, cellY, *edge, pointIds[ii]);
           }
         }
-        self->Triangles->InsertNextCell(3,pointIds);
-      }//for each triangle
+        self->Triangles->InsertNextCell(3, pointIds);
+      } // for each triangle
     }
   }
 }
 
 //----------------------------------------------------------------------------
 template <class T>
-void vtkImageMarchingCubesMarch(vtkImageMarchingCubes *self,
-                                vtkImageData *inData, T *ptr,
-                                int chunkMin, int chunkMax,
-                                int numContours, double *values)
+void vtkImageMarchingCubesMarch(vtkImageMarchingCubes* self, vtkImageData* inData, T* ptr,
+  int chunkMin, int chunkMax, int numContours, double* values)
 {
   int idx0, idx1, idx2;
   int min0, max0, min1, max1, min2, max2;
@@ -599,11 +587,11 @@ void vtkImageMarchingCubesMarch(vtkImageMarchingCubes *self,
 
   // Get information to loop through images.
   inData->GetExtent(min0, max0, min1, max1, min2, max2);
-  ptr2 = (T *)(inData->GetScalarPointer(min0, min1, chunkMin));
+  ptr2 = (T*)(inData->GetScalarPointer(min0, min1, chunkMin));
   inData->GetIncrements(inc0, inc1, inc2);
 
   // Setup the abort interval
-  target = (unsigned long)((max0-min0+1) * (max1-min1+1) / 50.0);
+  target = (unsigned long)((max0 - min0 + 1) * (max1 - min1 + 1) / 50.0);
   ++target;
   count = 0;
 
@@ -613,7 +601,7 @@ void vtkImageMarchingCubesMarch(vtkImageMarchingCubes *self,
     ptr1 = ptr2;
     for (idx1 = min1; idx1 < max1; ++idx1)
     {
-      if (!(count%target))
+      if (!(count % target))
       {
         if (self->GetAbortExecute())
         {
@@ -626,8 +614,7 @@ void vtkImageMarchingCubesMarch(vtkImageMarchingCubes *self,
       for (idx0 = min0; idx0 < max0; ++idx0)
       {
         // put magnitudes into the cube structure.
-        vtkImageMarchingCubesHandleCube(self, idx0, idx1, idx2, inData, ptr0,
-                                       numContours, values);
+        vtkImageMarchingCubesHandleCube(self, idx0, idx1, idx2, inData, ptr0, numContours, values);
 
         ptr0 += inc0;
       }
@@ -638,29 +625,23 @@ void vtkImageMarchingCubesMarch(vtkImageMarchingCubes *self,
   }
 }
 
-
-
 //----------------------------------------------------------------------------
 // This method calls the proper templade function.
-void vtkImageMarchingCubes::March(vtkImageData *inData,
-                                 int chunkMin, int chunkMax,
-                                 int numContours, double *values)
+void vtkImageMarchingCubes::March(
+  vtkImageData* inData, int chunkMin, int chunkMax, int numContours, double* values)
 {
-  void *ptr = inData->GetScalarPointer();
+  void* ptr = inData->GetScalarPointer();
 
   switch (inData->GetScalarType())
   {
-    vtkTemplateMacro(
-      vtkImageMarchingCubesMarch(this, inData, static_cast<VTK_TT*>(ptr),
-                                 chunkMin, chunkMax, numContours, values)
-      );
+    vtkTemplateMacro(vtkImageMarchingCubesMarch(
+      this, inData, static_cast<VTK_TT*>(ptr), chunkMin, chunkMax, numContours, values));
     default:
       vtkErrorMacro(<< "Unknown output ScalarType");
       return;
   }
 }
 
-
 //============================================================================
 // These method act as the point locator so vertices will be shared.
 // One 2d array of cubes is stored. (z dimension is ignored).
@@ -669,15 +650,13 @@ void vtkImageMarchingCubes::March(vtkImageData *inData,
 // edges on their min faces.  Their is an extra row and column of cubes
 // to store the max edges of the last row/column of cubes,
 
-
 //----------------------------------------------------------------------------
 // This method allocates and initializes the point array.
 // One 2d array of cubes is stored. (z dimension is ignored).
-void vtkImageMarchingCubes::InitializeLocator(int min0, int max0,
-                                              int min1, int max1)
+void vtkImageMarchingCubes::InitializeLocator(int min0, int max0, int min1, int max1)
 {
   // Free old memory
-  delete [] this->LocatorPointIds;
+  delete[] this->LocatorPointIds;
 
   // Extra row and column
   this->LocatorDimX = (max0 - min0 + 2);
@@ -701,15 +680,15 @@ void vtkImageMarchingCubes::InitializeLocator(int min0, int max0,
 void vtkImageMarchingCubes::DeleteLocator()
 {
   // Free old memory
-  delete [] this->LocatorPointIds;
-  this->LocatorPointIds = NULL;
+  delete[] this->LocatorPointIds;
+  this->LocatorPointIds = nullptr;
 }
 
 //----------------------------------------------------------------------------
 // This method moves the Z index of the locator up one slice.
 void vtkImageMarchingCubes::IncrementLocatorZ()
 {
-  vtkIdType *ptr = this->LocatorPointIds;
+  vtkIdType* ptr = this->LocatorPointIds;
   for (int y = 0; y < this->LocatorDimY; ++y)
   {
     for (int x = 0; x < this->LocatorDimX; ++x)
@@ -731,12 +710,11 @@ void vtkImageMarchingCubes::IncrementLocatorZ()
 // (1,1,1)->(0,1,1): 6,  (0,1,1)->(0,0,1): 7,
 // (0,0,0)->(0,0,1): 8,  (1,0,0)->(1,0,1): 9,
 // (0,1,0)->(0,1,1): 10, (1,1,0)->(1,1,1): 11.
-// Shared edges are computed internaly. (no error checking)
-void vtkImageMarchingCubes::AddLocatorPoint(int cellX, int cellY, int edge,
-                                            vtkIdType ptId)
+// Shared edges are computed internally. (no error checking)
+void vtkImageMarchingCubes::AddLocatorPoint(int cellX, int cellY, int edge, vtkIdType ptId)
 {
   // Get the correct position in the array.
-  vtkIdType *ptr = this->GetLocatorPointer(cellX, cellY, edge);
+  vtkIdType* ptr = this->GetLocatorPointer(cellX, cellY, edge);
   *ptr = ptId;
 }
 
@@ -745,25 +723,47 @@ void vtkImageMarchingCubes::AddLocatorPoint(int cellX, int cellY, int edge,
 vtkIdType vtkImageMarchingCubes::GetLocatorPoint(int cellX, int cellY, int edge)
 {
   // Get the correct position in the array.
-  vtkIdType *ptr = this->GetLocatorPointer(cellX, cellY, edge);
+  vtkIdType* ptr = this->GetLocatorPointer(cellX, cellY, edge);
   return *ptr;
 }
 
 //----------------------------------------------------------------------------
 // This method returns a pointer to an ID from a cube and an edge.
-vtkIdType *vtkImageMarchingCubes::GetLocatorPointer(int cellX,int cellY,int edge)
+vtkIdType* vtkImageMarchingCubes::GetLocatorPointer(int cellX, int cellY, int edge)
 {
   // Remove redundant edges (shared by more than one cube).
   // Take care of shared edges
   switch (edge)
   {
-    case 9:  ++cellX;          edge = 8; break;
-    case 10: ++cellY;          edge = 8; break;
-    case 11: ++cellX; ++cellY; edge = 8; break;
-    case 5:  ++cellX;          edge = 7; break;
-    case 6:  ++cellY;          edge = 4; break;
-    case 1:  ++cellX;          edge = 3; break;
-    case 2:  ++cellY;          edge = 0; break;
+    case 9:
+      ++cellX;
+      edge = 8;
+      break;
+    case 10:
+      ++cellY;
+      edge = 8;
+      break;
+    case 11:
+      ++cellX;
+      ++cellY;
+      edge = 8;
+      break;
+    case 5:
+      ++cellX;
+      edge = 7;
+      break;
+    case 6:
+      ++cellY;
+      edge = 4;
+      break;
+    case 1:
+      ++cellX;
+      edge = 3;
+      break;
+    case 2:
+      ++cellY;
+      edge = 0;
+      break;
   }
 
   // relative to min and max.
@@ -782,12 +782,12 @@ vtkIdType *vtkImageMarchingCubes::GetLocatorPointer(int cellX,int cellY,int edge
   }
 
   // return correct pointer
-  return this->LocatorPointIds + edge
-    + (cellX + cellY * static_cast<vtkIdType>(this->LocatorDimX)) * 5;
+  return this->LocatorPointIds + edge +
+    (cellX + cellY * static_cast<vtkIdType>(this->LocatorDimX)) * 5;
 }
 
 //----------------------------------------------------------------------------
-int vtkImageMarchingCubes::FillInputPortInformation(int, vtkInformation *info)
+int vtkImageMarchingCubes::FillInputPortInformation(int, vtkInformation* info)
 {
   info->Set(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkImageData");
   return 1;
@@ -796,13 +796,13 @@ int vtkImageMarchingCubes::FillInputPortInformation(int, vtkInformation *info)
 //----------------------------------------------------------------------------
 void vtkImageMarchingCubes::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 
-  this->ContourValues->PrintSelf(os,indent.GetNextIndent());
+  this->ContourValues->PrintSelf(os, indent.GetNextIndent());
 
   os << indent << "ComputeScalars: " << this->ComputeScalars << "\n";
   os << indent << "ComputeNormals: " << this->ComputeNormals << "\n";
   os << indent << "ComputeGradients: " << this->ComputeGradients << "\n";
 
-  os << indent << "InputMemoryLimit: " << this->InputMemoryLimit <<"K bytes\n";
+  os << indent << "InputMemoryLimit: " << this->InputMemoryLimit << "K bytes\n";
 }
