@@ -48,13 +48,13 @@
  *
  * @sa
  * vtkLocator vtkCellLocator vtkPointLocator
-*/
+ */
 
 #ifndef vtkOBBTree_h
 #define vtkOBBTree_h
 
-#include "vtkFiltersGeneralModule.h" // For export macro
 #include "vtkAbstractCellLocator.h"
+#include "vtkFiltersGeneralModule.h" // For export macro
 
 class vtkMatrix4x4;
 
@@ -62,22 +62,22 @@ class vtkMatrix4x4;
 //
 
 //
-class VTKFILTERSGENERAL_EXPORT vtkOBBNode { //;prevent man page generation
+class VTKFILTERSGENERAL_EXPORT vtkOBBNode
+{ //;prevent man page generation
 public:
   vtkOBBNode();
   ~vtkOBBNode();
 
-  double Corner[3]; //center point of this node
-  double Axes[3][3]; //the axes defining the OBB - ordered from long->short
-  vtkOBBNode *Parent; //parent node; NULL if root
-  vtkOBBNode **Kids; //two children of this node; NULL if leaf
-  vtkIdList *Cells; //list of cells in node
-  void DebugPrintTree( int level, double *leaf_vol, int *minCells,
-                       int *maxCells );
+  double Corner[3];   // center point of this node
+  double Axes[3][3];  // the axes defining the OBB - ordered from long->short
+  vtkOBBNode* Parent; // parent node; nullptr if root
+  vtkOBBNode** Kids;  // two children of this node; nullptr if leaf
+  vtkIdList* Cells;   // list of cells in node
+  void DebugPrintTree(int level, double* leaf_vol, int* minCells, int* maxCells);
 
 private:
-  vtkOBBNode(const vtkOBBNode& other) VTK_DELETE_FUNCTION;
-  vtkOBBNode& operator=(const vtkOBBNode& rhs) VTK_DELETE_FUNCTION;
+  vtkOBBNode(const vtkOBBNode& other) = delete;
+  vtkOBBNode& operator=(const vtkOBBNode& rhs) = delete;
 };
 
 //
@@ -85,14 +85,14 @@ private:
 class VTKFILTERSGENERAL_EXPORT vtkOBBTree : public vtkAbstractCellLocator
 {
 public:
-  vtkTypeMacro(vtkOBBTree,vtkAbstractCellLocator);
-  void PrintSelf(ostream& os, vtkIndent indent) VTK_OVERRIDE;
+  vtkTypeMacro(vtkOBBTree, vtkAbstractCellLocator);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
   /**
    * Construct with automatic computation of divisions, averaging
    * 25 cells per octant.
    */
-  static vtkOBBTree *New();
+  static vtkOBBTree* New();
 
   // Re-use any superclass signatures that we don't override.
   using vtkAbstractCellLocator::IntersectWithLine;
@@ -105,28 +105,28 @@ public:
    * The return value of the function is 0 if no intersections were found,
    * -1 if point 'a0' lies inside the closed surface, or +1 if point 'a0'
    * lies outside the closed surface.
-   * Either 'points' or 'cellIds' can be set to NULL if you don't want
+   * Either 'points' or 'cellIds' can be set to nullptr if you don't want
    * to receive that information.
    */
-  int IntersectWithLine(const double a0[3], const double a1[3],
-                        vtkPoints *points, vtkIdList *cellIds) VTK_OVERRIDE;
+  int IntersectWithLine(
+    const double a0[3], const double a1[3], vtkPoints* points, vtkIdList* cellIds) override;
 
   /**
    * Return the first intersection of the specified line segment with
    * the OBB tree, as well as information about the cell which the
-   * line segment intersected.
+   * line segment intersected. A return value of 1 indicates an intersection
+   * and 0 indicates no intersection.
    */
-  int IntersectWithLine(double a0[3], double a1[3], double tol,
-                        double& t, double x[3], double pcoords[3],
-                        int &subId, vtkIdType &cellId, vtkGenericCell *cell) VTK_OVERRIDE;
+  int IntersectWithLine(const double a0[3], const double a1[3], double tol, double& t, double x[3],
+    double pcoords[3], int& subId, vtkIdType& cellId, vtkGenericCell* cell) override;
 
   /**
    * Compute an OBB from the list of points given. Return the corner point
    * and the three axes defining the orientation of the OBB. Also return
    * a sorted list of relative "sizes" of axes for comparison purposes.
    */
-  static void ComputeOBB(vtkPoints *pts, double corner[3], double max[3],
-                  double mid[3], double min[3], double size[3]);
+  static void ComputeOBB(
+    vtkPoints* pts, double corner[3], double max[3], double mid[3], double min[3], double size[3]);
 
   /**
    * Compute an OBB for the input dataset using the cells in the data.
@@ -134,8 +134,8 @@ public:
    * of the OBB. Also return a sorted list of relative "sizes" of axes for
    * comparison purposes.
    */
-  void ComputeOBB(vtkDataSet *input, double corner[3], double max[3],
-                  double mid[3], double min[3], double size[3]);
+  void ComputeOBB(vtkDataSet* input, double corner[3], double max[3], double mid[3], double min[3],
+    double size[3]);
 
   /**
    * Determine whether a point is inside or outside the data used to build
@@ -148,38 +148,33 @@ public:
    * Returns true if nodeB and nodeA are disjoint after optional
    * transformation of nodeB with matrix XformBtoA
    */
-  int DisjointOBBNodes( vtkOBBNode *nodeA, vtkOBBNode *nodeB,
-                        vtkMatrix4x4 *XformBtoA );
+  int DisjointOBBNodes(vtkOBBNode* nodeA, vtkOBBNode* nodeB, vtkMatrix4x4* XformBtoA);
 
   /**
    * Returns true if line intersects node.
    */
-  int LineIntersectsNode( vtkOBBNode *pA, double b0[3], double b1[3] );
+  int LineIntersectsNode(vtkOBBNode* pA, const double b0[3], const double b1[3]);
 
   /**
    * Returns true if triangle (optionally transformed) intersects node.
    */
-  int TriangleIntersectsNode( vtkOBBNode *pA,
-                              double p0[3], double p1[3],
-                              double p2[3], vtkMatrix4x4 *XformBtoA );
+  int TriangleIntersectsNode(
+    vtkOBBNode* pA, double p0[3], double p1[3], double p2[3], vtkMatrix4x4* XformBtoA);
 
   /**
    * For each intersecting leaf node pair, call function.
    * OBBTreeB is optionally transformed by XformBtoA before testing.
    */
-  int IntersectWithOBBTree( vtkOBBTree *OBBTreeB, vtkMatrix4x4 *XformBtoA,
-                            int(*function)( vtkOBBNode *nodeA,
-                                            vtkOBBNode *nodeB,
-                                            vtkMatrix4x4 *Xform,
-                                            void *arg ),
-                            void *data_arg );
+  int IntersectWithOBBTree(vtkOBBTree* OBBTreeB, vtkMatrix4x4* XformBtoA,
+    int (*function)(vtkOBBNode* nodeA, vtkOBBNode* nodeB, vtkMatrix4x4* Xform, void* arg),
+    void* data_arg);
 
   //@{
   /**
    * Satisfy locator's abstract interface, see vtkLocator.
    */
-  void FreeSearchStructure() VTK_OVERRIDE;
-  void BuildLocator() VTK_OVERRIDE;
+  void FreeSearchStructure() override;
+  void BuildLocator() override;
   //@}
 
   /**
@@ -191,31 +186,31 @@ public:
    * represented either as two crossed polygons, or as a line, depending on
    * the relative diameter of the OBB compared to the diameter (d).
    */
-  void GenerateRepresentation(int level, vtkPolyData *pd) VTK_OVERRIDE;
+  void GenerateRepresentation(int level, vtkPolyData* pd) override;
 
 protected:
   vtkOBBTree();
-  ~vtkOBBTree() VTK_OVERRIDE;
+  ~vtkOBBTree() override;
 
   // Compute an OBB from the list of cells given.  This used to be
   // public but should not have been.  A public call has been added
   // so that the functionality can be accessed.
-  void ComputeOBB(vtkIdList *cells, double corner[3], double max[3],
-                       double mid[3], double min[3], double size[3]);
+  void ComputeOBB(vtkIdList* cells, double corner[3], double max[3], double mid[3], double min[3],
+    double size[3]);
 
-  vtkOBBNode *Tree;
-  void BuildTree(vtkIdList *cells, vtkOBBNode *parent, int level);
-  vtkPoints *PointsList;
-  int *InsertedPoints;
+  vtkOBBNode* Tree;
+  void BuildTree(vtkIdList* cells, vtkOBBNode* parent, int level);
+  vtkPoints* PointsList;
+  int* InsertedPoints;
   int OBBCount;
 
-  void DeleteTree(vtkOBBNode *OBBptr);
-  void GeneratePolygons(vtkOBBNode *OBBptr, int level, int repLevel,
-                        vtkPoints* pts, vtkCellArray *polys);
+  void DeleteTree(vtkOBBNode* OBBptr);
+  void GeneratePolygons(
+    vtkOBBNode* OBBptr, int level, int repLevel, vtkPoints* pts, vtkCellArray* polys);
 
 private:
-  vtkOBBTree(const vtkOBBTree&) VTK_DELETE_FUNCTION;
-  void operator=(const vtkOBBTree&) VTK_DELETE_FUNCTION;
+  vtkOBBTree(const vtkOBBTree&) = delete;
+  void operator=(const vtkOBBTree&) = delete;
 };
 
 #endif
