@@ -33,14 +33,12 @@ vtkShrinkFilter::vtkShrinkFilter()
 }
 
 //----------------------------------------------------------------------------
-vtkShrinkFilter::~vtkShrinkFilter()
-{
-}
+vtkShrinkFilter::~vtkShrinkFilter() = default;
 
 //----------------------------------------------------------------------------
 void vtkShrinkFilter::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
   os << indent << "Shrink Factor: " << this->ShrinkFactor << "\n";
 }
 
@@ -54,9 +52,8 @@ int vtkShrinkFilter::FillInputPortInformation(int, vtkInformation* info)
 }
 
 //----------------------------------------------------------------------------
-int vtkShrinkFilter::RequestData(vtkInformation*,
-                                 vtkInformationVector** inputVector,
-                                 vtkInformationVector* outputVector)
+int vtkShrinkFilter::RequestData(
+  vtkInformation*, vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
   // Get input and output data.
   vtkDataSet* input = vtkDataSet::GetData(inputVector[0]);
@@ -68,7 +65,7 @@ int vtkShrinkFilter::RequestData(vtkInformation*,
   // Skip execution if there is no input geometry.
   vtkIdType numCells = input->GetNumberOfCells();
   vtkIdType numPts = input->GetNumberOfPoints();
-  if(numCells < 1 || numPts < 1)
+  if (numCells < 1 || numPts < 1)
   {
     vtkDebugMacro("No data to shrink!");
     return 1;
@@ -85,16 +82,16 @@ int vtkShrinkFilter::RequestData(vtkInformation*,
 
   // Allocate space for a new set of points.
   vtkSmartPointer<vtkPoints> newPts = vtkSmartPointer<vtkPoints>::New();
-  newPts->Allocate(numPts*8, numPts);
+  newPts->Allocate(numPts * 8, numPts);
 
   // Allocate space for data associated with the new set of points.
   vtkPointData* inPD = input->GetPointData();
   vtkPointData* outPD = output->GetPointData();
-  outPD->CopyAllocate(inPD, numPts*8, numPts);
+  outPD->CopyAllocate(inPD, numPts * 8, numPts);
 
   // Support progress and abort.
-  vtkIdType tenth = (numCells >= 10? numCells/10 : 1);
-  double numCellsInv = 1.0/numCells;
+  vtkIdType tenth = (numCells >= 10 ? numCells / 10 : 1);
+  double numCellsInv = 1.0 / numCells;
   int abort = 0;
 
   // Point Id map.
@@ -102,38 +99,38 @@ int vtkShrinkFilter::RequestData(vtkInformation*,
 
   // Traverse all cells, obtaining node coordinates.  Compute "center"
   // of cell, then create new vertices shrunk towards center.
-  for(vtkIdType cellId = 0; cellId < numCells && !abort; ++cellId)
+  for (vtkIdType cellId = 0; cellId < numCells && !abort; ++cellId)
   {
     // Get the list of points for this cell.
     input->GetCellPoints(cellId, ptIds);
     vtkIdType numIds = ptIds->GetNumberOfIds();
 
     // Periodically update progress and check for an abort request.
-    if(cellId % tenth == 0)
+    if (cellId % tenth == 0)
     {
-      this->UpdateProgress((cellId+1)*numCellsInv);
+      this->UpdateProgress((cellId + 1) * numCellsInv);
       abort = this->GetAbortExecute();
     }
 
     // Compute the center of mass of the cell points.
-    double center[3] = {0,0,0};
-    for(vtkIdType i=0; i < numIds; ++i)
+    double center[3] = { 0, 0, 0 };
+    for (vtkIdType i = 0; i < numIds; ++i)
     {
       double p[3];
       input->GetPoint(ptIds->GetId(i), p);
-      for(int j=0; j < 3; ++j)
+      for (int j = 0; j < 3; ++j)
       {
         center[j] += p[j];
       }
     }
-    for(int j=0; j < 3; ++j)
+    for (int j = 0; j < 3; ++j)
     {
       center[j] /= numIds;
     }
 
     // Create new points for this cell.
     newPtIds->Reset();
-    for(vtkIdType i=0; i < numIds; ++i)
+    for (vtkIdType i = 0; i < numIds; ++i)
     {
       // Get the old point location.
       double p[3];
@@ -141,9 +138,9 @@ int vtkShrinkFilter::RequestData(vtkInformation*,
 
       // Compute the new point location.
       double newPt[3];
-      for(int j=0; j < 3; ++j)
+      for (int j = 0; j < 3; ++j)
       {
-        newPt[j] = center[j] + this->ShrinkFactor*(p[j] - center[j]);
+        newPt[j] = center[j] + this->ShrinkFactor * (p[j] - center[j]);
       }
 
       // Create the new point for this cell.
@@ -157,15 +154,14 @@ int vtkShrinkFilter::RequestData(vtkInformation*,
     }
 
     // special handling for polyhedron cells
-    if (vtkUnstructuredGrid::SafeDownCast(input) &&
-        input->GetCellType(cellId) == VTK_POLYHEDRON)
+    if (vtkUnstructuredGrid::SafeDownCast(input) && input->GetCellType(cellId) == VTK_POLYHEDRON)
     {
       vtkUnstructuredGrid::SafeDownCast(input)->GetFaceStream(cellId, newPtIds);
       vtkUnstructuredGrid::ConvertFaceStreamPointIds(newPtIds, pointMap);
     }
     else
     {
-      for(vtkIdType i=0; i < numIds; ++i)
+      for (vtkIdType i = 0; i < numIds; ++i)
       {
         newPtIds->InsertId(i, pointMap[ptIds->GetId(i)]);
       }
@@ -185,7 +181,7 @@ int vtkShrinkFilter::RequestData(vtkInformation*,
   // Avoid keeping extra memory around.
   output->Squeeze();
 
-  delete [] pointMap;
+  delete[] pointMap;
 
   return 1;
 }
