@@ -14,9 +14,9 @@ PURPOSE.  See the above copyright notice for more information.
 =========================================================================*/
 #include "vtkGenericGlyph3DFilter.h"
 
-#include "vtkGenericDataSet.h"
 #include "vtkGenericAttribute.h"
 #include "vtkGenericAttributeCollection.h"
+#include "vtkGenericDataSet.h"
 #include "vtkGenericPointIterator.h"
 
 #include "vtkCell.h"
@@ -54,13 +54,13 @@ vtkGenericGlyph3DFilter::vtkGenericGlyph3DFilter()
   this->VectorMode = VTK_USE_VECTOR;
   this->Clamping = 0;
   this->IndexMode = VTK_INDEXING_OFF;
-//  this->NumberOfRequiredInputs = 1;
+  //  this->NumberOfRequiredInputs = 1;
   this->GeneratePointIds = 0;
-  this->PointIdsName = NULL;
+  this->PointIdsName = nullptr;
   this->SetPointIdsName("InputPointIds");
-  this->InputScalarsSelection = NULL;
-  this->InputVectorsSelection = NULL;
-  this->InputNormalsSelection = NULL;
+  this->InputScalarsSelection = nullptr;
+  this->InputVectorsSelection = nullptr;
+  this->InputNormalsSelection = nullptr;
   this->SetNumberOfInputPorts(2);
 }
 
@@ -68,89 +68,84 @@ vtkGenericGlyph3DFilter::vtkGenericGlyph3DFilter()
 vtkGenericGlyph3DFilter::~vtkGenericGlyph3DFilter()
 {
   delete[] this->PointIdsName;
-  this->SetInputScalarsSelection(NULL);
-  this->SetInputVectorsSelection(NULL);
-  this->SetInputNormalsSelection(NULL);
+  this->SetInputScalarsSelection(nullptr);
+  this->SetInputVectorsSelection(nullptr);
+  this->SetInputNormalsSelection(nullptr);
 }
 
 //-----------------------------------------------------------------------------
-int vtkGenericGlyph3DFilter::RequestData(
-  vtkInformation *vtkNotUsed(request),
-  vtkInformationVector **inputVector,
-  vtkInformationVector *outputVector)
+int vtkGenericGlyph3DFilter::RequestData(vtkInformation* vtkNotUsed(request),
+  vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
   // get the info objects
-  vtkInformation *inInfo = inputVector[0]->GetInformationObject(0);
-  vtkInformation *outInfo = outputVector->GetInformationObject(0);
+  vtkInformation* inInfo = inputVector[0]->GetInformationObject(0);
+  vtkInformation* outInfo = outputVector->GetInformationObject(0);
 
   // get the input and output
-  vtkGenericDataSet *input = vtkGenericDataSet::SafeDownCast(
-    inInfo->Get(vtkDataObject::DATA_OBJECT()));
-  vtkPolyData *output = vtkPolyData::SafeDownCast(
-    outInfo->Get(vtkDataObject::DATA_OBJECT()));
+  vtkGenericDataSet* input =
+    vtkGenericDataSet::SafeDownCast(inInfo->Get(vtkDataObject::DATA_OBJECT()));
+  vtkPolyData* output = vtkPolyData::SafeDownCast(outInfo->Get(vtkDataObject::DATA_OBJECT()));
 
-
-
-  vtkPointData *pd = NULL;
+  vtkPointData* pd = nullptr;
   //  vtkDataArray *inScalars;
   //  vtkDataArray *inVectors;
   //  vtkDataArray *inNormals;
-  vtkDataArray *sourceNormals = NULL;
-  vtkGenericAttribute *inScalars=0;
-  vtkGenericAttribute *inVectors=0;
-  vtkGenericAttribute *inNormals=0;
+  vtkDataArray* sourceNormals = nullptr;
+  vtkGenericAttribute* inScalars = nullptr;
+  vtkGenericAttribute* inVectors = nullptr;
+  vtkGenericAttribute* inNormals = nullptr;
   //  vtkGenericAttribute *sourceNormals=0;
 
-  unsigned char* inGhostLevels=0;
+  unsigned char* inGhostLevels = nullptr;
 
   vtkIdType numPts, numSourcePts, numSourceCells, inPtId, i;
   int index;
-  vtkPoints *sourcePts = NULL;
-  vtkPoints *newPts;
-  vtkDataArray *newScalars=NULL;
-  vtkDataArray *newVectors=NULL;
-  vtkDataArray *newNormals=NULL;
+  vtkPoints* sourcePts = nullptr;
+  vtkPoints* newPts;
+  vtkDataArray* newScalars = nullptr;
+  vtkDataArray* newVectors = nullptr;
+  vtkDataArray* newNormals = nullptr;
   double x[3], v[3], vNew[3], s = 0.0, vMag = 0.0, value;
-  vtkTransform *trans;
-  vtkCell *cell;
-  vtkIdList *cellPts;
+  vtkTransform* trans;
+  vtkCell* cell;
+  vtkIdList* cellPts;
   int npts;
-  vtkIdList *pts;
+  vtkIdList* pts;
   vtkIdType ptIncr, cellId;
   int haveVectors, haveNormals;
-  double scalex,scaley,scalez, den;
-  vtkPointData *outputPD = output->GetPointData();
-//  vtkGenericDataSet *input = this->GetInput();
+  double scalex, scaley, scalez, den;
+  vtkPointData* outputPD = output->GetPointData();
+  //  vtkGenericDataSet *input = this->GetInput();
   int numberOfSources = this->GetNumberOfInputConnections(1);
-  vtkPolyData *defaultSource = NULL;
-  vtkIdTypeArray *pointIds=0;
+  vtkPolyData* defaultSource = nullptr;
+  vtkIdTypeArray* pointIds = nullptr;
 
-  vtkGenericAttributeCollection *attributes=0;
-  int attrib=-1;
+  vtkGenericAttributeCollection* attributes = nullptr;
+  int attrib = -1;
 
-  vtkDebugMacro(<<"Generating glyphs");
+  vtkDebugMacro(<< "Generating glyphs");
 
   if (!input)
   {
-    vtkErrorMacro(<<"No input");
+    vtkErrorMacro(<< "No input");
     return 1;
   }
 
   attributes = input->GetAttributes();
-  if((attributes==0) || (attributes->IsEmpty()))
+  if ((attributes == nullptr) || (attributes->IsEmpty()))
   {
     vtkDebugMacro("No attributes, nothing to do.");
     return 1;
   }
-  if (this->InputScalarsSelection!=0)
+  if (this->InputScalarsSelection != nullptr)
   {
-    attrib=attributes->FindAttribute(this->InputScalarsSelection);
-    if(attrib!=-1)
+    attrib = attributes->FindAttribute(this->InputScalarsSelection);
+    if (attrib != -1)
     {
       inScalars = attributes->GetAttribute(attrib);
-      if(inScalars->GetNumberOfComponents()!=1)
+      if (inScalars->GetNumberOfComponents() != 1)
       {
-        inScalars=0;
+        inScalars = nullptr;
         vtkDebugMacro("The attribute is not a scalar.");
       }
     }
@@ -159,17 +154,17 @@ int vtkGenericGlyph3DFilter::RequestData(
       vtkDebugMacro("No scalar attribute.");
     }
   }
-  if (this->InputVectorsSelection!=0)
+  if (this->InputVectorsSelection != nullptr)
   {
     vtkDebugMacro("this->InputVectorsSelection!=0");
-    attrib=attributes->FindAttribute(this->InputVectorsSelection);
+    attrib = attributes->FindAttribute(this->InputVectorsSelection);
     vtkDebugMacro("inVectors just set");
-    if(attrib!=-1)
+    if (attrib != -1)
     {
       inVectors = attributes->GetAttribute(attrib);
-      if(inVectors->GetNumberOfComponents()!=3)
+      if (inVectors->GetNumberOfComponents() != 3)
       {
-        inVectors=0;
+        inVectors = nullptr;
         vtkDebugMacro("The attribute is not a vector.");
       }
       else
@@ -187,15 +182,15 @@ int vtkGenericGlyph3DFilter::RequestData(
     vtkDebugMacro("No input vector selection.");
   }
 
-  if (this->InputNormalsSelection!=0)
+  if (this->InputNormalsSelection != nullptr)
   {
     attrib = attributes->FindAttribute(this->InputNormalsSelection);
-    if(attrib!=-1)
+    if (attrib != -1)
     {
       inNormals = attributes->GetAttribute(attrib);
-      if(inNormals->GetNumberOfComponents()!=3)
+      if (inNormals->GetNumberOfComponents() != 3)
       {
-        inNormals=0;
+        inNormals = nullptr;
         vtkDebugMacro("The attribute is not a normal vector.");
       }
     }
@@ -231,25 +226,25 @@ int vtkGenericGlyph3DFilter::RequestData(
   numPts = input->GetNumberOfPoints();
   if (numPts < 1)
   {
-    vtkDebugMacro(<<"No points to glyph!");
+    vtkDebugMacro(<< "No points to glyph!");
     return 1;
   }
   else
   {
     pts = vtkIdList::New();
     pts->Allocate(VTK_CELL_SIZE);
-    trans=vtkTransform::New();
+    trans = vtkTransform::New();
   }
 
   // Check input for consistency
   //
-  if ( (den = this->Range[1] - this->Range[0]) == 0.0 )
+  if ((den = this->Range[1] - this->Range[0]) == 0.0)
   {
     den = 1.0;
   }
-  if ( this->VectorMode != VTK_VECTOR_ROTATION_OFF &&
-       ((this->VectorMode == VTK_USE_VECTOR && inVectors != NULL) ||
-        (this->VectorMode == VTK_USE_NORMAL && inNormals != NULL)) )
+  if (this->VectorMode != VTK_VECTOR_ROTATION_OFF &&
+    ((this->VectorMode == VTK_USE_VECTOR && inVectors != nullptr) ||
+      (this->VectorMode == VTK_USE_NORMAL && inNormals != nullptr)))
   {
     haveVectors = 1;
   }
@@ -258,21 +253,21 @@ int vtkGenericGlyph3DFilter::RequestData(
     haveVectors = 0;
   }
 
-  if ( (this->IndexMode == VTK_INDEXING_BY_SCALAR && !inScalars) ||
-       (this->IndexMode == VTK_INDEXING_BY_VECTOR &&
-        ((!inVectors && this->VectorMode == VTK_USE_VECTOR) ||
-         (!inNormals && this->VectorMode == VTK_USE_NORMAL))) )
+  if ((this->IndexMode == VTK_INDEXING_BY_SCALAR && !inScalars) ||
+    (this->IndexMode == VTK_INDEXING_BY_VECTOR &&
+      ((!inVectors && this->VectorMode == VTK_USE_VECTOR) ||
+        (!inNormals && this->VectorMode == VTK_USE_NORMAL))))
   {
-    if ( this->GetSource(0) == NULL )
+    if (this->GetSource(0) == nullptr)
     {
-      vtkErrorMacro(<<"Indexing on but don't have data to index with");
+      vtkErrorMacro(<< "Indexing on but don't have data to index with");
       pts->Delete();
       trans->Delete();
       return 1;
     }
     else
     {
-      vtkWarningMacro(<<"Turning indexing off: no data to index with");
+      vtkWarningMacro(<< "Turning indexing off: no data to index with");
       this->IndexMode = VTK_INDEXING_OFF;
     }
   }
@@ -285,8 +280,8 @@ int vtkGenericGlyph3DFilter::RequestData(
   if (!this->GetSource(0))
   {
     defaultSource = vtkPolyData::New();
-    defaultSource->Allocate();
-    vtkPoints *defaultPoints = vtkPoints::New();
+    defaultSource->AllocateExact(1024, 1024);
+    vtkPoints* defaultPoints = vtkPoints::New();
     defaultPoints->Allocate(6);
     defaultPoints->InsertNextPoint(0, 0, 0);
     defaultPoints->InsertNextPoint(1, 0, 0);
@@ -296,18 +291,18 @@ int vtkGenericGlyph3DFilter::RequestData(
     defaultSource->SetPoints(defaultPoints);
     defaultSource->InsertNextCell(VTK_LINE, 2, defaultPointIds);
     defaultSource->Delete();
-    defaultSource = NULL;
+    defaultSource = nullptr;
     defaultPoints->Delete();
-    defaultPoints = NULL;
+    defaultPoints = nullptr;
   }
 
-  if ( this->IndexMode != VTK_INDEXING_OFF )
+  if (this->IndexMode != VTK_INDEXING_OFF)
   {
-    pd = NULL;
+    pd = nullptr;
     haveNormals = 1;
-    for (numSourcePts=numSourceCells=i=0; i < numberOfSources; i++)
+    for (numSourcePts = numSourceCells = i = 0; i < numberOfSources; i++)
     {
-      if ( this->GetSource(i) != NULL )
+      if (this->GetSource(i) != nullptr)
       {
         if (this->GetSource(i)->GetNumberOfPoints() > numSourcePts)
         {
@@ -317,7 +312,7 @@ int vtkGenericGlyph3DFilter::RequestData(
         {
           numSourceCells = this->GetSource(i)->GetNumberOfCells();
         }
-        if ( !(sourceNormals = this->GetSource(i)->GetPointData()->GetNormals()) )
+        if (!(sourceNormals = this->GetSource(i)->GetPointData()->GetNormals()))
         {
           haveNormals = 0;
         }
@@ -331,7 +326,7 @@ int vtkGenericGlyph3DFilter::RequestData(
     numSourceCells = this->GetSource(0)->GetNumberOfCells();
 
     sourceNormals = this->GetSource(0)->GetPointData()->GetNormals();
-    if ( sourceNormals )
+    if (sourceNormals)
     {
       haveNormals = 1;
     }
@@ -346,145 +341,144 @@ int vtkGenericGlyph3DFilter::RequestData(
   }
 
   newPts = vtkPoints::New();
-  newPts->Allocate(numPts*numSourcePts);
-  if ( this->GeneratePointIds )
+  newPts->Allocate(numPts * numSourcePts);
+  if (this->GeneratePointIds)
   {
     pointIds = vtkIdTypeArray::New();
     pointIds->SetName(this->PointIdsName);
-    pointIds->Allocate(numPts*numSourcePts);
+    pointIds->Allocate(numPts * numSourcePts);
     outputPD->AddArray(pointIds);
   }
-  if ( this->ColorMode == VTK_COLOR_BY_SCALAR && inScalars )
+  if (this->ColorMode == VTK_COLOR_BY_SCALAR && inScalars)
   {
     //    newScalars = inScalars->NewInstance();
-    newScalars=vtkDoubleArray::New();
+    newScalars = vtkDoubleArray::New();
     newScalars->SetNumberOfComponents(inScalars->GetNumberOfComponents());
-    newScalars->Allocate(inScalars->GetNumberOfComponents()*numPts*numSourcePts);
+    newScalars->Allocate(inScalars->GetNumberOfComponents() * numPts * numSourcePts);
     newScalars->SetName(inScalars->GetName());
   }
-  else if ( (this->ColorMode == VTK_COLOR_BY_SCALE) && inScalars)
+  else if ((this->ColorMode == VTK_COLOR_BY_SCALE) && inScalars)
   {
     newScalars = vtkDoubleArray::New();
-    newScalars->Allocate(numPts*numSourcePts);
+    newScalars->Allocate(numPts * numSourcePts);
     newScalars->SetName("GlyphScale");
-    if (this->ScaleMode== VTK_SCALE_BY_SCALAR)
+    if (this->ScaleMode == VTK_SCALE_BY_SCALAR)
     {
       newScalars->SetName(inScalars->GetName());
     }
   }
-  else if ( (this->ColorMode == VTK_COLOR_BY_VECTOR) && haveVectors)
+  else if ((this->ColorMode == VTK_COLOR_BY_VECTOR) && haveVectors)
   {
     newScalars = vtkDoubleArray::New();
-    newScalars->Allocate(numPts*numSourcePts);
+    newScalars->Allocate(numPts * numSourcePts);
     newScalars->SetName("VectorMagnitude");
   }
-  if ( haveVectors )
+  if (haveVectors)
   {
     newVectors = vtkDoubleArray::New();
     newVectors->SetNumberOfComponents(3);
-    newVectors->Allocate(3*numPts*numSourcePts);
+    newVectors->Allocate(3 * numPts * numSourcePts);
     newVectors->SetName("GlyphVector");
   }
-  if ( haveNormals )
+  if (haveNormals)
   {
     newNormals = vtkDoubleArray::New();
     newNormals->SetNumberOfComponents(3);
-    newNormals->Allocate(3*numPts*numSourcePts);
+    newNormals->Allocate(3 * numPts * numSourcePts);
     newNormals->SetName("Normals");
   }
 
   // Setting up for calls to PolyData::InsertNextCell()
-  if (this->IndexMode != VTK_INDEXING_OFF )
+  if (this->IndexMode != VTK_INDEXING_OFF)
   {
-    output->Allocate(3*numPts*numSourceCells,numPts*numSourceCells);
+    output->AllocateEstimate(3 * numPts * numSourceCells, numPts * numSourceCells);
   }
   else
   {
-    output->Allocate(this->GetSource(0),3*numPts*numSourceCells,numPts*numSourceCells);
+    output->AllocateCopy(this->GetSource(0));
   }
 
   // Traverse all Input points, transforming Source points and copying
   // point attributes.
   //
-  ptIncr=0;
-  inPtId=0; // used only for the progress information
+  ptIncr = 0;
+  inPtId = 0; // used only for the progress information
 
-//  vtkGenericAdaptorCell *acell=0;
-//  vtkCellIterator *it=input->NewVertexIterator();
-  vtkGenericPointIterator *it=input->NewPointIterator();
+  //  vtkGenericAdaptorCell *acell=0;
+  //  vtkCellIterator *it=input->NewVertexIterator();
+  vtkGenericPointIterator* it = input->NewPointIterator();
   it->Begin();
-  while(!it->IsAtEnd())
+  while (!it->IsAtEnd())
   {
     scalex = scaley = scalez = 1.0;
-    if ( ! (inPtId % 10000) )
+    if (!(inPtId % 10000))
     {
-      this->UpdateProgress(static_cast<double>(inPtId)/numPts);
+      this->UpdateProgress(static_cast<double>(inPtId) / numPts);
       if (this->GetAbortExecute())
       {
         break;
       }
     }
 
-//    acell=it->GetCell();
+    //    acell=it->GetCell();
     // Get the scalar and vector data
-    if ( inScalars )
+    if (inScalars)
     {
-      inScalars->GetTuple(it,&s);
+      inScalars->GetTuple(it, &s);
       //      s = inScalars->GetComponent(inPtId, 0);
-      if ( this->ScaleMode == VTK_SCALE_BY_SCALAR ||
-           this->ScaleMode == VTK_DATA_SCALING_OFF )
+      if (this->ScaleMode == VTK_SCALE_BY_SCALAR || this->ScaleMode == VTK_DATA_SCALING_OFF)
       {
         scalex = scaley = scalez = s;
       }
     }
 
-    if ( haveVectors )
+    if (haveVectors)
     {
-      if ( this->VectorMode == VTK_USE_NORMAL )
+      if (this->VectorMode == VTK_USE_NORMAL)
       {
         //          inNormals->GetTuple(inPtId, v);
-        inNormals->GetTuple(it,v);
+        inNormals->GetTuple(it, v);
       }
       else
       {
-        inVectors->GetTuple(it,v);
+        inVectors->GetTuple(it, v);
         //          inVectors->GetTuple(inPtId, v);
       }
       vMag = vtkMath::Norm(v);
-      if ( this->ScaleMode == VTK_SCALE_BY_VECTORCOMPONENTS )
+      if (this->ScaleMode == VTK_SCALE_BY_VECTORCOMPONENTS)
       {
         scalex = v[0];
         scaley = v[1];
         scalez = v[2];
       }
-      else if ( this->ScaleMode == VTK_SCALE_BY_VECTOR )
+      else if (this->ScaleMode == VTK_SCALE_BY_VECTOR)
       {
         scalex = scaley = scalez = vMag;
       }
     }
 
     // Clamp data scale if enabled
-    if ( this->Clamping )
+    if (this->Clamping)
     {
-      scalex = (scalex < this->Range[0] ? this->Range[0] :
-                (scalex > this->Range[1] ? this->Range[1] : scalex));
+      scalex = (scalex < this->Range[0] ? this->Range[0]
+                                        : (scalex > this->Range[1] ? this->Range[1] : scalex));
       scalex = (scalex - this->Range[0]) / den;
-      scaley = (scaley < this->Range[0] ? this->Range[0] :
-                (scaley > this->Range[1] ? this->Range[1] : scaley));
+      scaley = (scaley < this->Range[0] ? this->Range[0]
+                                        : (scaley > this->Range[1] ? this->Range[1] : scaley));
       scaley = (scaley - this->Range[0]) / den;
-      scalez = (scalez < this->Range[0] ? this->Range[0] :
-                (scalez > this->Range[1] ? this->Range[1] : scalez));
+      scalez = (scalez < this->Range[0] ? this->Range[0]
+                                        : (scalez > this->Range[1] ? this->Range[1] : scalez));
       scalez = (scalez - this->Range[0]) / den;
     }
 
     // Compute index into table of glyphs
-    if ( this->IndexMode == VTK_INDEXING_OFF )
+    if (this->IndexMode == VTK_INDEXING_OFF)
     {
       index = 0;
     }
     else
     {
-      if ( this->IndexMode == VTK_INDEXING_BY_SCALAR )
+      if (this->IndexMode == VTK_INDEXING_BY_SCALAR)
       {
         value = s;
       }
@@ -493,12 +487,10 @@ int vtkGenericGlyph3DFilter::RequestData(
         value = vMag;
       }
 
-      index = static_cast<int>(
-        static_cast<double>(value - this->Range[0]) * numberOfSources / den);
-      index = (index < 0 ? 0 :
-               (index >= numberOfSources ? (numberOfSources-1) : index));
+      index = static_cast<int>(static_cast<double>(value - this->Range[0]) * numberOfSources / den);
+      index = (index < 0 ? 0 : (index >= numberOfSources ? (numberOfSources - 1) : index));
 
-      if ( this->GetSource(index) != NULL )
+      if (this->GetSource(index) != nullptr)
       {
         sourcePts = this->GetSource(index)->GetPoints();
         sourceNormals = this->GetSource(index)->GetPointData()->GetNormals();
@@ -508,7 +500,7 @@ int vtkGenericGlyph3DFilter::RequestData(
     }
 
     // Make sure we're not indexing into empty glyph
-    if ( this->GetSource(index) == NULL )
+    if (this->GetSource(index) == nullptr)
     {
       continue;
     }
@@ -516,8 +508,7 @@ int vtkGenericGlyph3DFilter::RequestData(
     // Check ghost points.
     // If we are processing a piece, we do not want to duplicate
     // glyphs on the borders.
-    if (inGhostLevels &&
-        inGhostLevels[inPtId] & vtkDataSetAttributes::DUPLICATEPOINT)
+    if (inGhostLevels && inGhostLevels[inPtId] & vtkDataSetAttributes::DUPLICATEPOINT)
     {
       continue;
     }
@@ -526,16 +517,16 @@ int vtkGenericGlyph3DFilter::RequestData(
     trans->Identity();
 
     // Copy all topology (transformation independent)
-    for (cellId=0; cellId < numSourceCells; cellId++)
+    for (cellId = 0; cellId < numSourceCells; cellId++)
     {
       cell = this->GetSource(index)->GetCell(cellId);
       cellPts = cell->GetPointIds();
       npts = cellPts->GetNumberOfIds();
-      for (pts->Reset(), i=0; i < npts; i++)
+      for (pts->Reset(), i = 0; i < npts; i++)
       {
-        pts->InsertId(i,cellPts->GetId(i) + ptIncr);
+        pts->InsertId(i, cellPts->GetId(i) + ptIncr);
       }
-      output->InsertNextCell(cell->GetCellType(),pts);
+      output->InsertNextCell(cell->GetCellType(), pts);
     }
 
     // translate Source to Input point
@@ -543,66 +534,65 @@ int vtkGenericGlyph3DFilter::RequestData(
     it->GetPosition(x);
     trans->Translate(x[0], x[1], x[2]);
 
-    if ( haveVectors )
+    if (haveVectors)
     {
       // Copy Input vector
-      for (i=0; i < numSourcePts; i++)
+      for (i = 0; i < numSourcePts; i++)
       {
-        newVectors->InsertTuple(i+ptIncr, v);
+        newVectors->InsertTuple(i + ptIncr, v);
       }
       if (this->Orient && (vMag > 0.0))
       {
         // if there is no y or z component
-        if ( v[1] == 0.0 && v[2] == 0.0 )
+        if (v[1] == 0.0 && v[2] == 0.0)
         {
-          if (v[0] < 0) //just flip x if we need to
+          if (v[0] < 0) // just flip x if we need to
           {
-            trans->RotateWXYZ(180.0,0,1,0);
+            trans->RotateWXYZ(180.0, 0, 1, 0);
           }
         }
         else
         {
-          vNew[0] = (v[0]+vMag) / 2.0;
+          vNew[0] = (v[0] + vMag) / 2.0;
           vNew[1] = v[1] / 2.0;
           vNew[2] = v[2] / 2.0;
-          trans->RotateWXYZ(static_cast<double>(180.0),vNew[0],vNew[1],
-                            vNew[2]);
+          trans->RotateWXYZ(static_cast<double>(180.0), vNew[0], vNew[1], vNew[2]);
         }
       }
     }
 
     // determine scale factor from scalars if appropriate
-    if ( inScalars )
+    if (inScalars)
     {
       // Copy scalar value
       if (this->ColorMode == VTK_COLOR_BY_SCALE)
       {
-        for (i=0; i < numSourcePts; i++)
+        for (i = 0; i < numSourcePts; i++)
         {
-          newScalars->InsertTuple(i+ptIncr, &scalex); // = scaley = scalez
+          newScalars->InsertTuple(i + ptIncr, &scalex); // = scaley = scalez
         }
       }
       else if (this->ColorMode == VTK_COLOR_BY_SCALAR)
       {
-        for (i=0; i < numSourcePts; i++)
+        for (i = 0; i < numSourcePts; i++)
         {
           //          outputPD->CopyTuple(inScalars, newScalars, inPtId, ptIncr+i);
-          newScalars->InsertTuple(i+ptIncr, &s);
+          newScalars->InsertTuple(i + ptIncr, &s);
         }
       }
     }
     if (haveVectors && this->ColorMode == VTK_COLOR_BY_VECTOR)
     {
-      for (i=0; i < numSourcePts; i++)
+      for (i = 0; i < numSourcePts; i++)
       {
-        newScalars->InsertTuple(i+ptIncr, &vMag);
+        newScalars->InsertTuple(i + ptIncr, &vMag);
       }
     }
 
     // scale data if appropriate
-    if ( this->Scaling )
+    if (this->Scaling)
     {
-      if ( this->ScaleMode == VTK_DATA_SCALING_OFF )
+      if (this->ScaleMode == VTK_DATA_SCALING_OFF)
       {
         scalex = scaley = scalez = this->ScaleFactor;
       }
@@ -613,43 +603,43 @@ int vtkGenericGlyph3DFilter::RequestData(
         scalez *= this->ScaleFactor;
       }
 
-      if ( scalex == 0.0 )
+      if (scalex == 0.0)
       {
         scalex = 1.0e-10;
       }
-      if ( scaley == 0.0 )
+      if (scaley == 0.0)
       {
         scaley = 1.0e-10;
       }
-      if ( scalez == 0.0 )
+      if (scalez == 0.0)
       {
         scalez = 1.0e-10;
       }
-      trans->Scale(scalex,scaley,scalez);
+      trans->Scale(scalex, scaley, scalez);
     }
 
     // multiply points and normals by resulting matrix
-    trans->TransformPoints(sourcePts,newPts);
+    trans->TransformPoints(sourcePts, newPts);
 
-    if ( haveNormals )
+    if (haveNormals)
     {
-      trans->TransformNormals(sourceNormals,newNormals);
+      trans->TransformNormals(sourceNormals, newNormals);
     }
 
     // Copy point data from source (if possible): WRONG to from source but
     // from input.
-    if ( pd )
+    if (pd)
     {
-      for (i=0; i < numSourcePts; i++)
+      for (i = 0; i < numSourcePts; i++)
       {
-        outputPD->CopyData(pd,inPtId,ptIncr+i);
+        outputPD->CopyData(pd, inPtId, ptIncr + i);
       }
     }
 
     // If point ids are to be generated, do it here
-    if ( this->GeneratePointIds )
+    if (this->GeneratePointIds)
     {
-      for (i=0; i < numSourcePts; i++)
+      for (i = 0; i < numSourcePts; i++)
       {
         pointIds->InsertNextValue(inPtId);
       }
@@ -694,16 +684,14 @@ int vtkGenericGlyph3DFilter::RequestData(
 // Since indexing determines size of outputs, EstimatedWholeMemorySize is
 // truly an estimate.  Ignore Indexing (although for a best estimate we
 // should average the size of the sources instead of using 0).
-int vtkGenericGlyph3DFilter::RequestInformation(
-  vtkInformation *vtkNotUsed(request),
-  vtkInformationVector **vtkNotUsed(inputVector),
-  vtkInformationVector *vtkNotUsed(outputVector))
+int vtkGenericGlyph3DFilter::RequestInformation(vtkInformation* vtkNotUsed(request),
+  vtkInformationVector** vtkNotUsed(inputVector), vtkInformationVector* vtkNotUsed(outputVector))
 {
   // get the info objects
-//  vtkInformation *inInfo = inputVector[0]->GetInformationObject(0);
-//  vtkInformation *outInfo = outputVector->GetInformationObject(0);
+  //  vtkInformation *inInfo = inputVector[0]->GetInformationObject(0);
+  //  vtkInformation *outInfo = outputVector->GetInformationObject(0);
 
-  if (this->GetInput() == NULL)
+  if (this->GetInput() == nullptr)
   {
     vtkErrorMacro("Missing input");
     return 1;
@@ -713,7 +701,7 @@ int vtkGenericGlyph3DFilter::RequestInformation(
 
 //-----------------------------------------------------------------------------
 // Specify a source object at a specified table location.
-void vtkGenericGlyph3DFilter::SetSourceData(int id, vtkPolyData *pd)
+void vtkGenericGlyph3DFilter::SetSourceData(int id, vtkPolyData* pd)
 {
   int numConnections = this->GetNumberOfInputConnections(1);
 
@@ -723,7 +711,7 @@ void vtkGenericGlyph3DFilter::SetSourceData(int id, vtkPolyData *pd)
     return;
   }
 
-  vtkTrivialProducer* tp = 0;
+  vtkTrivialProducer* tp = nullptr;
   if (pd)
   {
     tp = vtkTrivialProducer::New();
@@ -738,7 +726,7 @@ void vtkGenericGlyph3DFilter::SetSourceData(int id, vtkPolyData *pd)
     }
     else
     {
-      this->SetNthInputConnection(1, id, 0);
+      this->SetNthInputConnection(1, id, nullptr);
     }
   }
   else if (id == numConnections && tp)
@@ -750,40 +738,36 @@ void vtkGenericGlyph3DFilter::SetSourceData(int id, vtkPolyData *pd)
   {
     tp->Delete();
   }
-
 }
 
 //-----------------------------------------------------------------------------
 // Get a pointer to a source object at a specified table location.
-vtkPolyData *vtkGenericGlyph3DFilter::GetSource(int id)
+vtkPolyData* vtkGenericGlyph3DFilter::GetSource(int id)
 {
-  if ( id < 0 || id >= this->GetNumberOfInputConnections(1) )
+  if (id < 0 || id >= this->GetNumberOfInputConnections(1))
   {
-    return NULL;
+    return nullptr;
   }
   else
   {
-    return vtkPolyData::SafeDownCast(
-    this->GetExecutive()->GetInputData(1, id));
+    return vtkPolyData::SafeDownCast(this->GetExecutive()->GetInputData(1, id));
   }
 }
 
 //-----------------------------------------------------------------------------
 void vtkGenericGlyph3DFilter::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 
-  os << indent << "Generate Point Ids "
-     << (this->GeneratePointIds ? "On\n" : "Off\n");
+  os << indent << "Generate Point Ids " << (this->GeneratePointIds ? "On\n" : "Off\n");
 
-  os << indent << "PointIdsName: " << (this->PointIdsName ? this->PointIdsName
-                                       : "(none)") << "\n";
+  os << indent << "PointIdsName: " << (this->PointIdsName ? this->PointIdsName : "(none)") << "\n";
 
   os << indent << "Color Mode: " << this->GetColorModeAsString() << endl;
 
-  if ( this->GetNumberOfInputConnections(1) < 2 )
+  if (this->GetNumberOfInputConnections(1) < 2)
   {
-    if ( this->GetSource(0) != NULL )
+    if (this->GetSource(0) != nullptr)
     {
       os << indent << "Source: (" << this->GetSource(0) << ")\n";
     }
@@ -794,17 +778,18 @@ void vtkGenericGlyph3DFilter::PrintSelf(ostream& os, vtkIndent indent)
   }
   else
   {
-    os << indent << "A table of " << this->GetNumberOfInputConnections(1) << " glyphs has been defined\n";
+    os << indent << "A table of " << this->GetNumberOfInputConnections(1)
+       << " glyphs has been defined\n";
   }
 
   os << indent << "Scaling: " << (this->Scaling ? "On\n" : "Off\n");
 
   os << indent << "Scale Mode: ";
-  if ( this->ScaleMode == VTK_SCALE_BY_SCALAR )
+  if (this->ScaleMode == VTK_SCALE_BY_SCALAR)
   {
     os << "Scale by scalar\n";
   }
-  else if ( this->ScaleMode == VTK_SCALE_BY_VECTOR )
+  else if (this->ScaleMode == VTK_SCALE_BY_VECTOR)
   {
     os << "Scale by vector\n";
   }
@@ -817,14 +802,14 @@ void vtkGenericGlyph3DFilter::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Clamping: " << (this->Clamping ? "On\n" : "Off\n");
   os << indent << "Range: (" << this->Range[0] << ", " << this->Range[1] << ")\n";
   os << indent << "Orient: " << (this->Orient ? "On\n" : "Off\n");
-  os << indent << "Orient Mode: " << (this->VectorMode == VTK_USE_VECTOR ?
-                                      "Orient by vector\n" : "Orient by normal\n");
+  os << indent << "Orient Mode: "
+     << (this->VectorMode == VTK_USE_VECTOR ? "Orient by vector\n" : "Orient by normal\n");
   os << indent << "Index Mode: ";
-  if ( this->IndexMode == VTK_INDEXING_BY_SCALAR )
+  if (this->IndexMode == VTK_INDEXING_BY_SCALAR)
   {
     os << "Index by scalar value\n";
   }
-  else if ( this->IndexMode == VTK_INDEXING_BY_VECTOR )
+  else if (this->IndexMode == VTK_INDEXING_BY_VECTOR)
   {
     os << "Index by vector value\n";
   }
@@ -841,46 +826,39 @@ void vtkGenericGlyph3DFilter::PrintSelf(ostream& os, vtkIndent indent)
 }
 
 //-----------------------------------------------------------------------------
-int vtkGenericGlyph3DFilter::RequestUpdateExtent(
-  vtkInformation *vtkNotUsed(request),
-  vtkInformationVector **inputVector,
-  vtkInformationVector *outputVector)
+int vtkGenericGlyph3DFilter::RequestUpdateExtent(vtkInformation* vtkNotUsed(request),
+  vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
   // get the info objects
-  vtkInformation *inInfo = inputVector[0]->GetInformationObject(0);
-  vtkInformation *outInfo = outputVector->GetInformationObject(0);
-
-  vtkInformation *sourceInfo = inputVector[1]->GetInformationObject(0);
+  vtkInformation* inInfo = inputVector[0]->GetInformationObject(0);
+  vtkInformation* outInfo = outputVector->GetInformationObject(0);
 
+  vtkInformation* sourceInfo = inputVector[1]->GetInformationObject(0);
 
   if (sourceInfo)
   {
-    sourceInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_PIECE_NUMBER(),
-                    0);
-    sourceInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_PIECES(),
-                    1);
-    sourceInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_GHOST_LEVELS(),
-                    0);
+    sourceInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_PIECE_NUMBER(), 0);
+    sourceInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_PIECES(), 1);
+    sourceInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_GHOST_LEVELS(), 0);
   }
   inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_PIECE_NUMBER(),
-              outInfo->Get(vtkStreamingDemandDrivenPipeline::UPDATE_PIECE_NUMBER()));
+    outInfo->Get(vtkStreamingDemandDrivenPipeline::UPDATE_PIECE_NUMBER()));
   inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_PIECES(),
-              outInfo->Get(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_PIECES()));
+    outInfo->Get(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_PIECES()));
   inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_GHOST_LEVELS(),
-              outInfo->Get(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_GHOST_LEVELS()));
+    outInfo->Get(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_GHOST_LEVELS()));
   inInfo->Set(vtkStreamingDemandDrivenPipeline::EXACT_EXTENT(), 1);
 
   return 1;
 }
 
 //----------------------------------------------------------------------------
-int vtkGenericGlyph3DFilter
-::FillInputPortInformation(int port, vtkInformation* info)
+int vtkGenericGlyph3DFilter ::FillInputPortInformation(int port, vtkInformation* info)
 {
-   if(!this->Superclass::FillInputPortInformation(port, info))
-   {
+  if (!this->Superclass::FillInputPortInformation(port, info))
+  {
     return 0;
-   }
+  }
   if (port == 1)
   {
     info->Set(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkPolyData");
