@@ -14,40 +14,39 @@
 ===================================================================*/
 // .SECTION Thanks
 // This test was written by Philippe Pebay, Kitware 2012
-// This work was supported in part by Commissariat a l'Energie Atomique (CEA/DIF)
+// This test was revised by Philippe Pebay, 2016
+// This work was supported by Commissariat a l'Energie Atomique (CEA/DIF)
 
+#include "vtkHyperTreeGrid.h"
 #include "vtkHyperTreeGridGeometry.h"
 #include "vtkHyperTreeGridSource.h"
 
 #include "vtkCamera.h"
 #include "vtkCellData.h"
 #include "vtkNew.h"
-#include "vtkProperty.h"
+#include "vtkPolyData.h"
 #include "vtkPolyDataMapper.h"
+#include "vtkProperty.h"
+#include "vtkQuadric.h"
 #include "vtkRegressionTestImage.h"
-#include "vtkRenderer.h"
 #include "vtkRenderWindow.h"
 #include "vtkRenderWindowInteractor.h"
-#include "vtkQuadric.h"
+#include "vtkRenderer.h"
 #include "vtkTimerLog.h"
 
-int TestHyperTreeGridTernarySphereMaterial( int argc, char* argv[] )
+int TestHyperTreeGridTernarySphereMaterial(int argc, char* argv[])
 {
   // Hyper tree grid
   vtkNew<vtkHyperTreeGridSource> htGrid;
-  htGrid->SetMaximumLevel( 4 );
-  htGrid->SetGridSize( 5, 5, 6 );
-  htGrid->SetGridScale( 1.5, 1., .7 );
-  htGrid->SetDimension( 3 );
-  htGrid->SetBranchFactor( 3 );
+  htGrid->SetMaxDepth(4);
+  htGrid->SetDimensions(6, 6, 7); // GridCell 5, 5, 6
+  htGrid->SetGridScale(1.5, 1., .7);
+  htGrid->SetBranchFactor(3);
   htGrid->UseDescriptorOff();
-  htGrid->UseMaterialMaskOn();
+  htGrid->UseMaskOn();
   vtkNew<vtkQuadric> quadric;
-  quadric->SetCoefficients( 1., 1., 1.,
-                            0, 0., 0.,
-                            0.0, 0., 0.,
-                            -25. );
-  htGrid->SetQuadric( quadric.GetPointer() );
+  quadric->SetCoefficients(1., 1., 1., 0, 0., 0., 0.0, 0., 0., -25.);
+  htGrid->SetQuadric(quadric);
   vtkNew<vtkTimerLog> timer;
   timer->StartTimer();
   htGrid->Update();
@@ -55,65 +54,65 @@ int TestHyperTreeGridTernarySphereMaterial( int argc, char* argv[] )
   cerr << "Creation time : " << timer->GetElapsedTime() << endl;
   timer->StartTimer();
   vtkNew<vtkHyperTreeGrid> htgCopy;
-  htgCopy->ShallowCopy( htGrid->GetOutput() );
+  htgCopy->ShallowCopy(htGrid->GetOutput());
   timer->StopTimer();
   cerr << "Copy time : " << timer->GetElapsedTime() << endl;
   // Geometry
   timer->StartTimer();
   vtkNew<vtkHyperTreeGridGeometry> geometry;
-  geometry->SetInputData( htgCopy.GetPointer() );
+  geometry->SetInputData(htgCopy);
   geometry->Update();
-  vtkPolyData* pd = geometry->GetOutput();
+  vtkPolyData* pd = geometry->GetPolyDataOutput();
   timer->StopTimer();
   cerr << "Geometry time : " << timer->GetElapsedTime() << endl;
 
   // Mappers
   vtkMapper::SetResolveCoincidentTopologyToPolygonOffset();
   vtkNew<vtkPolyDataMapper> mapper1;
-  mapper1->SetInputConnection( geometry->GetOutputPort() );
-  mapper1->SetScalarRange( pd->GetCellData()->GetScalars()->GetRange() );
+  mapper1->SetInputConnection(geometry->GetOutputPort());
+  mapper1->SetScalarRange(pd->GetCellData()->GetScalars()->GetRange());
   vtkNew<vtkPolyDataMapper> mapper2;
-  mapper2->SetInputConnection( geometry->GetOutputPort() );
+  mapper2->SetInputConnection(geometry->GetOutputPort());
   mapper2->ScalarVisibilityOff();
 
   // Actors
   vtkNew<vtkActor> actor1;
-  actor1->SetMapper( mapper1.GetPointer() );
+  actor1->SetMapper(mapper1);
   vtkNew<vtkActor> actor2;
-  actor2->SetMapper( mapper2.GetPointer() );
+  actor2->SetMapper(mapper2);
   actor2->GetProperty()->SetRepresentationToWireframe();
-  actor2->GetProperty()->SetColor( .7, .7, .7 );
+  actor2->GetProperty()->SetColor(.7, .7, .7);
 
   // Camera
   double bd[6];
-  pd->GetBounds( bd );
+  pd->GetBounds(bd);
   vtkNew<vtkCamera> camera;
-  camera->SetClippingRange( 1., 100. );
-  camera->SetFocalPoint( pd->GetCenter() );
-  camera->SetPosition( -.7 * bd[1], .9 * bd[3], -2.5 * bd[5] );
+  camera->SetClippingRange(1., 100.);
+  camera->SetFocalPoint(pd->GetCenter());
+  camera->SetPosition(-.7 * bd[1], .9 * bd[3], -2.5 * bd[5]);
 
   // Renderer
   vtkNew<vtkRenderer> renderer;
-  renderer->SetActiveCamera( camera.GetPointer() );
-  renderer->SetBackground( 1., 1., 1. );
-  renderer->AddActor( actor1.GetPointer() );
-  renderer->AddActor( actor2.GetPointer() );
+  renderer->SetActiveCamera(camera);
+  renderer->SetBackground(1., 1., 1.);
+  renderer->AddActor(actor1);
+  renderer->AddActor(actor2);
 
   // Render window
   vtkNew<vtkRenderWindow> renWin;
-  renWin->AddRenderer( renderer.GetPointer() );
-  renWin->SetSize( 400, 400 );
-  renWin->SetMultiSamples( 0 );
+  renWin->AddRenderer(renderer);
+  renWin->SetSize(400, 400);
+  renWin->SetMultiSamples(0);
 
   // Interactor
   vtkNew<vtkRenderWindowInteractor> iren;
-  iren->SetRenderWindow( renWin.GetPointer() );
+  iren->SetRenderWindow(renWin);
 
   // Render and test
   renWin->Render();
 
-  int retVal = vtkRegressionTestImageThreshold( renWin.GetPointer(), 110 );
-  if ( retVal == vtkRegressionTester::DO_INTERACTOR )
+  int retVal = vtkRegressionTestImageThreshold(renWin, 110);
+  if (retVal == vtkRegressionTester::DO_INTERACTOR)
   {
     iren->Start();
   }
