@@ -19,17 +19,13 @@
 vtkStandardNewMacro(vtkTransmitStructuredGridPiece);
 
 //----------------------------------------------------------------------------
-vtkTransmitStructuredGridPiece::vtkTransmitStructuredGridPiece()
-{
-}
+vtkTransmitStructuredGridPiece::vtkTransmitStructuredGridPiece() = default;
 
 //----------------------------------------------------------------------------
-vtkTransmitStructuredGridPiece::~vtkTransmitStructuredGridPiece()
-{
-}
+vtkTransmitStructuredGridPiece::~vtkTransmitStructuredGridPiece() = default;
 
 //----------------------------------------------------------------------------
 void vtkTransmitStructuredGridPiece::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 }
