@@ -26,20 +26,20 @@
  *
  * @par Thanks:
  * Developed by Timothy M. Shead (tshead@sandia.gov) at Sandia National Laboratories.
-*/
+ */
 
 #ifndef vtkDiagonalMatrixSource_h
 #define vtkDiagonalMatrixSource_h
 
-#include "vtkFiltersSourcesModule.h" // For export macro
 #include "vtkArrayDataAlgorithm.h"
+#include "vtkFiltersSourcesModule.h" // For export macro
 
 class VTKFILTERSSOURCES_EXPORT vtkDiagonalMatrixSource : public vtkArrayDataAlgorithm
 {
 public:
   static vtkDiagonalMatrixSource* New();
   vtkTypeMacro(vtkDiagonalMatrixSource, vtkArrayDataAlgorithm);
-  void PrintSelf(ostream& os, vtkIndent indent) VTK_OVERRIDE;
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
   // Determines whether the output matrix will be dense or sparse
   enum StorageType
@@ -103,16 +103,13 @@ public:
 
 protected:
   vtkDiagonalMatrixSource();
-  ~vtkDiagonalMatrixSource() VTK_OVERRIDE;
+  ~vtkDiagonalMatrixSource() override;
 
-  int RequestData(
-    vtkInformation*,
-    vtkInformationVector**,
-    vtkInformationVector*) VTK_OVERRIDE;
+  int RequestData(vtkInformation*, vtkInformationVector**, vtkInformationVector*) override;
 
 private:
-  vtkDiagonalMatrixSource(const vtkDiagonalMatrixSource&) VTK_DELETE_FUNCTION;
-  void operator=(const vtkDiagonalMatrixSource&) VTK_DELETE_FUNCTION;
+  vtkDiagonalMatrixSource(const vtkDiagonalMatrixSource&) = delete;
+  void operator=(const vtkDiagonalMatrixSource&) = delete;
 
   vtkArray* GenerateDenseArray();
   vtkArray* GenerateSparseArray();
@@ -127,4 +124,3 @@ private:
 };
 
 #endif
-
