@@ -63,18 +63,18 @@
  * @warning
  *     We use the terms "point" and "node" interchangeably.
  *     Also, we use the terms "element" and "cell" interchangeably.
-*/
+ */
 
 #ifndef vtkExodusIIWriter_h
 #define vtkExodusIIWriter_h
 
 #include "vtkIOExodusModule.h" // For export macro
+#include "vtkSmartPointer.h"   // For vtkSmartPointer
 #include "vtkWriter.h"
-#include "vtkSmartPointer.h" // For vtkSmartPointer
 
-#include <vector> // STL Header
 #include <map>    // STL Header
 #include <string> // STL Header
+#include <vector> // STL Header
 
 class vtkModelMetadata;
 class vtkDoubleArray;
@@ -84,9 +84,9 @@ class vtkUnstructuredGrid;
 class VTKIOEXODUS_EXPORT vtkExodusIIWriter : public vtkWriter
 {
 public:
-  static vtkExodusIIWriter *New ();
-  vtkTypeMacro(vtkExodusIIWriter,vtkWriter);
-  void PrintSelf (ostream& os, vtkIndent indent);
+  static vtkExodusIIWriter* New();
+  vtkTypeMacro(vtkExodusIIWriter, vtkWriter);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
   /**
    * Specify the vtkModelMetadata object which contains the Exodus file
@@ -98,7 +98,7 @@ public:
    * find it and use it.
    */
 
-  void SetModelMetadata (vtkModelMetadata*);
+  void SetModelMetadata(vtkModelMetadata*);
   vtkGetObjectMacro(ModelMetadata, vtkModelMetadata);
 
   /**
@@ -129,15 +129,15 @@ public:
   vtkSetMacro(GhostLevel, int);
   vtkGetMacro(GhostLevel, int);
 
-   /**
-    * By default, the integer array containing the global Block Ids of the
-    * cells is not included when the new Exodus II file is written out.  If
-    * you do want to include this array, set WriteOutBlockIdArray to ON.
-    */
+  /**
+   * By default, the integer array containing the global Block Ids of the
+   * cells is not included when the new Exodus II file is written out.  If
+   * you do want to include this array, set WriteOutBlockIdArray to ON.
+   */
 
-  vtkSetMacro(WriteOutBlockIdArray, int);
-  vtkGetMacro(WriteOutBlockIdArray, int);
-  vtkBooleanMacro(WriteOutBlockIdArray, int);
+  vtkSetMacro(WriteOutBlockIdArray, vtkTypeBool);
+  vtkGetMacro(WriteOutBlockIdArray, vtkTypeBool);
+  vtkBooleanMacro(WriteOutBlockIdArray, vtkTypeBool);
 
   /**
    * By default, the integer array containing the global Node Ids
@@ -145,9 +145,9 @@ public:
    * you do want to include this array, set WriteOutGlobalNodeIdArray to ON.
    */
 
-  vtkSetMacro(WriteOutGlobalNodeIdArray, int);
-  vtkGetMacro(WriteOutGlobalNodeIdArray, int);
-  vtkBooleanMacro(WriteOutGlobalNodeIdArray, int);
+  vtkSetMacro(WriteOutGlobalNodeIdArray, vtkTypeBool);
+  vtkGetMacro(WriteOutGlobalNodeIdArray, vtkTypeBool);
+  vtkBooleanMacro(WriteOutGlobalNodeIdArray, vtkTypeBool);
 
   /**
    * By default, the integer array containing the global Element Ids
@@ -155,31 +155,40 @@ public:
    * do want to include this array, set WriteOutGlobalElementIdArray to ON.
    */
 
-  vtkSetMacro(WriteOutGlobalElementIdArray, int);
-  vtkGetMacro(WriteOutGlobalElementIdArray, int);
-  vtkBooleanMacro(WriteOutGlobalElementIdArray, int);
+  vtkSetMacro(WriteOutGlobalElementIdArray, vtkTypeBool);
+  vtkGetMacro(WriteOutGlobalElementIdArray, vtkTypeBool);
+  vtkBooleanMacro(WriteOutGlobalElementIdArray, vtkTypeBool);
 
   /**
    * When WriteAllTimeSteps is turned ON, the writer is executed once for
    * each timestep available from the reader.
    */
 
-  vtkSetMacro(WriteAllTimeSteps, int);
-  vtkGetMacro(WriteAllTimeSteps, int);
-  vtkBooleanMacro(WriteAllTimeSteps, int);
+  vtkSetMacro(WriteAllTimeSteps, vtkTypeBool);
+  vtkGetMacro(WriteAllTimeSteps, vtkTypeBool);
+  vtkBooleanMacro(WriteAllTimeSteps, vtkTypeBool);
 
   vtkSetStringMacro(BlockIdArrayName);
   vtkGetStringMacro(BlockIdArrayName);
 
+  /**
+   * In certain cases we know that metadata doesn't exist and
+   * we want to ignore that warning.
+   */
+
+  vtkSetMacro(IgnoreMetaDataWarning, bool);
+  vtkGetMacro(IgnoreMetaDataWarning, bool);
+  vtkBooleanMacro(IgnoreMetaDataWarning, bool);
+
 protected:
-  vtkExodusIIWriter ();
-  ~vtkExodusIIWriter ();
+  vtkExodusIIWriter();
+  ~vtkExodusIIWriter() override;
 
   vtkModelMetadata* ModelMetadata;
 
-  char *BlockIdArrayName;
+  char* BlockIdArrayName;
 
-  char *FileName;
+  char* FileName;
   int fid;
 
   int NumberOfProcesses;
@@ -189,31 +198,31 @@ protected:
 
   int StoreDoubles;
   int GhostLevel;
-  int WriteOutBlockIdArray;
-  int WriteOutGlobalNodeIdArray;
-  int WriteOutGlobalElementIdArray;
-  int WriteAllTimeSteps;
+  vtkTypeBool WriteOutBlockIdArray;
+  vtkTypeBool WriteOutGlobalNodeIdArray;
+  vtkTypeBool WriteOutGlobalElementIdArray;
+  vtkTypeBool WriteAllTimeSteps;
   int NumberOfTimeSteps;
 
-  vtkDoubleArray* TimeValues;
   int CurrentTimeIndex;
   int FileTimeOffset;
   bool TopologyChanged;
+  bool IgnoreMetaDataWarning;
 
-  vtkDataObject *OriginalInput;
-  std::vector< vtkSmartPointer<vtkUnstructuredGrid> > FlattenedInput;
-  std::vector< vtkSmartPointer<vtkUnstructuredGrid> > NewFlattenedInput;
+  vtkDataObject* OriginalInput;
+  std::vector<vtkSmartPointer<vtkUnstructuredGrid> > FlattenedInput;
+  std::vector<vtkSmartPointer<vtkUnstructuredGrid> > NewFlattenedInput;
 
-  std::vector< vtkStdString > FlattenedNames;
-  std::vector< vtkStdString > NewFlattenedNames;
+  std::vector<vtkStdString> FlattenedNames;
+  std::vector<vtkStdString> NewFlattenedNames;
 
-  std::vector< vtkIntArray* > BlockIdList;
+  std::vector<vtkIntArray*> BlockIdList;
 
   struct Block
   {
-    Block ()
+    Block()
     {
-      this->Name = 0;
+      this->Name = nullptr;
       this->Type = 0;
       this->NumElements = 0;
       this->ElementStartIndex = -1;
@@ -223,9 +232,9 @@ protected:
       this->GridIndex = 0;
       this->OutputIndex = -1;
       this->NumAttributes = 0;
-      this->BlockAttributes = 0;
+      this->BlockAttributes = nullptr;
     };
-    const char *Name;
+    const char* Name;
     int Type;
     int NumElements;
     int ElementStartIndex;
@@ -236,7 +245,7 @@ protected:
     // std::vector<int> CellIndex;
     int OutputIndex;
     int NumAttributes;
-    float *BlockAttributes; // Owned by metamodel or null.  Don't delete.
+    float* BlockAttributes; // Owned by metamodel or null.  Don't delete.
   };
   std::map<int, Block> BlockInfoMap;
   int NumCells, NumPoints, MaxId;
@@ -261,106 +270,103 @@ protected:
   int NumberOfScalarElementArrays;
   int NumberOfScalarNodeArrays;
 
-  std::vector< std::vector<int> > CellToElementOffset;
+  std::vector<std::vector<int> > CellToElementOffset;
 
   // By BlockId, and within block ID by element variable, with variables
   // appearing in the same order in which they appear in OutputElementArrayNames
 
-  int *BlockElementVariableTruthTable;
+  int* BlockElementVariableTruthTable;
   int AllVariablesDefinedInAllBlocks;
 
   int BlockVariableTruthValue(int blockIdx, int varIdx);
 
-  char *StrDupWithNew (const char *s);
-  void StringUppercase (std::string& str);
+  char* StrDupWithNew(const char* s);
+  void StringUppercase(std::string& str);
 
-  int ProcessRequest (vtkInformation* request,
-                      vtkInformationVector** inputVector,
-                      vtkInformationVector* outputVector);
+  vtkTypeBool ProcessRequest(vtkInformation* request, vtkInformationVector** inputVector,
+    vtkInformationVector* outputVector) override;
 
-  int RequestInformation (vtkInformation* request,
-                          vtkInformationVector** inputVector,
-                          vtkInformationVector* outputVector);
+  int RequestInformation(vtkInformation* request, vtkInformationVector** inputVector,
+    vtkInformationVector* outputVector);
 
-  virtual int RequestUpdateExtent (vtkInformation* request,
-                                   vtkInformationVector** inputVector,
-                                   vtkInformationVector* outputVector);
+  virtual int RequestUpdateExtent(vtkInformation* request, vtkInformationVector** inputVector,
+    vtkInformationVector* outputVector);
 
-  int FillInputPortInformation (int port, vtkInformation* info);
+  int FillInputPortInformation(int port, vtkInformation* info) override;
 
-  int RequestData (vtkInformation* request,
-                   vtkInformationVector** inputVector,
-                   vtkInformationVector* outputVector);
+  int RequestData(vtkInformation* request, vtkInformationVector** inputVector,
+    vtkInformationVector* outputVector) override;
 
-  void WriteData ();
+  void WriteData() override;
 
-  int FlattenHierarchy (vtkDataObject* input, const char *name, bool& changed);
+  int FlattenHierarchy(vtkDataObject* input, const char* name, bool& changed);
 
-  int CreateNewExodusFile ();
-  void CloseExodusFile ();
+  int CreateNewExodusFile();
+  void CloseExodusFile();
 
-  int IsDouble ();
-  void RemoveGhostCells ();
-  int CheckParametersInternal (int NumberOfProcesses, int MyRank);
-  virtual int CheckParameters ();
+  int IsDouble();
+  void RemoveGhostCells();
+  int CheckParametersInternal(int NumberOfProcesses, int MyRank);
+  virtual int CheckParameters();
   // If writing in parallel multiple time steps exchange after each time step
   // if we should continue the execution. Pass local continueExecution as a
   // parameter and return the global continueExecution.
   virtual int GlobalContinueExecuting(int localContinueExecution);
-  int CheckInputArrays ();
+  int CheckInputArrays();
   virtual void CheckBlockInfoMap();
-  int ConstructBlockInfoMap ();
-  int ConstructVariableInfoMaps ();
-  int ParseMetadata ();
-  int CreateDefaultMetadata ();
-  char *GetCellTypeName (int t);
+  int ConstructBlockInfoMap();
+  int ConstructVariableInfoMaps();
+  int ParseMetadata();
+  int CreateDefaultMetadata();
+  char* GetCellTypeName(int t);
 
-  int CreateBlockIdMetadata(vtkModelMetadata *em);
-  int CreateBlockVariableMetadata (vtkModelMetadata* em);
-  int CreateSetsMetadata (vtkModelMetadata* em);
+  int CreateBlockIdMetadata(vtkModelMetadata* em);
+  int CreateBlockVariableMetadata(vtkModelMetadata* em);
+  int CreateSetsMetadata(vtkModelMetadata* em);
 
-  void ConvertVariableNames (std::map<std::string, VariableInfo>& variableMap);
-  char **FlattenOutVariableNames (
-            int nScalarArrays,
-            const std::map<std::string, VariableInfo>& variableMap);
-  std::string CreateNameForScalarArray (const char *root,
-                                           int component,
-                                           int numComponents);
+  void ConvertVariableNames(std::map<std::string, VariableInfo>& variableMap);
+  char** FlattenOutVariableNames(
+    int nScalarArrays, const std::map<std::string, VariableInfo>& variableMap);
+  std::string CreateNameForScalarArray(const char* root, int component, int numComponents);
 
-  std::map<vtkIdType, vtkIdType> *LocalNodeIdMap;
-  std::map<vtkIdType, vtkIdType> *LocalElementIdMap;
+  std::map<vtkIdType, vtkIdType>* LocalNodeIdMap;
+  std::map<vtkIdType, vtkIdType>* LocalElementIdMap;
 
   vtkIdType GetNodeLocalId(vtkIdType id);
   vtkIdType GetElementLocalId(vtkIdType id);
   int GetElementType(vtkIdType id);
 
-  int WriteInitializationParameters ();
-  int WriteInformationRecords ();
-  int WritePoints ();
-  int WriteCoordinateNames ();
-  int WriteGlobalPointIds ();
-  int WriteBlockInformation ();
-  int WriteGlobalElementIds ();
-  int WriteVariableArrayNames ();
-  int WriteNodeSetInformation ();
-  int WriteSideSetInformation ();
-  int WriteProperties ();
-  int WriteNextTimeStep ();
-  vtkIntArray* GetBlockIdArray (
-    const char* BlockIdArrayName, vtkUnstructuredGrid* input);
-  static bool SameTypeOfCells (vtkIntArray* cellToBlockId,
-                               vtkUnstructuredGrid* input);
+  int WriteInitializationParameters();
+  int WriteInformationRecords();
+  int WritePoints();
+  int WriteCoordinateNames();
+  int WriteGlobalPointIds();
+  int WriteBlockInformation();
+  int WriteGlobalElementIds();
+  int WriteVariableArrayNames();
+  int WriteNodeSetInformation();
+  int WriteSideSetInformation();
+  int WriteProperties();
+  int WriteNextTimeStep();
+  vtkIntArray* GetBlockIdArray(const char* BlockIdArrayName, vtkUnstructuredGrid* input);
+  static bool SameTypeOfCells(vtkIntArray* cellToBlockId, vtkUnstructuredGrid* input);
 
-  double ExtractGlobalData (const char *name, int comp, int ts);
-  int WriteGlobalData (int timestep, vtkDataArray *buffer);
-  void ExtractCellData (const char *name, int comp, vtkDataArray *buffer);
-  int WriteCellData (int timestep, vtkDataArray *buffer);
-  void ExtractPointData (const char *name, int comp, vtkDataArray *buffer);
-  int WritePointData (int timestep, vtkDataArray *buffer);
+  double ExtractGlobalData(const char* name, int comp, int ts);
+  int WriteGlobalData(int timestep, vtkDataArray* buffer);
+  void ExtractCellData(const char* name, int comp, vtkDataArray* buffer);
+  int WriteCellData(int timestep, vtkDataArray* buffer);
+  void ExtractPointData(const char* name, int comp, vtkDataArray* buffer);
+  int WritePointData(int timestep, vtkDataArray* buffer);
+
+  /**
+   * Get the maximum length name in the input data set. If it is smaller
+   * than 32 characters long we just return the ExodusII default of 32.
+   */
+  virtual unsigned int GetMaxNameLength();
 
 private:
-  vtkExodusIIWriter (const vtkExodusIIWriter&) VTK_DELETE_FUNCTION;
-  void operator= (const vtkExodusIIWriter&) VTK_DELETE_FUNCTION;
+  vtkExodusIIWriter(const vtkExodusIIWriter&) = delete;
+  void operator=(const vtkExodusIIWriter&) = delete;
 };
 
 #endif
