@@ -26,21 +26,21 @@
 #include "vtkObjectFactory.h"
 #include "vtkStringArray.h"
 
-#include <string>
 #include <algorithm>
-#include <vector>
-#include <vtksys/SystemTools.hxx>
 #include <istream>
 #include <sstream>
+#include <string>
+#include <vector>
+#include <vtksys/FStream.hxx>
+#include <vtksys/SystemTools.hxx>
 
+#include <cctype>
 #include <cmath>
 #include <cstring>
-#include <cctype>
 
 #include "vtkSmartPointer.h"
 
-#define VTK_CREATE(type, name) \
-  vtkSmartPointer<type> name = vtkSmartPointer<type>::New()
+#define VTK_CREATE(type, name) vtkSmartPointer<type> name = vtkSmartPointer<type>::New()
 
 //=============================================================================
 static std::string trim(std::string s)
@@ -51,11 +51,11 @@ static std::string trim(std::string s)
     start++;
   }
   size_t end = s.length();
-  while ((end > start) && (isspace(s[end-1])))
+  while ((end > start) && (isspace(s[end - 1])))
   {
     end--;
   }
-  return s.substr(start, end-start);
+  return s.substr(start, end - start);
 }
 
 //-----------------------------------------------------------------------------
@@ -69,19 +69,20 @@ static std::vector<std::string> split(std::string s)
     {
       startValue++;
     }
-    if (startValue >= s.length()) return result;
+    if (startValue >= s.length())
+      return result;
     size_t endValue = startValue;
     while ((endValue < s.length()) && !isspace(s[endValue]))
     {
       endValue++;
     }
-    result.push_back(s.substr(startValue, endValue-startValue));
+    result.push_back(s.substr(startValue, endValue - startValue));
     startValue = endValue;
   }
 }
 
 //-----------------------------------------------------------------------------
-static void GetVector(std::string &s, std::vector<int> &dest)
+static void GetVector(std::string& s, std::vector<int>& dest)
 {
   std::vector<std::string> strlist = split(s);
   for (size_t i = 0; i < dest.size(); i++)
@@ -98,7 +99,7 @@ static void GetVector(std::string &s, std::vector<int> &dest)
 }
 
 //-----------------------------------------------------------------------------
-static void GetVector(std::string &s, std::vector<double> &dest)
+static void GetVector(std::string& s, std::vector<double>& dest)
 {
   std::vector<std::string> strlist = split(s);
   for (size_t i = 0; i < dest.size(); i++)
@@ -120,15 +121,17 @@ static std::vector<double> ParseVector(std::string s)
   std::vector<double> result;
 
   s = trim(s);
-  if ((s[0] != '(') || (s[s.length()-1] != ')')) return result;
-  s = s.substr(1, s.length()-2);
+  if ((s[0] != '(') || (s[s.length() - 1] != ')'))
+    return result;
+  s = s.substr(1, s.length() - 2);
   while (true)
   {
     size_t i = s.find(',');
     std::string value = s.substr(0, i);
     result.push_back(atof(value.c_str()));
-    if (i == s.npos) break;
-    s = s.substr(i+1);
+    if (i == s.npos)
+      break;
+    s = s.substr(i + 1);
   }
 
   return result;
@@ -138,48 +141,43 @@ static std::vector<double> ParseVector(std::string s)
 static int NrrdType2VTKType(std::string nrrdType)
 {
   nrrdType = trim(nrrdType);
-  if (   (nrrdType == "signed char")
-      || (nrrdType == "int8") || (nrrdType == "int8_t") )
+  if ((nrrdType == "signed char") || (nrrdType == "int8") || (nrrdType == "int8_t"))
   {
     return VTK_CHAR;
   }
-  else if (   (nrrdType == "uchar") || (nrrdType == "unsigned char")
-           || (nrrdType == "uint8") || (nrrdType == "uint8_t") )
+  else if ((nrrdType == "uchar") || (nrrdType == "unsigned char") || (nrrdType == "uint8") ||
+    (nrrdType == "uint8_t"))
   {
     return VTK_UNSIGNED_CHAR;
   }
-  else if (   (nrrdType == "short") || (nrrdType == "short int")
-           || (nrrdType == "signed short") || (nrrdType == "signed short int")
-           || (nrrdType == "int16") || (nrrdType == "int16_t") )
+  else if ((nrrdType == "short") || (nrrdType == "short int") || (nrrdType == "signed short") ||
+    (nrrdType == "signed short int") || (nrrdType == "int16") || (nrrdType == "int16_t"))
   {
     return VTK_SHORT;
   }
-  else if (   (nrrdType == "ushort") || (nrrdType == "unsigned short")
-           || (nrrdType == "unsigned short int")
-           || (nrrdType == "uint16") || (nrrdType == "uint16_t") )
+  else if ((nrrdType == "ushort") || (nrrdType == "unsigned short") ||
+    (nrrdType == "unsigned short int") || (nrrdType == "uint16") || (nrrdType == "uint16_t"))
   {
     return VTK_UNSIGNED_SHORT;
   }
-  else if (   (nrrdType == "int") || (nrrdType == "signed int")
-           || (nrrdType == "int32") || (nrrdType == "int32_t") )
+  else if ((nrrdType == "int") || (nrrdType == "signed int") || (nrrdType == "int32") ||
+    (nrrdType == "int32_t"))
   {
     return VTK_INT;
   }
-  else if (   (nrrdType == "uint") || (nrrdType == "unsigned int")
-           || (nrrdType == "uint32") || (nrrdType == "uint32_t") )
+  else if ((nrrdType == "uint") || (nrrdType == "unsigned int") || (nrrdType == "uint32") ||
+    (nrrdType == "uint32_t"))
   {
     return VTK_UNSIGNED_INT;
   }
-  else if (   (nrrdType == "longlong") || (nrrdType == "long long")
-           || (nrrdType == "long long int") || (nrrdType == "signed long long")
-           || (nrrdType == "signed long long int") || (nrrdType == "int64")
-           || (nrrdType == "int64_t") )
+  else if ((nrrdType == "longlong") || (nrrdType == "long long") || (nrrdType == "long long int") ||
+    (nrrdType == "signed long long") || (nrrdType == "signed long long int") ||
+    (nrrdType == "int64") || (nrrdType == "int64_t"))
   {
     return VTK_TYPE_INT64;
   }
-  else if (   (nrrdType == "ulonglong") || (nrrdType == "unsigned long long")
-           || (nrrdType == "unsigned long long int")
-           || (nrrdType == "uint64") || (nrrdType == "uint64_t") )
+  else if ((nrrdType == "ulonglong") || (nrrdType == "unsigned long long") ||
+    (nrrdType == "unsigned long long int") || (nrrdType == "uint64") || (nrrdType == "uint64_t"))
   {
     return VTK_TYPE_UINT64;
   }
@@ -217,29 +215,31 @@ vtkNrrdReader::vtkNrrdReader()
 vtkNrrdReader::~vtkNrrdReader()
 {
   this->DataFiles->Delete();
-  this->DataFiles = NULL;
+  this->DataFiles = nullptr;
 }
 
-void vtkNrrdReader::PrintSelf(ostream &os, vtkIndent indent)
+void vtkNrrdReader::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
   os << indent << "Encoding: ";
   switch (this->Encoding)
   {
-    case ENCODING_RAW: os << "raw" << endl; break;
-    case ENCODING_ASCII: os << "ascii" << endl; break;
-    default: os << "UNKNOWN!" << endl; break;
+    case ENCODING_RAW:
+      os << "raw" << endl;
+      break;
+    case ENCODING_ASCII:
+      os << "ascii" << endl;
+      break;
+    default:
+      os << "UNKNOWN!" << endl;
+      break;
   }
 }
 
-
-
-
-
 //-----------------------------------------------------------------------------
-int vtkNrrdReader::CanReadFile(const char *filename)
+int vtkNrrdReader::CanReadFile(const char* filename)
 {
-  ifstream file(filename, ios::in | ios::binary);
+  vtksys::ifstream file(filename, ios::in | ios::binary);
   std::string firstLine;
   getline(file, firstLine);
   if (firstLine.substr(0, 4) == "NRRD")
@@ -253,14 +253,13 @@ int vtkNrrdReader::CanReadFile(const char *filename)
 }
 
 //-----------------------------------------------------------------------------
-int vtkNrrdReader::RequestInformation(vtkInformation *request,
-                                      vtkInformationVector **inputVector,
-                                      vtkInformationVector *outputVector)
+int vtkNrrdReader::RequestInformation(
+  vtkInformation* request, vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
-  if (!this->ReadHeader()) return 0;
+  if (!this->ReadHeader())
+    return 0;
 
-  return this->Superclass::RequestInformation(request,
-                                              inputVector, outputVector);
+  return this->Superclass::RequestInformation(request, inputVector, outputVector);
 }
 
 //-----------------------------------------------------------------------------
@@ -272,35 +271,33 @@ int vtkNrrdReader::ReadHeaderInternal(vtkCharArray* headerBuffer)
     return 0;
   }
 
-  ifstream file(this->FileName, ios::in | ios::binary);
+  vtksys::ifstream file(this->FileName, ios::in | ios::binary);
   // Read in 4 MB.  Assuming that the header will be smaller than that.
   headerBuffer->SetNumberOfTuples(0x400000);
-  file.read(headerBuffer->GetPointer(0), 0x400000-1);
+  file.read(headerBuffer->GetPointer(0), 0x400000 - 1);
   vtkIdType buffersize = file.gcount();
   headerBuffer->SetValue(buffersize, '\0');
-  headerBuffer->SetNumberOfTuples(buffersize+1);
+  headerBuffer->SetNumberOfTuples(buffersize + 1);
 
   // Find a blank line (which signals the end of the header).  Be careful
   // because line endings can be "\n", "\r\n", or both.  It is possible that
   // the entire file is the header (happens with "detached headers").
-  char *bufferStart = headerBuffer->GetPointer(0);
-  char *s = bufferStart;
-  while ((s = strchr(s+1, '\n')) != NULL)
+  char* bufferStart = headerBuffer->GetPointer(0);
+  char* s = bufferStart;
+  while ((s = strchr(s + 1, '\n')) != nullptr)
   {
     // If you find a double line ending, terminate the string and shorten the
     // buffer.
     if (s[1] == '\n')
     {
       s[2] = '\0';
-      headerBuffer->SetNumberOfTuples(
-                                 static_cast<vtkIdType>(s + 3 - bufferStart));
+      headerBuffer->SetNumberOfTuples(static_cast<vtkIdType>(s + 3 - bufferStart));
       break;
     }
     if ((s[1] == '\r') && (s[2] == '\n'))
     {
       s[3] = '\0';
-      headerBuffer->SetNumberOfTuples(
-                                 static_cast<vtkIdType>(s + 4 - bufferStart));
+      headerBuffer->SetNumberOfTuples(static_cast<vtkIdType>(s + 4 - bufferStart));
       break;
     }
   }
@@ -308,13 +305,12 @@ int vtkNrrdReader::ReadHeaderInternal(vtkCharArray* headerBuffer)
   return 1;
 }
 
-
 //-----------------------------------------------------------------------------
 int vtkNrrdReader::ReadHeader()
 {
   VTK_CREATE(vtkCharArray, headerBuffer);
 
-  if(!this->ReadHeaderInternal(headerBuffer))
+  if (!this->ReadHeaderInternal(headerBuffer))
   {
     return 0;
   }
@@ -323,7 +319,7 @@ int vtkNrrdReader::ReadHeader()
 }
 
 //-----------------------------------------------------------------------------
-int vtkNrrdReader::ReadHeader(vtkCharArray *headerBuffer)
+int vtkNrrdReader::ReadHeader(vtkCharArray* headerBuffer)
 {
   this->HeaderSize = headerBuffer->GetNumberOfTuples();
 
@@ -348,7 +344,8 @@ int vtkNrrdReader::ReadHeader(vtkCharArray *headerBuffer)
   while (1)
   {
     getline(header, line);
-    if (line.length() < 1) break;
+    if (line.length() < 1)
+      break;
 
     if (line[0] == '#')
     {
@@ -361,7 +358,7 @@ int vtkNrrdReader::ReadHeader(vtkCharArray *headerBuffer)
     {
       // A field/description pair.
       std::string field = line.substr(0, delm);
-      std::string description = trim(line.substr(delm+2));
+      std::string description = trim(line.substr(delm + 2));
       if (field == "dimension")
       {
         numDimensions = atoi(description.c_str());
@@ -379,20 +376,17 @@ int vtkNrrdReader::ReadHeader(vtkCharArray *headerBuffer)
       else if (field == "type")
       {
         this->DataScalarType = NrrdType2VTKType(description);
-        if (this->DataScalarType == VTK_VOID) return 0;
+        if (this->DataScalarType == VTK_VOID)
+          return 0;
       }
       else if (field == "encoding")
       {
-        std::transform(description.begin(), description.end(),
-                       description.begin(),
-                       ::tolower);
+        std::transform(description.begin(), description.end(), description.begin(), ::tolower);
         if (description == "raw")
         {
           this->Encoding = ENCODING_RAW;
         }
-        else if (description == "ascii"
-                 || description == "txt"
-                 || description == "text")
+        else if (description == "ascii" || description == "txt" || description == "text")
         {
           this->Encoding = ENCODING_ASCII;
         }
@@ -408,35 +402,37 @@ int vtkNrrdReader::ReadHeader(vtkCharArray *headerBuffer)
         if (filepatterninfo[0] == "LIST")
         {
           // After LIST there is an optional subdimension (see next case below).
-          subDimension = (  (filepatterninfo.size() > 1)
-                          ? atoi(filepatterninfo[1].c_str()) : numDimensions );
+          subDimension =
+            ((filepatterninfo.size() > 1) ? atoi(filepatterninfo[1].c_str()) : numDimensions);
 
           // In this mode files are listed one per line to the end of the file.
           while (1)
           {
             getline(header, line);
             trim(line);
-            if (line.length() < 1) break;
+            if (line.length() < 1)
+              break;
             this->DataFiles->InsertNextValue(line);
           }
           break;
         }
-        else if (filepatterninfo.size() >=4)
+        else if (filepatterninfo.size() >= 4)
         {
           // description should be "<format> <min> <max> <step> [<subdim>]"
-          // where <format> is a string to be processed by sprintf and <min>,
+          // where <format> is a string to be processed by snprintf and <min>,
           // <max>, and <step> form the numbers.  <subdim> defines on which
           // dimension the files are split up.
           std::string format = filepatterninfo[0];
           int min = atoi(filepatterninfo[1].c_str());
           int max = atoi(filepatterninfo[2].c_str());
           int step = atoi(filepatterninfo[3].c_str());
-          subDimension = (  (filepatterninfo.size() > 4)
-                          ? atoi(filepatterninfo[4].c_str()) : numDimensions );
-          char *filename = new char[format.size() + 20];
+          subDimension =
+            ((filepatterninfo.size() > 4) ? atoi(filepatterninfo[4].c_str()) : numDimensions);
+          size_t filenamelen = format.size() + 20;
+          char* filename = new char[filenamelen];
           for (int i = min; i <= max; i += step)
           {
-            sprintf(filename, format.c_str(), i);
+            snprintf(filename, filenamelen, format.c_str(), i);
             this->DataFiles->InsertNextValue(filename);
           }
           delete[] filename;
@@ -455,9 +451,8 @@ int vtkNrrdReader::ReadHeader(vtkCharArray *headerBuffer)
           vtkErrorMacro(<< "Time in NRRD array not supported (yet).");
           return 0;
         }
-        if (   (description == "left-anterior-superior")
-            || (description == "LAS")
-            || (description == "3D-left-handed") )
+        if ((description == "left-anterior-superior") || (description == "LAS") ||
+          (description == "3D-left-handed"))
         {
           this->FileLowerLeft = 0;
         }
@@ -465,10 +460,10 @@ int vtkNrrdReader::ReadHeader(vtkCharArray *headerBuffer)
       }
       else if (field == "labels")
       {
-        std::string dataname = description.substr(description.find("\"")+1);
-        dataname = dataname.substr(0, dataname.find("\""));
+        std::string dataname = description.substr(description.find('\"') + 1);
+        dataname = dataname.substr(0, dataname.find('\"'));
         delete[] this->ScalarArrayName;
-        this->ScalarArrayName = new char[dataname.size()+1];
+        this->ScalarArrayName = new char[dataname.size() + 1];
         strcpy(this->ScalarArrayName, dataname.c_str());
       }
       else if (field == "space dimension")
@@ -499,7 +494,7 @@ int vtkNrrdReader::ReadHeader(vtkCharArray *headerBuffer)
           double mag = 0.0;
           for (size_t k = 0; k < dir.size(); k++)
           {
-            mag += dir[k]*dir[k];
+            mag += dir[k] * dir[k];
           }
           dimSpacing.push_back(sqrt(mag));
         }
@@ -544,21 +539,13 @@ int vtkNrrdReader::ReadHeader(vtkCharArray *headerBuffer)
           return 0;
         }
       }
-      else if (   (field == "space units")
-               || (field == "sample units") || (field == "sampleunits")
-               || (field == "measurement frame")
-               || (field == "block size") || (field == "blocksize")
-               || (field == "content")
-               || (field == "thicknesses")
-               || (field == "axis mins") || (field == "axismins")
-               || (field == "axis maxs") || (field == "axismaxs")
-               || (field == "centers") || (field == "centerings")
-               || (field == "units")
-               || (field == "kinds")
-               || (field == "min") || (field == "max")
-               || (field == "old min") || (field == "oldmin")
-               || (field == "old max") || (field == "oldmax")
-               || (field == "number") )
+      else if ((field == "space units") || (field == "sample units") || (field == "sampleunits") ||
+        (field == "measurement frame") || (field == "block size") || (field == "blocksize") ||
+        (field == "content") || (field == "thicknesses") || (field == "axis mins") ||
+        (field == "axismins") || (field == "axis maxs") || (field == "axismaxs") ||
+        (field == "centers") || (field == "centerings") || (field == "units") ||
+        (field == "kinds") || (field == "min") || (field == "max") || (field == "old min") ||
+        (field == "oldmin") || (field == "old max") || (field == "oldmax") || (field == "number"))
       {
         // Ignored.
       }
@@ -582,13 +569,13 @@ int vtkNrrdReader::ReadHeader(vtkCharArray *headerBuffer)
   // VTK really needs to know the difference.  Here we are going to guess.
   // If the fastest changing dimension is 9 or less we consider that a tuple.
   // We will also consider any 4th dimension as a tuple.
-  if (   (dimSizes.size() > 3)
-      || ((dimSizes.size() > 0) && (dimSizes[0] <= 9))
-      || ((dimSpacing.size() > 0) && (dimSpacing[0] == 0)) )
+  if ((dimSizes.size() > 3) || ((!dimSizes.empty()) && (dimSizes[0] <= 9)) ||
+    ((!dimSpacing.empty()) && (dimSpacing[0] == 0)))
   {
     this->NumberOfScalarComponents = dimSizes[0];
     dimSizes.erase(dimSizes.begin());
-    if (!dimSpacing.empty()) dimSpacing.erase(dimSpacing.begin());
+    if (!dimSpacing.empty())
+      dimSpacing.erase(dimSpacing.begin());
     subDimension--;
   }
   else
@@ -600,8 +587,8 @@ int vtkNrrdReader::ReadHeader(vtkCharArray *headerBuffer)
   this->FileDimensionality = static_cast<int>(dimSizes.size());
   for (unsigned int i = 0; i < 3; i++)
   {
-    this->DataExtent[i*2+0] = 0;
-    this->DataExtent[i*2+1] = (i < dimSizes.size()) ? dimSizes[i]-1 : 0;
+    this->DataExtent[i * 2 + 0] = 0;
+    this->DataExtent[i * 2 + 1] = (i < dimSizes.size()) ? dimSizes[i] - 1 : 0;
     this->DataSpacing[i] = (i < dimSpacing.size()) ? dimSpacing[i] : 1;
   }
 
@@ -625,14 +612,11 @@ int vtkNrrdReader::ReadHeader(vtkCharArray *headerBuffer)
                       << " dimension.");
       }
     }
-    std::string parentDir
-      = vtksys::SystemTools::GetParentDirectory(this->FileName);
+    std::string parentDir = vtksys::SystemTools::GetParentDirectory(this->FileName);
     for (vtkIdType i = 0; i < this->DataFiles->GetNumberOfValues(); i++)
     {
       std::string relativePath = this->DataFiles->GetValue(i);
-      std::string fullPath
-        = vtksys::SystemTools::CollapseFullPath(relativePath.c_str(),
-                                                parentDir.c_str());
+      std::string fullPath = vtksys::SystemTools::CollapseFullPath(relativePath, parentDir.c_str());
       this->DataFiles->SetValue(i, fullPath);
     }
     // Header file pointing to data files.  Data files should have no header.
@@ -643,23 +627,22 @@ int vtkNrrdReader::ReadHeader(vtkCharArray *headerBuffer)
 }
 
 //=============================================================================
-int vtkNrrdReader::RequestData(vtkInformation *request,
-                               vtkInformationVector **inputVector,
-                               vtkInformationVector *outputVector)
+int vtkNrrdReader::RequestData(
+  vtkInformation* request, vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
   // Get rid of superclasses FileNames.  We don't support that functionality,
   // but we exploit that of the superclass.
-  if (this->FileNames != NULL)
+  if (this->FileNames != nullptr)
   {
     this->FileNames->Delete();
-    this->FileNames = NULL;
+    this->FileNames = nullptr;
   }
 
-  char *saveFileName = this->FileName;
+  char* saveFileName = this->FileName;
 
   if (this->DataFiles->GetNumberOfValues() == 1)
   {
-    this->FileName = const_cast<char *>(this->DataFiles->GetValue(0).c_str());
+    this->FileName = const_cast<char*>(this->DataFiles->GetValue(0).c_str());
   }
   else if (this->DataFiles->GetNumberOfValues() > 1)
   {
@@ -676,9 +659,9 @@ int vtkNrrdReader::RequestData(vtkInformation *request,
   }
   else if (this->Encoding == ENCODING_ASCII)
   {
-    vtkImageData *outputData = vtkImageData::GetData(outputVector);
+    vtkImageData* outputData = vtkImageData::GetData(outputVector);
     this->AllocateOutputData(outputData, outputVector->GetInformationObject(0));
-    if (outputData == NULL)
+    if (outputData == nullptr)
     {
       vtkErrorMacro(<< "Data not created correctly?");
       return 0;
@@ -693,16 +676,14 @@ int vtkNrrdReader::RequestData(vtkInformation *request,
   }
 
   this->FileName = saveFileName;
-  this->FileNames = NULL;
+  this->FileNames = nullptr;
 
   return result;
 }
 
 //=============================================================================
-template<typename T>
-int vtkNrrdReaderReadDataAsciiTemplate(vtkNrrdReader *self,
-                                       vtkImageData *output,
-                                       T *outBuffer)
+template <typename T>
+int vtkNrrdReaderReadDataAsciiTemplate(vtkNrrdReader* self, vtkImageData* output, T* outBuffer)
 {
   // Get the requested extent
   int outExtent[6];
@@ -716,13 +697,13 @@ int vtkNrrdReaderReadDataAsciiTemplate(vtkNrrdReader *self,
   fileDataIncrements[1] = fileDataIncrements[0] * fileDataExtent[1];
   fileDataIncrements[2] = fileDataIncrements[1] * fileDataExtent[3];
 
-  vtkStringArray *filenames = self->GetFileNames();
+  vtkStringArray* filenames = self->GetFileNames();
   vtkStdString filename = self->GetFileName();
 
-  std::ifstream file;
+  vtksys::ifstream file;
   if (self->GetFileDimensionality() == 3)
   {
-    if (filenames != NULL)
+    if (filenames != nullptr)
     {
       filename = filenames->GetValue(0);
     }
@@ -733,7 +714,7 @@ int vtkNrrdReaderReadDataAsciiTemplate(vtkNrrdReader *self,
       return 0;
     }
     // Skip to start of first slab.
-    for (vtkIdType skip = 0; skip < fileDataIncrements[2]*outExtent[4]; skip++)
+    for (vtkIdType skip = 0; skip < fileDataIncrements[2] * outExtent[4]; skip++)
     {
       T dummy;
       file >> dummy;
@@ -742,14 +723,15 @@ int vtkNrrdReaderReadDataAsciiTemplate(vtkNrrdReader *self,
 
   vtkIdType bufferIndex = 0;
   int fileDataIndex[3];
-  for (fileDataIndex[2] = outExtent[4];
-       fileDataIndex[2] <= outExtent[5];
-       fileDataIndex[2]++)
+  for (fileDataIndex[2] = outExtent[4]; fileDataIndex[2] <= outExtent[5]; fileDataIndex[2]++)
   {
     if (self->GetFileDimensionality() == 2)
     {
-      if (file.is_open()) { file.close(); }
-      if (filenames != NULL)
+      if (file.is_open())
+      {
+        file.close();
+      }
+      if (filenames != nullptr)
       {
         filename = filenames->GetValue(fileDataIndex[2]);
       }
@@ -761,31 +743,26 @@ int vtkNrrdReaderReadDataAsciiTemplate(vtkNrrdReader *self,
       }
     }
     // Skip unused rows.
-    for (vtkIdType skip = 0; skip < fileDataIncrements[1]*outExtent[2]; skip++)
+    for (vtkIdType skip = 0; skip < fileDataIncrements[1] * outExtent[2]; skip++)
     {
       T dummy;
       file >> dummy;
     }
-    for (fileDataIndex[1] = outExtent[2];
-         fileDataIndex[1] <= outExtent[3];
-         fileDataIndex[1]++)
+    for (fileDataIndex[1] = outExtent[2]; fileDataIndex[1] <= outExtent[3]; fileDataIndex[1]++)
     {
       // Skip unused columns.
-      for (vtkIdType skip = 0; skip<fileDataIncrements[0]*outExtent[0]; skip++)
+      for (vtkIdType skip = 0; skip < fileDataIncrements[0] * outExtent[0]; skip++)
       {
         T dummy;
         file >> dummy;
       }
-      for (fileDataIndex[0] = outExtent[0];
-           fileDataIndex[0] <= outExtent[1];
-           fileDataIndex[0]++)
+      for (fileDataIndex[0] = outExtent[0]; fileDataIndex[0] <= outExtent[1]; fileDataIndex[0]++)
       {
         file >> outBuffer[bufferIndex];
         bufferIndex++;
       }
       // Skip unused columns.
-      for (vtkIdType skip = 0;
-           skip < fileDataIncrements[0]*(fileDataExtent[1] - outExtent[1]);
+      for (vtkIdType skip = 0; skip < fileDataIncrements[0] * (fileDataExtent[1] - outExtent[1]);
            skip++)
       {
         T dummy;
@@ -793,8 +770,7 @@ int vtkNrrdReaderReadDataAsciiTemplate(vtkNrrdReader *self,
       }
     }
     // Skip unused rows.
-    for (vtkIdType skip = 0;
-         skip < fileDataIncrements[1]*(fileDataExtent[2] - outExtent[2]);
+    for (vtkIdType skip = 0; skip < fileDataIncrements[1] * (fileDataExtent[2] - outExtent[2]);
          skip++)
     {
       T dummy;
@@ -807,16 +783,14 @@ int vtkNrrdReaderReadDataAsciiTemplate(vtkNrrdReader *self,
 }
 
 //=============================================================================
-int vtkNrrdReader::ReadDataAscii(vtkImageData *output)
+int vtkNrrdReader::ReadDataAscii(vtkImageData* output)
 {
-  void *outBuffer = output->GetScalarPointer();
+  void* outBuffer = output->GetScalarPointer();
   switch (output->GetScalarType())
   {
-    vtkTemplateMacro(vtkNrrdReaderReadDataAsciiTemplate(this,
-                                                        output,
-                                                        (VTK_TT *)(outBuffer)));
+    vtkTemplateMacro(vtkNrrdReaderReadDataAsciiTemplate(this, output, (VTK_TT*)(outBuffer)));
     default:
-      vtkErrorMacro("Unkown data type");
+      vtkErrorMacro("Unknown data type");
       return 0;
   }
 
