@@ -22,7 +22,7 @@
  * is currently under patent in the US and is disabled until the patent
  * expires. However, the mechanism for supporting this compression is available
  * for those with a valid license or to whom the patent does not apply.)
-*/
+ */
 
 #ifndef vtkTIFFWriter_h
 #define vtkTIFFWriter_h
@@ -33,16 +33,17 @@
 class VTKIOIMAGE_EXPORT vtkTIFFWriter : public vtkImageWriter
 {
 public:
-  static vtkTIFFWriter *New();
-  vtkTypeMacro(vtkTIFFWriter,vtkImageWriter);
-  void PrintSelf(ostream& os, vtkIndent indent) VTK_OVERRIDE;
+  static vtkTIFFWriter* New();
+  vtkTypeMacro(vtkTIFFWriter, vtkImageWriter);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
   /**
    * The main interface which triggers the writer to start.
    */
-  virtual void Write();
+  void Write() override;
 
-  enum { // Compression types
+  enum
+  { // Compression types
     NoCompression,
     PackBits,
     JPEG,
@@ -58,19 +59,19 @@ public:
   vtkSetClampMacro(Compression, int, NoCompression, LZW);
   vtkGetMacro(Compression, int);
   void SetCompressionToNoCompression() { this->SetCompression(NoCompression); }
-  void SetCompressionToPackBits()      { this->SetCompression(PackBits); }
-  void SetCompressionToJPEG()          { this->SetCompression(JPEG); }
-  void SetCompressionToDeflate()       { this->SetCompression(Deflate); }
-  void SetCompressionToLZW()           { this->SetCompression(LZW); }
+  void SetCompressionToPackBits() { this->SetCompression(PackBits); }
+  void SetCompressionToJPEG() { this->SetCompression(JPEG); }
+  void SetCompressionToDeflate() { this->SetCompression(Deflate); }
+  void SetCompressionToLZW() { this->SetCompression(LZW); }
   //@}
 
 protected:
   vtkTIFFWriter();
-  ~vtkTIFFWriter() {}
+  ~vtkTIFFWriter() override {}
 
-  virtual void WriteFile(ofstream *file, vtkImageData *data, int ext[6], int wExt[6]);
-  virtual void WriteFileHeader(ofstream *, vtkImageData *, int wExt[6]);
-  virtual void WriteFileTrailer(ofstream *, vtkImageData *);
+  void WriteFile(ostream* file, vtkImageData* data, int ext[6], int wExt[6]) override;
+  void WriteFileHeader(ostream*, vtkImageData*, int wExt[6]) override;
+  void WriteFileTrailer(ostream*, vtkImageData*) override;
 
   void* TIFFPtr;
   int Compression;
@@ -81,11 +82,11 @@ protected:
   double YResolution;
 
 private:
-  vtkTIFFWriter(const vtkTIFFWriter&) VTK_DELETE_FUNCTION;
-  void operator=(const vtkTIFFWriter&) VTK_DELETE_FUNCTION;
+  vtkTIFFWriter(const vtkTIFFWriter&) = delete;
+  void operator=(const vtkTIFFWriter&) = delete;
 
-  template<typename T> void WriteVolume(T *buffer);
+  template <typename T>
+  void WriteVolume(T* buffer);
 };
 
 #endif
-
