@@ -2,23 +2,23 @@
 #define vtkMySQLDatabasePrivate_h
 
 #ifdef _WIN32
-# include <winsock.h> // mysql.h relies on the typedefs from here
+#include <winsock.h> // mysql.h relies on the typedefs from here
 #endif
 
 #include "vtkIOMySQLModule.h" // For export macro
-#include <mysql.h> // needed for MYSQL typedefs
+#include <mysql.h>            // needed for MYSQL typedefs
 
 class VTKIOMYSQL_EXPORT vtkMySQLDatabasePrivate
 {
 public:
-  vtkMySQLDatabasePrivate() :
-    Connection( NULL )
+  vtkMySQLDatabasePrivate()
+    : Connection(nullptr)
   {
-  mysql_init( &this->NullConnection );
+    mysql_init(&this->NullConnection);
   }
 
   MYSQL NullConnection;
-  MYSQL *Connection;
+  MYSQL* Connection;
 };
 
 #endif // vtkMySQLDatabasePrivate_h
