@@ -30,7 +30,8 @@
 #include <vtksys/SystemTools.hxx>
 
 #include "vtkSmartPointer.h"
-#define VTK_CREATE(classname, varname) vtkSmartPointer<classname> varname = vtkSmartPointer<classname>::New()
+#define VTK_CREATE(classname, varname)                                                             \
+  vtkSmartPointer<classname> varname = vtkSmartPointer<classname>::New()
 
 #include <libpq-fe.h>
 
@@ -61,26 +62,26 @@ vtkPostgreSQLDatabase::vtkPostgreSQLDatabase()
 // ----------------------------------------------------------------------
 vtkPostgreSQLDatabase::~vtkPostgreSQLDatabase()
 {
-  if ( this->IsOpen() )
+  if (this->IsOpen())
   {
     this->Close();
   }
 
-  this->SetHostName( 0 );
-  this->SetUser( 0 );
-  this->SetDatabaseName( 0 );
-  this->SetConnectOptions( 0 );
-  this->SetDatabaseType( 0 );
-  this->SetLastErrorText( 0 );
+  this->SetHostName(0);
+  this->SetUser(0);
+  this->SetDatabaseName(0);
+  this->SetConnectOptions(0);
+  this->SetDatabaseType(0);
+  this->SetLastErrorText(0);
   this->Tables->UnRegister(this);
 }
 
 // ----------------------------------------------------------------------
-void vtkPostgreSQLDatabase::PrintSelf(ostream &os, vtkIndent indent)
+void vtkPostgreSQLDatabase::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
   os << indent << "Connection: ";
-  if ( this->Connection )
+  if (this->Connection)
   {
     os << this->Connection << endl;
   }
@@ -88,27 +89,28 @@ void vtkPostgreSQLDatabase::PrintSelf(ostream &os, vtkIndent indent)
   {
     os << "(null)" << endl;
   }
-  os << indent << "DatabaseType: " << (this->DatabaseType ? this->DatabaseType : "NULL") << endl;
-  os << indent << "HostName: " << (this->HostName ? this->HostName : "NULL") << endl;
-  os << indent << "User: " << (this->User ? this->User : "NULL") << endl;
-  os << indent << "Password: " << (this->Password? "(hidden)":"(none)") << endl;
-  os << indent << "DatabaseName: " << (this->DatabaseName ? this->DatabaseName : "NULL") << endl;
+  os << indent << "DatabaseType: " << (this->DatabaseType ? this->DatabaseType : "nullptr") << endl;
+  os << indent << "HostName: " << (this->HostName ? this->HostName : "nullptr") << endl;
+  os << indent << "User: " << (this->User ? this->User : "nullptr") << endl;
+  os << indent << "Password: " << (this->Password ? "(hidden)" : "(none)") << endl;
+  os << indent << "DatabaseName: " << (this->DatabaseName ? this->DatabaseName : "nullptr") << endl;
   os << indent << "ServerPort: " << this->ServerPort << endl;
-  os << indent << "ConnectOptions: " << (this->ConnectOptions ? this->ConnectOptions : "NULL") << endl;
+  os << indent << "ConnectOptions: " << (this->ConnectOptions ? this->ConnectOptions : "nullptr")
+     << endl;
   os << indent << "LastErrorText: " << this->LastErrorText << endl;
 }
 
 // ----------------------------------------------------------------------
 vtkStdString vtkPostgreSQLDatabase::GetColumnSpecification(
-  vtkSQLDatabaseSchema* schema, int tblHandle, int colHandle )
+  vtkSQLDatabaseSchema* schema, int tblHandle, int colHandle)
 {
   std::ostringstream queryStr;
-  queryStr << schema->GetColumnNameFromHandle( tblHandle, colHandle );
+  queryStr << schema->GetColumnNameFromHandle(tblHandle, colHandle);
 
   // Figure out column type
-  int colType = schema->GetColumnTypeFromHandle( tblHandle, colHandle );
+  int colType = schema->GetColumnTypeFromHandle(tblHandle, colHandle);
   vtkStdString colTypeStr;
-  switch ( static_cast<vtkSQLDatabaseSchema::DatabaseColumnType>( colType ) )
+  switch (static_cast<vtkSQLDatabaseSchema::DatabaseColumnType>(colType))
   {
     case vtkSQLDatabaseSchema::SERIAL:
       colTypeStr = "SERIAL";
@@ -148,80 +150,80 @@ vtkStdString vtkPostgreSQLDatabase::GetColumnSpecification(
       break;
   }
 
-  if ( colTypeStr.size() )
+  if (colTypeStr.size())
   {
     queryStr << " " << colTypeStr;
   }
   else // if ( colTypeStr.size() )
   {
-    vtkGenericWarningMacro( "Unable to get column specification: unsupported data type " << colType );
+    vtkGenericWarningMacro("Unable to get column specification: unsupported data type " << colType);
     return vtkStdString();
   }
 
   // Decide whether size is allowed, required, or unused
   int colSizeType = 0;
-  switch ( static_cast<vtkSQLDatabaseSchema::DatabaseColumnType>( colType ) )
+  switch (static_cast<vtkSQLDatabaseSchema::DatabaseColumnType>(colType))
   {
     case vtkSQLDatabaseSchema::SERIAL:
-      colSizeType =  0;
+      colSizeType = 0;
       break;
     case vtkSQLDatabaseSchema::SMALLINT:
-      colSizeType =  0;
+      colSizeType = 0;
       break;
     case vtkSQLDatabaseSchema::INTEGER:
-      colSizeType =  0;
+      colSizeType = 0;
       break;
     case vtkSQLDatabaseSchema::BIGINT:
-      colSizeType =  0;
+      colSizeType = 0;
       break;
     case vtkSQLDatabaseSchema::VARCHAR:
       colSizeType = -1;
       break;
     case vtkSQLDatabaseSchema::TEXT:
-      colSizeType =  0;
+      colSizeType = 0;
       break;
     case vtkSQLDatabaseSchema::REAL:
-      colSizeType =  0;
+      colSizeType = 0;
       break;
     case vtkSQLDatabaseSchema::DOUBLE:
-      colSizeType =  0;
+      colSizeType = 0;
       break;
     case vtkSQLDatabaseSchema::BLOB:
-      colSizeType =  0;
+      colSizeType = 0;
       break;
     case vtkSQLDatabaseSchema::TIME:
-      colSizeType =  1;
+      colSizeType = 1;
       break;
     case vtkSQLDatabaseSchema::DATE:
-      colSizeType =  0;
+      colSizeType = 0;
       break;
     case vtkSQLDatabaseSchema::TIMESTAMP:
-      colSizeType =  0;
+      colSizeType = 0;
       break;
   }
 
   // Specify size if allowed or required
-  if ( colSizeType )
+  if (colSizeType)
   {
-    int colSize = schema->GetColumnSizeFromHandle( tblHandle, colHandle );
+    int colSize = schema->GetColumnSizeFromHandle(tblHandle, colHandle);
     // IF size is provided but absurd,
     // OR, if size is required but not provided OR absurd,
     // THEN assign the default size.
-    if ( ( colSize < 0 ) || ( colSizeType == -1 && colSize < 1 ) )
+    if ((colSize < 0) || (colSizeType == -1 && colSize < 1))
     {
       colSize = VTK_SQL_DEFAULT_COLUMN_SIZE;
     }
 
     // At this point, we have either a valid size if required, or a possibly null valid size
     // if not required. Thus, skip sizing in the latter case.
-    if ( colSize > 0 )
+    if (colSize > 0)
     {
       queryStr << "(" << colSize << ")";
     }
   }
 
-  vtkStdString attStr = schema->GetColumnAttributesFromHandle( tblHandle, colHandle );
-  if ( attStr.size() )
+  vtkStdString attStr = schema->GetColumnAttributesFromHandle(tblHandle, colHandle);
+  if (attStr.size())
   {
     queryStr << " " << attStr;
   }
@@ -230,18 +232,18 @@ vtkStdString vtkPostgreSQLDatabase::GetColumnSpecification(
 }
 
 // ----------------------------------------------------------------------
-bool vtkPostgreSQLDatabase::Open( const char* password )
+bool vtkPostgreSQLDatabase::Open(const char* password)
 {
-  if ( ! this->HostName || ! this->DatabaseName )
+  if (!this->HostName || !this->DatabaseName)
   {
-    this->SetLastErrorText( "Cannot open database because HostName and/or DatabaseName are null." );
-    vtkErrorMacro( << this->GetLastErrorText() );
+    this->SetLastErrorText("Cannot open database because HostName and/or DatabaseName are null.");
+    vtkErrorMacro(<< this->GetLastErrorText());
     return false;
   }
 
-  if ( this->Connection )
+  if (this->Connection)
   {
-    if ( this->ConnectionMTime > this->URLMTime )
+    if (this->ConnectionMTime > this->URLMTime)
     {
       return true; // we already had that database open.
     }
@@ -252,29 +254,29 @@ bool vtkPostgreSQLDatabase::Open( const char* password )
   options = "dbname=";
   options += this->DatabaseName;
 
-  if ( this->ServerPort > 0 )
+  if (this->ServerPort > 0)
   {
     options += " port=";
     std::ostringstream stream;
     stream << this->ServerPort;
     options += stream.str();
   }
-  if ( this->User && strlen( this->User ) > 0 )
+  if (this->User && strlen(this->User) > 0)
   {
     options += " user=";
     options += this->User;
   }
-  if ( password && this->Password != password )
+  if (password && this->Password != password)
   {
-    delete [] this->Password;
-    this->Password = password ? vtksys::SystemTools::DuplicateString( password ) : 0;
+    delete[] this->Password;
+    this->Password = password ? vtksys::SystemTools::DuplicateString(password) : 0;
   }
-  if ( this->Password && strlen( this->Password ) > 0 )
+  if (this->Password && strlen(this->Password) > 0)
   {
     options += " password=";
     options += this->Password;
   }
-  if ( this->ConnectOptions && strlen( this->ConnectOptions ) > 0 )
+  if (this->ConnectOptions && strlen(this->ConnectOptions) > 0)
   {
     options += this->ConnectOptions;
   }
@@ -282,20 +284,20 @@ bool vtkPostgreSQLDatabase::Open( const char* password )
   // If localhost is specified, try the local socket connection
   // first. Only if that doesn't work will we try the loopback
   // device.
-  if ( ! strcmp( this->HostName, "localhost" ) )
+  if (!strcmp(this->HostName, "localhost"))
   {
-    if ( this->OpenInternal( options.c_str() ) )
+    if (this->OpenInternal(options.c_str()))
     {
-      this->SetLastErrorText( 0 );
+      this->SetLastErrorText(0);
       return true;
     }
   }
-  std::string hspec( "host=" );
+  std::string hspec("host=");
   hspec += this->HostName;
   options = hspec + " " + options;
-  if ( this->OpenInternal( options.c_str() ) )
+  if (this->OpenInternal(options.c_str()))
   {
-    this->SetLastErrorText( 0 );
+    this->SetLastErrorText(0);
     return true;
   }
 
@@ -305,11 +307,11 @@ bool vtkPostgreSQLDatabase::Open( const char* password )
 // ----------------------------------------------------------------------
 void vtkPostgreSQLDatabase::Close()
 {
-  if ( this->Connection )
+  if (this->Connection)
   {
     delete this->Connection;
     this->Connection = 0;
-    this->SetLastErrorText( 0 );
+    this->SetLastErrorText(0);
     this->URLMTime.Modified(); // Force a re-open to occur when Open() is called.
   }
 }
@@ -317,16 +319,15 @@ void vtkPostgreSQLDatabase::Close()
 // ----------------------------------------------------------------------
 bool vtkPostgreSQLDatabase::IsOpen()
 {
-  return (this->Connection != 0 &&
-          this->Connection->Connection != 0 &&
-          PQstatus(this->Connection->Connection) == CONNECTION_OK);
+  return (this->Connection != 0 && this->Connection->Connection != 0 &&
+    PQstatus(this->Connection->Connection) == CONNECTION_OK);
 }
 
 // ----------------------------------------------------------------------
 vtkSQLQuery* vtkPostgreSQLDatabase::GetQueryInstance()
 {
   vtkPostgreSQLQuery* query = vtkPostgreSQLQuery::New();
-  query->SetDatabase( this );
+  query->SetDatabase(this);
   return query;
 }
 
@@ -334,7 +335,7 @@ vtkSQLQuery* vtkPostgreSQLDatabase::GetQueryInstance()
 bool vtkPostgreSQLDatabase::HasError()
 {
   // Assume that an unopened connection is not a symptom of failure.
-  if ( this->Connection )
+  if (this->Connection)
   {
     return this->LastErrorText ? true : false;
   }
@@ -355,9 +356,9 @@ vtkStdString vtkPostgreSQLDatabase::GetURL()
 {
   vtkStdString url = this->GetDatabaseType();
   url += "://";
-  if ( this->HostName && this->DatabaseName )
+  if (this->HostName && this->DatabaseName)
   {
-    if ( this->User && strlen( this->User ) > 0 )
+    if (this->User && strlen(this->User) > 0)
     {
       url += this->User;
       url += "@";
@@ -370,9 +371,9 @@ vtkStdString vtkPostgreSQLDatabase::GetURL()
 }
 
 // ----------------------------------------------------------------------
-bool vtkPostgreSQLDatabase::ParseURL( const char* URL )
+bool vtkPostgreSQLDatabase::ParseURL(const char* URL)
 {
-  std::string urlstr( URL ? URL : "" );
+  std::string urlstr(URL ? URL : "");
   std::string protocol;
   std::string username;
   std::string password;
@@ -381,20 +382,20 @@ bool vtkPostgreSQLDatabase::ParseURL( const char* URL )
   std::string database;
 
   // Okay now for all the other database types get more detailed info
-  if ( ! vtksys::SystemTools::ParseURL(
-      urlstr, protocol, username, password, hostname, dataport, database) )
+  if (!vtksys::SystemTools::ParseURL(
+        urlstr, protocol, username, password, hostname, dataport, database))
   {
-    vtkErrorMacro( "Invalid URL: \"" << urlstr.c_str() << "\"" );
+    vtkErrorMacro("Invalid URL: \"" << urlstr.c_str() << "\"");
     return false;
   }
 
-  if ( protocol == "psql" )
+  if (protocol == "psql")
   {
-    this->SetUser( username.empty() ? 0 : username.c_str() );
-    this->SetPassword( password.empty() ? 0 : password.c_str() );
-    this->SetHostName( hostname.empty() ? 0 : hostname.c_str() );
-    this->SetServerPort( atoi( dataport.c_str() ) );
-    this->SetDatabaseName( database.empty() ? 0 : database.c_str() );
+    this->SetUser(username.empty() ? 0 : username.c_str());
+    this->SetPassword(password.empty() ? 0 : password.c_str());
+    this->SetHostName(hostname.empty() ? 0 : hostname.c_str());
+    this->SetServerPort(atoi(dataport.c_str()));
+    this->SetDatabaseName(database.empty() ? 0 : database.c_str());
     return true;
   }
 
@@ -405,7 +406,7 @@ bool vtkPostgreSQLDatabase::ParseURL( const char* URL )
 vtkStringArray* vtkPostgreSQLDatabase::GetTables()
 {
   this->Tables->Resize(0);
-  if ( ! this->Connection )
+  if (!this->Connection)
   {
     vtkErrorMacro(<< this->GetLastErrorText());
     return this->Tables;
@@ -416,12 +417,11 @@ vtkStringArray* vtkPostgreSQLDatabase::GetTables()
   // user_defined_type_schema, user_defined_type_name, is_insertable_into, is_typed,
   // commit_action
   vtkSQLQuery* query = this->GetQueryInstance();
-  query->SetQuery(
-    "SELECT table_name FROM information_schema.tables"
-    "  WHERE table_schema='public' and table_type='BASE TABLE'" );
+  query->SetQuery("SELECT table_name FROM information_schema.tables"
+                  "  WHERE table_schema='public' and table_type='BASE TABLE'");
   bool status = query->Execute();
 
-  if ( ! status )
+  if (!status)
   {
     vtkErrorMacro(<< "Database returned error: " << query->GetLastErrorText());
     this->SetLastErrorText(query->GetLastErrorText());
@@ -429,35 +429,36 @@ vtkStringArray* vtkPostgreSQLDatabase::GetTables()
     return this->Tables;
   }
   vtkDebugMacro(<< "GetTables(): SQL query succeeded.");
-  while ( query->NextRow() )
+  while (query->NextRow())
   {
-    this->Tables->InsertNextValue( query->DataValue( 0 ).ToString() );
+    this->Tables->InsertNextValue(query->DataValue(0).ToString());
   }
   query->Delete();
-  this->SetLastErrorText(NULL);
+  this->SetLastErrorText(nullptr);
   return this->Tables;
 }
 
 // ----------------------------------------------------------------------
-vtkStringArray* vtkPostgreSQLDatabase::GetRecord( const char* table )
+vtkStringArray* vtkPostgreSQLDatabase::GetRecord(const char* table)
 {
   // NB: There are *too many* other column names to list. Even the ones
   // currently in the query below are probably over the top. But there's
   // just so much peanut-buttery goodness in the table, I couldn't resist.
   vtkSQLQuery* query = this->GetQueryInstance();
-  vtkStdString text(
-    "SELECT column_name,column_default,data_type,is_nullable,character_maximum_length,numeric_precision,datetime_precision"
-    "  FROM information_schema.columns"
-    "  WHERE table_name='" );
+  vtkStdString text("SELECT "
+                    "column_name,column_default,data_type,is_nullable,character_maximum_length,"
+                    "numeric_precision,datetime_precision"
+                    "  FROM information_schema.columns"
+                    "  WHERE table_name='");
   text += table;
   text += "' ORDER BY ordinal_position";
 
-  query->SetQuery( text.c_str() );
+  query->SetQuery(text.c_str());
   bool status = query->Execute();
-  if ( ! status )
+  if (!status)
   {
-    vtkErrorMacro(<< "GetRecord(" << table << "): Database returned error: "
-                  << query->GetLastErrorText());
+    vtkErrorMacro(<< "GetRecord(" << table
+                  << "): Database returned error: " << query->GetLastErrorText());
     this->SetLastErrorText(query->GetLastErrorText());
     query->Delete();
     return 0;
@@ -467,9 +468,9 @@ vtkStringArray* vtkPostgreSQLDatabase::GetRecord( const char* table )
   // describes a single column in the table.
   vtkStringArray* results = vtkStringArray::New();
 
-  while ( query->NextRow() )
+  while (query->NextRow())
   {
-    results->InsertNextValue( query->DataValue( 0 ).ToString() );
+    results->InsertNextValue(query->DataValue(0).ToString());
   }
 
   query->Delete();
@@ -478,7 +479,7 @@ vtkStringArray* vtkPostgreSQLDatabase::GetRecord( const char* table )
 }
 
 // ----------------------------------------------------------------------
-bool vtkPostgreSQLDatabase::IsSupported( int feature )
+bool vtkPostgreSQLDatabase::IsSupported(int feature)
 {
   switch (feature)
   {
@@ -495,10 +496,9 @@ bool vtkPostgreSQLDatabase::IsSupported( int feature )
       return true;
     default:
     {
-    vtkErrorMacro(
-      << "Unknown SQL feature code " << feature << "!  See "
-      << "vtkSQLDatabase.h for a list of possible features.");
-    return false;
+      vtkErrorMacro(<< "Unknown SQL feature code " << feature << "!  See "
+                    << "vtkSQLDatabase.h for a list of possible features.");
+      return false;
     };
   }
 }
@@ -506,51 +506,51 @@ bool vtkPostgreSQLDatabase::IsSupported( int feature )
 // ----------------------------------------------------------------------
 vtkStringArray* vtkPostgreSQLDatabase::GetDatabases()
 {
-  if ( ! this->Connection )
+  if (!this->Connection)
   {
-    vtkErrorMacro( "Must be connected to a server to get a list of databases." );
+    vtkErrorMacro("Must be connected to a server to get a list of databases.");
     return 0;
   }
 
   vtkSQLQuery* query = this->GetQueryInstance();
-  if ( ! query )
+  if (!query)
   {
-    vtkErrorMacro( "Could not create a query." );
+    vtkErrorMacro("Could not create a query.");
     return 0;
   }
 
-  query->SetQuery( "SELECT datname FROM pg_database" );
-  if ( ! query->Execute() )
+  query->SetQuery("SELECT datname FROM pg_database");
+  if (!query->Execute())
   {
     query->Delete();
     return 0;
   }
   vtkStringArray* dbNames = vtkStringArray::New();
-  while ( query->NextRow() )
+  while (query->NextRow())
   {
-    dbNames->InsertNextValue( query->DataValue( 0 ).ToString() );
+    dbNames->InsertNextValue(query->DataValue(0).ToString());
   }
   query->Delete();
   return dbNames;
 }
 
 // ----------------------------------------------------------------------
-bool vtkPostgreSQLDatabase::CreateDatabase( const char* dbName, bool dropExisting )
+bool vtkPostgreSQLDatabase::CreateDatabase(const char* dbName, bool dropExisting)
 {
-  if ( ! dbName )
+  if (!dbName)
   {
-    vtkErrorMacro( "Databases must have a non-NULL name" );
+    vtkErrorMacro("Databases must have a non-nullptr name");
     return false;
   }
 
   bool dropCurrentlyConnected = false;
-  if ( this->DatabaseName && ! strcmp( this->DatabaseName, dbName ) )
+  if (this->DatabaseName && !strcmp(this->DatabaseName, dbName))
   {
     dropCurrentlyConnected = true;
-    if ( dropExisting )
+    if (dropExisting)
     {
       // we can't drop a database we're connected to...
-      this->SetDatabaseName( "template1" );
+      this->SetDatabaseName("template1");
       this->Open();
     }
     else
@@ -559,95 +559,93 @@ bool vtkPostgreSQLDatabase::CreateDatabase( const char* dbName, bool dropExistin
     }
   }
 
-  if ( ! this->Connection )
+  if (!this->Connection)
   {
-    if ( this->DatabaseName && ! strcmp( this->DatabaseName, dbName ) )
+    if (this->DatabaseName && !strcmp(this->DatabaseName, dbName))
     {
       // we can't connect to a database we haven't created yet and aren't connected to...
-      this->SetDatabaseName( "template1" );
+      this->SetDatabaseName("template1");
       dropCurrentlyConnected = true;
     }
     bool err = true;
-    if ( this->DatabaseName && this->HostName )
+    if (this->DatabaseName && this->HostName)
     {
       err = this->Open() ? false : true;
     }
-    if ( err )
+    if (err)
     {
-      vtkErrorMacro( "Must be connected to a server to create a database." );
+      vtkErrorMacro("Must be connected to a server to create a database.");
       return false;
     }
   }
 
-  if ( dropExisting )
+  if (dropExisting)
   {
-    this->DropDatabase( dbName );
+    this->DropDatabase(dbName);
   }
 
-  std::string qstr( "CREATE DATABASE \"" );
+  std::string qstr("CREATE DATABASE \"");
   qstr += dbName;
   qstr += "\"";
-  vtkSQLQuery *query = this->GetQueryInstance();
+  vtkSQLQuery* query = this->GetQueryInstance();
   query->SetQuery(qstr.c_str());
   if (query->Execute() == false)
   {
     this->SetLastErrorText(query->GetLastErrorText());
     vtkErrorMacro(
-      "Could not create database \"" << dbName << "\". "
-      << this->GetLastErrorText() << "\n");
+      "Could not create database \"" << dbName << "\". " << this->GetLastErrorText() << "\n");
     query->Delete();
     return false;
   }
 
   query->Delete();
   this->SetLastErrorText(0);
-  if ( dropCurrentlyConnected )
+  if (dropCurrentlyConnected)
   {
-    this->SetDatabaseName( dbName );
+    this->SetDatabaseName(dbName);
     this->Open();
   }
   return true;
 }
 
 // ----------------------------------------------------------------------
-bool vtkPostgreSQLDatabase::DropDatabase( const char* dbName )
+bool vtkPostgreSQLDatabase::DropDatabase(const char* dbName)
 {
-  if ( ! dbName || strlen( dbName ) <= 0 )
+  if (!dbName || strlen(dbName) == 0)
   {
-    vtkErrorMacro( "DropDatabase called with an empty database name" );
+    vtkErrorMacro("DropDatabase called with an empty database name");
     return false;
   }
 
-  if ( ! strcmp( dbName, this->DatabaseName ) )
+  if (!strcmp(dbName, this->DatabaseName))
   {
     // Can't drop database we're connected to... connect to the default db.
-    this->SetDatabaseName( "template1" );
+    this->SetDatabaseName("template1");
   }
 
-  if ( ! this->Connection )
+  if (!this->Connection)
   {
     bool err = true;
-    if ( this->DatabaseName && this->HostName )
+    if (this->DatabaseName && this->HostName)
     {
       err = this->Open() ? false : true;
     }
-    if ( err )
+    if (err)
     {
-      vtkErrorMacro( "Must be connected to a server to create a database." );
+      vtkErrorMacro("Must be connected to a server to create a database.");
       return false;
     }
   }
 
-  std::string qstr( "DROP DATABASE IF EXISTS \"" );
+  std::string qstr("DROP DATABASE IF EXISTS \"");
   qstr += dbName;
   qstr += "\"";
-  vtkSQLQuery *query = this->GetQueryInstance();
+  vtkSQLQuery* query = this->GetQueryInstance();
   query->SetQuery(qstr.c_str());
   if (query->Execute() == false)
   {
     this->SetLastErrorText(query->GetLastErrorText());
-    vtkErrorMacro(<<"Could not drop database \""
-                  << dbName << "\".  "
+    vtkErrorMacro(<< "Could not drop database \"" << dbName << "\".  "
                   << query->GetLastErrorText());
     query->Delete();
     return false;
@@ -657,20 +655,20 @@ bool vtkPostgreSQLDatabase::DropDatabase( const char* dbName )
   return true;
 }
 
-void vtkPostgreSQLDatabase::NullTrailingWhitespace( char* msg )
+void vtkPostgreSQLDatabase::NullTrailingWhitespace(char* msg)
 {
-  // overwrite any blank space at the end of a message with NULL.
+  // overwrite any blank space at the end of a message with nullptr.
   // PostgreSQL error messages are terminated with a newline, which
   // does not work well with VTK's already lengthy error output.
-  int msglen = strlen( msg );
+  int msglen = strlen(msg);
   char* tail = msg + msglen - 1;
-  while ( tail > msg && isspace( *tail ) )
+  while (tail > msg && isspace(*tail))
     *(tail--) = 0;
 }
 
-bool vtkPostgreSQLDatabase::OpenInternal( const char* connectionOptions )
+bool vtkPostgreSQLDatabase::OpenInternal(const char* connectionOptions)
 {
-  assert(this->Connection == NULL);
+  assert(this->Connection == nullptr);
   this->Connection = new vtkPostgreSQLDatabasePrivate;
   this->Connection->Connection = PQconnectdb(connectionOptions);
   if (PQstatus(this->Connection->Connection) == CONNECTION_OK)
@@ -682,8 +680,7 @@ bool vtkPostgreSQLDatabase::OpenInternal( const char* connectionOptions )
   else
   {
     this->SetLastErrorText(PQerrorMessage(this->Connection->Connection));
-    vtkErrorMacro(<<"Unable to open database connection. "
-                  << this->GetLastErrorText());
+    vtkErrorMacro(<< "Unable to open database connection. " << this->GetLastErrorText());
     delete this->Connection;
     this->Connection = 0;
     return false;
@@ -701,12 +698,12 @@ void vtkPostgreSQLDatabase::UpdateDataTypeMap()
 
   this->Connection->DataTypeMap.clear();
 
-  vtkSQLQuery *typeQuery = this->GetQueryInstance();
+  vtkSQLQuery* typeQuery = this->GetQueryInstance();
   typeQuery->SetQuery("SELECT oid, typname, typlen FROM pg_type");
   bool status = typeQuery->Execute();
   if (!status)
   {
-    vtkErrorMacro(<<"I was totally surprised to see the data type query fail.  Error message: "
+    vtkErrorMacro(<< "I was totally surprised to see the data type query fail.  Error message: "
                   << typeQuery->GetLastErrorText());
     typeQuery->Delete();
   }
@@ -724,44 +721,43 @@ void vtkPostgreSQLDatabase::UpdateDataTypeMap()
       name = typeQuery->DataValue(1).ToString();
       len = typeQuery->DataValue(2).ToInt();
 
-      if ( name == "int8" || ( name == "oid" && len == 8 ) )
+      if (name == "int8" || (name == "oid" && len == 8))
       {
-        this->Connection->DataTypeMap[ oid ] = VTK_TYPE_INT64;
+        this->Connection->DataTypeMap[oid] = VTK_TYPE_INT64;
       }
-      else if ( name == "int4" || ( name == "oid" && len == 4 ) )
+      else if (name == "int4" || (name == "oid" && len == 4))
       {
-        this->Connection->DataTypeMap[ oid ] = VTK_TYPE_INT32;
+        this->Connection->DataTypeMap[oid] = VTK_TYPE_INT32;
       }
-      else if ( name == "int2" )
+      else if (name == "int2")
       {
-        this->Connection->DataTypeMap[ oid ] = VTK_TYPE_INT16;
+        this->Connection->DataTypeMap[oid] = VTK_TYPE_INT16;
       }
-      else if ( name == "char" )
+      else if (name == "char")
       {
-        this->Connection->DataTypeMap[ oid ] = VTK_TYPE_INT8;
+        this->Connection->DataTypeMap[oid] = VTK_TYPE_INT8;
       }
-      else if ( name == "time_stamp" )
+      else if (name == "time_stamp")
       {
-        this->Connection->DataTypeMap[ oid ] = VTK_TYPE_INT64;
+        this->Connection->DataTypeMap[oid] = VTK_TYPE_INT64;
       }
-      else if ( name == "float4" )
+      else if (name == "float4")
       {
-        this->Connection->DataTypeMap[ oid ] = VTK_FLOAT;
+        this->Connection->DataTypeMap[oid] = VTK_FLOAT;
       }
-      else if ( name == "float8" )
+      else if (name == "float8")
       {
-        this->Connection->DataTypeMap[ oid ] = VTK_DOUBLE;
+        this->Connection->DataTypeMap[oid] = VTK_DOUBLE;
       }
-      else if ( name == "abstime" || name == "reltime" )
+      else if (name == "abstime" || name == "reltime")
       {
-        this->Connection->DataTypeMap[ oid ] = ( len == 4 ? VTK_TYPE_INT32 : VTK_TYPE_INT64 );
+        this->Connection->DataTypeMap[oid] = (len == 4 ? VTK_TYPE_INT32 : VTK_TYPE_INT64);
       }
-      else if ( name == "text" )
+      else if (name == "text")
       {
-        this->Connection->DataTypeMap[ oid ] = VTK_STRING;
+        this->Connection->DataTypeMap[oid] = VTK_STRING;
       }
     } // done looping over rows
-  } // done with "query is successful"
+  }   // done with "query is successful"
   typeQuery->Delete();
 }
-
