@@ -18,18 +18,13 @@
 
 vtkStandardNewMacro(vtkXMLMultiGroupDataReader);
 //----------------------------------------------------------------------------
-vtkXMLMultiGroupDataReader::vtkXMLMultiGroupDataReader()
-{
-}
+vtkXMLMultiGroupDataReader::vtkXMLMultiGroupDataReader() = default;
 
 //----------------------------------------------------------------------------
-vtkXMLMultiGroupDataReader::~vtkXMLMultiGroupDataReader()
-{
-}
+vtkXMLMultiGroupDataReader::~vtkXMLMultiGroupDataReader() = default;
 
 //----------------------------------------------------------------------------
 void vtkXMLMultiGroupDataReader::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
-
