@@ -25,7 +25,7 @@
 vtkStandardNewMacro(vtkImageAnisotropicDiffusion3D);
 
 //----------------------------------------------------------------------------
-// Construct an instance of vtkImageAnisotropicDiffusion3D fitler.
+// Construct an instance of vtkImageAnisotropicDiffusion3D filter.
 vtkImageAnisotropicDiffusion3D::vtkImageAnisotropicDiffusion3D()
 {
   this->HandleBoundaries = 1;
@@ -44,8 +44,7 @@ vtkImageAnisotropicDiffusion3D::vtkImageAnisotropicDiffusion3D()
 }
 
 //----------------------------------------------------------------------------
-void
-vtkImageAnisotropicDiffusion3D::PrintSelf(ostream& os, vtkIndent indent)
+void vtkImageAnisotropicDiffusion3D::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
   os << indent << "NumberOfIterations: " << this->NumberOfIterations << "\n";
@@ -104,7 +103,7 @@ void vtkImageAnisotropicDiffusion3D::SetNumberOfIterations(int num)
   }
 
   this->Modified();
-  temp = num*2 + 1;
+  temp = num * 2 + 1;
   this->KernelSize[0] = temp;
   this->KernelSize[1] = temp;
   this->KernelSize[2] = temp;
@@ -119,57 +118,49 @@ void vtkImageAnisotropicDiffusion3D::SetNumberOfIterations(int num)
 // This method contains a switch statement that calls the correct
 // templated function for the input region type.  The input and output regions
 // must have the same data type.
-void vtkImageAnisotropicDiffusion3D::ThreadedRequestData(
-  vtkInformation *vtkNotUsed(request),
-  vtkInformationVector **inputVector,
-  vtkInformationVector *vtkNotUsed(outputVector),
-  vtkImageData ***inData,
-  vtkImageData **outData,
-  int outExt[6], int id)
+void vtkImageAnisotropicDiffusion3D::ThreadedRequestData(vtkInformation* vtkNotUsed(request),
+  vtkInformationVector** inputVector, vtkInformationVector* vtkNotUsed(outputVector),
+  vtkImageData*** inData, vtkImageData** outData, int outExt[6], int id)
 {
   int inExt[6], wholeExt[6];
-  double *ar;
+  double* ar;
   int idx;
-  vtkImageData *temp;
+  vtkImageData* temp;
 
-  vtkInformation *inInfo = inputVector[0]->GetInformationObject(0);
+  vtkInformation* inInfo = inputVector[0]->GetInformationObject(0);
   inInfo->Get(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT(), wholeExt);
-  this->InternalRequestUpdateExtent(inExt,outExt,wholeExt);
+  this->InternalRequestUpdateExtent(inExt, outExt, wholeExt);
 
   // this filter expects that input is the same type as output.
   if (inData[0][0]->GetScalarType() != outData[0]->GetScalarType())
   {
-    vtkErrorMacro("Execute: input ScalarType, "
-                  << inData[0][0]->GetScalarType()
-                  << ", must match out ScalarType "
-                  << outData[0]->GetScalarType());
+    vtkErrorMacro("Execute: input ScalarType, " << inData[0][0]->GetScalarType()
+                                                << ", must match out ScalarType "
+                                                << outData[0]->GetScalarType());
     return;
   }
 
   ar = inData[0][0]->GetSpacing();
 
   // make the temporary regions to iterate over.
-  vtkImageData *in = vtkImageData::New();
+  vtkImageData* in = vtkImageData::New();
   in->SetExtent(inExt);
-  in->AllocateScalars(VTK_DOUBLE,
-                      inData[0][0]->GetNumberOfScalarComponents());
-  in->CopyAndCastFrom(inData[0][0],inExt);
+  in->AllocateScalars(VTK_DOUBLE, inData[0][0]->GetNumberOfScalarComponents());
+  in->CopyAndCastFrom(inData[0][0], inExt);
 
-  vtkImageData *out = vtkImageData::New();
+  vtkImageData* out = vtkImageData::New();
   out->SetExtent(inExt);
-  out->AllocateScalars(VTK_DOUBLE,
-                       inData[0][0]->GetNumberOfScalarComponents());
+  out->AllocateScalars(VTK_DOUBLE, inData[0][0]->GetNumberOfScalarComponents());
 
   // Loop performing the diffusion
   // Note: region extent could get smaller as the diffusion progresses
   // (but never get smaller than output region).
-  for (idx = this->NumberOfIterations - 1;
-       !this->AbortExecute && idx >= 0; --idx)
+  for (idx = this->NumberOfIterations - 1; !this->AbortExecute && idx >= 0; --idx)
   {
     if (!id)
     {
-      this->UpdateProgress(static_cast<double>(this->NumberOfIterations - idx)
-                           /this->NumberOfIterations);
+      this->UpdateProgress(
+        static_cast<double>(this->NumberOfIterations - idx) / this->NumberOfIterations);
     }
     this->Iterate(in, out, ar[0], ar[1], ar[2], outExt, idx);
     temp = in;
@@ -178,7 +169,7 @@ void vtkImageAnisotropicDiffusion3D::ThreadedRequestData(
   }
 
   // copy results into output.
-  outData[0]->CopyAndCastFrom(in,outExt);
+  outData[0]->CopyAndCastFrom(in, outExt);
   in->Delete();
   out->Delete();
 }
@@ -187,10 +178,8 @@ void vtkImageAnisotropicDiffusion3D::ThreadedRequestData(
 // This method performs one pass of the diffusion filter.
 // The inData and outData are assumed to have data type double,
 // and have the same extent.
-void vtkImageAnisotropicDiffusion3D::Iterate(vtkImageData *inData,
-                                             vtkImageData *outData,
-                                             double ar0, double ar1, double ar2,
-                                             int *coreExtent, int count)
+void vtkImageAnisotropicDiffusion3D::Iterate(vtkImageData* inData, vtkImageData* outData,
+  double ar0, double ar1, double ar2, int* coreExtent, int count)
 {
   int idx0, idx1, idx2;
   vtkIdType inInc0, inInc1, inInc2;
@@ -210,8 +199,7 @@ void vtkImageAnisotropicDiffusion3D::Iterate(vtkImageData *inData,
   maxC = inData->GetNumberOfScalarComponents();
 
   // Avoid the warnings.
-  th0 = th1 = th2 = th01 = th02 = th12 = th012 =
-    df0 = df1 = df2 = df01 = df02 = df12 = df012 = 0.0;
+  th0 = th1 = th2 = th01 = th02 = th12 = th012 = df0 = df1 = df2 = df01 = df02 = df12 = df012 = 0.0;
 
   // Compute direction specific diffusion thresholds and factors.
   sum = 0.0;
@@ -228,13 +216,13 @@ void vtkImageAnisotropicDiffusion3D::Iterate(vtkImageData *inData,
   }
   if (this->Edges)
   {
-    temp = sqrt(ar0*ar0 + ar1*ar1);
+    temp = sqrt(ar0 * ar0 + ar1 * ar1);
     th01 = temp * this->DiffusionThreshold;
     df01 = 1 / temp;
-    temp = sqrt(ar0*ar0 + ar2*ar2);
+    temp = sqrt(ar0 * ar0 + ar2 * ar2);
     th02 = temp * this->DiffusionThreshold;
     df02 = 1 / temp;
-    temp = sqrt(ar1*ar1 + ar2*ar2);
+    temp = sqrt(ar1 * ar1 + ar2 * ar2);
     th12 = temp * this->DiffusionThreshold;
     df12 = 1 / temp;
     // four edges per plane
@@ -242,7 +230,7 @@ void vtkImageAnisotropicDiffusion3D::Iterate(vtkImageData *inData,
   }
   if (this->Corners)
   {
-    temp = sqrt(ar0*ar0 + ar1*ar1 + ar2*ar2);
+    temp = sqrt(ar0 * ar0 + ar1 * ar1 + ar2 * ar2);
     th012 = temp * this->DiffusionThreshold;
     df012 = 1 / temp;
     // eight corners in a cube
@@ -280,9 +268,8 @@ void vtkImageAnisotropicDiffusion3D::Iterate(vtkImageData *inData,
   min2 = (min2 > inMin2) ? min2 : inMin2;
   max2 = (max2 < inMax2) ? max2 : inMax2;
 
-  vtkDebugMacro(<< "Iteration count: " << count << " ("
-  << min0 << ", " << max0 << ", " << min1 << ", " << max1 << ", "
-  << min2 << ", " << max2 << ")");
+  vtkDebugMacro(<< "Iteration count: " << count << " (" << min0 << ", " << max0 << ", " << min1
+                << ", " << max1 << ", " << min2 << ", " << max2 << ")");
 
   // I apologize for explicitly diffusing each neighbor, but it is the easiest
   // way to deal with the boundary conditions.  Besides it is fast.
@@ -290,21 +277,20 @@ void vtkImageAnisotropicDiffusion3D::Iterate(vtkImageData *inData,
 
   for (idxC = 0; idxC < maxC; idxC++)
   {
-    inPtr2 = static_cast<double *>(inData->GetScalarPointer(min0, min1, min2));
-    outPtr2 =
-      static_cast<double *>(outData->GetScalarPointer(min0, min1, min2));
+    inPtr2 = static_cast<double*>(inData->GetScalarPointer(min0, min1, min2));
+    outPtr2 = static_cast<double*>(outData->GetScalarPointer(min0, min1, min2));
     inPtr2 += idxC;
     outPtr2 += idxC;
 
-    for (idx2 = min2; idx2 <= max2; ++idx2, inPtr2+=inInc2, outPtr2+=outInc2)
+    for (idx2 = min2; idx2 <= max2; ++idx2, inPtr2 += inInc2, outPtr2 += outInc2)
     {
       inPtr1 = inPtr2;
       outPtr1 = outPtr2;
-      for (idx1 = min1; idx1 <= max1; ++idx1, inPtr1+=inInc1, outPtr1+=outInc1)
+      for (idx1 = min1; idx1 <= max1; ++idx1, inPtr1 += inInc1, outPtr1 += outInc1)
       {
         inPtr0 = inPtr1;
         outPtr0 = outPtr1;
-        for (idx0 = min0; idx0 <= max0; ++idx0, inPtr0+=inInc0, outPtr0+=outInc0)
+        for (idx0 = min0; idx0 <= max0; ++idx0, inPtr0 += inInc0, outPtr0 += outInc0)
         {
           // Copy center
           *outPtr0 = *inPtr0;
@@ -314,17 +300,17 @@ void vtkImageAnisotropicDiffusion3D::Iterate(vtkImageData *inData,
           {
             double d0, d1, d2;
             // compute the gradient magnitude (central differences).
-            d0  = (idx0 != inMax0) ? inPtr0[inInc0] : *inPtr0;
+            d0 = (idx0 != inMax0) ? inPtr0[inInc0] : *inPtr0;
             d0 -= (idx0 != inMin0) ? inPtr0[-inInc0] : *inPtr0;
             d0 /= ar0;
-            d1  = (idx1 != inMax1) ? inPtr0[inInc1] : *inPtr0;
+            d1 = (idx1 != inMax1) ? inPtr0[inInc1] : *inPtr0;
             d1 -= (idx1 != inMin1) ? inPtr0[-inInc1] : *inPtr0;
             d1 /= ar1;
-            d2  = (idx2 != inMax2) ? inPtr0[inInc2] : *inPtr0;
+            d2 = (idx2 != inMax2) ? inPtr0[inInc2] : *inPtr0;
             d2 -= (idx2 != inMin2) ? inPtr0[-inInc2] : *inPtr0;
             d2 /= ar2;
             // If magnitude is big, don't diffuse.
-            d0 = sqrt(d0*d0 + d1*d1 + d2*d2);
+            d0 = sqrt(d0 * d0 + d1 * d1 + d2 * d2);
             if (d0 > this->DiffusionThreshold)
             {
               // hack to not diffuse
@@ -401,7 +387,7 @@ void vtkImageAnisotropicDiffusion3D::Iterate(vtkImageData *inData,
             // left up
             if (idx0 != inMin0 && idx1 != inMin1)
             {
-              temp = inPtr0[-inInc0-inInc1] - *inPtr0;
+              temp = inPtr0[-inInc0 - inInc1] - *inPtr0;
               if (fabs(temp) < th01)
               {
                 *outPtr0 += temp * df01;
@@ -410,7 +396,7 @@ void vtkImageAnisotropicDiffusion3D::Iterate(vtkImageData *inData,
             // right up
             if (idx0 != inMax0 && idx1 != inMin1)
             {
-              temp = inPtr0[inInc0-inInc1] - *inPtr0;
+              temp = inPtr0[inInc0 - inInc1] - *inPtr0;
               if (fabs(temp) < th01)
               {
                 *outPtr0 += temp * df01;
@@ -419,7 +405,7 @@ void vtkImageAnisotropicDiffusion3D::Iterate(vtkImageData *inData,
             // left down
             if (idx0 != inMin0 && idx1 != inMax1)
             {
-              temp = inPtr0[-inInc0+inInc1] - *inPtr0;
+              temp = inPtr0[-inInc0 + inInc1] - *inPtr0;
               if (fabs(temp) < th01)
               {
                 *outPtr0 += temp * df01;
@@ -428,7 +414,7 @@ void vtkImageAnisotropicDiffusion3D::Iterate(vtkImageData *inData,
             // right down
             if (idx0 != inMax0 && idx1 != inMax1)
             {
-              temp = inPtr0[inInc0+inInc1] - *inPtr0;
+              temp = inPtr0[inInc0 + inInc1] - *inPtr0;
               if (fabs(temp) < th01)
               {
                 *outPtr0 += temp * df01;
@@ -438,7 +424,7 @@ void vtkImageAnisotropicDiffusion3D::Iterate(vtkImageData *inData,
             // left in
             if (idx0 != inMin0 && idx2 != inMin2)
             {
-              temp = inPtr0[-inInc0-inInc2] - *inPtr0;
+              temp = inPtr0[-inInc0 - inInc2] - *inPtr0;
               if (fabs(temp) < th02)
               {
                 *outPtr0 += temp * df02;
@@ -447,7 +433,7 @@ void vtkImageAnisotropicDiffusion3D::Iterate(vtkImageData *inData,
             // right in
             if (idx0 != inMax0 && idx2 != inMin2)
             {
-              temp = inPtr0[inInc0-inInc2] - *inPtr0;
+              temp = inPtr0[inInc0 - inInc2] - *inPtr0;
               if (fabs(temp) < th02)
               {
                 *outPtr0 += temp * df02;
@@ -456,7 +442,7 @@ void vtkImageAnisotropicDiffusion3D::Iterate(vtkImageData *inData,
             // left out
             if (idx0 != inMin0 && idx2 != inMax2)
             {
-              temp = inPtr0[-inInc0+inInc2] - *inPtr0;
+              temp = inPtr0[-inInc0 + inInc2] - *inPtr0;
               if (fabs(temp) < th02)
               {
                 *outPtr0 += temp * df02;
@@ -465,7 +451,7 @@ void vtkImageAnisotropicDiffusion3D::Iterate(vtkImageData *inData,
             // right out
             if (idx0 != inMax0 && idx2 != inMax2)
             {
-              temp = inPtr0[inInc0+inInc2] - *inPtr0;
+              temp = inPtr0[inInc0 + inInc2] - *inPtr0;
               if (fabs(temp) < th02)
               {
                 *outPtr0 += temp * df02;
@@ -475,7 +461,7 @@ void vtkImageAnisotropicDiffusion3D::Iterate(vtkImageData *inData,
             // up in
             if (idx1 != inMin1 && idx2 != inMin2)
             {
-              temp = inPtr0[-inInc1-inInc2] - *inPtr0;
+              temp = inPtr0[-inInc1 - inInc2] - *inPtr0;
               if (fabs(temp) < th12)
               {
                 *outPtr0 += temp * df12;
@@ -484,7 +470,7 @@ void vtkImageAnisotropicDiffusion3D::Iterate(vtkImageData *inData,
             // down in
             if (idx1 != inMax1 && idx2 != inMin2)
             {
-              temp = inPtr0[inInc1-inInc2] - *inPtr0;
+              temp = inPtr0[inInc1 - inInc2] - *inPtr0;
               if (fabs(temp) < th12)
               {
                 *outPtr0 += temp * df12;
@@ -493,7 +479,7 @@ void vtkImageAnisotropicDiffusion3D::Iterate(vtkImageData *inData,
             // up out
             if (idx1 != inMin1 && idx2 != inMax2)
             {
-              temp = inPtr0[-inInc1+inInc2] - *inPtr0;
+              temp = inPtr0[-inInc1 + inInc2] - *inPtr0;
               if (fabs(temp) < th12)
               {
                 *outPtr0 += temp * df12;
@@ -502,7 +488,7 @@ void vtkImageAnisotropicDiffusion3D::Iterate(vtkImageData *inData,
             // down out
             if (idx1 != inMax1 && idx2 != inMax2)
             {
-              temp = inPtr0[inInc1+inInc2] - *inPtr0;
+              temp = inPtr0[inInc1 + inInc2] - *inPtr0;
               if (fabs(temp) < th12)
               {
                 *outPtr0 += temp * df12;
@@ -515,7 +501,7 @@ void vtkImageAnisotropicDiffusion3D::Iterate(vtkImageData *inData,
             // left up in
             if (idx0 != inMin0 && idx1 != inMin1 && idx2 != inMin2)
             {
-              temp = inPtr0[-inInc0-inInc1-inInc2] - *inPtr0;
+              temp = inPtr0[-inInc0 - inInc1 - inInc2] - *inPtr0;
               if (fabs(temp) < th012)
               {
                 *outPtr0 += temp * df012;
@@ -524,7 +510,7 @@ void vtkImageAnisotropicDiffusion3D::Iterate(vtkImageData *inData,
             // right up in
             if (idx0 != inMax0 && idx1 != inMin1 && idx2 != inMin2)
             {
-              temp = inPtr0[inInc0-inInc1-inInc2] - *inPtr0;
+              temp = inPtr0[inInc0 - inInc1 - inInc2] - *inPtr0;
               if (fabs(temp) < th012)
               {
                 *outPtr0 += temp * df012;
@@ -533,7 +519,7 @@ void vtkImageAnisotropicDiffusion3D::Iterate(vtkImageData *inData,
             // left down in
             if (idx0 != inMin0 && idx1 != inMax1 && idx2 != inMin2)
             {
-              temp = inPtr0[-inInc0+inInc1-inInc2] - *inPtr0;
+              temp = inPtr0[-inInc0 + inInc1 - inInc2] - *inPtr0;
               if (fabs(temp) < th012)
               {
                 *outPtr0 += temp * df012;
@@ -542,7 +528,7 @@ void vtkImageAnisotropicDiffusion3D::Iterate(vtkImageData *inData,
             // right down in
             if (idx0 != inMax0 && idx1 != inMax1 && idx2 != inMin2)
             {
-              temp = inPtr0[inInc0+inInc1-inInc2] - *inPtr0;
+              temp = inPtr0[inInc0 + inInc1 - inInc2] - *inPtr0;
               if (fabs(temp) < th012)
               {
                 *outPtr0 += temp * df012;
@@ -551,7 +537,7 @@ void vtkImageAnisotropicDiffusion3D::Iterate(vtkImageData *inData,
             // left up out
             if (idx0 != inMin0 && idx1 != inMin1 && idx2 != inMax2)
             {
-              temp = inPtr0[-inInc0-inInc1+inInc2] - *inPtr0;
+              temp = inPtr0[-inInc0 - inInc1 + inInc2] - *inPtr0;
               if (fabs(temp) < th012)
               {
                 *outPtr0 += temp * df012;
@@ -560,7 +546,7 @@ void vtkImageAnisotropicDiffusion3D::Iterate(vtkImageData *inData,
             // right up out
             if (idx0 != inMax0 && idx1 != inMin1 && idx2 != inMax2)
             {
-              temp = inPtr0[inInc0-inInc1+inInc2] - *inPtr0;
+              temp = inPtr0[inInc0 - inInc1 + inInc2] - *inPtr0;
               if (fabs(temp) < th012)
               {
                 *outPtr0 += temp * df012;
@@ -569,7 +555,7 @@ void vtkImageAnisotropicDiffusion3D::Iterate(vtkImageData *inData,
             // left down out
             if (idx0 != inMin0 && idx1 != inMax1 && idx2 != inMax2)
             {
-              temp = inPtr0[-inInc0+inInc1+inInc2] - *inPtr0;
+              temp = inPtr0[-inInc0 + inInc1 + inInc2] - *inPtr0;
               if (fabs(temp) < th012)
               {
                 *outPtr0 += temp * df012;
@@ -578,7 +564,7 @@ void vtkImageAnisotropicDiffusion3D::Iterate(vtkImageData *inData,
             // right down out
             if (idx0 != inMax0 && idx1 != inMax1 && idx2 != inMax2)
             {
-              temp = inPtr0[inInc0+inInc1+inInc2] - *inPtr0;
+              temp = inPtr0[inInc0 + inInc1 + inInc2] - *inPtr0;
               if (fabs(temp) < th012)
               {
                 *outPtr0 += temp * df012;
