@@ -14,7 +14,8 @@
 =========================================================================*/
 /**
  * @class   vtkInteractorStyleRubberBandPick
- * @brief   Like TrackBallCamera, but this can pick props underneath a rubber band selection rectangle.
+ * @brief   Like TrackBallCamera, but this can pick props underneath a rubber band selection
+ * rectangle.
  *
  *
  * This interactor style allows the user to draw a rectangle in the render
@@ -27,7 +28,7 @@
  *
  * @sa
  * vtkAreaPicker
-*/
+ */
 
 #ifndef vtkInteractorStyleRubberBandPick_h
 #define vtkInteractorStyleRubberBandPick_h
@@ -37,12 +38,13 @@
 
 class vtkUnsignedCharArray;
 
-class VTKINTERACTIONSTYLE_EXPORT vtkInteractorStyleRubberBandPick : public vtkInteractorStyleTrackballCamera
+class VTKINTERACTIONSTYLE_EXPORT vtkInteractorStyleRubberBandPick
+  : public vtkInteractorStyleTrackballCamera
 {
 public:
-  static vtkInteractorStyleRubberBandPick *New();
+  static vtkInteractorStyleRubberBandPick* New();
   vtkTypeMacro(vtkInteractorStyleRubberBandPick, vtkInteractorStyleTrackballCamera);
-  void PrintSelf(ostream& os, vtkIndent indent);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
   void StartSelect();
 
@@ -50,15 +52,15 @@ public:
   /**
    * Event bindings
    */
-  virtual void OnMouseMove();
-  virtual void OnLeftButtonDown();
-  virtual void OnLeftButtonUp();
-  virtual void OnChar();
+  void OnMouseMove() override;
+  void OnLeftButtonDown() override;
+  void OnLeftButtonUp() override;
+  void OnChar() override;
   //@}
 
 protected:
   vtkInteractorStyleRubberBandPick();
-  ~vtkInteractorStyleRubberBandPick();
+  ~vtkInteractorStyleRubberBandPick() override;
 
   virtual void Pick();
   void RedrawRubberBand();
@@ -68,13 +70,13 @@ protected:
 
   int Moving;
 
-  vtkUnsignedCharArray *PixelArray;
+  vtkUnsignedCharArray* PixelArray;
 
   int CurrentMode;
 
 private:
-  vtkInteractorStyleRubberBandPick(const vtkInteractorStyleRubberBandPick&) VTK_DELETE_FUNCTION;
-  void operator=(const vtkInteractorStyleRubberBandPick&) VTK_DELETE_FUNCTION;
+  vtkInteractorStyleRubberBandPick(const vtkInteractorStyleRubberBandPick&) = delete;
+  void operator=(const vtkInteractorStyleRubberBandPick&) = delete;
 };
 
 #endif
