@@ -14,16 +14,16 @@
 =========================================================================*/
 #include "vtkCaptionRepresentation.h"
 #include "vtkCaptionActor2D.h"
-#include "vtkPointHandleRepresentation3D.h"
 #include "vtkConeSource.h"
-#include "vtkTextProperty.h"
 #include "vtkObjectFactory.h"
-#include "vtkRenderer.h"
-#include "vtkRenderWindowInteractor.h"
+#include "vtkPointHandleRepresentation3D.h"
 #include "vtkPointWidget.h"
 #include "vtkRenderWindow.h"
+#include "vtkRenderWindowInteractor.h"
+#include "vtkRenderer.h"
 #include "vtkTextActor.h"
 #include "vtkTextMapper.h"
+#include "vtkTextProperty.h"
 #include "vtkTextRenderer.h"
 
 vtkStandardNewMacro(vtkCaptionRepresentation);
@@ -40,22 +40,21 @@ vtkCaptionRepresentation::vtkCaptionRepresentation()
 
   this->CaptionActor2D = vtkCaptionActor2D::New();
   this->CaptionActor2D->GetPositionCoordinate()->SetCoordinateSystemToDisplay();
-  this->CaptionActor2D->GetPositionCoordinate()->SetReferenceCoordinate(0);
+  this->CaptionActor2D->GetPositionCoordinate()->SetReferenceCoordinate(nullptr);
   this->CaptionActor2D->GetPosition2Coordinate()->SetCoordinateSystemToDisplay();
-  this->CaptionActor2D->GetPosition2Coordinate()->SetReferenceCoordinate(0);
-  this->CaptionActor2D->GetPositionCoordinate()->SetValue(10,10);
-  this->CaptionActor2D->GetPosition2Coordinate()->SetValue(20,20);
+  this->CaptionActor2D->GetPosition2Coordinate()->SetReferenceCoordinate(nullptr);
+  this->CaptionActor2D->GetPositionCoordinate()->SetValue(10, 10);
+  this->CaptionActor2D->GetPosition2Coordinate()->SetValue(20, 20);
   this->CaptionActor2D->SetCaption("Caption Here");
-  this->CaptionActor2D->SetAttachmentPoint(0,0,0);
+  this->CaptionActor2D->SetAttachmentPoint(0, 0, 0);
   this->CaptionActor2D->BorderOn();
   this->CaptionActor2D->LeaderOn();
   this->CaptionActor2D->ThreeDimensionalLeaderOn();
 
   this->CaptionGlyph = vtkConeSource::New();
   this->CaptionGlyph->SetResolution(6);
-  this->CaptionGlyph->SetCenter(-0.5,0,0);
-  this->CaptionActor2D->SetLeaderGlyphConnection(
-    this->CaptionGlyph->GetOutputPort());
+  this->CaptionGlyph->SetCenter(-0.5, 0, 0);
+  this->CaptionActor2D->SetLeaderGlyphConnection(this->CaptionGlyph->GetOutputPort());
 
   this->SetShowBorder(vtkBorderRepresentation::BORDER_OFF);
   this->FontFactor = 1.0;
@@ -64,52 +63,51 @@ vtkCaptionRepresentation::vtkCaptionRepresentation()
 //-------------------------------------------------------------------------
 vtkCaptionRepresentation::~vtkCaptionRepresentation()
 {
-  this->SetCaptionActor2D(0);
+  this->SetCaptionActor2D(nullptr);
   this->CaptionGlyph->Delete();
-  this->SetAnchorRepresentation(0);
+  this->SetAnchorRepresentation(nullptr);
 }
 
 //-------------------------------------------------------------------------
-void vtkCaptionRepresentation::SetCaptionActor2D(vtkCaptionActor2D *capActor)
+void vtkCaptionRepresentation::SetCaptionActor2D(vtkCaptionActor2D* capActor)
 {
-  if ( capActor != this->CaptionActor2D )
+  if (capActor != this->CaptionActor2D)
   {
-    if ( this->CaptionActor2D )
+    if (this->CaptionActor2D)
     {
       this->CaptionActor2D->Delete();
     }
     this->CaptionActor2D = capActor;
-    if ( this->CaptionActor2D )
+    if (this->CaptionActor2D)
     {
       this->CaptionActor2D->Register(this);
       this->CaptionActor2D->GetPositionCoordinate()->SetCoordinateSystemToDisplay();
-      this->CaptionActor2D->GetPositionCoordinate()->SetReferenceCoordinate(0);
+      this->CaptionActor2D->GetPositionCoordinate()->SetReferenceCoordinate(nullptr);
       this->CaptionActor2D->GetPosition2Coordinate()->SetCoordinateSystemToDisplay();
-      this->CaptionActor2D->GetPosition2Coordinate()->SetReferenceCoordinate(0);
-      this->CaptionActor2D->GetPositionCoordinate()->SetValue(10,10);
-      this->CaptionActor2D->GetPosition2Coordinate()->SetValue(20,20);
-      this->CaptionActor2D->SetAttachmentPoint(0,0,0);
+      this->CaptionActor2D->GetPosition2Coordinate()->SetReferenceCoordinate(nullptr);
+      this->CaptionActor2D->GetPositionCoordinate()->SetValue(10, 10);
+      this->CaptionActor2D->GetPosition2Coordinate()->SetValue(20, 20);
+      this->CaptionActor2D->SetAttachmentPoint(0, 0, 0);
       this->CaptionActor2D->BorderOn();
       this->CaptionActor2D->LeaderOn();
       this->CaptionActor2D->ThreeDimensionalLeaderOn();
-      this->CaptionActor2D->SetLeaderGlyphConnection(
-        this->CaptionGlyph->GetOutputPort());
+      this->CaptionActor2D->SetLeaderGlyphConnection(this->CaptionGlyph->GetOutputPort());
     }
     this->Modified();
   }
 }
 
 //-------------------------------------------------------------------------
-void vtkCaptionRepresentation::SetAnchorRepresentation(vtkPointHandleRepresentation3D *rep)
+void vtkCaptionRepresentation::SetAnchorRepresentation(vtkPointHandleRepresentation3D* rep)
 {
-  if ( rep != this->AnchorRepresentation )
+  if (rep != this->AnchorRepresentation)
   {
-    if ( this->AnchorRepresentation )
+    if (this->AnchorRepresentation)
     {
       this->AnchorRepresentation->Delete();
     }
     this->AnchorRepresentation = rep;
-    if ( this->AnchorRepresentation )
+    if (this->AnchorRepresentation)
     {
       this->AnchorRepresentation->Register(this);
     }
@@ -133,10 +131,9 @@ void vtkCaptionRepresentation::GetAnchorPosition(double pos[3])
 //-------------------------------------------------------------------------
 void vtkCaptionRepresentation::BuildRepresentation()
 {
-  if ( this->GetMTime() > this->BuildTime ||
-       this->CaptionActor2D->GetMTime() > this->BuildTime ||
-       (this->Renderer && this->Renderer->GetVTKWindow() &&
-        this->Renderer->GetVTKWindow()->GetMTime() > this->BuildTime) )
+  if (this->GetMTime() > this->BuildTime || this->CaptionActor2D->GetMTime() > this->BuildTime ||
+    (this->Renderer && this->Renderer->GetVTKWindow() &&
+      this->Renderer->GetVTKWindow()->GetMTime() > this->BuildTime))
   {
 
     // If the text actor's text scaling is off, we still want to be able
@@ -144,36 +141,32 @@ void vtkCaptionRepresentation::BuildRepresentation()
     // *relative* font size factor. We will also need to change the
     // caption's boundary size accordingly.
 
-    if(!this->Moving && this->CaptionActor2D
-        && this->CaptionActor2D->GetCaption()
-        && (this->CaptionActor2D->GetTextActor()->GetTextScaleMode()
-            == vtkTextActor::TEXT_SCALE_MODE_NONE ))
+    if (!this->Moving && this->CaptionActor2D && this->CaptionActor2D->GetCaption() &&
+      (this->CaptionActor2D->GetTextActor()->GetTextScaleMode() ==
+        vtkTextActor::TEXT_SCALE_MODE_NONE))
     {
       // Create a dummy text mapper for getting font sizes
-      vtkTextMapper *textMapper = vtkTextMapper::New();
-      vtkTextProperty *tprop = textMapper->GetTextProperty();
+      vtkTextMapper* textMapper = vtkTextMapper::New();
+      vtkTextProperty* tprop = textMapper->GetTextProperty();
 
       tprop->ShallowCopy(this->CaptionActor2D->GetCaptionTextProperty());
       textMapper->SetInput(this->CaptionActor2D->GetCaption());
       int textsize[2];
-      int fsize = vtkTextMapper::SetRelativeFontSize(textMapper,
-        this->Renderer, this->Renderer->GetSize(), textsize,
-        0.015*this->FontFactor);
+      int fsize = vtkTextMapper::SetRelativeFontSize(
+        textMapper, this->Renderer, this->Renderer->GetSize(), textsize, 0.015 * this->FontFactor);
       this->CaptionActor2D->GetCaptionTextProperty()->SetFontSize(fsize);
       textMapper->Delete();
       this->AdjustCaptionBoundary();
     }
 
     // Ask the superclass the size and set the caption
-    int *pos1 = this->PositionCoordinate->
-      GetComputedDisplayValue(this->Renderer);
-    int *pos2 = this->Position2Coordinate->
-      GetComputedDisplayValue(this->Renderer);
+    int* pos1 = this->PositionCoordinate->GetComputedDisplayValue(this->Renderer);
+    int* pos2 = this->Position2Coordinate->GetComputedDisplayValue(this->Renderer);
 
-    if ( this->CaptionActor2D )
+    if (this->CaptionActor2D)
     {
-      this->CaptionActor2D->GetPositionCoordinate()->SetValue(pos1[0],pos1[1]);
-      this->CaptionActor2D->GetPosition2Coordinate()->SetValue(pos2[0],pos2[1]);
+      this->CaptionActor2D->GetPositionCoordinate()->SetValue(pos1[0], pos1[1]);
+      this->CaptionActor2D->GetPosition2Coordinate()->SetValue(pos2[0], pos2[1]);
     }
 
     // Note that the transform is updated by the superclass
@@ -184,28 +177,27 @@ void vtkCaptionRepresentation::BuildRepresentation()
 //----------------------------------------------------------------------------
 void vtkCaptionRepresentation::AdjustCaptionBoundary()
 {
-  if(this->CaptionActor2D->GetCaption())
+  if (this->CaptionActor2D->GetCaption())
   {
     vtkTextRenderer* tren = vtkTextRenderer::GetInstance();
     if (!tren)
     {
-      vtkErrorMacro(<<"Failed getting the vtkTextRenderer instance");
+      vtkErrorMacro(<< "Failed getting the vtkTextRenderer instance");
       return;
     }
 
-    vtkWindow *win = this->Renderer->GetVTKWindow();
+    vtkWindow* win = this->Renderer->GetVTKWindow();
     if (!win)
     {
-      vtkErrorMacro(<<"No render window available: cannot determine DPI.");
+      vtkErrorMacro(<< "No render window available: cannot determine DPI.");
       return;
     }
 
     int text_bbox[4];
     if (!tren->GetBoundingBox(this->CaptionActor2D->GetCaptionTextProperty(),
-                              this->CaptionActor2D->GetCaption(), text_bbox,
-                              win->GetDPI()))
+          this->CaptionActor2D->GetCaption(), text_bbox, win->GetDPI()))
     {
-      vtkErrorMacro(<<"Error calculating caption bounding box.");
+      vtkErrorMacro(<< "Error calculating caption bounding box.");
       return;
     }
 
@@ -217,15 +209,15 @@ void vtkCaptionRepresentation::AdjustCaptionBoundary()
     text_size[0] = (text_bbox[1] - text_bbox[0] + 5);
     text_size[1] = (text_bbox[3] - text_bbox[2] + 5);
 
-    this->GetRenderer()->DisplayToNormalizedDisplay (text_size[0], text_size[1]);
-    this->GetRenderer()->NormalizedDisplayToViewport (text_size[0], text_size[1]);
-    this->GetRenderer()->ViewportToNormalizedViewport (text_size[0], text_size[1]);
+    this->GetRenderer()->DisplayToNormalizedDisplay(text_size[0], text_size[1]);
+    this->GetRenderer()->NormalizedDisplayToViewport(text_size[0], text_size[1]);
+    this->GetRenderer()->ViewportToNormalizedViewport(text_size[0], text_size[1]);
 
     // update the PositionCoordinate
-    //this->NeedToAdjustSize = 1;
+    // this->NeedToAdjustSize = 1;
 
     double* pos2 = this->Position2Coordinate->GetValue();
-    if(pos2[0] != text_size[0] || pos2[1] != text_size[1])
+    if (pos2[0] != text_size[0] || pos2[1] != text_size[1])
     {
       this->Position2Coordinate->SetValue(text_size[0], text_size[1], 0);
       this->Modified();
@@ -234,21 +226,21 @@ void vtkCaptionRepresentation::AdjustCaptionBoundary()
 }
 
 //-------------------------------------------------------------------------
-void vtkCaptionRepresentation::GetActors2D(vtkPropCollection *pc)
+void vtkCaptionRepresentation::GetActors2D(vtkPropCollection* pc)
 {
   pc->AddItem(this->CaptionActor2D);
   this->Superclass::GetActors2D(pc);
 }
 
 //-------------------------------------------------------------------------
-void vtkCaptionRepresentation::ReleaseGraphicsResources(vtkWindow *w)
+void vtkCaptionRepresentation::ReleaseGraphicsResources(vtkWindow* w)
 {
   this->CaptionActor2D->ReleaseGraphicsResources(w);
   this->Superclass::ReleaseGraphicsResources(w);
 }
 
 //-------------------------------------------------------------------------
-int vtkCaptionRepresentation::RenderOverlay(vtkViewport *w)
+int vtkCaptionRepresentation::RenderOverlay(vtkViewport* w)
 {
   this->BuildRepresentation();
   int count = this->Superclass::RenderOverlay(w);
@@ -257,7 +249,7 @@ int vtkCaptionRepresentation::RenderOverlay(vtkViewport *w)
 }
 
 //-------------------------------------------------------------------------
-int vtkCaptionRepresentation::RenderOpaqueGeometry(vtkViewport *w)
+int vtkCaptionRepresentation::RenderOpaqueGeometry(vtkViewport* w)
 {
   this->BuildRepresentation();
   int count = this->Superclass::RenderOpaqueGeometry(w);
@@ -266,7 +258,7 @@ int vtkCaptionRepresentation::RenderOpaqueGeometry(vtkViewport *w)
 }
 
 //-------------------------------------------------------------------------
-int vtkCaptionRepresentation::RenderTranslucentPolygonalGeometry(vtkViewport *w)
+int vtkCaptionRepresentation::RenderTranslucentPolygonalGeometry(vtkViewport* w)
 {
   this->BuildRepresentation();
   int count = this->Superclass::RenderTranslucentPolygonalGeometry(w);
@@ -277,7 +269,7 @@ int vtkCaptionRepresentation::RenderTranslucentPolygonalGeometry(vtkViewport *w)
 //-----------------------------------------------------------------------------
 // Description:
 // Does this prop have some translucent polygonal geometry?
-int vtkCaptionRepresentation::HasTranslucentPolygonalGeometry()
+vtkTypeBool vtkCaptionRepresentation::HasTranslucentPolygonalGeometry()
 {
   this->BuildRepresentation();
   int result = this->Superclass::HasTranslucentPolygonalGeometry();
@@ -288,11 +280,11 @@ int vtkCaptionRepresentation::HasTranslucentPolygonalGeometry()
 //-------------------------------------------------------------------------
 void vtkCaptionRepresentation::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 
   os << indent << "Caption Actor: " << this->CaptionActor2D << "\n";
   os << indent << "Font Factor: " << this->FontFactor << "\n";
 
   os << indent << "Anchor Representation:\n";
-  this->AnchorRepresentation->PrintSelf(os,indent.GetNextIndent());
+  this->AnchorRepresentation->PrintSelf(os, indent.GetNextIndent());
 }
