@@ -13,21 +13,20 @@
 
 =========================================================================*/
 #include "vtkOrientedPolygonalHandleRepresentation3D.h"
-#include "vtkPolyDataMapper.h"
 #include "vtkActor.h"
-#include "vtkCellPicker.h"
-#include "vtkRenderer.h"
-#include "vtkObjectFactory.h"
-#include "vtkProperty.h"
 #include "vtkCamera.h"
-#include "vtkTransformPolyDataFilter.h"
+#include "vtkCellPicker.h"
 #include "vtkFollower.h"
+#include "vtkObjectFactory.h"
+#include "vtkPolyDataMapper.h"
+#include "vtkProperty.h"
+#include "vtkRenderer.h"
+#include "vtkTransformPolyDataFilter.h"
 
 vtkStandardNewMacro(vtkOrientedPolygonalHandleRepresentation3D);
 
 //----------------------------------------------------------------------
-vtkOrientedPolygonalHandleRepresentation3D
-::vtkOrientedPolygonalHandleRepresentation3D()
+vtkOrientedPolygonalHandleRepresentation3D ::vtkOrientedPolygonalHandleRepresentation3D()
 {
   this->Actor = vtkFollower::New();
   this->Actor->SetMapper(this->Mapper);
@@ -36,10 +35,8 @@ vtkOrientedPolygonalHandleRepresentation3D
 }
 
 //----------------------------------------------------------------------
-vtkOrientedPolygonalHandleRepresentation3D
-::~vtkOrientedPolygonalHandleRepresentation3D()
-{
-}
+vtkOrientedPolygonalHandleRepresentation3D ::~vtkOrientedPolygonalHandleRepresentation3D() =
+  default;
 
 //----------------------------------------------------------------------
 void vtkOrientedPolygonalHandleRepresentation3D::UpdateHandle()
@@ -49,22 +46,21 @@ void vtkOrientedPolygonalHandleRepresentation3D::UpdateHandle()
   // Our handle actor is a follower. It follows the camera set on it.
   if (this->Renderer)
   {
-    vtkFollower *follower = vtkFollower::SafeDownCast(this->Actor);
+    vtkFollower* follower = vtkFollower::SafeDownCast(this->Actor);
     if (follower)
     {
-      follower->SetCamera( this->Renderer->GetActiveCamera() );
+      follower->SetCamera(this->Renderer->GetActiveCamera());
     }
   }
 
   // Update the actor position
   double handlePosition[3];
-  this->GetWorldPosition( handlePosition );
-  this->Actor->SetPosition( handlePosition );
+  this->GetWorldPosition(handlePosition);
+  this->Actor->SetPosition(handlePosition);
 }
 
 //----------------------------------------------------------------------
 void vtkOrientedPolygonalHandleRepresentation3D::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 }
-
