@@ -12,6 +12,7 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
+#include "vtkSphereRepresentation.h"
 #include "vtkActor.h"
 #include "vtkActor2D.h"
 #include "vtkAssemblyPath.h"
@@ -33,13 +34,14 @@
 #include "vtkRenderWindowInteractor.h"
 #include "vtkRenderer.h"
 #include "vtkSphere.h"
-#include "vtkSphereRepresentation.h"
 #include "vtkSphereSource.h"
 #include "vtkTextMapper.h"
 #include "vtkTextProperty.h"
 #include "vtkTransform.h"
 #include "vtkWindow.h"
 
+#include <assert.h>
+
 vtkStandardNewMacro(vtkSphereRepresentation);
 
 //----------------------------------------------------------------------------
@@ -55,12 +57,12 @@ vtkSphereRepresentation::vtkSphereRepresentation()
   this->Representation = VTK_SPHERE_WIREFRAME;
 
   // Set up the initial properties
-  this->SphereProperty = NULL;
-  this->SelectedSphereProperty = NULL;
-  this->HandleProperty = NULL;
-  this->SelectedHandleProperty = NULL;
-  this->HandleTextProperty = NULL;
-  this->RadialLineProperty = NULL;
+  this->SphereProperty = nullptr;
+  this->SelectedSphereProperty = nullptr;
+  this->HandleProperty = nullptr;
+  this->SelectedHandleProperty = nullptr;
+  this->HandleTextProperty = nullptr;
+  this->RadialLineProperty = nullptr;
   this->CreateDefaultProperties();
 
   // Build the representation of the widget
@@ -70,8 +72,7 @@ vtkSphereRepresentation::vtkSphereRepresentation()
   this->SphereSource->SetPhiResolution(8);
   this->SphereSource->LatLongTessellationOn();
   this->SphereMapper = vtkPolyDataMapper::New();
-  this->SphereMapper->SetInputConnection(
-    this->SphereSource->GetOutputPort());
+  this->SphereMapper->SetInputConnection(this->SphereSource->GetOutputPort());
   this->SphereActor = vtkActor::New();
   this->SphereActor->SetMapper(this->SphereMapper);
 
@@ -84,12 +85,10 @@ vtkSphereRepresentation::vtkSphereRepresentation()
   this->HandleSource->SetThetaResolution(16);
   this->HandleSource->SetPhiResolution(8);
   this->HandleMapper = vtkPolyDataMapper::New();
-  this->HandleMapper->SetInputConnection(
-    this->HandleSource->GetOutputPort());
+  this->HandleMapper->SetInputConnection(this->HandleSource->GetOutputPort());
   this->HandleActor = vtkActor::New();
   this->HandleActor->SetMapper(this->HandleMapper);
 
-
   // Manage the handle label
   this->HandleText = 1;
   this->HandleTextMapper = vtkTextMapper::New();
@@ -115,8 +114,7 @@ vtkSphereRepresentation::vtkSphereRepresentation()
   this->CenterCursorSource->AxesOn();
   this->CenterCursorSource->TranslationModeOn();
   this->CenterMapper = vtkPolyDataMapper::New();
-  this->CenterMapper->SetInputConnection(
-    this->CenterCursorSource->GetOutputPort());
+  this->CenterMapper->SetInputConnection(this->CenterCursorSource->GetOutputPort());
   this->CenterActor = vtkActor::New();
   this->CenterActor->SetMapper(this->CenterMapper);
 
@@ -134,7 +132,7 @@ vtkSphereRepresentation::vtkSphereRepresentation()
 
   // Manage the picking stuff
   this->HandlePicker = vtkCellPicker::New();
-  this->HandlePicker->SetTolerance(0.005); //need some fluff
+  this->HandlePicker->SetTolerance(0.005); // need some fluff
   this->HandlePicker->AddPickList(this->HandleActor);
   this->HandlePicker->PickFromListOn();
 
@@ -145,6 +143,8 @@ vtkSphereRepresentation::vtkSphereRepresentation()
 
   this->SphereActor->SetProperty(this->SphereProperty);
   this->HandleActor->SetProperty(this->HandleProperty);
+
+  this->TranslationAxis = Axis::NONE;
 }
 
 //----------------------------------------------------------------------------
@@ -177,32 +177,33 @@ vtkSphereRepresentation::~vtkSphereRepresentation()
   this->CenterMapper->Delete();
   this->CenterActor->Delete();
 
-  if ( this->SphereProperty )
+  if (this->SphereProperty)
   {
     this->SphereProperty->Delete();
   }
-  if ( this->SelectedSphereProperty )
+  if (this->SelectedSphereProperty)
   {
     this->SelectedSphereProperty->Delete();
   }
-  if ( this->HandleProperty )
+  if (this->HandleProperty)
   {
     this->HandleProperty->Delete();
   }
-  if ( this->SelectedHandleProperty )
+  if (this->SelectedHandleProperty)
   {
     this->SelectedHandleProperty->Delete();
   }
 }
 
 //----------------------------------------------------------------------
-void vtkSphereRepresentation::GetPolyData(vtkPolyData *pd)
+void vtkSphereRepresentation::GetPolyData(vtkPolyData* pd)
 {
+  this->SphereSource->Update();
   pd->ShallowCopy(this->SphereSource->GetOutput());
 }
 
 //----------------------------------------------------------------------
-void vtkSphereRepresentation::GetSphere(vtkSphere *sphere)
+void vtkSphereRepresentation::GetSphere(vtkSphere* sphere)
 {
   sphere->SetRadius(this->SphereSource->GetRadius());
   sphere->SetCenter(this->SphereSource->GetCenter());
@@ -211,7 +212,7 @@ void vtkSphereRepresentation::GetSphere(vtkSphere *sphere)
 //----------------------------------------------------------------------
 void vtkSphereRepresentation::HighlightSphere(int highlight)
 {
-  if ( highlight )
+  if (highlight)
   {
     this->ValidPick = 1;
     this->SphereActor->SetProperty(this->SelectedSphereProperty);
@@ -225,7 +226,7 @@ void vtkSphereRepresentation::HighlightSphere(int highlight)
 //----------------------------------------------------------------------
 void vtkSphereRepresentation::HighlightHandle(int highlight)
 {
-  if ( highlight )
+  if (highlight)
   {
     this->ValidPick = 1;
     this->HandleActor->SetProperty(this->SelectedHandleProperty);
@@ -239,28 +240,30 @@ void vtkSphereRepresentation::HighlightHandle(int highlight)
 //------------------------------------------------------------------------------
 void vtkSphereRepresentation::RegisterPickers()
 {
-  this->Renderer->GetRenderWindow()->GetInteractor()->GetPickingManager()
-    ->AddPicker(this->HandlePicker, this);
-  this->Renderer->GetRenderWindow()->GetInteractor()->GetPickingManager()
-    ->AddPicker(this->SpherePicker, this);
+  vtkPickingManager* pm = this->GetPickingManager();
+  if (!pm)
+  {
+    return;
+  }
+  pm->AddPicker(this->HandlePicker, this);
+  pm->AddPicker(this->SpherePicker, this);
 }
 
 //----------------------------------------------------------------------
-void vtkSphereRepresentation::Scale(double *p1, double *p2,
-                                    int vtkNotUsed(X), int Y)
+void vtkSphereRepresentation::Scale(const double* p1, const double* p2, int vtkNotUsed(X), int Y)
 {
-  //Get the motion vector
+  // Get the motion vector
   double v[3];
   v[0] = p2[0] - p1[0];
   v[1] = p2[1] - p1[1];
   v[2] = p2[2] - p1[2];
 
   double radius = this->SphereSource->GetRadius();
-  double *c = this->SphereSource->GetCenter();
+  double* c = this->SphereSource->GetCenter();
 
   // Compute the scale factor
   double sf = vtkMath::Norm(v) / radius;
-  if ( Y > this->LastEventPosition[1] )
+  if (Y > this->LastEventPosition[1])
   {
     sf = 1.0 + sf;
   }
@@ -271,16 +274,16 @@ void vtkSphereRepresentation::Scale(double *p1, double *p2,
 
   // Make sure that the radius is valid; don't let it shrink further
   // but it can still grow in radius.
-  if ( Y <= this->LastEventPosition[1] && sf*radius < 1.0e-06*this->InitialLength )
+  if (Y <= this->LastEventPosition[1] && sf * radius < 1.0e-06 * this->InitialLength)
   {
     return;
   }
 
   // Need to prevent radius going to zero
-  this->SphereSource->SetRadius(sf*radius);
-  this->HandlePosition[0] = c[0]+sf*(this->HandlePosition[0]-c[0]);
-  this->HandlePosition[1] = c[1]+sf*(this->HandlePosition[1]-c[1]);
-  this->HandlePosition[2] = c[2]+sf*(this->HandlePosition[2]-c[2]);
+  this->SphereSource->SetRadius(sf * radius);
+  this->HandlePosition[0] = c[0] + sf * (this->HandlePosition[0] - c[0]);
+  this->HandlePosition[1] = c[1] + sf * (this->HandlePosition[1] - c[1]);
+  this->HandlePosition[2] = c[2] + sf * (this->HandlePosition[2] - c[2]);
   this->HandleSource->SetCenter(this->HandlePosition);
   this->AdaptCenterCursorBounds();
 }
@@ -298,15 +301,15 @@ void vtkSphereRepresentation::StartWidgetInteraction(double e[2])
   this->LastEventPosition[1] = e[1];
   this->LastEventPosition[2] = 0.0;
 
-  this->ComputeInteractionState(static_cast<int>(e[0]),static_cast<int>(e[1]),0);
+  this->ComputeInteractionState(static_cast<int>(e[0]), static_cast<int>(e[1]), 0);
 }
 
 //----------------------------------------------------------------------
 void vtkSphereRepresentation::WidgetInteraction(double e[2])
 {
   // Convert events to appropriate coordinate systems
-  vtkCamera *camera = this->Renderer->GetActiveCamera();
-  if ( !camera )
+  vtkCamera* camera = this->Renderer->GetActiveCamera();
+  if (!camera)
   {
     return;
   }
@@ -315,31 +318,28 @@ void vtkSphereRepresentation::WidgetInteraction(double e[2])
   camera->GetViewPlaneNormal(vpn);
 
   // Compute the two points defining the motion vector
-  vtkInteractorObserver::ComputeWorldToDisplay(this->Renderer,
-                                               this->LastPickPosition[0], this->LastPickPosition[1], this->LastPickPosition[2],
-                                               focalPoint);
+  vtkInteractorObserver::ComputeWorldToDisplay(this->Renderer, this->LastPickPosition[0],
+    this->LastPickPosition[1], this->LastPickPosition[2], focalPoint);
   z = focalPoint[2];
-  vtkInteractorObserver::ComputeDisplayToWorld(this->Renderer,this->LastEventPosition[0],
-                                               this->LastEventPosition[1], z, prevPickPoint);
+  vtkInteractorObserver::ComputeDisplayToWorld(
+    this->Renderer, this->LastEventPosition[0], this->LastEventPosition[1], z, prevPickPoint);
   vtkInteractorObserver::ComputeDisplayToWorld(this->Renderer, e[0], e[1], z, pickPoint);
 
   // Process the motion
-  if ( this->InteractionState == vtkSphereRepresentation::Translating )
+  if (this->InteractionState == vtkSphereRepresentation::Translating)
   {
     this->Translate(prevPickPoint, pickPoint);
   }
 
-  else if ( this->InteractionState == vtkSphereRepresentation::Scaling )
+  else if (this->InteractionState == vtkSphereRepresentation::Scaling)
   {
-    this->Scale(prevPickPoint, pickPoint,
-                static_cast<int>(e[0]), static_cast<int>(e[1]));
+    this->Scale(prevPickPoint, pickPoint, static_cast<int>(e[0]), static_cast<int>(e[1]));
   }
-  else if ( this->InteractionState == vtkSphereRepresentation::MovingHandle )
+  else if (this->InteractionState == vtkSphereRepresentation::MovingHandle)
   {
-    vtkAssemblyPath* path = this->GetAssemblyPath(e[0], e[1], 0.,
-                                                  this->SpherePicker);
+    vtkAssemblyPath* path = this->GetAssemblyPath(e[0], e[1], 0., this->SpherePicker);
 
-    if ( path != NULL )
+    if (path != nullptr)
     {
       double pos[3], dir[3], c[3];
       this->SpherePicker->GetPickPosition(pos);
@@ -359,19 +359,28 @@ void vtkSphereRepresentation::WidgetInteraction(double e[2])
 
 //----------------------------------------------------------------------------
 // Loop through all points and translate them
-void vtkSphereRepresentation::Translate(double *p1, double *p2)
+void vtkSphereRepresentation::Translate(const double* p1, const double* p2)
 {
-  //Get the motion vector
-  double v[3];
-  v[0] = p2[0] - p1[0];
-  v[1] = p2[1] - p1[1];
-  v[2] = p2[2] - p1[2];
+  // Get the motion vector
+  double v[3] = { 0, 0, 0 };
 
-  //int res = this->SphereSource->GetResolution();
-  double *center = this->SphereSource->GetCenter();
+  if (!this->IsTranslationConstrained())
+  {
+    v[0] = p2[0] - p1[0];
+    v[1] = p2[1] - p1[1];
+    v[2] = p2[2] - p1[2];
+  }
+  else
+  {
+    assert(this->TranslationAxis > -1 && this->TranslationAxis < 3 &&
+      "this->TranslationAxis out of bounds");
+    v[this->TranslationAxis] = p2[this->TranslationAxis] - p1[this->TranslationAxis];
+  }
+
+  double* center = this->SphereSource->GetCenter();
 
   double center1[3];
-  for (int i=0; i<3; i++)
+  for (int i = 0; i < 3; i++)
   {
     center1[i] = center[i] + v[i];
     this->HandlePosition[i] += v[i];
@@ -385,27 +394,27 @@ void vtkSphereRepresentation::Translate(double *p1, double *p2)
 //----------------------------------------------------------------------------
 void vtkSphereRepresentation::CreateDefaultProperties()
 {
-  if ( ! this->SphereProperty )
+  if (!this->SphereProperty)
   {
     this->SphereProperty = vtkProperty::New();
   }
-  if ( ! this->SelectedSphereProperty )
+  if (!this->SelectedSphereProperty)
   {
     this->SelectedSphereProperty = vtkProperty::New();
   }
 
-  if ( ! this->HandleProperty )
+  if (!this->HandleProperty)
   {
     this->HandleProperty = vtkProperty::New();
-    this->HandleProperty->SetColor(1,1,1);
+    this->HandleProperty->SetColor(1, 1, 1);
   }
-  if ( ! this->SelectedHandleProperty )
+  if (!this->SelectedHandleProperty)
   {
     this->SelectedHandleProperty = vtkProperty::New();
-    this->SelectedHandleProperty->SetColor(1,0,0);
+    this->SelectedHandleProperty->SetColor(1, 0, 0);
   }
 
-  if ( ! this->HandleTextProperty )
+  if (!this->HandleTextProperty)
   {
     this->HandleTextProperty = vtkTextProperty::New();
     this->HandleTextProperty->SetFontSize(12);
@@ -415,17 +424,17 @@ void vtkSphereRepresentation::CreateDefaultProperties()
     this->HandleTextProperty->SetFontFamilyToArial();
   }
 
-  if ( ! this->RadialLineProperty )
+  if (!this->RadialLineProperty)
   {
     this->RadialLineProperty = vtkProperty::New();
-    this->RadialLineProperty->SetColor(1,0,0);
+    this->RadialLineProperty->SetColor(1, 0, 0);
   }
 }
 
 //----------------------------------------------------------------------------
 void vtkSphereRepresentation::PlaceWidget(double center[3], double handle[3])
 {
-  double r = sqrt( vtkMath::Distance2BetweenPoints(center,handle) );
+  double r = sqrt(vtkMath::Distance2BetweenPoints(center, handle));
   this->SphereSource->SetCenter(center);
   this->SphereSource->SetRadius(r);
   this->SphereSource->Update();
@@ -460,19 +469,18 @@ void vtkSphereRepresentation::SetCenter(double center[3])
 {
   double c[3];
   this->SphereSource->GetCenter(c);
-  if ( c[0] != center[0] || c[1] != center[1] || c[2] != center[2] )
+  if (c[0] != center[0] || c[1] != center[1] || c[2] != center[2])
   {
     double handle[3];
     this->SphereSource->SetCenter(center);
 
-    if(this->GetHandleVisibility())
+    if (this->GetHandleVisibility())
     {
       this->HandleSource->GetCenter(handle);
       this->HandleDirection[0] = handle[0] - center[0];
       this->HandleDirection[1] = handle[1] - center[1];
       this->HandleDirection[2] = handle[2] - center[2];
-      double r = sqrt( static_cast<double>(
-        vtkMath::Distance2BetweenPoints(handle,center) ) );
+      double r = sqrt(static_cast<double>(vtkMath::Distance2BetweenPoints(handle, center)));
       this->SphereSource->SetRadius(r);
     }
 
@@ -488,13 +496,13 @@ void vtkSphereRepresentation::SetCenter(double center[3])
 //----------------------------------------------------------------------------
 void vtkSphereRepresentation::SetRadius(double r)
 {
-  r = (r <= this->InitialLength*1.0e-04 ? this->InitialLength*1.0e-04 : r);
-  if ( r != this->SphereSource->GetRadius() )
+  r = (r <= this->InitialLength * 1.0e-04 ? this->InitialLength * 1.0e-04 : r);
+  if (r != this->SphereSource->GetRadius())
   {
     double center[3];
     this->SphereSource->SetRadius(r);
     this->SphereSource->GetCenter(center);
-    this->PlaceHandle(center,r);
+    this->PlaceHandle(center, r);
     this->SphereSource->Update();
     this->Modified();
   }
@@ -506,7 +514,7 @@ void vtkSphereRepresentation::SetHandlePosition(double handle[3])
 {
   double h[3];
   this->HandleSource->GetCenter(h);
-  if ( h[0] != handle[0] || h[1] != handle[1] || h[2] != handle[2] )
+  if (h[0] != handle[0] || h[1] != handle[1] || h[2] != handle[2])
   {
     double c[3];
     this->HandleSource->SetCenter(handle);
@@ -514,8 +522,7 @@ void vtkSphereRepresentation::SetHandlePosition(double handle[3])
     this->HandleDirection[0] = handle[0] - c[0];
     this->HandleDirection[1] = handle[1] - c[1];
     this->HandleDirection[2] = handle[2] - c[2];
-    double r = static_cast<double>(
-      vtkMath::Distance2BetweenPoints(handle,c) );
+    double r = static_cast<double>(vtkMath::Distance2BetweenPoints(handle, c));
     this->SphereSource->SetRadius(sqrt(r));
     this->SphereSource->Update();
     this->HandleSource->Update();
@@ -530,17 +537,17 @@ void vtkSphereRepresentation::SetHandlePosition(double handle[3])
 // adjusted to be consistent with the sphere center and the current sphere radius.
 void vtkSphereRepresentation::SetHandleDirection(double dir[3])
 {
-  double *d = this->HandleDirection;
+  double* d = this->HandleDirection;
   double dirMag = vtkMath::Norm(dir);
-  if ( (dirMag != 0.0) && (d[0] != dir[0] || d[1] != dir[1] || d[2] != dir[2]) )
+  if ((dirMag != 0.0) && (d[0] != dir[0] || d[1] != dir[1] || d[2] != dir[2]))
   {
     double r, f, c[3];
     r = this->SphereSource->GetRadius();
     f = r / dirMag;
     this->SphereSource->GetCenter(c);
-    this->HandlePosition[0] = c[0] + f*dir[0];
-    this->HandlePosition[1] = c[1] + f*dir[1];
-    this->HandlePosition[2] = c[2] + f*dir[2];
+    this->HandlePosition[0] = c[0] + f * dir[0];
+    this->HandlePosition[1] = c[1] + f * dir[1];
+    this->HandlePosition[2] = c[2] + f * dir[2];
     this->HandleSource->SetCenter(this->HandlePosition);
     this->HandleSource->Update();
     this->Modified();
@@ -554,15 +561,15 @@ void vtkSphereRepresentation::PlaceWidget(double bds[6])
 
   this->AdjustBounds(bds, bounds, center);
 
-  radius = (bounds[1]-bounds[0]) / 2.0;
-  if ( radius > ((bounds[3]-bounds[2])/2.0) )
+  radius = (bounds[1] - bounds[0]) / 2.0;
+  if (radius > ((bounds[3] - bounds[2]) / 2.0))
   {
-    radius = (bounds[3]-bounds[2])/2.0;
+    radius = (bounds[3] - bounds[2]) / 2.0;
   }
-  radius = (bounds[1]-bounds[0]) / 2.0;
-  if ( radius > ((bounds[5]-bounds[4])/2.0) )
+  radius = (bounds[1] - bounds[0]) / 2.0;
+  if (radius > ((bounds[5] - bounds[4]) / 2.0))
   {
-    radius = (bounds[5]-bounds[4])/2.0;
+    radius = (bounds[5] - bounds[4]) / 2.0;
   }
 
   this->SphereSource->SetCenter(center);
@@ -573,28 +580,28 @@ void vtkSphereRepresentation::PlaceWidget(double bds[6])
   this->CenterCursorSource->Update();
 
   // place the handle
-  this->PlaceHandle(center,radius);
+  this->PlaceHandle(center, radius);
 
-  for (int i=0; i<6; i++)
+  for (int i = 0; i < 6; i++)
   {
     this->InitialBounds[i] = bounds[i];
   }
-  this->InitialLength = sqrt((bounds[1]-bounds[0])*(bounds[1]-bounds[0]) +
-                             (bounds[3]-bounds[2])*(bounds[3]-bounds[2]) +
-                             (bounds[5]-bounds[4])*(bounds[5]-bounds[4]));
+  this->InitialLength = sqrt((bounds[1] - bounds[0]) * (bounds[1] - bounds[0]) +
+    (bounds[3] - bounds[2]) * (bounds[3] - bounds[2]) +
+    (bounds[5] - bounds[4]) * (bounds[5] - bounds[4]));
 
   this->ValidPick = 1; // since we have set up widget properly
   this->SizeHandles();
 }
 
 //----------------------------------------------------------------------------
-void vtkSphereRepresentation::PlaceHandle(double *center, double radius)
+void vtkSphereRepresentation::PlaceHandle(const double* center, double radius)
 {
   double sf = radius / vtkMath::Norm(this->HandleDirection);
 
-  this->HandlePosition[0] = center[0] + sf*this->HandleDirection[0];
-  this->HandlePosition[1] = center[1] + sf*this->HandleDirection[1];
-  this->HandlePosition[2] = center[2] + sf*this->HandleDirection[2];
+  this->HandlePosition[0] = center[0] + sf * this->HandleDirection[0];
+  this->HandlePosition[1] = center[1] + sf * this->HandleDirection[1];
+  this->HandlePosition[2] = center[2] + sf * this->HandleDirection[2];
   this->HandleSource->SetCenter(this->HandlePosition);
   this->HandleSource->Update();
 }
@@ -612,13 +619,13 @@ int vtkSphereRepresentation::ComputeInteractionState(int X, int Y, int vtkNotUse
 
   // Try and pick a handle first. This allows the picking of the handle even
   // if it is "behind" the sphere.
-  vtkAssemblyPath *path;
+  vtkAssemblyPath* path;
   int handlePicked = 0;
-  if ( this->HandleVisibility || this->HandleText || this->RadialLine )
+  if (this->HandleVisibility || this->HandleText || this->RadialLine)
   {
     path = this->GetAssemblyPath(X, Y, 0., this->HandlePicker);
 
-    if ( path != NULL )
+    if (path != nullptr)
     {
       this->ValidPick = 1;
       this->InteractionState = vtkSphereRepresentation::MovingHandle;
@@ -628,11 +635,11 @@ int vtkSphereRepresentation::ComputeInteractionState(int X, int Y, int vtkNotUse
     }
   }
 
-  if ( ! handlePicked )
+  if (!handlePicked)
   {
     path = this->GetAssemblyPath(X, Y, 0., this->SpherePicker);
 
-    if ( path != NULL )
+    if (path != nullptr)
     {
       this->ValidPick = 1;
       this->InteractionState = vtkSphereRepresentation::OnSphere;
@@ -648,11 +655,11 @@ void vtkSphereRepresentation::AdaptCenterCursorBounds()
 {
   double center[3], newBounds[6];
   this->CenterCursorSource->GetFocalPoint(center);
-  double radius = this->SizeHandlesInPixels(2.0,center);
-  for (int i=0; i<3; i++)
+  double radius = this->SizeHandlesInPixels(2.0, center);
+  for (int i = 0; i < 3; i++)
   {
-    newBounds[2*i] = center[i] - radius;
-    newBounds[2*i+1] = center[i] + radius;
+    newBounds[2 * i] = center[i] - radius;
+    newBounds[2 * i + 1] = center[i] + radius;
   }
   this->CenterCursorSource->SetModelBounds(newBounds);
 }
@@ -661,15 +668,16 @@ void vtkSphereRepresentation::AdaptCenterCursorBounds()
 void vtkSphereRepresentation::SetInteractionState(int state)
 {
   // Clamp to allowable values
-  state = ( state < vtkSphereRepresentation::Outside ? vtkSphereRepresentation::Outside :
-            (state > vtkSphereRepresentation::Scaling ? vtkSphereRepresentation::Scaling : state) );
+  state = (state < vtkSphereRepresentation::Outside
+      ? vtkSphereRepresentation::Outside
+      : (state > vtkSphereRepresentation::Scaling ? vtkSphereRepresentation::Scaling : state));
 
   // Depending on state, highlight appropriate parts of representation
   this->InteractionState = state;
 }
 
 //----------------------------------------------------------------------
-double *vtkSphereRepresentation::GetBounds()
+double* vtkSphereRepresentation::GetBounds()
 {
   this->BuildRepresentation();
   return this->SphereSource->GetOutput()->GetBounds();
@@ -679,7 +687,7 @@ double *vtkSphereRepresentation::GetBounds()
 void vtkSphereRepresentation::BuildRepresentation()
 {
   // Always rebuild, it's not worth keeping track of modified
-  switch ( this->Representation )
+  switch (this->Representation)
   {
     case VTK_SPHERE_OFF:
       break;
@@ -696,33 +704,33 @@ void vtkSphereRepresentation::BuildRepresentation()
   this->SizeHandles();
 
   // Now the annotations
-  if ( this->RadialLine )
+  if (this->RadialLine)
   {
     this->RadialLineSource->SetPoint1(this->SphereSource->GetCenter());
     this->RadialLineSource->SetPoint2(this->HandleSource->GetCenter());
     this->RadialLineSource->Update();
   }
 
-  if ( this->HandleText && this->Renderer )
+  if (this->HandleText && this->Renderer)
   {
     char str[256];
     double c[3], hc[3], tc[4];
     this->SphereSource->GetCenter(c);
     this->HandleSource->GetCenter(hc);
-    double r = sqrt( static_cast<double>(vtkMath::Distance2BetweenPoints(c,hc)) );
-    r = (r<=0.0 ? 1.0 : r);
-    double theta = vtkMath::DegreesFromRadians( atan2( ( hc[1] - c[1] ), ( hc[0] - c[0] ) ) );
-    double phi   = vtkMath::DegreesFromRadians( acos( ( hc[2] - c[2] ) / r ) );
-    sprintf(str,"(%0.2g, %1.1f, %1.1f)", r, theta, phi);
+    double r = sqrt(static_cast<double>(vtkMath::Distance2BetweenPoints(c, hc)));
+    r = (r <= 0.0 ? 1.0 : r);
+    double theta = vtkMath::DegreesFromRadians(atan2((hc[1] - c[1]), (hc[0] - c[0])));
+    double phi = vtkMath::DegreesFromRadians(acos((hc[2] - c[2]) / r));
+    snprintf(str, sizeof(str), "(%0.2g, %1.1f, %1.1f)", r, theta, phi);
     this->HandleTextMapper->SetInput(str);
     vtkInteractorObserver::ComputeWorldToDisplay(this->Renderer, hc[0], hc[1], hc[2], tc);
-    this->HandleTextActor->GetPositionCoordinate()->SetValue(tc[0]+10,tc[1]+10);
+    this->HandleTextActor->GetPositionCoordinate()->SetValue(tc[0] + 10, tc[1] + 10);
   }
   this->AdaptCenterCursorBounds();
 }
 
 //----------------------------------------------------------------------------
-void vtkSphereRepresentation::ReleaseGraphicsResources(vtkWindow *w)
+void vtkSphereRepresentation::ReleaseGraphicsResources(vtkWindow* w)
 {
   this->SphereActor->ReleaseGraphicsResources(w);
   this->HandleActor->ReleaseGraphicsResources(w);
@@ -732,20 +740,20 @@ void vtkSphereRepresentation::ReleaseGraphicsResources(vtkWindow *w)
 }
 
 //----------------------------------------------------------------------------
-int vtkSphereRepresentation::RenderOpaqueGeometry(vtkViewport *v)
+int vtkSphereRepresentation::RenderOpaqueGeometry(vtkViewport* v)
 {
-  int count=0;
+  int count = 0;
   this->BuildRepresentation();
 
-  if ( this->Representation != VTK_SPHERE_OFF )
+  if (this->Representation != VTK_SPHERE_OFF)
   {
     count += this->SphereActor->RenderOpaqueGeometry(v);
   }
-  if ( this->HandleVisibility )
+  if (this->HandleVisibility)
   {
     count += this->HandleActor->RenderOpaqueGeometry(v);
   }
-  if ( this->RadialLine )
+  if (this->RadialLine)
   {
     count += this->RadialLineActor->RenderOpaqueGeometry(v);
   }
@@ -758,19 +766,19 @@ int vtkSphereRepresentation::RenderOpaqueGeometry(vtkViewport *v)
 }
 
 //----------------------------------------------------------------------------
-int vtkSphereRepresentation::RenderTranslucentPolygonalGeometry(vtkViewport *v)
+int vtkSphereRepresentation::RenderTranslucentPolygonalGeometry(vtkViewport* v)
 {
-  int count=0;
+  int count = 0;
 
-  if ( this->Representation != VTK_SPHERE_OFF )
+  if (this->Representation != VTK_SPHERE_OFF)
   {
     count += this->SphereActor->RenderTranslucentPolygonalGeometry(v);
   }
-  if ( this->HandleVisibility )
+  if (this->HandleVisibility)
   {
     count += this->HandleActor->RenderTranslucentPolygonalGeometry(v);
   }
-  if ( this->RadialLine )
+  if (this->RadialLine)
   {
     count += this->RadialLineActor->RenderTranslucentPolygonalGeometry(v);
   }
@@ -783,11 +791,11 @@ int vtkSphereRepresentation::RenderTranslucentPolygonalGeometry(vtkViewport *v)
 }
 
 //----------------------------------------------------------------------------
-int vtkSphereRepresentation::RenderOverlay(vtkViewport *v)
+int vtkSphereRepresentation::RenderOverlay(vtkViewport* v)
 {
-  int count=0;
+  int count = 0;
 
-  if ( this->HandleText )
+  if (this->HandleText)
   {
     count += this->HandleTextActor->RenderOverlay(v);
   }
@@ -796,24 +804,24 @@ int vtkSphereRepresentation::RenderOverlay(vtkViewport *v)
 }
 
 //----------------------------------------------------------------------------
-int vtkSphereRepresentation::HasTranslucentPolygonalGeometry()
+vtkTypeBool vtkSphereRepresentation::HasTranslucentPolygonalGeometry()
 {
-  int result=0;
+  int result = 0;
   this->BuildRepresentation();
 
-  if ( this->Representation != VTK_SPHERE_OFF )
+  if (this->Representation != VTK_SPHERE_OFF)
   {
     result |= this->SphereActor->HasTranslucentPolygonalGeometry();
   }
-  if ( this->HandleVisibility )
+  if (this->HandleVisibility)
   {
     result |= this->HandleActor->HasTranslucentPolygonalGeometry();
   }
-  if ( this->HandleText )
+  if (this->HandleText)
   {
     result |= this->HandleTextActor->HasTranslucentPolygonalGeometry();
   }
-  if ( this->RadialLine )
+  if (this->RadialLine)
   {
     result |= this->RadialLineActor->HasTranslucentPolygonalGeometry();
   }
@@ -825,37 +833,34 @@ int vtkSphereRepresentation::HasTranslucentPolygonalGeometry()
   return result;
 }
 
-
 //----------------------------------------------------------------------------
 void vtkSphereRepresentation::SizeHandles()
 {
-  double radius = this->vtkWidgetRepresentation::
-    SizeHandlesInPixels(1.5,this->HandleSource->GetOutput()->GetCenter());
+  double radius = this->vtkWidgetRepresentation::SizeHandlesInPixels(
+    1.5, this->HandleSource->GetOutput()->GetCenter());
   this->HandleSource->SetRadius(radius);
 }
 
-
-
 //----------------------------------------------------------------------------
 void vtkSphereRepresentation::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 
   os << indent << "Sphere Representation: ";
-  if ( this->Representation == VTK_SPHERE_OFF )
+  if (this->Representation == VTK_SPHERE_OFF)
   {
     os << "Off\n";
   }
-  else if ( this->Representation == VTK_SPHERE_WIREFRAME )
+  else if (this->Representation == VTK_SPHERE_WIREFRAME)
   {
     os << "Wireframe\n";
   }
-  else //if ( this->Representation == VTK_SPHERE_SURFACE )
+  else // if ( this->Representation == VTK_SPHERE_SURFACE )
   {
     os << "Surface\n";
   }
 
-  if ( this->SphereProperty )
+  if (this->SphereProperty)
   {
     os << indent << "Sphere Property: " << this->SphereProperty << "\n";
   }
@@ -863,17 +868,16 @@ void vtkSphereRepresentation::PrintSelf(ostream& os, vtkIndent indent)
   {
     os << indent << "Sphere Property: (none)\n";
   }
-  if ( this->SelectedSphereProperty )
+  if (this->SelectedSphereProperty)
   {
-    os << indent << "Selected Sphere Property: "
-       << this->SelectedSphereProperty << "\n";
+    os << indent << "Selected Sphere Property: " << this->SelectedSphereProperty << "\n";
   }
   else
   {
     os << indent << "Selected Sphere Property: (none)\n";
   }
 
-  if ( this->HandleProperty )
+  if (this->HandleProperty)
   {
     os << indent << "Handle Property: " << this->HandleProperty << "\n";
   }
@@ -881,41 +885,36 @@ void vtkSphereRepresentation::PrintSelf(ostream& os, vtkIndent indent)
   {
     os << indent << "Handle Property: (none)\n";
   }
-  if ( this->SelectedHandleProperty )
+  if (this->SelectedHandleProperty)
   {
-    os << indent << "Selected Handle Property: "
-       << this->SelectedHandleProperty << "\n";
+    os << indent << "Selected Handle Property: " << this->SelectedHandleProperty << "\n";
   }
   else
   {
     os << indent << "Selected Handle Property: (none)\n";
   }
 
-  os << indent << "Handle Visibility: "
-     << (this->HandleVisibility ? "On\n" : "Off\n");
+  os << indent << "Handle Visibility: " << (this->HandleVisibility ? "On\n" : "Off\n");
   os << indent << "Handle Direction: (" << this->HandleDirection[0] << ", "
-     << this->HandleDirection[1] << ", "
-     << this->HandleDirection[2] << ")\n";
-  os << indent << "Handle Position: (" << this->HandlePosition[0] << ", "
-     << this->HandlePosition[1] << ", "
-     << this->HandlePosition[2] << ")\n";
+     << this->HandleDirection[1] << ", " << this->HandleDirection[2] << ")\n";
+  os << indent << "Handle Position: (" << this->HandlePosition[0] << ", " << this->HandlePosition[1]
+     << ", " << this->HandlePosition[2] << ")\n";
 
   int thetaRes = this->SphereSource->GetThetaResolution();
   int phiRes = this->SphereSource->GetPhiResolution();
-  double *center = this->SphereSource->GetCenter();
+  double* center = this->SphereSource->GetCenter();
   double r = this->SphereSource->GetRadius();
 
   os << indent << "Theta Resolution: " << thetaRes << "\n";
   os << indent << "Phi Resolution: " << phiRes << "\n";
-  os << indent << "Center: (" << center[0] << ", "
-     << center[1] << ", " << center[2] << ")\n";
+  os << indent << "Center: (" << center[0] << ", " << center[1] << ", " << center[2] << ")\n";
   os << indent << "Radius: " << r << "\n";
 
   os << indent << "Handle Text: " << this->HandleText << "\n";
   os << indent << "Radial Line: " << this->RadialLine << "\n";
   os << indent << "Center Cursor: " << this->CenterCursor << "\n";
 
-  if ( this->HandleTextProperty )
+  if (this->HandleTextProperty)
   {
     os << indent << "Handle Text Property: " << this->HandleTextProperty << "\n";
   }
@@ -924,7 +923,7 @@ void vtkSphereRepresentation::PrintSelf(ostream& os, vtkIndent indent)
     os << indent << "Handle Text Property: (none)\n";
   }
 
-  if ( this->RadialLineProperty )
+  if (this->RadialLineProperty)
   {
     os << indent << "Radial Line Property: " << this->RadialLineProperty << "\n";
   }
@@ -933,5 +932,3 @@ void vtkSphereRepresentation::PrintSelf(ostream& os, vtkIndent indent)
     os << indent << "Radial Line Property: (none)\n";
   }
 }
-
-
