@@ -42,15 +42,14 @@ vtkSphereWidget::vtkSphereWidget()
 
   this->Representation = VTK_SPHERE_WIREFRAME;
 
-  //Build the representation of the widget
+  // Build the representation of the widget
   // Represent the sphere
   this->SphereSource = vtkSphereSource::New();
   this->SphereSource->SetThetaResolution(16);
   this->SphereSource->SetPhiResolution(8);
   this->SphereSource->LatLongTessellationOn();
   this->SphereMapper = vtkPolyDataMapper::New();
-  this->SphereMapper->SetInputConnection(
-    this->SphereSource->GetOutputPort());
+  this->SphereMapper->SetInputConnection(this->SphereSource->GetOutputPort());
   this->SphereActor = vtkActor::New();
   this->SphereActor->SetMapper(this->SphereMapper);
 
@@ -67,8 +66,7 @@ vtkSphereWidget::vtkSphereWidget()
   this->HandleSource->SetThetaResolution(16);
   this->HandleSource->SetPhiResolution(8);
   this->HandleMapper = vtkPolyDataMapper::New();
-  this->HandleMapper->SetInputConnection(
-    this->HandleSource->GetOutputPort());
+  this->HandleMapper->SetInputConnection(this->HandleSource->GetOutputPort());
   this->HandleActor = vtkActor::New();
   this->HandleActor->SetMapper(this->HandleMapper);
 
@@ -84,18 +82,18 @@ vtkSphereWidget::vtkSphereWidget()
   // Initial creation of the widget, serves to initialize it
   this->PlaceWidget(bounds);
 
-  //Manage the picking stuff
+  // Manage the picking stuff
   this->Picker = vtkCellPicker::New();
-  this->Picker->SetTolerance(0.005); //need some fluff
+  this->Picker->SetTolerance(0.005); // need some fluff
   this->Picker->AddPickList(this->SphereActor);
   this->Picker->AddPickList(this->HandleActor);
   this->Picker->PickFromListOn();
 
   // Set up the initial properties
-  this->SphereProperty = NULL;
-  this->SelectedSphereProperty = NULL;
-  this->HandleProperty = NULL;
-  this->SelectedHandleProperty = NULL;
+  this->SphereProperty = nullptr;
+  this->SelectedSphereProperty = nullptr;
+  this->HandleProperty = nullptr;
+  this->SelectedHandleProperty = nullptr;
   this->CreateDefaultProperties();
 }
 
@@ -112,19 +110,19 @@ vtkSphereWidget::~vtkSphereWidget()
   this->HandleMapper->Delete();
   this->HandleActor->Delete();
 
-  if ( this->SphereProperty )
+  if (this->SphereProperty)
   {
     this->SphereProperty->Delete();
   }
-  if ( this->SelectedSphereProperty )
+  if (this->SelectedSphereProperty)
   {
     this->SelectedSphereProperty->Delete();
   }
-  if ( this->HandleProperty )
+  if (this->HandleProperty)
   {
     this->HandleProperty->Delete();
   }
-  if ( this->SelectedHandleProperty )
+  if (this->SelectedHandleProperty)
   {
     this->SelectedHandleProperty->Delete();
   }
@@ -133,28 +131,26 @@ vtkSphereWidget::~vtkSphereWidget()
 //----------------------------------------------------------------------------
 void vtkSphereWidget::SetEnabled(int enabling)
 {
-  if ( ! this->Interactor )
+  if (!this->Interactor)
   {
-    vtkErrorMacro(<<"The interactor must be set prior to enabling/disabling widget");
+    vtkErrorMacro(<< "The interactor must be set prior to enabling/disabling widget");
     return;
   }
 
-  if ( enabling ) //----------------------------------------------------------
+  if (enabling) //----------------------------------------------------------
   {
-    vtkDebugMacro(<<"Enabling sphere widget");
+    vtkDebugMacro(<< "Enabling sphere widget");
 
-    if ( this->Enabled ) //already enabled, just return
+    if (this->Enabled) // already enabled, just return
     {
       return;
     }
 
-    if ( ! this->CurrentRenderer )
+    if (!this->CurrentRenderer)
     {
-      this->SetCurrentRenderer(
-        this->Interactor->FindPokedRenderer(
-          this->Interactor->GetLastEventPosition()[0],
-          this->Interactor->GetLastEventPosition()[1]));
-      if (this->CurrentRenderer == NULL)
+      this->SetCurrentRenderer(this->Interactor->FindPokedRenderer(
+        this->Interactor->GetLastEventPosition()[0], this->Interactor->GetLastEventPosition()[1]));
+      if (this->CurrentRenderer == nullptr)
       {
         return;
       }
@@ -163,17 +159,12 @@ void vtkSphereWidget::SetEnabled(int enabling)
     this->Enabled = 1;
 
     // listen for the following events
-    vtkRenderWindowInteractor *i = this->Interactor;
-    i->AddObserver(vtkCommand::MouseMoveEvent,
-                   this->EventCallbackCommand, this->Priority);
-    i->AddObserver(vtkCommand::LeftButtonPressEvent,
-                   this->EventCallbackCommand, this->Priority);
-    i->AddObserver(vtkCommand::LeftButtonReleaseEvent,
-                   this->EventCallbackCommand, this->Priority);
-    i->AddObserver(vtkCommand::RightButtonPressEvent,
-                   this->EventCallbackCommand, this->Priority);
-    i->AddObserver(vtkCommand::RightButtonReleaseEvent,
-                   this->EventCallbackCommand, this->Priority);
+    vtkRenderWindowInteractor* i = this->Interactor;
+    i->AddObserver(vtkCommand::MouseMoveEvent, this->EventCallbackCommand, this->Priority);
+    i->AddObserver(vtkCommand::LeftButtonPressEvent, this->EventCallbackCommand, this->Priority);
+    i->AddObserver(vtkCommand::LeftButtonReleaseEvent, this->EventCallbackCommand, this->Priority);
+    i->AddObserver(vtkCommand::RightButtonPressEvent, this->EventCallbackCommand, this->Priority);
+    i->AddObserver(vtkCommand::RightButtonReleaseEvent, this->EventCallbackCommand, this->Priority);
 
     // Add the sphere
     this->CurrentRenderer->AddActor(this->SphereActor);
@@ -183,15 +174,16 @@ void vtkSphereWidget::SetEnabled(int enabling)
     this->HandleActor->SetProperty(this->HandleProperty);
     this->SelectRepresentation();
     this->SizeHandles();
+    this->RegisterPickers();
 
-    this->InvokeEvent(vtkCommand::EnableEvent,NULL);
+    this->InvokeEvent(vtkCommand::EnableEvent, nullptr);
   }
 
-  else //disabling----------------------------------------------------------
+  else // disabling----------------------------------------------------------
   {
-    vtkDebugMacro(<<"Disabling sphere widget");
+    vtkDebugMacro(<< "Disabling sphere widget");
 
-    if ( ! this->Enabled ) //already disabled, just return
+    if (!this->Enabled) // already disabled, just return
     {
       return;
     }
@@ -205,23 +197,22 @@ void vtkSphereWidget::SetEnabled(int enabling)
     this->CurrentRenderer->RemoveActor(this->SphereActor);
     this->CurrentRenderer->RemoveActor(this->HandleActor);
 
-    this->InvokeEvent(vtkCommand::DisableEvent,NULL);
-    this->SetCurrentRenderer(NULL);
+    this->InvokeEvent(vtkCommand::DisableEvent, nullptr);
+    this->SetCurrentRenderer(nullptr);
+    this->UnRegisterPickers();
   }
 
   this->Interactor->Render();
 }
 
 //----------------------------------------------------------------------------
-void vtkSphereWidget::ProcessEvents(vtkObject* vtkNotUsed(object),
-                                    unsigned long event,
-                                    void* clientdata,
-                                    void* vtkNotUsed(calldata))
+void vtkSphereWidget::ProcessEvents(
+  vtkObject* vtkNotUsed(object), unsigned long event, void* clientdata, void* vtkNotUsed(calldata))
 {
-  vtkSphereWidget* self = reinterpret_cast<vtkSphereWidget *>( clientdata );
+  vtkSphereWidget* self = reinterpret_cast<vtkSphereWidget*>(clientdata);
 
-  //okay, let's do the right thing
-  switch(event)
+  // okay, let's do the right thing
+  switch (event)
   {
     case vtkCommand::LeftButtonPressEvent:
       self->OnLeftButtonDown();
@@ -244,23 +235,23 @@ void vtkSphereWidget::ProcessEvents(vtkObject* vtkNotUsed(object),
 //----------------------------------------------------------------------------
 void vtkSphereWidget::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 
   os << indent << "Sphere Representation: ";
-  if ( this->Representation == VTK_SPHERE_OFF )
+  if (this->Representation == VTK_SPHERE_OFF)
   {
     os << "Off\n";
   }
-  else if ( this->Representation == VTK_SPHERE_WIREFRAME )
+  else if (this->Representation == VTK_SPHERE_WIREFRAME)
   {
     os << "Wireframe\n";
   }
-  else //if ( this->Representation == VTK_SPHERE_SURFACE )
+  else // if ( this->Representation == VTK_SPHERE_SURFACE )
   {
     os << "Surface\n";
   }
 
-  if ( this->SphereProperty )
+  if (this->SphereProperty)
   {
     os << indent << "Sphere Property: " << this->SphereProperty << "\n";
   }
@@ -268,17 +259,16 @@ void vtkSphereWidget::PrintSelf(ostream& os, vtkIndent indent)
   {
     os << indent << "Sphere Property: (none)\n";
   }
-  if ( this->SelectedSphereProperty )
+  if (this->SelectedSphereProperty)
   {
-    os << indent << "Selected Sphere Property: "
-       << this->SelectedSphereProperty << "\n";
+    os << indent << "Selected Sphere Property: " << this->SelectedSphereProperty << "\n";
   }
   else
   {
     os << indent << "Selected Sphere Property: (none)\n";
   }
 
-  if ( this->HandleProperty )
+  if (this->HandleProperty)
   {
     os << indent << "Handle Property: " << this->HandleProperty << "\n";
   }
@@ -286,10 +276,9 @@ void vtkSphereWidget::PrintSelf(ostream& os, vtkIndent indent)
   {
     os << indent << "Handle Property: (none)\n";
   }
-  if ( this->SelectedHandleProperty )
+  if (this->SelectedHandleProperty)
   {
-    os << indent << "Selected Handle Property: "
-       << this->SelectedHandleProperty << "\n";
+    os << indent << "Selected Handle Property: " << this->SelectedHandleProperty << "\n";
   }
   else
   {
@@ -299,47 +288,43 @@ void vtkSphereWidget::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Translation: " << (this->Translation ? "On\n" : "Off\n");
   os << indent << "Scale: " << (this->Scale ? "On\n" : "Off\n");
 
-  os << indent << "Handle Visibility: "
-     << (this->HandleVisibility ? "On\n" : "Off\n");
+  os << indent << "Handle Visibility: " << (this->HandleVisibility ? "On\n" : "Off\n");
   os << indent << "Handle Direction: (" << this->HandleDirection[0] << ", "
-     << this->HandleDirection[1] << ", "
-     << this->HandleDirection[2] << ")\n";
-  os << indent << "Handle Position: (" << this->HandlePosition[0] << ", "
-     << this->HandlePosition[1] << ", "
-     << this->HandlePosition[2] << ")\n";
+     << this->HandleDirection[1] << ", " << this->HandleDirection[2] << ")\n";
+  os << indent << "Handle Position: (" << this->HandlePosition[0] << ", " << this->HandlePosition[1]
+     << ", " << this->HandlePosition[2] << ")\n";
 
   int thetaRes = this->SphereSource->GetThetaResolution();
   int phiRes = this->SphereSource->GetPhiResolution();
-  double *center = this->SphereSource->GetCenter();
+  double* center = this->SphereSource->GetCenter();
   double r = this->SphereSource->GetRadius();
 
   os << indent << "Theta Resolution: " << thetaRes << "\n";
   os << indent << "Phi Resolution: " << phiRes << "\n";
-  os << indent << "Center: (" << center[0] << ", "
-     << center[1] << ", " << center[2] << ")\n";
+  os << indent << "Center: (" << center[0] << ", " << center[1] << ", " << center[2] << ")\n";
   os << indent << "Radius: " << r << "\n";
 }
 
 //----------------------------------------------------------------------------
 void vtkSphereWidget::SelectRepresentation()
 {
-  if ( ! this->HandleVisibility )
+  if (!this->HandleVisibility)
   {
     this->CurrentRenderer->RemoveActor(this->HandleActor);
   }
 
-  if ( this->Representation == VTK_SPHERE_OFF )
+  if (this->Representation == VTK_SPHERE_OFF)
   {
     this->CurrentRenderer->RemoveActor(this->SphereActor);
   }
-  else if ( this->Representation == VTK_SPHERE_WIREFRAME )
+  else if (this->Representation == VTK_SPHERE_WIREFRAME)
   {
     this->CurrentRenderer->RemoveActor(this->SphereActor);
     this->CurrentRenderer->AddActor(this->SphereActor);
     this->SphereProperty->SetRepresentationToWireframe();
     this->SelectedSphereProperty->SetRepresentationToWireframe();
   }
-  else //if ( this->Representation == VTK_SPHERE_SURFACE )
+  else // if ( this->Representation == VTK_SPHERE_SURFACE )
   {
     this->CurrentRenderer->RemoveActor(this->SphereActor);
     this->CurrentRenderer->AddActor(this->SphereActor);
@@ -349,7 +334,7 @@ void vtkSphereWidget::SelectRepresentation()
 }
 
 //----------------------------------------------------------------------------
-void vtkSphereWidget::GetSphere(vtkSphere *sphere)
+void vtkSphereWidget::GetSphere(vtkSphere* sphere)
 {
   sphere->SetRadius(this->SphereSource->GetRadius());
   sphere->SetCenter(this->SphereSource->GetCenter());
@@ -358,7 +343,7 @@ void vtkSphereWidget::GetSphere(vtkSphere *sphere)
 //----------------------------------------------------------------------------
 void vtkSphereWidget::HighlightSphere(int highlight)
 {
-  if ( highlight )
+  if (highlight)
   {
     this->ValidPick = 1;
     this->Picker->GetPickPosition(this->LastPickPosition);
@@ -373,7 +358,7 @@ void vtkSphereWidget::HighlightSphere(int highlight)
 //----------------------------------------------------------------------------
 void vtkSphereWidget::HighlightHandle(int highlight)
 {
-  if ( highlight )
+  if (highlight)
   {
     this->ValidPick = 1;
     this->Picker->GetPickPosition(this->LastPickPosition);
@@ -407,17 +392,17 @@ void vtkSphereWidget::OnLeftButtonDown()
   // if no handles picked, then try to pick the sphere.
   vtkAssemblyPath* path = this->GetAssemblyPath(X, Y, 0., this->Picker);
 
-  if ( path == NULL )
+  if (path == nullptr)
   {
     this->State = vtkSphereWidget::Outside;
     return;
   }
-  else if (path->GetFirstNode()->GetViewProp() == this->SphereActor )
+  else if (path->GetFirstNode()->GetViewProp() == this->SphereActor)
   {
     this->State = vtkSphereWidget::Moving;
     this->HighlightSphere(1);
   }
-  else if (path->GetFirstNode()->GetViewProp() == this->HandleActor )
+  else if (path->GetFirstNode()->GetViewProp() == this->HandleActor)
   {
     this->State = vtkSphereWidget::Positioning;
     this->HighlightHandle(1);
@@ -425,7 +410,7 @@ void vtkSphereWidget::OnLeftButtonDown()
 
   this->EventCallbackCommand->SetAbortFlag(1);
   this->StartInteraction();
-  this->InvokeEvent(vtkCommand::StartInteractionEvent,NULL);
+  this->InvokeEvent(vtkCommand::StartInteractionEvent, nullptr);
   this->Interactor->Render();
 }
 
@@ -433,8 +418,7 @@ void vtkSphereWidget::OnLeftButtonDown()
 void vtkSphereWidget::OnMouseMove()
 {
   // See whether we're active
-  if ( this->State == vtkSphereWidget::Outside ||
-       this->State == vtkSphereWidget::Start )
+  if (this->State == vtkSphereWidget::Outside || this->State == vtkSphereWidget::Start)
   {
     return;
   }
@@ -452,47 +436,44 @@ void vtkSphereWidget::OnMouseMove()
   double focalPoint[4], pickPoint[4], prevPickPoint[4];
   double z;
 
-  vtkCamera *camera = this->CurrentRenderer->GetActiveCamera();
-  if ( !camera )
+  vtkCamera* camera = this->CurrentRenderer->GetActiveCamera();
+  if (!camera)
   {
     return;
   }
 
   // Compute the two points defining the motion vector
   camera->GetFocalPoint(focalPoint);
-  this->ComputeWorldToDisplay(focalPoint[0], focalPoint[1],
-                              focalPoint[2], focalPoint);
+  this->ComputeWorldToDisplay(focalPoint[0], focalPoint[1], focalPoint[2], focalPoint);
   z = focalPoint[2];
   this->ComputeDisplayToWorld(double(this->Interactor->GetLastEventPosition()[0]),
-                              double(this->Interactor->GetLastEventPosition()[1]),
-                              z,
-                              prevPickPoint);
+    double(this->Interactor->GetLastEventPosition()[1]), z, prevPickPoint);
   this->ComputeDisplayToWorld(double(X), double(Y), z, pickPoint);
 
   // Process the motion
-  if ( this->State == vtkSphereWidget::Moving )
+  if (this->State == vtkSphereWidget::Moving)
   {
     this->Translate(prevPickPoint, pickPoint);
   }
-  else if ( this->State == vtkSphereWidget::Scaling )
+  else if (this->State == vtkSphereWidget::Scaling)
   {
     this->ScaleSphere(prevPickPoint, pickPoint, X, Y);
   }
-  else if ( this->State == vtkSphereWidget::Positioning )
+  else if (this->State == vtkSphereWidget::Positioning)
   {
     this->MoveHandle(prevPickPoint, pickPoint, X, Y);
   }
 
   // Interact, if desired
   this->EventCallbackCommand->SetAbortFlag(1);
-  this->InvokeEvent(vtkCommand::InteractionEvent,NULL);
+  this->InvokeEvent(vtkCommand::InteractionEvent, nullptr);
   this->Interactor->Render();
 }
 
 //----------------------------------------------------------------------------
 void vtkSphereWidget::OnLeftButtonUp()
 {
-  if ( this->State == vtkSphereWidget::Outside )
+  if (this->State == vtkSphereWidget::Outside)
   {
     return;
   }
@@ -504,7 +485,7 @@ void vtkSphereWidget::OnLeftButtonUp()
 
   this->EventCallbackCommand->SetAbortFlag(1);
   this->EndInteraction();
-  this->InvokeEvent(vtkCommand::EndInteractionEvent,NULL);
+  this->InvokeEvent(vtkCommand::EndInteractionEvent, nullptr);
   if (this->Interactor)
   {
     this->Interactor->Render();
@@ -535,7 +516,7 @@ void vtkSphereWidget::OnRightButtonDown()
   // if no handles picked, then pick the bounding box.
   vtkAssemblyPath* path = this->GetAssemblyPath(X, Y, 0., this->Picker);
 
-  if ( path == NULL )
+  if (path == nullptr)
   {
     this->State = vtkSphereWidget::Outside;
     this->HighlightSphere(0);
@@ -548,14 +529,14 @@ void vtkSphereWidget::OnRightButtonDown()
 
   this->EventCallbackCommand->SetAbortFlag(1);
   this->StartInteraction();
-  this->InvokeEvent(vtkCommand::StartInteractionEvent,NULL);
+  this->InvokeEvent(vtkCommand::StartInteractionEvent, nullptr);
   this->Interactor->Render();
 }
 
 //----------------------------------------------------------------------------
 void vtkSphereWidget::OnRightButtonUp()
 {
-  if ( this->State == vtkSphereWidget::Outside )
+  if (this->State == vtkSphereWidget::Outside)
   {
     return;
   }
@@ -567,7 +548,7 @@ void vtkSphereWidget::OnRightButtonUp()
 
   this->EventCallbackCommand->SetAbortFlag(1);
   this->EndInteraction();
-  this->InvokeEvent(vtkCommand::EndInteractionEvent,NULL);
+  this->InvokeEvent(vtkCommand::EndInteractionEvent, nullptr);
   if (this->Interactor)
   {
     this->Interactor->Render();
@@ -576,24 +557,24 @@ void vtkSphereWidget::OnRightButtonUp()
 
 //----------------------------------------------------------------------------
 // Loop through all points and translate them
-void vtkSphereWidget::Translate(double *p1, double *p2)
+void vtkSphereWidget::Translate(double* p1, double* p2)
 {
-  if ( !this->Translation )
+  if (!this->Translation)
   {
     return;
   }
 
-  //Get the motion vector
+  // Get the motion vector
   double v[3];
   v[0] = p2[0] - p1[0];
   v[1] = p2[1] - p1[1];
   v[2] = p2[2] - p1[2];
 
-  //int res = this->SphereSource->GetResolution();
-  double *center = this->SphereSource->GetCenter();
+  // int res = this->SphereSource->GetResolution();
+  double* center = this->SphereSource->GetCenter();
 
   double center1[3];
-  for (int i=0; i<3; i++)
+  for (int i = 0; i < 3; i++)
   {
     center1[i] = center[i] + v[i];
     this->HandlePosition[i] += v[i];
@@ -606,29 +587,28 @@ void vtkSphereWidget::Translate(double *p1, double *p2)
 }
 
 //----------------------------------------------------------------------------
-void vtkSphereWidget::ScaleSphere(double *p1, double *p2,
-                                  int vtkNotUsed(X), int Y)
+void vtkSphereWidget::ScaleSphere(double* p1, double* p2, int vtkNotUsed(X), int Y)
 {
-  if ( !this->Scale )
+  if (!this->Scale)
   {
     return;
   }
 
-  //Get the motion vector
+  // Get the motion vector
   double v[3];
   v[0] = p2[0] - p1[0];
   v[1] = p2[1] - p1[1];
   v[2] = p2[2] - p1[2];
 
   double radius = this->SphereSource->GetRadius();
-  double *c = this->SphereSource->GetCenter();
+  double* c = this->SphereSource->GetCenter();
 
   // Compute the scale factor
-  double sf=0.0;
-  if ( radius > 0.0 )
+  double sf = 0.0;
+  if (radius > 0.0)
   {
     sf = vtkMath::Norm(v) / radius;
-    if ( Y > this->Interactor->GetLastEventPosition()[1] )
+    if (Y > this->Interactor->GetLastEventPosition()[1])
     {
       sf = 1.0 + sf;
     }
@@ -638,43 +618,42 @@ void vtkSphereWidget::ScaleSphere(double *p1, double *p2,
     }
     radius *= sf;
   }
-  else //Bump the radius >0 otherwise it'll never scale up from 0.0
+  else // Bump the radius >0 otherwise it'll never scale up from 0.0
   {
     radius = VTK_DBL_EPSILON;
   }
 
   this->SphereSource->SetRadius(radius);
-  this->HandlePosition[0] = c[0]+sf*(this->HandlePosition[0]-c[0]);
-  this->HandlePosition[1] = c[1]+sf*(this->HandlePosition[1]-c[1]);
-  this->HandlePosition[2] = c[2]+sf*(this->HandlePosition[2]-c[2]);
+  this->HandlePosition[0] = c[0] + sf * (this->HandlePosition[0] - c[0]);
+  this->HandlePosition[1] = c[1] + sf * (this->HandlePosition[1] - c[1]);
+  this->HandlePosition[2] = c[2] + sf * (this->HandlePosition[2] - c[2]);
   this->HandleSource->SetCenter(this->HandlePosition);
 
   this->SelectRepresentation();
 }
 
 //----------------------------------------------------------------------------
-void vtkSphereWidget::MoveHandle(double *p1, double *p2,
-                                 int vtkNotUsed(X), int vtkNotUsed(Y))
+void vtkSphereWidget::MoveHandle(double* p1, double* p2, int vtkNotUsed(X), int vtkNotUsed(Y))
 {
-  //Get the motion vector
+  // Get the motion vector
   double v[3];
   v[0] = p2[0] - p1[0];
   v[1] = p2[1] - p1[1];
   v[2] = p2[2] - p1[2];
 
   // Compute the new location of the sphere
-  double *center = this->SphereSource->GetCenter();
+  double* center = this->SphereSource->GetCenter();
   double radius = this->SphereSource->GetRadius();
 
   // set the position of the sphere
   double p[3];
-  for (int i=0; i<3; i++)
+  for (int i = 0; i < 3; i++)
   {
     p[i] = this->HandlePosition[i] + v[i];
     this->HandleDirection[i] = p[i] - center[i];
   }
 
-  this->PlaceHandle(center,radius);
+  this->PlaceHandle(center, radius);
 
   this->SelectRepresentation();
 }
@@ -682,24 +661,24 @@ void vtkSphereWidget::MoveHandle(double *p1, double *p2,
 //----------------------------------------------------------------------------
 void vtkSphereWidget::CreateDefaultProperties()
 {
-  if ( ! this->SphereProperty )
+  if (!this->SphereProperty)
   {
     this->SphereProperty = vtkProperty::New();
   }
-  if ( ! this->SelectedSphereProperty )
+  if (!this->SelectedSphereProperty)
   {
     this->SelectedSphereProperty = vtkProperty::New();
   }
 
-  if ( ! this->HandleProperty )
+  if (!this->HandleProperty)
   {
     this->HandleProperty = vtkProperty::New();
-    this->HandleProperty->SetColor(1,1,1);
+    this->HandleProperty->SetColor(1, 1, 1);
   }
-  if ( ! this->SelectedHandleProperty )
+  if (!this->SelectedHandleProperty)
   {
     this->SelectedHandleProperty = vtkProperty::New();
-    this->SelectedHandleProperty->SetColor(1,0,0);
+    this->SelectedHandleProperty->SetColor(1, 0, 0);
   }
 }
 
@@ -710,15 +689,15 @@ void vtkSphereWidget::PlaceWidget(double bds[6])
 
   this->AdjustBounds(bds, bounds, center);
 
-  radius = (bounds[1]-bounds[0]) / 2.0;
-  if ( radius > ((bounds[3]-bounds[2])/2.0) )
+  radius = (bounds[1] - bounds[0]) / 2.0;
+  if (radius > ((bounds[3] - bounds[2]) / 2.0))
   {
-    radius = (bounds[3]-bounds[2])/2.0;
+    radius = (bounds[3] - bounds[2]) / 2.0;
   }
-  radius = (bounds[1]-bounds[0]) / 2.0;
-  if ( radius > ((bounds[5]-bounds[4])/2.0) )
+  radius = (bounds[1] - bounds[0]) / 2.0;
+  if (radius > ((bounds[5] - bounds[4]) / 2.0))
   {
-    radius = (bounds[5]-bounds[4])/2.0;
+    radius = (bounds[5] - bounds[4]) / 2.0;
   }
 
   this->SphereSource->SetCenter(center);
@@ -726,27 +705,27 @@ void vtkSphereWidget::PlaceWidget(double bds[6])
   this->SphereSource->Update();
 
   // place the handle
-  this->PlaceHandle(center,radius);
+  this->PlaceHandle(center, radius);
 
-  for (int i=0; i<6; i++)
+  for (int i = 0; i < 6; i++)
   {
     this->InitialBounds[i] = bounds[i];
   }
-  this->InitialLength = sqrt((bounds[1]-bounds[0])*(bounds[1]-bounds[0]) +
-                             (bounds[3]-bounds[2])*(bounds[3]-bounds[2]) +
-                             (bounds[5]-bounds[4])*(bounds[5]-bounds[4]));
+  this->InitialLength = sqrt((bounds[1] - bounds[0]) * (bounds[1] - bounds[0]) +
+    (bounds[3] - bounds[2]) * (bounds[3] - bounds[2]) +
+    (bounds[5] - bounds[4]) * (bounds[5] - bounds[4]));
 
   this->SizeHandles();
 }
 
 //----------------------------------------------------------------------------
-void vtkSphereWidget::PlaceHandle(double *center, double radius)
+void vtkSphereWidget::PlaceHandle(double* center, double radius)
 {
   double sf = radius / vtkMath::Norm(this->HandleDirection);
 
-  this->HandlePosition[0] = center[0] + sf*this->HandleDirection[0];
-  this->HandlePosition[1] = center[1] + sf*this->HandleDirection[1];
-  this->HandlePosition[2] = center[2] + sf*this->HandleDirection[2];
+  this->HandlePosition[0] = center[0] + sf * this->HandleDirection[0];
+  this->HandlePosition[1] = center[1] + sf * this->HandleDirection[1];
+  this->HandlePosition[2] = center[2] + sf * this->HandleDirection[2];
   this->HandleSource->SetCenter(this->HandlePosition);
 }
 
@@ -760,11 +739,16 @@ void vtkSphereWidget::SizeHandles()
 //------------------------------------------------------------------------------
 void vtkSphereWidget::RegisterPickers()
 {
-  this->Interactor->GetPickingManager()->AddPicker(this->Picker, this);
+  vtkPickingManager* pm = this->GetPickingManager();
+  if (!pm)
+  {
+    return;
+  }
+  pm->AddPicker(this->Picker, this);
 }
 
 //----------------------------------------------------------------------------
-void vtkSphereWidget::GetPolyData(vtkPolyData *pd)
+void vtkSphereWidget::GetPolyData(vtkPolyData* pd)
 {
   pd->ShallowCopy(this->SphereSource->GetOutput());
 }
