@@ -12,7 +12,7 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
-#include <mpi.h>
+#include <vtk_mpi.h>
 
 #include "vtkActor.h"
 #include "vtkCallbackCommand.h"
@@ -28,17 +28,16 @@
 #include "vtkNew.h"
 #include "vtkPolyData.h"
 #include "vtkPolyDataMapper.h"
-#include "vtkRenderer.h"
+#include "vtkRTAnalyticSource.h"
 #include "vtkRenderWindow.h"
 #include "vtkRenderWindowInteractor.h"
-#include "vtkRTAnalyticSource.h"
+#include "vtkRenderer.h"
 #include "vtkSphereSource.h"
 #include "vtkUnsignedLongArray.h"
 
 #include "vtkDebugLeaks.h"
 #include "vtkRegressionTestImage.h"
 
-
 static const int scMsgLength = 10;
 
 struct GenericCommunicatorArgs_tmp
@@ -48,11 +47,11 @@ struct GenericCommunicatorArgs_tmp
   char** argv;
 };
 
-void Process2(vtkMultiProcessController *contr, void* vtkNotUsed(arg))
+void Process2(vtkMultiProcessController* contr, void* vtkNotUsed(arg))
 {
   vtkCommunicator* comm = contr->GetCommunicator();
 
-  int i, retVal=1;
+  int i, retVal = 1;
 
   // Test receiving all supported types of arrays
   vtkIntArray* ia = vtkIntArray::New();
@@ -61,7 +60,7 @@ void Process2(vtkMultiProcessController *contr, void* vtkNotUsed(arg))
     cerr << "Server error: Error receiving data." << endl;
     retVal = 0;
   }
-  for (i=0; i<ia->GetNumberOfTuples(); i++)
+  for (i = 0; i < ia->GetNumberOfTuples(); i++)
   {
     if (ia->GetValue(i) != i)
     {
@@ -78,7 +77,7 @@ void Process2(vtkMultiProcessController *contr, void* vtkNotUsed(arg))
     cerr << "Server error: Error receiving data." << endl;
     retVal = 0;
   }
-  for (i=0; i<ula->GetNumberOfTuples(); i++)
+  for (i = 0; i < ula->GetNumberOfTuples(); i++)
   {
     if (ula->GetValue(i) != static_cast<unsigned long>(i))
     {
@@ -95,7 +94,7 @@ void Process2(vtkMultiProcessController *contr, void* vtkNotUsed(arg))
     cerr << "Server error: Error receiving data." << endl;
     retVal = 0;
   }
-  for (i=0; i<ca->GetNumberOfTuples(); i++)
+  for (i = 0; i < ca->GetNumberOfTuples(); i++)
   {
     if (ca->GetValue(i) != static_cast<char>(i))
     {
@@ -112,7 +111,7 @@ void Process2(vtkMultiProcessController *contr, void* vtkNotUsed(arg))
     cerr << "Server error: Error receiving data." << endl;
     retVal = 0;
   }
-  for (i=0; i<uca->GetNumberOfTuples(); i++)
+  for (i = 0; i < uca->GetNumberOfTuples(); i++)
   {
     if (uca->GetValue(i) != static_cast<unsigned char>(i))
     {
@@ -129,7 +128,7 @@ void Process2(vtkMultiProcessController *contr, void* vtkNotUsed(arg))
     cerr << "Server error: Error receiving data." << endl;
     retVal = 0;
   }
-  for (i=0; i<fa->GetNumberOfTuples(); i++)
+  for (i = 0; i < fa->GetNumberOfTuples(); i++)
   {
     if (fa->GetValue(i) != static_cast<float>(i))
     {
@@ -146,7 +145,7 @@ void Process2(vtkMultiProcessController *contr, void* vtkNotUsed(arg))
     cerr << "Server error: Error receiving data." << endl;
     retVal = 0;
   }
-  for (i=0; i<da->GetNumberOfTuples(); i++)
+  for (i = 0; i < da->GetNumberOfTuples(); i++)
   {
     if (da->GetValue(i) != static_cast<double>(i))
     {
@@ -163,7 +162,7 @@ void Process2(vtkMultiProcessController *contr, void* vtkNotUsed(arg))
     cerr << "Server error: Error receiving data." << endl;
     retVal = 0;
   }
-  for (i=0; i<ita->GetNumberOfTuples(); i++)
+  for (i = 0; i < ita->GetNumberOfTuples(); i++)
   {
     if (ita->GetValue(i) != static_cast<vtkIdType>(i))
     {
@@ -174,7 +173,6 @@ void Process2(vtkMultiProcessController *contr, void* vtkNotUsed(arg))
   }
   ita->Delete();
 
-
   vtkNew<vtkSphereSource> sphereSource;
   sphereSource->Update();
   std::vector<vtkSmartPointer<vtkDataObject> > rdata;
@@ -193,10 +191,9 @@ void Process2(vtkMultiProcessController *contr, void* vtkNotUsed(arg))
   comm->Send(&retVal, 1, 0, 11);
 }
 
-void Process1(vtkMultiProcessController *contr, void *arg)
+void Process1(vtkMultiProcessController* contr, void* arg)
 {
-  GenericCommunicatorArgs_tmp* args =
-    reinterpret_cast<GenericCommunicatorArgs_tmp*>(arg);
+  GenericCommunicatorArgs_tmp* args = reinterpret_cast<GenericCommunicatorArgs_tmp*>(arg);
 
   vtkCommunicator* comm = contr->GetCommunicator();
 
@@ -204,7 +201,7 @@ void Process1(vtkMultiProcessController *contr, void *arg)
 
   // Test sending all supported types of arrays
   int datai[scMsgLength];
-  for (i=0; i<scMsgLength; i++)
+  for (i = 0; i < scMsgLength; i++)
   {
     datai[i] = i;
   }
@@ -218,7 +215,7 @@ void Process1(vtkMultiProcessController *contr, void *arg)
   ia->Delete();
 
   unsigned long dataul[scMsgLength];
-  for (i=0; i<scMsgLength; i++)
+  for (i = 0; i < scMsgLength; i++)
   {
     dataul[i] = static_cast<unsigned long>(i);
   }
@@ -232,7 +229,7 @@ void Process1(vtkMultiProcessController *contr, void *arg)
   ula->Delete();
 
   char datac[scMsgLength];
-  for (i=0; i<scMsgLength; i++)
+  for (i = 0; i < scMsgLength; i++)
   {
     datac[i] = static_cast<char>(i);
   }
@@ -246,7 +243,7 @@ void Process1(vtkMultiProcessController *contr, void *arg)
   ca->Delete();
 
   unsigned char datauc[scMsgLength];
-  for (i=0; i<scMsgLength; i++)
+  for (i = 0; i < scMsgLength; i++)
   {
     datauc[i] = static_cast<unsigned char>(i);
   }
@@ -260,7 +257,7 @@ void Process1(vtkMultiProcessController *contr, void *arg)
   uca->Delete();
 
   float dataf[scMsgLength];
-  for (i=0; i<scMsgLength; i++)
+  for (i = 0; i < scMsgLength; i++)
   {
     dataf[i] = static_cast<float>(i);
   }
@@ -273,9 +270,8 @@ void Process1(vtkMultiProcessController *contr, void *arg)
   }
   fa->Delete();
 
-
   double datad[scMsgLength];
-  for (i=0; i<scMsgLength; i++)
+  for (i = 0; i < scMsgLength; i++)
   {
     datad[i] = static_cast<double>(i);
   }
@@ -289,7 +285,7 @@ void Process1(vtkMultiProcessController *contr, void *arg)
   da->Delete();
 
   vtkIdType datait[scMsgLength];
-  for (i=0; i<scMsgLength; i++)
+  for (i = 0; i < scMsgLength; i++)
   {
     datait[i] = static_cast<vtkIdType>(i);
   }
@@ -310,9 +306,8 @@ void Process1(vtkMultiProcessController *contr, void *arg)
     cerr << "Client error: Error gathering data." << endl;
     *(args->retVal) = 0;
   }
-  if (rdata.size() == 2
-    && vtkPolyData::SafeDownCast(rdata[0])
-    && vtkPolyData::SafeDownCast(rdata[1]))
+  if (rdata.size() == 2 && vtkPolyData::SafeDownCast(rdata[0]) &&
+    vtkPolyData::SafeDownCast(rdata[1]))
   {
   }
   else
@@ -321,14 +316,12 @@ void Process1(vtkMultiProcessController *contr, void *arg)
     *(args->retVal) = 0;
   }
   rdata.clear();
-  if (!comm->Gather(NULL, rdata, 0))
+  if (!comm->Gather(nullptr, rdata, 0))
   {
     cerr << "Client error: Error gathering data." << endl;
     *(args->retVal) = 0;
   }
-  if (rdata.size() == 2
-    && rdata[0] == NULL
-    && vtkPolyData::SafeDownCast(rdata[1]))
+  if (rdata.size() == 2 && rdata[0] == nullptr && vtkPolyData::SafeDownCast(rdata[1]))
   {
   }
   else
@@ -343,7 +336,6 @@ void Process1(vtkMultiProcessController *contr, void *arg)
   {
     *(args->retVal) = 0;
   }
-
 }
 
 int GenericCommunicator(int argc, char* argv[])
@@ -356,7 +348,7 @@ int GenericCommunicator(int argc, char* argv[])
   MPI_Init(&argc, &argv);
 
   vtkMPIController* contr = vtkMPIController::New();
-  contr->Initialize(&argc, &argv,1);
+  contr->Initialize(&argc, &argv, 1);
   contr->CreateOutputWindow();
 
   // Added for regression test.
@@ -369,7 +361,7 @@ int GenericCommunicator(int argc, char* argv[])
   // ----------------------------------------------
 
   contr->SetMultipleMethod(0, Process1, &args);
-  contr->SetMultipleMethod(1, Process2, 0);
+  contr->SetMultipleMethod(1, Process2, nullptr);
   contr->MultipleMethodExecute();
 
   contr->Finalize();
