@@ -22,13 +22,13 @@
  * be set up with a vtkContextDevice2D derived class that provides the functions
  * to facilitate the low level calls to the context. Currently only an OpenGL
  * based device is provided, but this could be extended in the future.
-*/
+ */
 
 #ifndef vtkContext2D_h
 #define vtkContext2D_h
 
-#include "vtkRenderingContext2DModule.h" // For export macro
 #include "vtkObject.h"
+#include "vtkRenderingContext2DModule.h" // For export macro
 
 class vtkWindow;
 
@@ -45,6 +45,7 @@ class vtkContextDevice2D;
 class vtkPen;
 class vtkBrush;
 class vtkImageData;
+class vtkPolyData;
 class vtkTransform2D;
 class vtkAbstractContextBufferId;
 
@@ -52,19 +53,19 @@ class VTKRENDERINGCONTEXT2D_EXPORT vtkContext2D : public vtkObject
 {
 public:
   vtkTypeMacro(vtkContext2D, vtkObject);
-  virtual void PrintSelf(ostream &os, vtkIndent indent);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
   /**
    * Creates a 2D Painter object.
    */
-  static vtkContext2D *New();
+  static vtkContext2D* New();
 
   /**
    * Begin painting on a vtkContextDevice2D, no painting can occur before this call
    * has been made. Only one painter is allowed at a time on any given paint
    * device. Returns true if successful, otherwise false.
    */
-  bool Begin(vtkContextDevice2D *device);
+  bool Begin(vtkContextDevice2D* device);
 
   vtkGetObjectMacro(Device, vtkContextDevice2D);
 
@@ -86,7 +87,7 @@ public:
    * \pre bufferId_exists: bufferId!=0
    * \post started: GetBufferIdMode()
    */
-  void BufferIdModeBegin(vtkAbstractContextBufferId *bufferId);
+  void BufferIdModeBegin(vtkAbstractContextBufferId* bufferId);
 
   /**
    * Finalize BufferId creation Mode. It makes sure that the content of the
@@ -110,25 +111,25 @@ public:
    * Draw a line between the specified points.
    * Note: Fastest path - points packed in x and y.
    */
-  void DrawLine(vtkPoints2D *points);
+  void DrawLine(vtkPoints2D* points);
 
   /**
    * Draw a poly line between the specified points.
    */
-  void DrawPoly(float *x, float *y, int n);
+  void DrawPoly(float* x, float* y, int n);
 
   /**
    * Draw a poly line between the specified points - fastest code path due to
    * memory layout of the coordinates.
    */
-  void DrawPoly(vtkPoints2D *points);
+  void DrawPoly(vtkPoints2D* points);
 
   /**
    * Draw a poly line between the specified points, where the float array is of
    * size 2*n and the points are packed x1, y1, x2, y2 etc.
    * Note: Fastest code path - points packed in x and y.
    */
-  void DrawPoly(float *points, int n);
+  void DrawPoly(float* points, int n);
 
   /**
    * Draw a poly line between the specified points, where the float array is of
@@ -136,20 +137,19 @@ public:
    * the colors array, which must have nc_comps components (defining a single color).
    * Note: Fastest code path - points packed in x and y.
    */
-  void DrawPoly(float *points, int n,
-                unsigned char *colors, int nc_comps);
+  void DrawPoly(float* points, int n, unsigned char* colors, int nc_comps);
 
   /**
    * Draw multiple lines between the specified pairs of points.
    * \sa DrawPoly()
    */
-  void DrawLines(vtkPoints2D *points);
+  void DrawLines(vtkPoints2D* points);
 
   /**
    * Draw multiple lines between the specified pairs of points
    * \sa DrawPoly()
    */
-  void DrawLines(float *points, int n);
+  void DrawLines(float* points, int n);
 
   /**
    * Draw a point at the supplied x and y coordinate
@@ -159,27 +159,27 @@ public:
   /**
    * Draw the specified number of points using the x and y arrays supplied
    */
-  void DrawPoints(float *x, float *y, int n);
+  void DrawPoints(float* x, float* y, int n);
 
   /**
    * Draw a poly line between the specified points - fastest code path due to
    * memory layout of the coordinates.
    */
-  void DrawPoints(vtkPoints2D *points);
+  void DrawPoints(vtkPoints2D* points);
 
   /**
    * Draw a poly line between the specified points, where the float array is of
    * size 2*n and the points are packed x1, y1, x2, y2 etc.
    * Note: Fastest code path - points packed in x and y.
    */
-  void DrawPoints(float *points, int n);
+  void DrawPoints(float* points, int n);
 
   /**
    * Draw a series of point sprites, images centred at the points supplied.
    * The supplied vtkImageData is the sprite to be drawn, only squares will be
    * drawn and the size is set using SetPointSize.
    */
-  void DrawPointSprites(vtkImageData *sprite, vtkPoints2D *points);
+  void DrawPointSprites(vtkImageData* sprite, vtkPoints2D* points);
 
   //@{
   /**
@@ -188,10 +188,9 @@ public:
    * drawn and the size is set using SetPointSize. Points will be colored by
    * the colors array, which must be the same length as points.
    */
-  void DrawPointSprites(vtkImageData *sprite, vtkPoints2D *points,
-                        vtkUnsignedCharArray *colors);
-  void DrawPointSprites(vtkImageData *sprite, float *points, int n,
-                        unsigned char *colors, int nc_comps);
+  void DrawPointSprites(vtkImageData* sprite, vtkPoints2D* points, vtkUnsignedCharArray* colors);
+  void DrawPointSprites(
+    vtkImageData* sprite, float* points, int n, unsigned char* colors, int nc_comps);
   //@}
 
   /**
@@ -199,7 +198,7 @@ public:
    * The supplied vtkImageData is the sprite to be drawn, only squares will be
    * drawn and the size is set using SetPointSize.
    */
-  void DrawPointSprites(vtkImageData *sprite, float *points, int n);
+  void DrawPointSprites(vtkImageData* sprite, float* points, int n);
 
   //@{
   /**
@@ -214,12 +213,12 @@ public:
    * \param colors is an optional array of colors.
    * \param nc_comps is the number of components for the color.
    */
-  virtual void DrawMarkers(int shape, bool highlight, float *points, int n,
-                           unsigned char *colors, int nc_comps);
-  virtual void DrawMarkers(int shape, bool highlight, float *points, int n);
-  virtual void DrawMarkers(int shape, bool highlight, vtkPoints2D *points);
-  virtual void DrawMarkers(int shape, bool highlight, vtkPoints2D *points,
-                           vtkUnsignedCharArray *colors);
+  virtual void DrawMarkers(
+    int shape, bool highlight, float* points, int n, unsigned char* colors, int nc_comps);
+  virtual void DrawMarkers(int shape, bool highlight, float* points, int n);
+  virtual void DrawMarkers(int shape, bool highlight, vtkPoints2D* points);
+  virtual void DrawMarkers(
+    int shape, bool highlight, vtkPoints2D* points, vtkUnsignedCharArray* colors);
   //@}
 
   /**
@@ -231,37 +230,55 @@ public:
   /**
    * Draw a quadrilateral at the specified points (4 points, 8 floats in x, y).
    */
-  void DrawQuad(float x1, float y1, float x2, float y2,
-                float x3, float y3, float x4, float y4);
-  void DrawQuad(float *p);
+  void DrawQuad(float x1, float y1, float x2, float y2, float x3, float y3, float x4, float y4);
+  void DrawQuad(float* p);
   //@}
 
   //@{
   /**
    * Draw a strip of quads
    */
-  void DrawQuadStrip(vtkPoints2D *points);
-  void DrawQuadStrip(float *p, int n);
+  void DrawQuadStrip(vtkPoints2D* points);
+  void DrawQuadStrip(float* p, int n);
   //@}
 
   /**
    * Draw a polygon specified specified by the points using the x and y arrays
    * supplied
    */
-  void DrawPolygon(float *x, float *y, int n);
+  void DrawPolygon(float* x, float* y, int n);
 
   /**
    * Draw a polygon defined by the specified points - fastest code path due to
    * memory layout of the coordinates.
    */
-  void DrawPolygon(vtkPoints2D *points);
+  void DrawPolygon(vtkPoints2D* points);
 
   /**
    * Draw a polygon defined by the specified points, where the float array is
    * of size 2*n and the points are packed x1, y1, x2, y2 etc.
    * Note: Fastest code path - points packed in x and y.
    */
-  void DrawPolygon(float *points, int n);
+  void DrawPolygon(float* points, int n);
+
+  /**
+   * Draw a polygon specified specified by the points using the x and y arrays
+   * supplied
+   */
+  void DrawPolygon(float* x, float* y, int n, unsigned char* color, int nc_comps);
+
+  /**
+   * Draw a polygon defined by the specified points - fastest code path due to
+   * memory layout of the coordinates.
+   */
+  void DrawPolygon(vtkPoints2D* points, unsigned char* color, int nc_comps);
+
+  /**
+   * Draw a polygon defined by the specified points, where the float array is
+   * of size 2*n and the points are packed x1, y1, x2, y2 etc.
+   * Note: Fastest code path - points packed in x and y.
+   */
+  void DrawPolygon(float* points, int n, unsigned char* color, int nc_comps);
 
   /**
    * Draw an ellipse with center at x, y and radii rx, ry.
@@ -278,9 +295,8 @@ public:
    * \pre positive_inRadius: inRadius>=0
    * \pre ordered_radii: inRadius<=outRadius
    */
-  void DrawWedge(float x, float y, float outRadius,
-                 float inRadius,float startAngle,
-                 float stopAngle);
+  void DrawWedge(
+    float x, float y, float outRadius, float inRadius, float startAngle, float stopAngle);
 
   /**
    * Draw an elliptic wedge with center at x, y, outer radii outRx, outRy,
@@ -293,18 +309,15 @@ public:
    * \pre ordered_rx: inRx<=outRx
    * \pre ordered_ry: inRy<=outRy
    */
-  void DrawEllipseWedge(float x, float y, float outRx, float outRy,
-                        float inRx, float inRy, float startAngle,
-                        float stopAngle);
-
+  void DrawEllipseWedge(float x, float y, float outRx, float outRy, float inRx, float inRy,
+    float startAngle, float stopAngle);
 
   /**
    * Draw a circular arc with center at x,y with radius r between angles
    * startAngle and stopAngle (expressed in degrees).
    * \pre positive_radius: r>=0
    */
-  void DrawArc(float x, float y, float r, float startAngle,
-               float stopAngle);
+  void DrawArc(float x, float y, float r, float startAngle, float stopAngle);
 
   /**
    * Draw an elliptic arc with center at x,y with radii rX and rY between
@@ -312,27 +325,32 @@ public:
    * \pre positive_rX: rX>=0
    * \pre positive_rY: rY>=0
    */
-  void DrawEllipticArc(float x, float y, float rX, float rY, float startAngle,
-                       float stopAngle);
-
+  void DrawEllipticArc(float x, float y, float rX, float rY, float startAngle, float stopAngle);
 
   /**
    * Draw the supplied image at the given x, y location (bottom corner).
    */
-  void DrawImage(float x, float y, vtkImageData *image);
+  void DrawImage(float x, float y, vtkImageData* image);
 
   /**
    * Draw the supplied image at the given x, y location (bottom corner).
    * Scale the supplied image by scale.
    */
-  void DrawImage(float x, float y, float scale, vtkImageData *image);
+  void DrawImage(float x, float y, float scale, vtkImageData* image);
 
   /**
    * Draw the supplied image at the given position. The origin, width, and
    * height are specified by the supplied vtkRectf variable pos. The image
    * will be drawn scaled to that size.
    */
-  void DrawImage(const vtkRectf& pos, vtkImageData *image);
+  void DrawImage(const vtkRectf& pos, vtkImageData* image);
+
+  /**
+   * Draw the supplied polyData at the given x, y position (bottom corner).
+   * \note Supports only 2D meshes.
+   */
+  void DrawPolyData(
+    float x, float y, vtkPolyData* polyData, vtkUnsignedCharArray* colors, int scalarMode);
 
   //@{
   /**
@@ -340,20 +358,20 @@ public:
    * of the text properties respecting the rectangle. The points should be
    * supplied as bottom corner (x, y), width, height.
    */
-  void DrawStringRect(vtkPoints2D *rect, const vtkStdString &string);
-  void DrawStringRect(vtkPoints2D *rect, const vtkUnicodeString &string);
-  void DrawStringRect(vtkPoints2D *rect, const char* string);
+  void DrawStringRect(vtkPoints2D* rect, const vtkStdString& string);
+  void DrawStringRect(vtkPoints2D* rect, const vtkUnicodeString& string);
+  void DrawStringRect(vtkPoints2D* rect, const char* string);
   //@}
 
   //@{
   /**
    * Draw some text to the screen.
    */
-  void DrawString(vtkPoints2D *point, const vtkStdString &string);
-  void DrawString(float x, float y, const vtkStdString &string);
-  void DrawString(vtkPoints2D *point, const vtkUnicodeString &string);
-  void DrawString(float x, float y, const vtkUnicodeString &string);
-  void DrawString(vtkPoints2D *point, const char* string);
+  void DrawString(vtkPoints2D* point, const vtkStdString& string);
+  void DrawString(float x, float y, const vtkStdString& string);
+  void DrawString(vtkPoints2D* point, const vtkUnicodeString& string);
+  void DrawString(float x, float y, const vtkUnicodeString& string);
+  void DrawString(vtkPoints2D* point, const char* string);
   void DrawString(float x, float y, const char* string);
   //@}
 
@@ -367,18 +385,17 @@ public:
    * NOTE:the text justification from the current text property is
    * NOT considered when computing these bounds.
    */
-  void ComputeStringBounds(const vtkStdString &string, vtkPoints2D *bounds);
-  void ComputeStringBounds(const vtkStdString &string, float bounds[4]);
-  void ComputeStringBounds(const vtkUnicodeString &string, vtkPoints2D *bounds);
-  void ComputeStringBounds(const vtkUnicodeString &string, float bounds[4]);
-  void ComputeStringBounds(const char* string, vtkPoints2D *bounds);
+  void ComputeStringBounds(const vtkStdString& string, vtkPoints2D* bounds);
+  void ComputeStringBounds(const vtkStdString& string, float bounds[4]);
+  void ComputeStringBounds(const vtkUnicodeString& string, vtkPoints2D* bounds);
+  void ComputeStringBounds(const vtkUnicodeString& string, float bounds[4]);
+  void ComputeStringBounds(const char* string, vtkPoints2D* bounds);
   void ComputeStringBounds(const char* string, float bounds[4]);
   //@}
 
   /**
    * Compute the bounds of the supplied string while taking into account the
-   * justification of the currently applied text property. Simple rotations
-   * (0, 90, 180, 270 degrees) are also propertly taken into account.
+   * justification and rotation of the currently applied text property.
    */
   void ComputeJustifiedStringBounds(const char* string, float bounds[4]);
 
@@ -388,8 +405,7 @@ public:
    * is also used to update the vtkTextProperty used by this object.
    * NOTE: text rotation is ignored for the purposes of this function.
    */
-  int ComputeFontSizeForBoundedString(const vtkStdString &string, float width,
-                                      float height);
+  int ComputeFontSizeForBoundedString(const vtkStdString& string, float width, float height);
 
   //@{
   /**
@@ -399,10 +415,10 @@ public:
    * be enabled manually during build configuration. This method will do nothing
    * but print a warning if vtkMathTextUtilities::GetInstance() returns NULL.
    */
-  void DrawMathTextString(vtkPoints2D *point, const vtkStdString &string);
-  void DrawMathTextString(float x, float y, const vtkStdString &string);
-  void DrawMathTextString(vtkPoints2D *point, const char *string);
-  void DrawMathTextString(float x, float y, const char *string);
+  void DrawMathTextString(vtkPoints2D* point, const vtkStdString& string);
+  void DrawMathTextString(float x, float y, const vtkStdString& string);
+  void DrawMathTextString(vtkPoints2D* point, const char* string);
+  void DrawMathTextString(float x, float y, const char* string);
   //@}
 
   //@{
@@ -414,17 +430,14 @@ public:
    * If MathText is not available on the target device the non-MathText string
    * in "fallback" is rendered using DrawString.
    */
-  void DrawMathTextString(vtkPoints2D *point, const vtkStdString &string,
-                          const vtkStdString &fallback);
-  void DrawMathTextString(float x, float y, const vtkStdString &string,
-                          const vtkStdString &fallback);
-  void DrawMathTextString(vtkPoints2D *point, const char *string,
-                          const char *fallback);
-  void DrawMathTextString(float x, float y, const char *string,
-                          const char *fallback);
+  void DrawMathTextString(
+    vtkPoints2D* point, const vtkStdString& string, const vtkStdString& fallback);
+  void DrawMathTextString(
+    float x, float y, const vtkStdString& string, const vtkStdString& fallback);
+  void DrawMathTextString(vtkPoints2D* point, const char* string, const char* fallback);
+  void DrawMathTextString(float x, float y, const char* string, const char* fallback);
   //@}
 
-
   /**
    * Return true if MathText rendering available on the current device.
    */
@@ -435,7 +448,7 @@ public:
    * lines, points and related primitives. This makes a deep copy of the vtkPen
    * object in the vtkContext2D, it does not hold a pointer to the supplied object.
    */
-  void ApplyPen(vtkPen *pen);
+  void ApplyPen(vtkPen* pen);
 
   /**
    * Get the pen which controls the outlines of shapes, as well as lines,
@@ -449,7 +462,7 @@ public:
    * lines, points and related primitives. This makes a deep copy of the vtkBrush
    * object in the vtkContext2D, it does not hold a pointer to the supplied object.
    */
-  void ApplyBrush(vtkBrush *brush);
+  void ApplyBrush(vtkBrush* brush);
 
   /**
    * Get the pen which controls the outlines of shapes as well as lines, points
@@ -462,7 +475,7 @@ public:
    * This makes a deep copy of the vtkTextProperty object in the vtkContext2D,
    * it does not hold a pointer to the supplied object.
    */
-  void ApplyTextProp(vtkTextProperty *prop);
+  void ApplyTextProp(vtkTextProperty* prop);
 
   /**
    * Get the text properties object for the vtkContext2D.
@@ -474,7 +487,7 @@ public:
    * matrix of the transform. Note, this is set immediately, later changes to
    * the matrix will have no effect until it is set again.
    */
-  void SetTransform(vtkTransform2D *transform);
+  void SetTransform(vtkTransform2D* transform);
 
   /**
    * Compute the current transform applied to the context.
@@ -487,7 +500,7 @@ public:
    * the matrix will have no effect until it is set again. The matrix of the
    * transform will multiply the current context transform.
    */
-  void AppendTransform(vtkTransform2D *transform);
+  void AppendTransform(vtkTransform2D* transform);
 
   //@{
   /**
@@ -515,23 +528,23 @@ public:
    * Get the vtkContext3D device, in order to do some 3D rendering. This API
    * is very experimental, and may be moved around.
    */
-  vtkGetObjectMacro(Context3D, vtkContext3D)
-  virtual void SetContext3D(vtkContext3D *context);
+  vtkGetObjectMacro(Context3D, vtkContext3D);
+  virtual void SetContext3D(vtkContext3D* context);
   //@}
 
 protected:
   vtkContext2D();
-  ~vtkContext2D();
+  ~vtkContext2D() override;
 
-  vtkContextDevice2D *Device; // The underlying device
-  vtkTransform2D *Transform;  // Current transform
+  vtkContextDevice2D* Device; // The underlying device
+  vtkTransform2D* Transform;  // Current transform
 
-  vtkAbstractContextBufferId *BufferId;
-  vtkContext3D *Context3D; // May be very temporary - get at a 3D version.
+  vtkAbstractContextBufferId* BufferId;
+  vtkContext3D* Context3D; // May be very temporary - get at a 3D version.
 
 private:
-  vtkContext2D(const vtkContext2D &) VTK_DELETE_FUNCTION;
-  void operator=(const vtkContext2D &) VTK_DELETE_FUNCTION;
+  vtkContext2D(const vtkContext2D&) = delete;
+  void operator=(const vtkContext2D&) = delete;
 
   /**
    * Calculate position of text for rendering in a rectangle.
@@ -548,7 +561,6 @@ private:
    * represent width and height.
    */
   vtkVector2f CalculateTextPosition(float rect[4]);
-
 };
 
 inline int vtkContext2D::FloatToInt(float x)
@@ -566,4 +578,4 @@ inline int vtkContext2D::FloatToInt(float x)
   return static_cast<int>(x + tol);
 }
 
-#endif //vtkContext2D_h
+#endif // vtkContext2D_h
