@@ -16,26 +16,27 @@
 #include "vtkOpenGLContextBufferId.h"
 
 #include "vtkIntArray.h"
-#include <cassert>
 #include "vtkObjectFactory.h"
+#include "vtkOpenGLError.h"
+#include "vtkOpenGLRenderWindow.h"
+#include "vtkOpenGLState.h"
 #include "vtkOpenGLTexture.h"
 #include "vtkTextureObject.h"
-#include "vtkOpenGLRenderWindow.h"
-#include "vtkOpenGLError.h"
+#include <cassert>
 
 vtkStandardNewMacro(vtkOpenGLContextBufferId);
 
 // ----------------------------------------------------------------------------
 vtkOpenGLContextBufferId::vtkOpenGLContextBufferId()
 {
-  this->Texture=0;
-  this->Context=0;
+  this->Texture = nullptr;
+  this->Context = nullptr;
 }
 
 // ----------------------------------------------------------------------------
 vtkOpenGLContextBufferId::~vtkOpenGLContextBufferId()
 {
-  if(this->Texture!=0)
+  if (this->Texture != nullptr)
   {
     vtkErrorMacro("texture should have been released.");
   }
@@ -44,17 +45,17 @@ vtkOpenGLContextBufferId::~vtkOpenGLContextBufferId()
 // ----------------------------------------------------------------------------
 void vtkOpenGLContextBufferId::ReleaseGraphicsResources()
 {
-  if(this->Texture!=0)
+  if (this->Texture != nullptr)
   {
     this->Texture->Delete();
-    this->Texture=0;
+    this->Texture = nullptr;
   }
 }
 
 // ----------------------------------------------------------------------------
-void vtkOpenGLContextBufferId::SetContext(vtkRenderWindow *context)
+void vtkOpenGLContextBufferId::SetContext(vtkRenderWindow* context)
 {
-  vtkOpenGLRenderWindow *c = vtkOpenGLRenderWindow::SafeDownCast(context);
+  vtkOpenGLRenderWindow* c = vtkOpenGLRenderWindow::SafeDownCast(context);
   if (this->Context != c)
   {
     this->ReleaseGraphicsResources();
@@ -64,7 +65,7 @@ void vtkOpenGLContextBufferId::SetContext(vtkRenderWindow *context)
 }
 
 // ----------------------------------------------------------------------------
-vtkRenderWindow *vtkOpenGLContextBufferId::GetContext()
+vtkRenderWindow* vtkOpenGLContextBufferId::GetContext()
 {
   return this->Context;
 }
@@ -72,46 +73,43 @@ vtkRenderWindow *vtkOpenGLContextBufferId::GetContext()
 // ----------------------------------------------------------------------------
 bool vtkOpenGLContextBufferId::IsSupported()
 {
-  assert("pre: context_is_set" && this->GetContext()!=0);
+  assert("pre: context_is_set" && this->GetContext() != nullptr);
   return vtkTextureObject::IsSupported(this->Context);
 }
 
 // ----------------------------------------------------------------------------
 void vtkOpenGLContextBufferId::Allocate()
 {
-  assert("pre: positive_width" && this->GetWidth()>0);
-  assert("pre: positive_height" && this->GetHeight()>0);
-  assert("pre: context_is_set" && this->GetContext()!=0);
+  assert("pre: positive_width" && this->GetWidth() > 0);
+  assert("pre: positive_height" && this->GetHeight() > 0);
+  assert("pre: context_is_set" && this->GetContext() != nullptr);
 
-  if(this->Texture==0)
+  if (this->Texture == nullptr)
   {
-    this->Texture=vtkTextureObject::New();
+    this->Texture = vtkTextureObject::New();
     this->Texture->SetContext(this->Context);
   }
   this->Context->MakeCurrent();
   // 3: RGB
   this->Texture->Allocate2D(static_cast<unsigned int>(this->GetWidth()),
-                            static_cast<unsigned int>(this->GetHeight()),3,
-                            VTK_UNSIGNED_CHAR);
+    static_cast<unsigned int>(this->GetHeight()), 3, VTK_UNSIGNED_CHAR);
 }
 
 // ----------------------------------------------------------------------------
 bool vtkOpenGLContextBufferId::IsAllocated() const
 {
-  return this->Texture!=0 &&
-    this->Texture->GetWidth()==static_cast<unsigned int>(this->Width) &&
-    this->Texture->GetHeight()==static_cast<unsigned int>(this->Height);
+  return this->Texture != nullptr &&
+    this->Texture->GetWidth() == static_cast<unsigned int>(this->Width) &&
+    this->Texture->GetHeight() == static_cast<unsigned int>(this->Height);
 }
 
 // ----------------------------------------------------------------------------
-void vtkOpenGLContextBufferId::SetValues(int srcXmin,
-                                         int srcYmin)
+void vtkOpenGLContextBufferId::SetValues(int srcXmin, int srcYmin)
 {
   assert("pre: is_allocated" && this->IsAllocated());
 
   // copy the current read buffer to the texture.
-  this->Texture->CopyFromFrameBuffer(srcXmin,srcYmin,0,0,this->Width,
-                                     this->Height);
+  this->Texture->CopyFromFrameBuffer(srcXmin, srcYmin, 0, 0, this->Width, this->Height);
 }
 
 // ----------------------------------------------------------------------------
@@ -121,103 +119,74 @@ vtkIdType vtkOpenGLContextBufferId::GetPickedItem(int x, int y)
 
   vtkOpenGLClearErrorMacro();
 
-  vtkIdType result=-1;
-  if(x<0 || x>=this->Width)
+  vtkIdType result = -1;
+  if (x < 0 || x >= this->Width)
   {
-    vtkDebugMacro(<<"x mouse position out of range: x=" << x << " (width="
-                    << this->Width <<")");
+    vtkDebugMacro(<< "x mouse position out of range: x=" << x << " (width=" << this->Width << ")");
   }
   else
   {
-    if(y<0 || y>=this->Height)
+    if (y < 0 || y >= this->Height)
     {
-      vtkDebugMacro(<<"y mouse position out of range: y="<< y << " (height="
-                      << this->Height << ")");
+      vtkDebugMacro(<< "y mouse position out of range: y=" << y << " (height=" << this->Height
+                    << ")");
     }
     else
     {
       this->Context->MakeCurrent();
+      vtkOpenGLState* ostate = this->Context->GetState();
+
       // Render texture to current write buffer. Texel x,y is rendered at
       // pixel x,y (instead of pixel 0,0 to work around pixel ownership test).
       GLint savedDrawBuffer;
-      glGetIntegerv(GL_DRAW_BUFFER,&savedDrawBuffer);
-      bool savedDepthTest=glIsEnabled(GL_DEPTH_TEST)==GL_TRUE;
-      bool savedAlphaTest=glIsEnabled(GL_ALPHA_TEST)==GL_TRUE;
-      bool savedStencilTest=glIsEnabled(GL_STENCIL_TEST)==GL_TRUE;
-      bool savedBlend=glIsEnabled(GL_BLEND)==GL_TRUE;
+      glGetIntegerv(GL_DRAW_BUFFER, &savedDrawBuffer);
 
-      if(savedDrawBuffer!=GL_BACK_LEFT)
-      {
-        glDrawBuffer(GL_BACK_LEFT);
-      }
-      if(savedDepthTest)
-      {
-        glDisable(GL_DEPTH_TEST);
-      }
-      if(savedAlphaTest)
-      {
-        glDisable(GL_ALPHA_TEST);
-      }
-      if(savedStencilTest)
-      {
-        glDisable(GL_STENCIL_TEST);
-      }
-      if(savedBlend)
-      {
-        glDisable(GL_BLEND);
-      }
+      vtkOpenGLState::ScopedglEnableDisable dsaver(ostate, GL_DEPTH_TEST);
+      vtkOpenGLState::ScopedglEnableDisable ssaver(ostate, GL_STENCIL_TEST);
+      vtkOpenGLState::ScopedglEnableDisable bsaver(ostate, GL_BLEND);
 
-      this->Texture->CopyToFrameBuffer(x,y,x,y,x,y,
-        this->Context->GetSize()[0],
-        this->Context->GetSize()[1],NULL,NULL);
+      if (savedDrawBuffer != GL_BACK_LEFT)
+      {
+        ostate->vtkglDrawBuffer(GL_BACK_LEFT);
+      }
+      ostate->vtkglDisable(GL_DEPTH_TEST);
+      ostate->vtkglDisable(GL_STENCIL_TEST);
+      ostate->vtkglDisable(GL_BLEND);
+
+      this->Texture->CopyToFrameBuffer(x, y, x, y, x, y, this->Context->GetSize()[0],
+        this->Context->GetSize()[1], nullptr, nullptr);
 
       GLint savedReadBuffer;
-      glGetIntegerv(GL_READ_BUFFER,&savedReadBuffer);
-      glReadBuffer(GL_BACK_LEFT);
+      glGetIntegerv(GL_READ_BUFFER, &savedReadBuffer);
+      ostate->vtkglReadBuffer(GL_BACK_LEFT);
 
       // To workaround pixel ownership test,
       // get value from current read buffer at pixel (x,y) instead of just
       // (0,0).
-      glPixelStorei(GL_PACK_ALIGNMENT,1);
+      glPixelStorei(GL_PACK_ALIGNMENT, 1);
       unsigned char rgb[3];
-      rgb[0]=5;
-      rgb[1]=1;
-      rgb[2]=8;
-      glReadPixels(x,y,1,1,GL_RGB,GL_UNSIGNED_BYTE,rgb);
+      rgb[0] = 5;
+      rgb[1] = 1;
+      rgb[2] = 8;
+      glReadPixels(x, y, 1, 1, GL_RGB, GL_UNSIGNED_BYTE, rgb);
 
-      if(savedReadBuffer!=GL_BACK_LEFT)
+      if (savedReadBuffer != GL_BACK_LEFT)
       {
-        glReadBuffer(static_cast<GLenum>(savedReadBuffer));
+        ostate->vtkglReadBuffer(static_cast<GLenum>(savedReadBuffer));
       }
-      if(savedDrawBuffer!=GL_BACK_LEFT)
+      if (savedDrawBuffer != GL_BACK_LEFT)
       {
-        glDrawBuffer(static_cast<GLenum>(savedDrawBuffer));
-      }
-      if(savedDepthTest)
-      {
-        glEnable(GL_DEPTH_TEST);
-      }
-      if(savedAlphaTest)
-      {
-        glEnable(GL_ALPHA_TEST);
-      }
-      if(savedStencilTest)
-      {
-        glEnable(GL_STENCIL_TEST);
-      }
-      if(savedBlend)
-      {
-        glEnable(GL_BLEND);
+        ostate->vtkglDrawBuffer(static_cast<GLenum>(savedDrawBuffer));
       }
 
-      int value=(static_cast<int>(rgb[0])<<16)|(static_cast<int>(rgb[1])<<8)
-        |static_cast<int>(rgb[2]);
+      int value = (static_cast<int>(rgb[0]) << 16) | (static_cast<int>(rgb[1]) << 8) |
+        static_cast<int>(rgb[2]);
 
-      result=static_cast<vtkIdType>(value-1);
+      result = static_cast<vtkIdType>(value - 1);
     }
   }
 
-  assert("post: valid_result" && result>=-1 );
+  assert("post: valid_result" && result >= -1);
 
   vtkOpenGLCheckErrorMacro("failed after GetPickedItem");
 
@@ -225,7 +194,7 @@ vtkIdType vtkOpenGLContextBufferId::GetPickedItem(int x, int y)
 }
 
 //-----------------------------------------------------------------------------
-void vtkOpenGLContextBufferId::PrintSelf(ostream &os, vtkIndent indent)
+void vtkOpenGLContextBufferId::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
