@@ -26,6 +26,7 @@
 #include "vtkOpenGLRenderWindow.h"
 #include "vtkOpenGLRenderer.h"
 #include "vtkOpenGLShaderCache.h"
+#include "vtkOpenGLState.h"
 #include "vtkOpenGLVertexArrayObject.h"
 #include "vtkOpenGLVertexBufferObject.h"
 #include "vtkPen.h"
@@ -35,41 +36,11 @@
 class vtkOpenGLContextDevice3D::Private
 {
 public:
-  Private()
-  {
-    this->SavedDepthTest = GL_TRUE;
-  }
+  Private() = default;
 
-  ~Private()
-  {
-  }
+  ~Private() = default;
 
-  void SaveGLState()
-  {
-    this->SavedDepthTest = glIsEnabled(GL_DEPTH_TEST);
-    this->SavedBlending = glIsEnabled(GL_BLEND);
-  }
-
-  void RestoreGLState()
-  {
-    this->SetGLCapability(GL_DEPTH_TEST, this->SavedDepthTest);
-    this->SetGLCapability(GL_BLEND, this->SavedBlending);
-  }
-
-  void SetGLCapability(GLenum capability, GLboolean state)
-  {
-    if (state)
-    {
-      glEnable(capability);
-    }
-    else
-    {
-      glDisable(capability);
-    }
-    vtkOpenGLStaticCheckErrorMacro("failed after SetGLCapability");
-  }
-
-  void Transpose(double *in, double *transposed)
+  void Transpose(double* in, double* transposed)
   {
     transposed[0] = in[0];
     transposed[1] = in[4];
@@ -94,52 +65,46 @@ public:
 
   void SetLineType(int type)
   {
-  if (type == vtkPen::SOLID_LINE || type == vtkPen::NO_PEN)
-  {
-    return;
+    if (type == vtkPen::SOLID_LINE || type == vtkPen::NO_PEN)
+    {
+      return;
+    }
+    vtkGenericWarningMacro(<< "Line Stipples are no longer supported");
   }
-  vtkGenericWarningMacro(<< "Line Stipples are no longer supported");
-  }
-
-  // Store the previous GL state so that we can restore it when complete
-  GLboolean SavedLighting;
-  GLboolean SavedDepthTest;
-  GLboolean SavedBlending;
 
   vtkVector2i Dim;
   vtkVector2i Offset;
 };
 
-vtkStandardNewMacro(vtkOpenGLContextDevice3D)
+vtkStandardNewMacro(vtkOpenGLContextDevice3D);
 
-vtkOpenGLContextDevice3D::vtkOpenGLContextDevice3D() : Storage(new Private)
+vtkOpenGLContextDevice3D::vtkOpenGLContextDevice3D()
+  : Storage(new Private)
 {
   this->ModelMatrix = vtkTransform::New();
   this->ModelMatrix->Identity();
-  this->VBO =  new vtkOpenGLHelper;
-  this->VCBO =  new vtkOpenGLHelper;
-  this->ClippingPlaneStates.resize(6,false);
+  this->VBO = new vtkOpenGLHelper;
+  this->VCBO = new vtkOpenGLHelper;
+  this->ClippingPlaneStates.resize(6, false);
   this->ClippingPlaneValues.resize(24);
 }
 
 vtkOpenGLContextDevice3D::~vtkOpenGLContextDevice3D()
 {
   delete this->VBO;
-  this->VBO = 0;
+  this->VBO = nullptr;
   delete this->VCBO;
-  this->VCBO = 0;
+  this->VCBO = nullptr;
 
   this->ModelMatrix->Delete();
   delete Storage;
 }
 
-void vtkOpenGLContextDevice3D::Initialize(vtkRenderer *ren,
-  vtkOpenGLContextDevice2D *dev)
+void vtkOpenGLContextDevice3D::Initialize(vtkRenderer* ren, vtkOpenGLContextDevice2D* dev)
 {
   this->Device2D = dev;
   this->Renderer = ren;
-  this->RenderWindow =
-    vtkOpenGLRenderWindow::SafeDownCast(ren->GetVTKWindow());
+  this->RenderWindow = vtkOpenGLRenderWindow::SafeDownCast(ren->GetVTKWindow());
 }
 //-----------------------------------------------------------------------------
 void vtkOpenGLContextDevice3D::Begin(vtkViewport* vtkNotUsed(viewport))
@@ -151,20 +116,19 @@ void vtkOpenGLContextDevice3D::Begin(vtkViewport* vtkNotUsed(viewport))
   }
 }
 
-void vtkOpenGLContextDevice3D::SetMatrices(vtkShaderProgram *prog)
+void vtkOpenGLContextDevice3D::SetMatrices(vtkShaderProgram* prog)
 {
+  vtkOpenGLState* ostate = this->RenderWindow->GetState();
+  ostate->vtkglDisable(GL_SCISSOR_TEST);
+  prog->SetUniformMatrix("WCDCMatrix", this->Device2D->GetProjectionMatrix());
 
-    glDisable(GL_SCISSOR_TEST);
-  prog->SetUniformMatrix("WCDCMatrix",
-    this->Device2D->GetProjectionMatrix());
-
-  vtkMatrix4x4 *mvm = this->Device2D->GetModelMatrix();
-  vtkMatrix4x4 *tmp = vtkMatrix4x4::New();
-  vtkMatrix4x4::Multiply4x4(mvm,this->ModelMatrix->GetMatrix(),tmp);
+  vtkMatrix4x4* mvm = this->Device2D->GetModelMatrix();
+  vtkMatrix4x4* tmp = vtkMatrix4x4::New();
+  vtkMatrix4x4::Multiply4x4(mvm, this->ModelMatrix->GetMatrix(), tmp);
 
   prog->SetUniformMatrix("MCWCMatrix",
-//    this->ModelMatrix->GetMatrix());
-  tmp);
+    //    this->ModelMatrix->GetMatrix());
+    tmp);
   tmp->Delete();
 
   // add all the clipping planes
@@ -174,10 +138,10 @@ void vtkOpenGLContextDevice3D::SetMatrices(vtkShaderProgram *prog)
   {
     if (this->ClippingPlaneStates[i])
     {
-      planeEquations[numClipPlanes][0] = this->ClippingPlaneValues[i*4];
-      planeEquations[numClipPlanes][1] = this->ClippingPlaneValues[i*4+1];
-      planeEquations[numClipPlanes][2] = this->ClippingPlaneValues[i*4+2];
-      planeEquations[numClipPlanes][3] = this->ClippingPlaneValues[i*4+3];
+      planeEquations[numClipPlanes][0] = this->ClippingPlaneValues[i * 4];
+      planeEquations[numClipPlanes][1] = this->ClippingPlaneValues[i * 4 + 1];
+      planeEquations[numClipPlanes][2] = this->ClippingPlaneValues[i * 4 + 2];
+      planeEquations[numClipPlanes][3] = this->ClippingPlaneValues[i * 4 + 3];
       numClipPlanes++;
     }
   }
@@ -185,11 +149,8 @@ void vtkOpenGLContextDevice3D::SetMatrices(vtkShaderProgram *prog)
   prog->SetUniform4fv("clipPlanes", 6, planeEquations);
 }
 
-void vtkOpenGLContextDevice3D::BuildVBO(
-  vtkOpenGLHelper *cellBO,
-  const float *f, int nv,
-  const unsigned char *colors, int nc,
-  float *tcoords)
+void vtkOpenGLContextDevice3D::BuildVBO(vtkOpenGLHelper* cellBO, const float* f, int nv,
+  const unsigned char* colors, int nc, float* tcoords)
 {
   int stride = 3;
   int cOffset = 0;
@@ -206,32 +167,32 @@ void vtkOpenGLContextDevice3D::BuildVBO(
   }
 
   std::vector<float> va;
-  va.resize(nv*stride);
-  vtkucfloat c;
+  va.resize(nv * stride);
+  vtkFourByteUnion c;
   for (int i = 0; i < nv; i++)
   {
-    va[i*stride] = f[i*3];
-    va[i*stride+1] = f[i*3+1];
-    va[i*stride+2] = f[i*3+2];
+    va[i * stride] = f[i * 3];
+    va[i * stride + 1] = f[i * 3 + 1];
+    va[i * stride + 2] = f[i * 3 + 2];
     if (colors)
     {
-      c.c[0] = colors[nc*i];
-      c.c[1] = colors[nc*i+1];
-      c.c[2] = colors[nc*i+2];
+      c.c[0] = colors[nc * i];
+      c.c[1] = colors[nc * i + 1];
+      c.c[2] = colors[nc * i + 2];
       if (nc == 4)
       {
-        c.c[3] = colors[nc*i+3];
+        c.c[3] = colors[nc * i + 3];
       }
       else
       {
-        c.c[3] =  255;
+        c.c[3] = 255;
       }
-      va[i*stride+cOffset] = c.f;
+      va[i * stride + cOffset] = c.f;
     }
     if (tcoords)
     {
-      va[i*stride+tOffset] = tcoords[i*2];
-      va[i*stride+tOffset+1] = tcoords[i*2+1];
+      va[i * stride + tOffset] = tcoords[i * 2];
+      va[i * stride + tOffset + 1] = tcoords[i * 2 + 1];
     }
   }
 
@@ -239,31 +200,22 @@ void vtkOpenGLContextDevice3D::BuildVBO(
   cellBO->IBO->Upload(va, vtkOpenGLBufferObject::ArrayBuffer);
   cellBO->VAO->Bind();
   if (!cellBO->VAO->AddAttributeArray(
-        cellBO->Program, cellBO->IBO,
-        "vertexMC", 0,
-        sizeof(float)*stride,
-        VTK_FLOAT, 3, false))
+        cellBO->Program, cellBO->IBO, "vertexMC", 0, sizeof(float) * stride, VTK_FLOAT, 3, false))
   {
     vtkErrorMacro(<< "Error setting vertexMC in shader VAO.");
   }
   if (colors)
   {
-    if (!cellBO->VAO->AddAttributeArray(
-          cellBO->Program, cellBO->IBO,
-          "vertexScalar", sizeof(float)*cOffset,
-          sizeof(float)*stride,
-          VTK_UNSIGNED_CHAR, 4, true))
+    if (!cellBO->VAO->AddAttributeArray(cellBO->Program, cellBO->IBO, "vertexScalar",
+          sizeof(float) * cOffset, sizeof(float) * stride, VTK_UNSIGNED_CHAR, 4, true))
     {
       vtkErrorMacro(<< "Error setting vertexScalar in shader VAO.");
     }
   }
   if (tcoords)
   {
-    if (!cellBO->VAO->AddAttributeArray(
-          cellBO->Program, cellBO->IBO,
-          "tcoordMC", sizeof(float)*tOffset,
-          sizeof(float)*stride,
-          VTK_FLOAT, 2, false))
+    if (!cellBO->VAO->AddAttributeArray(cellBO->Program, cellBO->IBO, "tcoordMC",
+          sizeof(float) * tOffset, sizeof(float) * stride, VTK_FLOAT, 2, false))
     {
       vtkErrorMacro(<< "Error setting tcoordMC in shader VAO.");
     }
@@ -276,37 +228,36 @@ void vtkOpenGLContextDevice3D::ReadyVBOProgram()
 {
   if (!this->VBO->Program)
   {
-    this->VBO->Program  =
-        this->RenderWindow->GetShaderCache()->ReadyShaderProgram(
-        // vertex shader
-        "//VTK::System::Dec\n"
-        "attribute vec3 vertexMC;\n"
-        "uniform mat4 WCDCMatrix;\n"
-        "uniform mat4 MCWCMatrix;\n"
-        "uniform int numClipPlanes;\n"
-        "uniform vec4 clipPlanes[6];\n"
-        "varying float clipDistances[6];\n"
-        "void main() {\n"
-        "vec4 vertex = vec4(vertexMC.xyz, 1.0);\n"
-        "for (int planeNum = 0; planeNum < numClipPlanes; planeNum++)\n"
-        "  {\n"
-        "  clipDistances[planeNum] = dot(clipPlanes[planeNum], vertex*MCWCMatrix);\n"
-        "  }\n"
-        "gl_Position = vertex*MCWCMatrix*WCDCMatrix; }\n",
-        // fragment shader
-        "//VTK::System::Dec\n"
-        "//VTK::Output::Dec\n"
-        "uniform vec4 vertexColor;\n"
-        "uniform int numClipPlanes;\n"
-        "varying float clipDistances[6];\n"
-        "void main() { \n"
-        "  for (int planeNum = 0; planeNum < numClipPlanes; planeNum++)\n"
-        "    {\n"
-        "    if (clipDistances[planeNum] < 0.0) discard;\n"
-        "    }\n"
-        "  gl_FragData[0] = vertexColor; }",
-        // geometry shader
-        "");
+    this->VBO->Program = this->RenderWindow->GetShaderCache()->ReadyShaderProgram(
+      // vertex shader
+      "//VTK::System::Dec\n"
+      "in vec3 vertexMC;\n"
+      "uniform mat4 WCDCMatrix;\n"
+      "uniform mat4 MCWCMatrix;\n"
+      "uniform int numClipPlanes;\n"
+      "uniform vec4 clipPlanes[6];\n"
+      "out float clipDistances[6];\n"
+      "void main() {\n"
+      "vec4 vertex = vec4(vertexMC.xyz, 1.0);\n"
+      "for (int planeNum = 0; planeNum < numClipPlanes; planeNum++)\n"
+      "  {\n"
+      "  clipDistances[planeNum] = dot(clipPlanes[planeNum], vertex*MCWCMatrix);\n"
+      "  }\n"
+      "gl_Position = vertex*MCWCMatrix*WCDCMatrix; }\n",
+      // fragment shader
+      "//VTK::System::Dec\n"
+      "//VTK::Output::Dec\n"
+      "uniform vec4 vertexColor;\n"
+      "uniform int numClipPlanes;\n"
+      "in float clipDistances[6];\n"
+      "void main() { \n"
+      "  for (int planeNum = 0; planeNum < numClipPlanes; planeNum++)\n"
+      "    {\n"
+      "    if (clipDistances[planeNum] < 0.0) discard;\n"
+      "    }\n"
+      "  gl_FragData[0] = vertexColor; }",
+      // geometry shader
+      "");
   }
   else
   {
@@ -318,40 +269,39 @@ void vtkOpenGLContextDevice3D::ReadyVCBOProgram()
 {
   if (!this->VCBO->Program)
   {
-    this->VCBO->Program  =
-        this->RenderWindow->GetShaderCache()->ReadyShaderProgram(
-        // vertex shader
-        "//VTK::System::Dec\n"
-        "attribute vec3 vertexMC;\n"
-        "attribute vec4 vertexScalar;\n"
-        "uniform mat4 WCDCMatrix;\n"
-        "uniform mat4 MCWCMatrix;\n"
-        "varying vec4 vertexColor;\n"
-        "uniform int numClipPlanes;\n"
-        "uniform vec4 clipPlanes[6];\n"
-        "varying float clipDistances[6];\n"
-        "void main() {\n"
-        "vec4 vertex = vec4(vertexMC.xyz, 1.0);\n"
-        "vertexColor = vertexScalar;\n"
-        "for (int planeNum = 0; planeNum < numClipPlanes; planeNum++)\n"
-        "  {\n"
-        "  clipDistances[planeNum] = dot(clipPlanes[planeNum], vertex*MCWCMatrix);\n"
-        "  }\n"
-        "gl_Position = vertex*MCWCMatrix*WCDCMatrix; }\n",
-        // fragment shader
-        "//VTK::System::Dec\n"
-        "//VTK::Output::Dec\n"
-        "varying vec4 vertexColor;\n"
-        "uniform int numClipPlanes;\n"
-        "varying float clipDistances[6];\n"
-        "void main() { \n"
-        "  for (int planeNum = 0; planeNum < numClipPlanes; planeNum++)\n"
-        "    {\n"
-        "    if (clipDistances[planeNum] < 0.0) discard;\n"
-        "    }\n"
-        "  gl_FragData[0] = vertexColor; }",
-        // geometry shader
-        "");
+    this->VCBO->Program = this->RenderWindow->GetShaderCache()->ReadyShaderProgram(
+      // vertex shader
+      "//VTK::System::Dec\n"
+      "in vec3 vertexMC;\n"
+      "in vec4 vertexScalar;\n"
+      "uniform mat4 WCDCMatrix;\n"
+      "uniform mat4 MCWCMatrix;\n"
+      "out vec4 vertexColor;\n"
+      "uniform int numClipPlanes;\n"
+      "uniform vec4 clipPlanes[6];\n"
+      "out float clipDistances[6];\n"
+      "void main() {\n"
+      "vec4 vertex = vec4(vertexMC.xyz, 1.0);\n"
+      "vertexColor = vertexScalar;\n"
+      "for (int planeNum = 0; planeNum < numClipPlanes; planeNum++)\n"
+      "  {\n"
+      "  clipDistances[planeNum] = dot(clipPlanes[planeNum], vertex*MCWCMatrix);\n"
+      "  }\n"
+      "gl_Position = vertex*MCWCMatrix*WCDCMatrix; }\n",
+      // fragment shader
+      "//VTK::System::Dec\n"
+      "//VTK::Output::Dec\n"
+      "in vec4 vertexColor;\n"
+      "uniform int numClipPlanes;\n"
+      "in float clipDistances[6];\n"
+      "void main() { \n"
+      "  for (int planeNum = 0; planeNum < numClipPlanes; planeNum++)\n"
+      "    {\n"
+      "    if (clipDistances[planeNum] < 0.0) discard;\n"
+      "    }\n"
+      "  gl_FragData[0] = vertexColor; }",
+      // geometry shader
+      "");
   }
   else
   {
@@ -361,8 +311,7 @@ void vtkOpenGLContextDevice3D::ReadyVCBOProgram()
 
 bool vtkOpenGLContextDevice3D::HaveWideLines()
 {
-  if (this->Pen->GetWidth() > 1.0
-      && vtkOpenGLRenderWindow::GetContextSupportsOpenGL32())
+  if (this->Pen->GetWidth() > 1.0)
   {
     // we have wide lines, but the OpenGL implementation may
     // actually support them, check the range to see if we
@@ -373,11 +322,10 @@ bool vtkOpenGLContextDevice3D::HaveWideLines()
   return false;
 }
 
-
-void vtkOpenGLContextDevice3D::DrawPoly(const float *verts, int n,
-                                        const unsigned char *colors, int nc)
+void vtkOpenGLContextDevice3D::DrawPoly(
+  const float* verts, int n, const unsigned char* colors, int nc)
 {
-  assert("verts must be non-null" && verts != NULL);
+  assert("verts must be non-null" && verts != nullptr);
   assert("n must be greater than 0" && n > 0);
 
   if (this->Pen->GetLineType() == vtkPen::NO_PEN)
@@ -391,29 +339,37 @@ void vtkOpenGLContextDevice3D::DrawPoly(const float *verts, int n,
 
   this->Storage->SetLineType(this->Pen->GetLineType());
 
-  vtkOpenGLHelper *cbo = 0;
+  vtkOpenGLHelper* cbo = nullptr;
   if (colors)
   {
     this->ReadyVCBOProgram();
     cbo = this->VCBO;
+    if (!cbo->Program)
+    {
+      return;
+    }
   }
   else
   {
     this->ReadyVBOProgram();
     cbo = this->VBO;
+    if (!cbo->Program)
+    {
+      return;
+    }
     if (this->HaveWideLines())
     {
-      vtkWarningMacro(<< "a line width has been requested that is larger than your system supports");
+      vtkWarningMacro(
+        << "a line width has been requested that is larger than your system supports");
     }
     else
     {
       glLineWidth(this->Pen->GetWidth());
     }
-    cbo->Program->SetUniform4uc("vertexColor",
-      this->Pen->GetColor());
+    cbo->Program->SetUniform4uc("vertexColor", this->Pen->GetColor());
   }
 
-  this->BuildVBO(cbo, verts, n, colors, nc, NULL);
+  this->BuildVBO(cbo, verts, n, colors, nc, nullptr);
   this->SetMatrices(cbo->Program);
 
   glDrawArrays(GL_LINE_STRIP, 0, n);
@@ -427,12 +383,11 @@ void vtkOpenGLContextDevice3D::DrawPoly(const float *verts, int n,
   vtkOpenGLCheckErrorMacro("failed after DrawPoly");
 }
 
-
 //-----------------------------------------------------------------------------
-void vtkOpenGLContextDevice3D::DrawLines(const float *verts, int n,
-                                         const unsigned char *colors, int nc)
+void vtkOpenGLContextDevice3D::DrawLines(
+  const float* verts, int n, const unsigned char* colors, int nc)
 {
-  assert("verts must be non-null" && verts != NULL);
+  assert("verts must be non-null" && verts != nullptr);
   assert("n must be greater than 0" && n > 0);
 
   if (this->Pen->GetLineType() == vtkPen::NO_PEN)
@@ -452,21 +407,28 @@ void vtkOpenGLContextDevice3D::DrawLines(const float *verts, int n,
   }
   glLineWidth(this->Pen->GetWidth());
 
-  vtkOpenGLHelper *cbo = 0;
+  vtkOpenGLHelper* cbo = nullptr;
   if (colors)
   {
     this->ReadyVCBOProgram();
     cbo = this->VCBO;
+    if (!cbo->Program)
+    {
+      return;
+    }
   }
   else
   {
     this->ReadyVBOProgram();
     cbo = this->VBO;
-    cbo->Program->SetUniform4uc("vertexColor",
-      this->Pen->GetColor());
+    if (!cbo->Program)
+    {
+      return;
+    }
+    cbo->Program->SetUniform4uc("vertexColor", this->Pen->GetColor());
   }
 
-  this->BuildVBO(cbo, verts, n, colors, nc, NULL);
+  this->BuildVBO(cbo, verts, n, colors, nc, nullptr);
   this->SetMatrices(cbo->Program);
 
   glDrawArrays(GL_LINE, 0, n);
@@ -480,10 +442,10 @@ void vtkOpenGLContextDevice3D::DrawLines(const float *verts, int n,
   vtkOpenGLCheckErrorMacro("failed after DrawLines");
 }
 
-void vtkOpenGLContextDevice3D::DrawPoints(const float *verts, int n,
-                                          const unsigned char *colors, int nc)
+void vtkOpenGLContextDevice3D::DrawPoints(
+  const float* verts, int n, const unsigned char* colors, int nc)
 {
-  assert("verts must be non-null" && verts != NULL);
+  assert("verts must be non-null" && verts != nullptr);
   assert("n must be greater than 0" && n > 0);
 
   vtkOpenGLClearErrorMacro();
@@ -492,21 +454,28 @@ void vtkOpenGLContextDevice3D::DrawPoints(const float *verts, int n,
 
   glPointSize(this->Pen->GetWidth());
 
-  vtkOpenGLHelper *cbo = 0;
+  vtkOpenGLHelper* cbo = nullptr;
   if (colors)
   {
     this->ReadyVCBOProgram();
     cbo = this->VCBO;
+    if (!cbo->Program)
+    {
+      return;
+    }
   }
   else
   {
     this->ReadyVBOProgram();
     cbo = this->VBO;
-    cbo->Program->SetUniform4uc("vertexColor",
-      this->Pen->GetColor());
+    if (!cbo->Program)
+    {
+      return;
+    }
+    cbo->Program->SetUniform4uc("vertexColor", this->Pen->GetColor());
   }
 
-  this->BuildVBO(cbo, verts, n, colors, nc, NULL);
+  this->BuildVBO(cbo, verts, n, colors, nc, nullptr);
   this->SetMatrices(cbo->Program);
 
   glDrawArrays(GL_POINTS, 0, n);
@@ -519,32 +488,38 @@ void vtkOpenGLContextDevice3D::DrawPoints(const float *verts, int n,
   vtkOpenGLCheckErrorMacro("failed DrawPoints");
 }
 
-void vtkOpenGLContextDevice3D::DrawTriangleMesh(const float *mesh, int n,
-                                                const unsigned char *colors,
-                                                int nc)
+void vtkOpenGLContextDevice3D::DrawTriangleMesh(
+  const float* mesh, int n, const unsigned char* colors, int nc)
 {
-  assert("mesh must be non-null" && mesh != NULL);
+  assert("mesh must be non-null" && mesh != nullptr);
   assert("n must be greater than 0" && n > 0);
 
   vtkOpenGLClearErrorMacro();
 
   this->EnableDepthBuffer();
 
-  vtkOpenGLHelper *cbo = 0;
+  vtkOpenGLHelper* cbo = nullptr;
   if (colors)
   {
     this->ReadyVCBOProgram();
     cbo = this->VCBO;
+    if (!cbo->Program)
+    {
+      return;
+    }
   }
   else
   {
     this->ReadyVBOProgram();
     cbo = this->VBO;
-    cbo->Program->SetUniform4uc("vertexColor",
-      this->Pen->GetColor());
+    if (!cbo->Program)
+    {
+      return;
+    }
+    cbo->Program->SetUniform4uc("vertexColor", this->Pen->GetColor());
   }
 
-  this->BuildVBO(cbo, mesh, n, colors, nc, NULL);
+  this->BuildVBO(cbo, mesh, n, colors, nc, nullptr);
   this->SetMatrices(cbo->Program);
 
   glDrawArrays(GL_TRIANGLES, 0, n);
@@ -557,12 +532,12 @@ void vtkOpenGLContextDevice3D::DrawTriangleMesh(const float *mesh, int n,
   vtkOpenGLCheckErrorMacro("failed after DrawTriangleMesh");
 }
 
-void vtkOpenGLContextDevice3D::ApplyPen(vtkPen *pen)
+void vtkOpenGLContextDevice3D::ApplyPen(vtkPen* pen)
 {
   this->Pen->DeepCopy(pen);
 }
 
-void vtkOpenGLContextDevice3D::ApplyBrush(vtkBrush *brush)
+void vtkOpenGLContextDevice3D::ApplyBrush(vtkBrush* brush)
 {
   this->Brush->DeepCopy(brush);
 }
@@ -579,28 +554,28 @@ void vtkOpenGLContextDevice3D::PopMatrix()
   this->ModelMatrix->Pop();
 }
 
-void vtkOpenGLContextDevice3D::SetMatrix(vtkMatrix4x4 *m)
+void vtkOpenGLContextDevice3D::SetMatrix(vtkMatrix4x4* m)
 {
   this->ModelMatrix->SetMatrix(m);
 }
 
-void vtkOpenGLContextDevice3D::GetMatrix(vtkMatrix4x4 *m)
+void vtkOpenGLContextDevice3D::GetMatrix(vtkMatrix4x4* m)
 {
   m->DeepCopy(this->ModelMatrix->GetMatrix());
 }
 
-void vtkOpenGLContextDevice3D::MultiplyMatrix(vtkMatrix4x4 *m)
+void vtkOpenGLContextDevice3D::MultiplyMatrix(vtkMatrix4x4* m)
 {
   this->ModelMatrix->Concatenate(m);
 }
 
-void vtkOpenGLContextDevice3D::SetClipping(const vtkRecti &rect)
+void vtkOpenGLContextDevice3D::SetClipping(const vtkRecti& rect)
 {
   // Check the bounds, and clamp if necessary
   GLint vp[4] = { this->Storage->Offset.GetX(), this->Storage->Offset.GetY(),
-                  this->Storage->Dim.GetX(), this->Storage->Dim.GetY()};
+    this->Storage->Dim.GetX(), this->Storage->Dim.GetY() };
 
-  if (rect.GetX() > 0 && rect.GetX() < vp[2] )
+  if (rect.GetX() > 0 && rect.GetX() < vp[2])
   {
     vp[0] += rect.GetX();
   }
@@ -617,22 +592,17 @@ void vtkOpenGLContextDevice3D::SetClipping(const vtkRecti &rect)
     vp[3] = rect.GetHeight();
   }
 
-  glScissor(vp[0], vp[1], vp[2], vp[3]);
+  vtkOpenGLState* ostate = this->RenderWindow->GetState();
+  ostate->vtkglScissor(vp[0], vp[1], vp[2], vp[3]);
 }
 
 void vtkOpenGLContextDevice3D::EnableClipping(bool enable)
 {
-  if (enable)
-  {
-    glEnable(GL_SCISSOR_TEST);
-  }
-  else
-  {
-    glDisable(GL_SCISSOR_TEST);
-  }
+  vtkOpenGLState* ostate = this->RenderWindow->GetState();
+  ostate->SetEnumState(GL_SCISSOR_TEST, enable);
 }
 
-void vtkOpenGLContextDevice3D::EnableClippingPlane(int i, double *planeEquation)
+void vtkOpenGLContextDevice3D::EnableClippingPlane(int i, double* planeEquation)
 {
   if (i >= 6)
   {
@@ -640,10 +610,10 @@ void vtkOpenGLContextDevice3D::EnableClippingPlane(int i, double *planeEquation)
     return;
   }
   this->ClippingPlaneStates[i] = true;
-  this->ClippingPlaneValues[i*4] = planeEquation[0];
-  this->ClippingPlaneValues[i*4+1] = planeEquation[1];
-  this->ClippingPlaneValues[i*4+2] = planeEquation[2];
-  this->ClippingPlaneValues[i*4+3] = planeEquation[3];
+  this->ClippingPlaneValues[i * 4] = planeEquation[0];
+  this->ClippingPlaneValues[i * 4 + 1] = planeEquation[1];
+  this->ClippingPlaneValues[i * 4 + 2] = planeEquation[2];
+  this->ClippingPlaneValues[i * 4 + 3] = planeEquation[3];
 }
 
 void vtkOpenGLContextDevice3D::DisableClippingPlane(int i)
@@ -658,15 +628,17 @@ void vtkOpenGLContextDevice3D::DisableClippingPlane(int i)
 
 void vtkOpenGLContextDevice3D::EnableDepthBuffer()
 {
-  glEnable(GL_DEPTH_TEST);
+  vtkOpenGLState* ostate = this->RenderWindow->GetState();
+  ostate->vtkglEnable(GL_DEPTH_TEST);
 }
 
 void vtkOpenGLContextDevice3D::DisableDepthBuffer()
 {
-  glDisable(GL_DEPTH_TEST);
+  vtkOpenGLState* ostate = this->RenderWindow->GetState();
+  ostate->vtkglDisable(GL_DEPTH_TEST);
 }
 
-void vtkOpenGLContextDevice3D::PrintSelf(ostream &os, vtkIndent indent)
+void vtkOpenGLContextDevice3D::PrintSelf(ostream& os, vtkIndent indent)
 {
   Superclass::PrintSelf(os, indent);
 }
