@@ -15,8 +15,8 @@
 
 #include "vtkActor.h"
 #include "vtkCamera.h"
-#include "vtkCompositeDataSet.h"
 #include "vtkCompositeDataDisplayAttributes.h"
+#include "vtkCompositeDataSet.h"
 #include "vtkCompositePolyDataMapper2.h"
 #include "vtkCullerCollection.h"
 #include "vtkInformation.h"
@@ -24,15 +24,16 @@
 #include "vtkMultiBlockDataSet.h"
 #include "vtkNew.h"
 #include "vtkProperty.h"
-#include "vtkRenderer.h"
 #include "vtkRenderWindow.h"
 #include "vtkRenderWindowInteractor.h"
+#include "vtkRenderer.h"
+#include "vtkRenderingOpenGLConfigure.h"
 #include "vtkSmartPointer.h"
 #include "vtkTimerLog.h"
 #include "vtkTrivialProducer.h"
 
-#include <vtkTestUtilities.h>
 #include <vtkRegressionTestImage.h>
+#include <vtkTestUtilities.h>
 
 #define syntheticData
 #ifdef syntheticData
@@ -48,12 +49,10 @@ int TestCompositePolyDataMapper2(int argc, char* argv[])
   {
     timeit = true;
   }
-  vtkSmartPointer<vtkRenderWindow> win =
-    vtkSmartPointer<vtkRenderWindow>::New();
+  vtkSmartPointer<vtkRenderWindow> win = vtkSmartPointer<vtkRenderWindow>::New();
   vtkSmartPointer<vtkRenderWindowInteractor> iren =
     vtkSmartPointer<vtkRenderWindowInteractor>::New();
-  vtkSmartPointer<vtkRenderer> ren =
-    vtkSmartPointer<vtkRenderer>::New();
+  vtkSmartPointer<vtkRenderer> ren = vtkSmartPointer<vtkRenderer>::New();
   win->AddRenderer(ren);
   win->SetInteractor(iren);
 
@@ -72,7 +71,7 @@ int TestCompositePolyDataMapper2(int argc, char* argv[])
 
   // build a composite dataset
   vtkNew<vtkMultiBlockDataSet> data;
-  int blocksPerLevel[3] = {1,32,64};
+  int blocksPerLevel[3] = { 1, 32, 64 };
   if (timeit)
   {
     blocksPerLevel[1] = 64;
@@ -86,31 +85,33 @@ int TestCompositePolyDataMapper2(int argc, char* argv[])
   int numLeaves = 0;
   int numNodes = 0;
   vtkStdString blockName("Rolf");
+  mapper->SetInputDataObject(data.GetPointer());
   for (int level = 1; level < numLevels; ++level)
   {
-    int nblocks=blocksPerLevel[level];
+    int nblocks = blocksPerLevel[level];
     for (unsigned parent = levelStart; parent < levelEnd; ++parent)
     {
       blocks[parent]->SetNumberOfBlocks(nblocks);
-      for (int block=0; block < nblocks; ++block, ++numNodes)
+      for (int block = 0; block < nblocks; ++block, ++numNodes)
       {
         if (level == numLevels - 1)
         {
           vtkNew<vtkPolyData> child;
-          cyl->SetCenter(block*0.25, 0.0, parent*0.5);
+          cyl->SetCenter(block * 0.25, 0.0, parent * 0.5);
           cyl->Update();
           child->DeepCopy(cyl->GetOutput(0));
-          blocks[parent]->SetBlock(
-            block, (block % 2) ? NULL : child.GetPointer());
-          blocks[parent]->GetMetaData(block)->Set(
-            vtkCompositeDataSet::NAME(), blockName.c_str());
+          blocks[parent]->SetBlock(block, (block % 2) ? nullptr : child.GetPointer());
+          blocks[parent]->GetMetaData(block)->Set(vtkCompositeDataSet::NAME(), blockName.c_str());
           // test not setting it on some
           if (block % 11)
           {
-            mapper->SetBlockColor(parent+numLeaves+1,
-              vtkMath::HSVToRGB(0.8*block/nblocks, 0.2 + 0.8*((parent - levelStart) % 8)/7.0, 1.0));
-//            mapper->SetBlockOpacity(parent+numLeaves, (block + 3) % 7 == 0 ? 0.3 : 1.0);
-            mapper->SetBlockVisibility(parent+numLeaves, (block % 7) != 0);
+            double rgb[3];
+            vtkMath::HSVToRGB(0.8 * block / nblocks, 0.2 + 0.8 * ((parent - levelStart) % 8) / 7.0,
+              1.0, rgb + 0, rgb + 1, rgb + 2);
+            mapper->SetBlockColor(parent + numLeaves + 1, rgb);
+            //            mapper->SetBlockOpacity(parent+numLeaves, (block + 3) % 7 == 0 ? 0.3
+            //            : 1.0);
+            mapper->SetBlockVisibility(parent + numLeaves, (block % 7) != 0);
           }
           ++numLeaves;
         }
@@ -126,8 +127,6 @@ int TestCompositePolyDataMapper2(int argc, char* argv[])
     levelEnd = static_cast<unsigned>(blocks.size());
   }
 
-  mapper->SetInputData((vtkPolyData *)(data.GetPointer()));
-
 #else
 
   vtkNew<vtkXMLMultiBlockDataReader> reader;
@@ -140,33 +139,33 @@ int TestCompositePolyDataMapper2(int argc, char* argv[])
 
   // comment the following in/out for worst/best case
   // for (int i = 0; i < 20000; ++i)
-  //   {
-  //   mapper->SetBlockColor(i,
-  //     vtkMath::HSVToRGB(0.8*(i%100)/100.0, 1.0, 1.0));
-  //   }
+  // {
+  //   double r, g, b;
+  //   vtkMath::HSVToRGB(0.8*(i%100)/100.0, 1.0, 1.0, &r, &g, &b);
+  //   mapper->SetBlockColor(i, r, g, b);
+  // }
 
 #endif
 
-  vtkSmartPointer<vtkActor> actor =
-    vtkSmartPointer<vtkActor>::New();
+  vtkSmartPointer<vtkActor> actor = vtkSmartPointer<vtkActor>::New();
   actor->SetMapper(mapper);
-  actor->GetProperty()->SetEdgeColor(1,0,0);
-//  actor->GetProperty()->EdgeVisibilityOn();
+  actor->GetProperty()->SetEdgeColor(1, 0, 0);
+  //  actor->GetProperty()->EdgeVisibilityOn();
   ren->AddActor(actor);
-  win->SetSize(400,400);
+  win->SetSize(400, 400);
 
   ren->RemoveCuller(ren->GetCullers()->GetLastItem());
   ren->ResetCamera();
 
   vtkSmartPointer<vtkTimerLog> timer = vtkSmartPointer<vtkTimerLog>::New();
-  win->Render();  // get the window up
+  win->Render(); // get the window up
 
 #ifdef syntheticData
   // modify the data to force a rebuild of OpenGL structs
   // after rendering set one cylinder to white
-  mapper->SetBlockColor(1011,1.0,1.0,1.0);
-  mapper->SetBlockOpacity(1011,1.0);
-  mapper->SetBlockVisibility(1011,1.0);
+  mapper->SetBlockColor(1011, 1.0, 1.0, 1.0);
+  mapper->SetBlockOpacity(1011, 1.0);
+  mapper->SetBlockVisibility(1011, 1.0);
 #endif
 
   timer->StartTimer();
@@ -179,20 +178,20 @@ int TestCompositePolyDataMapper2(int argc, char* argv[])
   int numFrames = (timeit ? 300 : 2);
   for (int i = 0; i <= numFrames; i++)
   {
-    ren->GetActiveCamera()->Elevation(40.0/numFrames);
-    ren->GetActiveCamera()->Zoom(pow(2.0,1.0/numFrames));
-    ren->GetActiveCamera()->Roll(20.0/numFrames);
+    ren->GetActiveCamera()->Elevation(40.0 / numFrames);
+    ren->GetActiveCamera()->Zoom(pow(2.0, 1.0 / numFrames));
+    ren->GetActiveCamera()->Roll(20.0 / numFrames);
     win->Render();
   }
 
   timer->StopTimer();
   if (timeit)
   {
-    double t =  timer->GetElapsedTime();
-    cout << "Avg Frame time: " << t/numFrames << " Frame Rate: " << numFrames / t << "\n";
+    double t = timer->GetElapsedTime();
+    cout << "Avg Frame time: " << t / numFrames << " Frame Rate: " << numFrames / t << "\n";
   }
-  int retVal = vtkRegressionTestImageThreshold( win.GetPointer(),15);
-  if ( retVal == vtkRegressionTester::DO_INTERACTOR)
+  int retVal = vtkRegressionTestImageThreshold(win.GetPointer(), 15);
+  if (retVal == vtkRegressionTester::DO_INTERACTOR)
   {
     iren->Start();
   }
