@@ -22,13 +22,13 @@
  * calls. This an abstract class. Concrete classes are OS specific.
  * @sa
  * vtkGPUInfo vtkDirectXGPUInfoList vtkCoreGraphicsGPUInfoList
-*/
+ */
 
 #ifndef vtkGPUInfoList_h
 #define vtkGPUInfoList_h
 
-#include "vtkRenderingCoreModule.h" // For export macro
 #include "vtkObject.h"
+#include "vtkRenderingCoreModule.h" // For export macro
 
 class vtkGPUInfoListArray; // STL Pimpl
 class vtkGPUInfo;
@@ -36,9 +36,9 @@ class vtkGPUInfo;
 class VTKRENDERINGCORE_EXPORT vtkGPUInfoList : public vtkObject
 {
 public:
-  static vtkGPUInfoList *New();
+  static vtkGPUInfoList* New();
   vtkTypeMacro(vtkGPUInfoList, vtkObject);
-  void PrintSelf(ostream& os, vtkIndent indent);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
   /**
    * Build the list of vtkInfoGPU if not done yet.
@@ -65,7 +65,7 @@ public:
    * \pre valid_index: i>=0 && i<GetNumberOfGPUs()
    * \post result_exists: result!=0
    */
-  virtual vtkGPUInfo *GetGPUInfo(int i);
+  virtual vtkGPUInfo* GetGPUInfo(int i);
 
 protected:
   //@{
@@ -73,15 +73,15 @@ protected:
    * Default constructor. Set Probed to false. Set Array to NULL.
    */
   vtkGPUInfoList();
-  virtual ~vtkGPUInfoList();
+  ~vtkGPUInfoList() override;
   //@}
 
   bool Probed;
-  vtkGPUInfoListArray *Array;
+  vtkGPUInfoListArray* Array;
 
 private:
-  vtkGPUInfoList(const vtkGPUInfoList&) VTK_DELETE_FUNCTION;
-  void operator=(const vtkGPUInfoList&) VTK_DELETE_FUNCTION;
+  vtkGPUInfoList(const vtkGPUInfoList&) = delete;
+  void operator=(const vtkGPUInfoList&) = delete;
 };
 
 #endif
