@@ -40,19 +40,19 @@
  *
  * @sa
  * vtkInteractorObserver
-*/
+ */
 
 #ifndef vtkRenderWindowInteractor_h
 #define vtkRenderWindowInteractor_h
 
-#include "vtkRenderingCoreModule.h" // For export macro
-#include "vtkObject.h"
 #include "vtkCommand.h" // for method sig
+#include "vtkObject.h"
+#include "vtkRenderingCoreModule.h" // For export macro
 
 class vtkTimerIdMap;
 
 // Timer flags for win32/X compatibility
-#define VTKI_TIMER_FIRST  0
+#define VTKI_TIMER_FIRST 0
 #define VTKI_TIMER_UPDATE 1
 
 // maximum pointers active at once
@@ -62,6 +62,7 @@ class vtkTimerIdMap;
 class vtkAbstractPicker;
 class vtkAbstractPropPicker;
 class vtkAssemblyPath;
+class vtkHardwareWindow;
 class vtkInteractorObserver;
 class vtkRenderWindow;
 class vtkRenderer;
@@ -75,9 +76,9 @@ class VTKRENDERINGCORE_EXPORT vtkRenderWindowInteractor : public vtkObject
   friend class vtkInteractorEventRecorder;
 
 public:
-  static vtkRenderWindowInteractor *New();
-  vtkTypeMacro(vtkRenderWindowInteractor,vtkObject);
-  void PrintSelf(ostream& os, vtkIndent indent);
+  static vtkRenderWindowInteractor* New();
+  vtkTypeMacro(vtkRenderWindowInteractor, vtkObject);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
   //@{
   /**
@@ -88,15 +89,19 @@ public:
    * of the event loop.
    */
   virtual void Initialize();
-  void ReInitialize() {  this->Initialized = 0; this->Enabled = 0;
-                        this->Initialize(); }
+  void ReInitialize()
+  {
+    this->Initialized = 0;
+    this->Enabled = 0;
+    this->Initialize();
+  }
   //@}
 
   /**
    * This Method detects loops of RenderWindow-Interactor,
    * so objects are freed properly.
    */
-  virtual void UnRegister(vtkObjectBase *o);
+  void UnRegister(vtkObjectBase* o) override;
 
   /**
    * Start the event loop. This is provided so that you do not have to
@@ -105,6 +110,19 @@ public:
    */
   virtual void Start();
 
+  /**
+   * Run the event loop and return. This is provided so that you can
+   * implement your own event loop but yet use the vtk event handling as
+   * well.
+   */
+  virtual void ProcessEvents() {}
+
+  /**
+   * Is the interactor loop done
+   */
+  vtkGetMacro(Done, bool);
+  vtkSetMacro(Done, bool);
+
   /**
    * Enable/Disable interactions.  By default interactors are enabled when
    * initialized.  Initialize() must be called prior to enabling/disabling
@@ -114,8 +132,16 @@ public:
    * and all other interactors associated with the widget are disabled
    * when their data is not displayed.
    */
-  virtual void Enable() { this->Enabled = 1; this->Modified();}
-  virtual void Disable() { this->Enabled = 0; this->Modified();}
+  virtual void Enable()
+  {
+    this->Enabled = 1;
+    this->Modified();
+  }
+  virtual void Disable()
+  {
+    this->Enabled = 0;
+    this->Modified();
+  }
   vtkGetMacro(Enabled, int);
 
   //@{
@@ -132,15 +158,28 @@ public:
   /**
    * Set/Get the rendering window being controlled by this object.
    */
-  void SetRenderWindow(vtkRenderWindow *aren);
-  vtkGetObjectMacro(RenderWindow,vtkRenderWindow);
+  void SetRenderWindow(vtkRenderWindow* aren);
+  vtkGetObjectMacro(RenderWindow, vtkRenderWindow);
+  //@}
+
+  //@{
+  /**
+   * Set/Get the hardware window being controlled by this object.
+   * For opengl the hardware window is not used as the opengl
+   * subclasses of RenderWindow provide the functionality.
+   */
+  void SetHardwareWindow(vtkHardwareWindow* aren);
+  vtkGetObjectMacro(HardwareWindow, vtkHardwareWindow);
   //@}
 
   /**
    * Event loop notification member for window size change.
    * Window size is measured in pixels.
+   *
+   * If the size has changed, this method will fire
+   * vtkCommand::WindowResizeEvent.
    */
-  virtual void UpdateSize(int x,int y);
+  virtual void UpdateSize(int x, int y);
 
   /**
    * This class provides two groups of methods for manipulating timers.  The
@@ -158,8 +197,8 @@ public:
    * DestroyTimer(timerId) methods take this timer id and operate on the
    * timer as appropriate. Methods are also available for determining
    */
-  virtual int CreateTimer(int timerType); //first group, for backward compatibility
-  virtual int DestroyTimer(); //first group, for backward compatibility
+  virtual int CreateTimer(int timerType); // first group, for backward compatibility
+  virtual int DestroyTimer();             // first group, for backward compatibility
 
   /**
    * Create a repeating timer, with the specified duration (in milliseconds).
@@ -168,7 +207,7 @@ public:
   int CreateRepeatingTimer(unsigned long duration);
 
   /**
-   * Create a one shot timer, with the specified duretion (in milliseconds).
+   * Create a one shot timer, with the specified duration (in milliseconds).
    * \return the timer id.
    */
   int CreateOneShotTimer(unsigned long duration);
@@ -202,7 +241,11 @@ public:
 
   // Moved into the public section of the class so that classless timer procs
   // can access these enum members without being "friends"...
-  enum {OneShotTimer=1,RepeatingTimer};
+  enum
+  {
+    OneShotTimer = 1,
+    RepeatingTimer
+  };
 
   //@{
   /**
@@ -214,8 +257,8 @@ public:
    * adjusting the timer interval from the default value of 10
    * milliseconds--it may adversely affect the interactors.
    */
-  vtkSetClampMacro(TimerDuration,unsigned long,1,100000);
-  vtkGetMacro(TimerDuration,unsigned long);
+  vtkSetClampMacro(TimerDuration, unsigned long, 1, 100000);
+  vtkGetMacro(TimerDuration, unsigned long);
   //@}
 
   //@{
@@ -246,15 +289,15 @@ public:
    * specified and should be overridden by platform dependent subclasses
    * to provide a termination procedure if one is required.
    */
-  virtual void TerminateApp(void) {}
+  virtual void TerminateApp(void) { this->Done = true; }
 
   //@{
   /**
    * External switching between joystick/trackball/new? modes. Initial value
    * is a vtkInteractorStyleSwitch object.
    */
-  virtual void SetInteractorStyle(vtkInteractorObserver *);
-  vtkGetObjectMacro(InteractorStyle,vtkInteractorObserver);
+  virtual void SetInteractorStyle(vtkInteractorObserver*);
+  vtkGetObjectMacro(InteractorStyle, vtkInteractorObserver);
   //@}
 
   //@{
@@ -262,9 +305,9 @@ public:
    * Turn on/off the automatic repositioning of lights as the camera moves.
    * Default is On.
    */
-  vtkSetMacro(LightFollowCamera,int);
-  vtkGetMacro(LightFollowCamera,int);
-  vtkBooleanMacro(LightFollowCamera,int);
+  vtkSetMacro(LightFollowCamera, vtkTypeBool);
+  vtkGetMacro(LightFollowCamera, vtkTypeBool);
+  vtkBooleanMacro(LightFollowCamera, vtkTypeBool);
   //@}
 
   //@{
@@ -275,8 +318,8 @@ public:
    * still, the StillUpdateRate is used instead.
    * The default is 15.
    */
-  vtkSetClampMacro(DesiredUpdateRate,double,0.0001,VTK_FLOAT_MAX);
-  vtkGetMacro(DesiredUpdateRate,double);
+  vtkSetClampMacro(DesiredUpdateRate, double, 0.0001, VTK_FLOAT_MAX);
+  vtkGetMacro(DesiredUpdateRate, double);
   //@}
 
   //@{
@@ -285,8 +328,8 @@ public:
    * For the non-still update rate, see the SetDesiredUpdateRate method.
    * The default is 0.0001
    */
-  vtkSetClampMacro(StillUpdateRate,double,0.0001,VTK_FLOAT_MAX);
-  vtkGetMacro(StillUpdateRate,double);
+  vtkSetClampMacro(StillUpdateRate, double, 0.0001, VTK_FLOAT_MAX);
+  vtkGetMacro(StillUpdateRate, double);
   //@}
 
   //@{
@@ -294,7 +337,7 @@ public:
    * See whether interactor has been initialized yet.
    * Default is 0.
    */
-  vtkGetMacro(Initialized,int);
+  vtkGetMacro(Initialized, int);
   //@}
 
   //@{
@@ -305,14 +348,14 @@ public:
    * instance of vtkProp.
    */
   virtual void SetPicker(vtkAbstractPicker*);
-  vtkGetObjectMacro(Picker,vtkAbstractPicker);
+  vtkGetObjectMacro(Picker, vtkAbstractPicker);
   //@}
 
   /**
    * Create default picker. Used to create one when none is specified.
    * Default is an instance of vtkPropPicker.
    */
-  virtual vtkAbstractPropPicker *CreateDefaultPicker();
+  virtual vtkAbstractPropPicker* CreateDefaultPicker();
 
   //@{
   /**
@@ -321,12 +364,12 @@ public:
    * By default, a valid but disabled picking manager is instantiated.
    */
   virtual void SetPickingManager(vtkPickingManager*);
-  vtkGetObjectMacro(PickingManager,vtkPickingManager);
+  vtkGetObjectMacro(PickingManager, vtkPickingManager);
   //@}
 
   //@{
   /**
-   * These methods correspond to the the Exit, User and Pick
+   * These methods correspond to the Exit, User and Pick
    * callbacks. They allow for the Style to invoke them.
    */
   virtual void ExitCallback();
@@ -338,7 +381,11 @@ public:
   /**
    * Get the current position of the mouse.
    */
-  virtual void GetMousePosition(int *x, int *y) { *x = 0 ; *y = 0; }
+  virtual void GetMousePosition(int* x, int* y)
+  {
+    *x = 0;
+    *y = 0;
+  }
 
   //@{
   /**
@@ -361,20 +408,18 @@ public:
    * The movement is animated over the number of frames specified in
    * NumberOfFlyFrames. The LOD desired frame rate is used.
    */
-  void FlyTo(vtkRenderer *ren, double x, double y, double z);
-  void FlyTo(vtkRenderer *ren, double *x)
-    {this->FlyTo(ren, x[0], x[1], x[2]);}
-  void FlyToImage(vtkRenderer *ren, double x, double y);
-  void FlyToImage(vtkRenderer *ren, double *x)
-    {this->FlyToImage(ren, x[0], x[1]);}
+  void FlyTo(vtkRenderer* ren, double x, double y, double z);
+  void FlyTo(vtkRenderer* ren, double* x) { this->FlyTo(ren, x[0], x[1], x[2]); }
+  void FlyToImage(vtkRenderer* ren, double x, double y);
+  void FlyToImage(vtkRenderer* ren, double* x) { this->FlyToImage(ren, x[0], x[1]); }
   //@}
 
   //@{
   /**
    * Set the number of frames to fly to when FlyTo is invoked.
    */
-  vtkSetClampMacro(NumberOfFlyFrames,int,1,VTK_INT_MAX);
-  vtkGetMacro(NumberOfFlyFrames,int);
+  vtkSetClampMacro(NumberOfFlyFrames, int, 1, VTK_INT_MAX);
+  vtkGetMacro(NumberOfFlyFrames, int);
   //@}
 
   //@{
@@ -382,8 +427,8 @@ public:
    * Set the total Dolly value to use when flying to (FlyTo()) a
    * specified point. Negative values fly away from the point.
    */
-  vtkSetMacro(Dolly,double);
-  vtkGetMacro(Dolly,double);
+  vtkSetMacro(Dolly, double);
+  vtkGetMacro(Dolly, double);
   //@}
 
   //@{
@@ -395,15 +440,15 @@ public:
    * are measured in pixels.
    * The other information is about key board input.
    */
-  vtkGetVector2Macro(EventPosition,int);
-  vtkGetVector2Macro(LastEventPosition,int);
-  vtkSetVector2Macro(LastEventPosition,int);
+  vtkGetVector2Macro(EventPosition, int);
+  vtkGetVector2Macro(LastEventPosition, int);
+  vtkSetVector2Macro(LastEventPosition, int);
   virtual void SetEventPosition(int x, int y)
   {
-    vtkDebugMacro(<< this->GetClassName() << " (" << this
-                  << "): setting EventPosition to (" << x << "," << y << ")");
+    vtkDebugMacro(<< this->GetClassName() << " (" << this << "): setting EventPosition to (" << x
+                  << "," << y << ")");
     if (this->EventPosition[0] != x || this->EventPosition[1] != y ||
-        this->LastEventPosition[0] != x || this->LastEventPosition[1] != y)
+      this->LastEventPosition[0] != x || this->LastEventPosition[1] != y)
     {
       this->LastEventPosition[0] = this->EventPosition[0];
       this->LastEventPosition[1] = this->EventPosition[1];
@@ -412,33 +457,27 @@ public:
       this->Modified();
     }
   }
-  virtual void SetEventPosition(int pos[2])
-  {
-    this->SetEventPosition(pos[0], pos[1]);
-  }
+  virtual void SetEventPosition(int pos[2]) { this->SetEventPosition(pos[0], pos[1]); }
   virtual void SetEventPositionFlipY(int x, int y)
   {
     this->SetEventPosition(x, this->Size[1] - y - 1);
   }
-  virtual void SetEventPositionFlipY(int pos[2])
-  {
-    this->SetEventPositionFlipY(pos[0], pos[1]);
-  }
+  virtual void SetEventPositionFlipY(int pos[2]) { this->SetEventPositionFlipY(pos[0], pos[1]); }
   //@}
 
-  virtual int *GetEventPositions(int pointerIndex)
+  virtual int* GetEventPositions(int pointerIndex)
   {
     if (pointerIndex >= VTKI_MAX_POINTERS)
     {
-      return NULL;
+      return nullptr;
     }
     return this->EventPositions[pointerIndex];
   }
-  virtual int *GetLastEventPositions(int pointerIndex)
+  virtual int* GetLastEventPositions(int pointerIndex)
   {
     if (pointerIndex >= VTKI_MAX_POINTERS)
     {
-      return NULL;
+      return nullptr;
     }
     return this->LastEventPositions[pointerIndex];
   }
@@ -455,10 +494,11 @@ public:
       this->EventPosition[0] = x;
       this->EventPosition[1] = y;
     }
-    vtkDebugMacro(<< this->GetClassName() << " (" << this
-                  << "): setting EventPosition to (" << x << "," << y << ") for pointerIndex number " << pointerIndex);
+    vtkDebugMacro(<< this->GetClassName() << " (" << this << "): setting EventPosition to (" << x
+                  << "," << y << ") for pointerIndex number " << pointerIndex);
     if (this->EventPositions[pointerIndex][0] != x || this->EventPositions[pointerIndex][1] != y ||
-        this->LastEventPositions[pointerIndex][0] != x || this->LastEventPositions[pointerIndex][1] != y)
+      this->LastEventPositions[pointerIndex][0] != x ||
+      this->LastEventPositions[pointerIndex][1] != y)
     {
       this->LastEventPositions[pointerIndex][0] = this->EventPositions[pointerIndex][0];
       this->LastEventPositions[pointerIndex][1] = this->EventPositions[pointerIndex][1];
@@ -525,7 +565,7 @@ public:
   /**
    * Set/get the key symbol for the key that was pressed. This is the key
    * symbol as defined by the relevant X headers. On X based platforms this
-   * corresponds to the installed X sevrer, whereas on other platforms the
+   * corresponds to the installed X server, whereas on other platforms the
    * native key codes are translated into a string representation.
    */
   vtkSetStringMacro(KeySym);
@@ -560,7 +600,7 @@ public:
 
   //@{
   /**
-   * Set/get the tranlation for pan/swipe gestures, update LastTranslation
+   * Set/get the translation for pan/swipe gestures, update LastTranslation
    */
   void SetTranslation(double val[2]);
   vtkGetVector2Macro(Translation, double);
@@ -571,34 +611,25 @@ public:
   /**
    * Set all the event information in one call.
    */
-  void SetEventInformation(int x,
-                           int y,
-                           int ctrl,
-                           int shift,
-                           char keycode,
-                           int repeatcount,
-                           const char* keysym,
-                           int pointerIndex)
+  void SetEventInformation(int x, int y, int ctrl, int shift, char keycode, int repeatcount,
+    const char* keysym, int pointerIndex)
   {
-      this->SetEventPosition(x,y,pointerIndex);
-      this->ControlKey = ctrl;
-      this->ShiftKey = shift;
-      this->KeyCode = keycode;
-      this->RepeatCount = repeatcount;
-      this->PointerIndex = pointerIndex;
-      if(keysym)
-      {
-        this->SetKeySym(keysym);
-      }
-      this->Modified();
+    this->SetEventPosition(x, y, pointerIndex);
+    this->ControlKey = ctrl;
+    this->ShiftKey = shift;
+    this->KeyCode = keycode;
+    this->RepeatCount = repeatcount;
+    this->PointerIndex = pointerIndex;
+    if (keysym)
+    {
+      this->SetKeySym(keysym);
+    }
+    this->Modified();
   }
-  void SetEventInformation(int x, int y,
-                           int ctrl=0, int shift=0,
-                           char keycode=0,
-                           int repeatcount=0,
-                           const char* keysym=0)
+  void SetEventInformation(int x, int y, int ctrl = 0, int shift = 0, char keycode = 0,
+    int repeatcount = 0, const char* keysym = nullptr)
   {
-      this->SetEventInformation(x,y,ctrl,shift,keycode,repeatcount,keysym,0);
+    this->SetEventInformation(x, y, ctrl, shift, keycode, repeatcount, keysym, 0);
   }
   //@}
 
@@ -607,29 +638,16 @@ public:
    * Calls SetEventInformation, but flips the Y based on the current Size[1]
    * value (i.e. y = this->Size[1] - y - 1).
    */
-  void SetEventInformationFlipY(int x, int y,
-                                int ctrl, int shift,
-                                char keycode,
-                                int repeatcount,
-                                const char* keysym,
-                                int pointerIndex)
+  void SetEventInformationFlipY(int x, int y, int ctrl, int shift, char keycode, int repeatcount,
+    const char* keysym, int pointerIndex)
   {
-      this->SetEventInformation(x,
-                                this->Size[1] - y - 1,
-                                ctrl,
-                                shift,
-                                keycode,
-                                repeatcount,
-                                keysym,
-                                pointerIndex);
+    this->SetEventInformation(
+      x, this->Size[1] - y - 1, ctrl, shift, keycode, repeatcount, keysym, pointerIndex);
   }
-  void SetEventInformationFlipY(int x, int y,
-                           int ctrl=0, int shift=0,
-                           char keycode=0,
-                           int repeatcount=0,
-                           const char* keysym=0)
+  void SetEventInformationFlipY(int x, int y, int ctrl = 0, int shift = 0, char keycode = 0,
+    int repeatcount = 0, const char* keysym = nullptr)
   {
-      this->SetEventInformationFlipY(x,y,ctrl,shift,keycode,repeatcount,keysym,0);
+    this->SetEventInformationFlipY(x, y, ctrl, shift, keycode, repeatcount, keysym, 0);
   }
   //@}
 
@@ -637,21 +655,18 @@ public:
   /**
    * Set all the keyboard-related event information in one call.
    */
-  void SetKeyEventInformation(int ctrl=0,
-                              int shift=0,
-                              char keycode=0,
-                              int repeatcount=0,
-                              const char* keysym=0)
+  void SetKeyEventInformation(int ctrl = 0, int shift = 0, char keycode = 0, int repeatcount = 0,
+    const char* keysym = nullptr)
   {
-      this->ControlKey = ctrl;
-      this->ShiftKey = shift;
-      this->KeyCode = keycode;
-      this->RepeatCount = repeatcount;
-      if(keysym)
-      {
-        this->SetKeySym(keysym);
-      }
-      this->Modified();
+    this->ControlKey = ctrl;
+    this->ShiftKey = shift;
+    this->KeyCode = keycode;
+    this->RepeatCount = repeatcount;
+    if (keysym)
+    {
+      this->SetKeySym(keysym);
+    }
+    this->Modified();
   }
   //@}
 
@@ -667,10 +682,10 @@ public:
    * (Expose event, for example).
    * Window size is measured in pixels.
    */
-  vtkSetVector2Macro(Size,int);
-  vtkGetVector2Macro(Size,int);
-  vtkSetVector2Macro(EventSize,int);
-  vtkGetVector2Macro(EventSize,int);
+  vtkSetVector2Macro(Size, int);
+  vtkGetVector2Macro(Size, int);
+  vtkSetVector2Macro(EventSize, int);
+  vtkGetVector2Macro(EventSize, int);
   //@}
 
   /**
@@ -678,7 +693,7 @@ public:
    * occurred within, since one RenderWindow may contain multiple
    * renderers.
    */
-  virtual vtkRenderer *FindPokedRenderer(int,int);
+  virtual vtkRenderer* FindPokedRenderer(int, int);
 
   /**
    * Return the object used to mediate between vtkInteractorObservers
@@ -687,7 +702,7 @@ public:
    * strategy to provide the resource based on priority of the observer plus
    * the particular request (default versus non-default cursor shape).
    */
-  vtkObserverMediator *GetObserverMediator();
+  vtkObserverMediator* GetObserverMediator();
 
   //@{
   /**
@@ -698,8 +713,8 @@ public:
    * It is must be called before the first Render to be effective, otherwise
    * it is ignored.
    */
-  vtkSetMacro(UseTDx,bool);
-  vtkGetMacro(UseTDx,bool);
+  vtkSetMacro(UseTDx, bool);
+  vtkGetMacro(UseTDx, bool);
   //@}
 
   //@{
@@ -725,6 +740,10 @@ public:
   virtual void KeyReleaseEvent();
   virtual void CharEvent();
   virtual void ExitEvent();
+  virtual void FourthButtonPressEvent();
+  virtual void FourthButtonReleaseEvent();
+  virtual void FifthButtonPressEvent();
+  virtual void FifthButtonReleaseEvent();
   //@}
 
   //@{
@@ -753,8 +772,8 @@ public:
    * will be converted into gestures by VTK. If turned off the
    * raw multitouch events will be passed down.
    */
-  vtkSetMacro(RecognizeGestures,bool);
-  vtkGetMacro(RecognizeGestures,bool);
+  vtkSetMacro(RecognizeGestures, bool);
+  vtkGetMacro(RecognizeGestures, bool);
   //@}
 
   //@{
@@ -763,7 +782,7 @@ public:
    * determine how many pointers are down for the gesture
    * this is useful for pan gestures for example
    */
-  vtkGetMacro(PointersDownCount,int);
+  vtkGetMacro(PointersDownCount, int);
   //@}
 
   //@{
@@ -783,55 +802,58 @@ public:
 
 protected:
   vtkRenderWindowInteractor();
-  ~vtkRenderWindowInteractor();
+  ~vtkRenderWindowInteractor() override;
 
-  vtkRenderWindow       *RenderWindow;
-  vtkInteractorObserver *InteractorStyle;
+  vtkRenderWindow* RenderWindow;
+  vtkHardwareWindow* HardwareWindow;
+  vtkInteractorObserver* InteractorStyle;
 
   // Used as a helper object to pick instances of vtkProp
-  vtkAbstractPicker     *Picker;
-  vtkPickingManager     *PickingManager;
+  vtkAbstractPicker* Picker;
+  vtkPickingManager* PickingManager;
+
+  bool Done; // is the event loop done running
 
   /**
    * Create default pickingManager. Used to create one when none is specified.
    * Default is an instance of vtkPickingManager.
    */
-  virtual vtkPickingManager *CreateDefaultPickingManager();
+  virtual vtkPickingManager* CreateDefaultPickingManager();
 
-  int    Initialized;
-  int    Enabled;
-  bool   EnableRender;
-  int    Style;
-  int    LightFollowCamera;
-  int    ActorMode;
+  int Initialized;
+  int Enabled;
+  bool EnableRender;
+  int Style;
+  vtkTypeBool LightFollowCamera;
+  int ActorMode;
   double DesiredUpdateRate;
   double StillUpdateRate;
 
   // Event information
-  int   AltKey;
-  int   ControlKey;
-  int   ShiftKey;
-  char  KeyCode;
+  int AltKey;
+  int ControlKey;
+  int ShiftKey;
+  char KeyCode;
   double Rotation;
   double LastRotation;
   double Scale;
   double LastScale;
   double Translation[2];
   double LastTranslation[2];
-  int   RepeatCount;
+  int RepeatCount;
   char* KeySym;
-  int   EventPosition[2];
-  int   LastEventPosition[2];
-  int   EventSize[2];
-  int   Size[2];
-  int   TimerEventId;
-  int   TimerEventType;
-  int   TimerEventDuration;
-  int   TimerEventPlatformId;
+  int EventPosition[2];
+  int LastEventPosition[2];
+  int EventSize[2];
+  int Size[2];
+  int TimerEventId;
+  int TimerEventType;
+  int TimerEventDuration;
+  int TimerEventPlatformId;
 
-  int   EventPositions[VTKI_MAX_POINTERS][2];
-  int   LastEventPositions[VTKI_MAX_POINTERS][2];
-  int   PointerIndex;
+  int EventPositions[VTKI_MAX_POINTERS][2];
+  int LastEventPositions[VTKI_MAX_POINTERS][2];
+  int PointerIndex;
 
   size_t PointerIndexLookup[VTKI_MAX_POINTERS];
 
@@ -848,20 +870,21 @@ protected:
    * declaration is done here to avoid doing so in the superclass vtkObject.
    */
   friend class vtkInteractorObserver;
-  void GrabFocus(vtkCommand *mouseEvents, vtkCommand *keypressEvents=NULL)
-    {this->Superclass::InternalGrabFocus(mouseEvents,keypressEvents);}
-  void ReleaseFocus()
-    {this->Superclass::InternalReleaseFocus();}
+  void GrabFocus(vtkCommand* mouseEvents, vtkCommand* keypressEvents = nullptr)
+  {
+    this->Superclass::InternalGrabFocus(mouseEvents, keypressEvents);
+  }
+  void ReleaseFocus() { this->Superclass::InternalReleaseFocus(); }
 
   /**
    * Widget mediators are used to resolve contention for cursors and other resources.
    */
-  vtkObserverMediator *ObserverMediator;
+  vtkObserverMediator* ObserverMediator;
 
   // Timer related members
   friend struct vtkTimerStruct;
-  vtkTimerIdMap *TimerMap; // An internal, PIMPLd map of timers and associated attributes
-  unsigned long  TimerDuration; //in milliseconds
+  vtkTimerIdMap* TimerMap;     // An internal, PIMPLd map of timers and associated attributes
+  unsigned long TimerDuration; // in milliseconds
   //@{
   /**
    * Internal methods for creating and destroying timers that must be
@@ -896,8 +919,8 @@ protected:
   vtkCommand::EventIds CurrentGesture;
 
 private:
-  vtkRenderWindowInteractor(const vtkRenderWindowInteractor&) VTK_DELETE_FUNCTION;
-  void operator=(const vtkRenderWindowInteractor&) VTK_DELETE_FUNCTION;
+  vtkRenderWindowInteractor(const vtkRenderWindowInteractor&) = delete;
+  void operator=(const vtkRenderWindowInteractor&) = delete;
 };
 
 #endif
