@@ -27,7 +27,7 @@
  *
  * @sa
  * vtkRenderWindow vtkActor vtkCamera vtkLight vtkVolume
-*/
+ */
 
 #ifndef vtkRenderer_h
 #define vtkRenderer_h
@@ -35,8 +35,8 @@
 #include "vtkRenderingCoreModule.h" // For export macro
 #include "vtkViewport.h"
 
+#include "vtkActorCollection.h"  // Needed for access in inline members
 #include "vtkVolumeCollection.h" // Needed for access in inline members
-#include "vtkActorCollection.h" // Needed for access in inline members
 
 class vtkFXAAOptions;
 class vtkRenderWindow;
@@ -45,6 +45,7 @@ class vtkCuller;
 class vtkActor;
 class vtkActor2D;
 class vtkCamera;
+class vtkFrameBufferObjectBase;
 class vtkInformation;
 class vtkLightCollection;
 class vtkCullerCollection;
@@ -57,15 +58,15 @@ class vtkTexture;
 class VTKRENDERINGCORE_EXPORT vtkRenderer : public vtkViewport
 {
 public:
-  vtkTypeMacro(vtkRenderer,vtkViewport);
-  void PrintSelf(ostream& os, vtkIndent indent);
+  vtkTypeMacro(vtkRenderer, vtkViewport);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
   /**
    * Create a vtkRenderer with a black background, a white ambient light,
    * two-sided lighting turned on, a viewport of (0,0,1,1), and backface
    * culling turned off.
    */
-  static vtkRenderer *New();
+  static vtkRenderer* New();
 
   //@{
   /**
@@ -73,21 +74,21 @@ public:
    * These methods are all synonyms to AddViewProp and RemoveViewProp.
    * They are here for convenience and backwards compatibility.
    */
-  void AddActor(vtkProp *p);
-  void AddVolume(vtkProp *p);
-  void RemoveActor(vtkProp *p);
-  void RemoveVolume(vtkProp *p);
+  void AddActor(vtkProp* p);
+  void AddVolume(vtkProp* p);
+  void RemoveActor(vtkProp* p);
+  void RemoveVolume(vtkProp* p);
   //@}
 
   /**
    * Add a light to the list of lights.
    */
-  void AddLight(vtkLight *);
+  void AddLight(vtkLight*);
 
   /**
    * Remove a light from the list of lights.
    */
-  void RemoveLight(vtkLight *);
+  void RemoveLight(vtkLight*);
 
   /**
    * Remove all lights from the list of lights.
@@ -97,7 +98,7 @@ public:
   /**
    * Return the collection of lights.
    */
-  vtkLightCollection *GetLights();
+  vtkLightCollection* GetLights();
 
   /**
    * Set the collection of lights.
@@ -105,7 +106,7 @@ public:
    * \pre lights_exist: lights!=0
    * \post lights_set: lights==this->GetLights()
    */
-  void SetLightCollection(vtkLightCollection *lights);
+  void SetLightCollection(vtkLightCollection* lights);
 
   /**
    * Create and add a light to renderer.
@@ -117,7 +118,7 @@ public:
    * For example, a vtkMesaRenderer should create a vtkMesaLight
    * in this function.   The default is to just call vtkLight::New.
    */
-  virtual vtkLight *MakeLight();
+  virtual vtkLight* MakeLight();
 
   //@{
   /**
@@ -126,9 +127,9 @@ public:
    * and the other side dark. If two-sided lighting on, both sides of the
    * surface will be lit.
    */
-  vtkGetMacro(TwoSidedLighting,int);
-  vtkSetMacro(TwoSidedLighting,int);
-  vtkBooleanMacro(TwoSidedLighting,int);
+  vtkGetMacro(TwoSidedLighting, vtkTypeBool);
+  vtkSetMacro(TwoSidedLighting, vtkTypeBool);
+  vtkBooleanMacro(TwoSidedLighting, vtkTypeBool);
   //@}
 
   //@{
@@ -145,9 +146,9 @@ public:
    * interactor's LightFollowCamera flag OFF, and leave the renderer's
    * LightFollowCamera flag ON.)
    */
-  vtkSetMacro(LightFollowCamera,int);
-  vtkGetMacro(LightFollowCamera,int);
-  vtkBooleanMacro(LightFollowCamera,int);
+  vtkSetMacro(LightFollowCamera, vtkTypeBool);
+  vtkGetMacro(LightFollowCamera, vtkTypeBool);
+  vtkBooleanMacro(LightFollowCamera, vtkTypeBool);
   //@}
 
   //@{
@@ -159,9 +160,9 @@ public:
    * light creation. (Turn AutomaticLightCreation off if you do not want lights
    * to be created.)
    */
-  vtkGetMacro(AutomaticLightCreation,int);
-  vtkSetMacro(AutomaticLightCreation,int);
-  vtkBooleanMacro(AutomaticLightCreation,int);
+  vtkGetMacro(AutomaticLightCreation, vtkTypeBool);
+  vtkSetMacro(AutomaticLightCreation, vtkTypeBool);
+  vtkBooleanMacro(AutomaticLightCreation, vtkTypeBool);
   //@}
 
   /**
@@ -169,36 +170,36 @@ public:
    * (for instance, Headlights or CameraLights that are attached to the
    * camera) to update their geometry to match the active camera.
    */
-  virtual int UpdateLightsGeometryToFollowCamera(void);
+  virtual vtkTypeBool UpdateLightsGeometryToFollowCamera(void);
 
   /**
    * Return the collection of volumes.
    */
-  vtkVolumeCollection *GetVolumes();
+  vtkVolumeCollection* GetVolumes();
 
   /**
    * Return any actors in this renderer.
    */
-  vtkActorCollection *GetActors();
+  vtkActorCollection* GetActors();
 
   /**
    * Specify the camera to use for this renderer.
    */
-  void SetActiveCamera(vtkCamera *);
+  void SetActiveCamera(vtkCamera*);
 
   /**
    * Get the current camera. If there is not camera assigned to the
    * renderer already, a new one is created automatically.
    * This does *not* reset the camera.
    */
-  vtkCamera *GetActiveCamera();
+  vtkCamera* GetActiveCamera();
 
   /**
    * Create a new Camera sutible for use with this type of Renderer.
    * For example, a vtkMesaRenderer should create a vtkMesaCamera
    * in this function.   The default is to just call vtkCamera::New.
    */
-  virtual vtkCamera *MakeCamera();
+  virtual vtkCamera* MakeCamera();
 
   //@{
   /**
@@ -207,9 +208,9 @@ public:
    * Both the RenderWindow Erase and Render Erase must be on
    * for the camera to clear the renderer.  By default, Erase is on.
    */
-  vtkSetMacro(Erase, int);
-  vtkGetMacro(Erase, int);
-  vtkBooleanMacro(Erase, int);
+  vtkSetMacro(Erase, vtkTypeBool);
+  vtkGetMacro(Erase, vtkTypeBool);
+  vtkBooleanMacro(Erase, vtkTypeBool);
   //@}
 
   //@{
@@ -218,45 +219,45 @@ public:
    * multiplex a vtkRenderWindow or render only part of a vtkRenderWindow.
    * By default, Draw is on.
    */
-  vtkSetMacro(Draw, int);
-  vtkGetMacro(Draw, int);
-  vtkBooleanMacro(Draw, int);
+  vtkSetMacro(Draw, vtkTypeBool);
+  vtkGetMacro(Draw, vtkTypeBool);
+  vtkBooleanMacro(Draw, vtkTypeBool);
   //@}
 
   /**
    * This function is called to capture an instance of vtkProp that requires
    * special handling during vtkRenderWindow::CaptureGL2PSSpecialProps().
    */
-  int CaptureGL2PSSpecialProp(vtkProp *);
+  int CaptureGL2PSSpecialProp(vtkProp*);
 
   /**
    * Set the prop collection object used during
    * vtkRenderWindow::CaptureGL2PSSpecialProps(). Do not call manually, this
    * is handled automatically by the render window.
    */
-  void SetGL2PSSpecialPropCollection(vtkPropCollection *);
+  void SetGL2PSSpecialPropCollection(vtkPropCollection*);
 
   /**
    * Add an culler to the list of cullers.
    */
-  void AddCuller(vtkCuller *);
+  void AddCuller(vtkCuller*);
 
   /**
    * Remove an actor from the list of cullers.
    */
-  void RemoveCuller(vtkCuller *);
+  void RemoveCuller(vtkCuller*);
 
   /**
    * Return the collection of cullers.
    */
-  vtkCullerCollection *GetCullers();
+  vtkCullerCollection* GetCullers();
 
   //@{
   /**
    * Set the intensity of ambient lighting.
    */
-  vtkSetVector3Macro(Ambient,double);
-  vtkGetVectorMacro(Ambient,double,3);
+  vtkSetVector3Macro(Ambient, double);
+  vtkGetVectorMacro(Ambient, double, 3);
   //@}
 
   //@{
@@ -264,7 +265,7 @@ public:
    * Set/Get the amount of time this renderer is allowed to spend
    * rendering its scene. This is used by vtkLODActor's.
    */
-  vtkSetMacro(AllocatedRenderTime,double);
+  vtkSetMacro(AllocatedRenderTime, double);
   virtual double GetAllocatedRenderTime();
   //@}
 
@@ -287,7 +288,7 @@ public:
   /**
    * Create an image. Subclasses of vtkRenderer must implement this method.
    */
-  virtual void DeviceRender() =0;
+  virtual void DeviceRender(){};
 
   /**
    * Render opaque polygonal geometry. Default implementation just calls
@@ -295,22 +296,24 @@ public:
    * Subclasses of vtkRenderer that can deal with, e.g. hidden line removal must
    * override this method.
    */
-  virtual void DeviceRenderOpaqueGeometry();
+  virtual void DeviceRenderOpaqueGeometry(vtkFrameBufferObjectBase* fbo = nullptr);
 
   /**
    * Render translucent polygonal geometry. Default implementation just call
    * UpdateTranslucentPolygonalGeometry().
    * Subclasses of vtkRenderer that can deal with depth peeling must
    * override this method.
+   * If UseDepthPeeling and UseDepthPeelingForVolumes are true, volumetric data
+   * will be rendered here as well.
    * It updates boolean ivar LastRenderingUsedDepthPeeling.
    */
-  virtual void DeviceRenderTranslucentPolygonalGeometry();
+  virtual void DeviceRenderTranslucentPolygonalGeometry(vtkFrameBufferObjectBase* fbo = nullptr);
 
   /**
    * Internal method temporarily removes lights before reloading them
    * into graphics pipeline.
    */
-  virtual void ClearLights(void) {};
+  virtual void ClearLights(void) {}
 
   /**
    * Clear the image to the background color.
@@ -331,18 +334,18 @@ public:
    * Compute the bounding box of all the visible props
    * Used in ResetCamera() and ResetCameraClippingRange()
    */
-  void ComputeVisiblePropBounds( double bounds[6] );
+  void ComputeVisiblePropBounds(double bounds[6]);
 
   /**
    * Wrapper-friendly version of ComputeVisiblePropBounds
    */
-  double *ComputeVisiblePropBounds();
+  double* ComputeVisiblePropBounds() VTK_SIZEHINT(6);
 
   /**
    * Reset the camera clipping range based on the bounds of the
    * visible actors. This ensures that no props are cut off
    */
-  void ResetCameraClippingRange();
+  virtual void ResetCameraClippingRange();
 
   //@{
   /**
@@ -351,10 +354,9 @@ public:
    * If Deering frustrum is used then the bounds get expanded
    * by the camera's modelview matrix.
    */
-  void ResetCameraClippingRange( double bounds[6] );
-  void ResetCameraClippingRange( double xmin, double xmax,
-                                 double ymin, double ymax,
-                                 double zmin, double zmax);
+  virtual void ResetCameraClippingRange(double bounds[6]);
+  virtual void ResetCameraClippingRange(
+    double xmin, double xmax, double ymin, double ymax, double zmin, double zmax);
   //@}
 
   //@{
@@ -363,8 +365,8 @@ public:
    * percentage of the far clipping plane distance. By default this will be
    * set to 0.01 for 16 bit zbuffers and 0.001 for higher depth z buffers
    */
-  vtkSetClampMacro(NearClippingPlaneTolerance,double,0,0.99);
-  vtkGetMacro(NearClippingPlaneTolerance,double);
+  vtkSetClampMacro(NearClippingPlaneTolerance, double, 0, 0.99);
+  vtkGetMacro(NearClippingPlaneTolerance, double);
   //@}
 
   //@{
@@ -373,8 +375,8 @@ public:
    * camera clipping range.  By default the range is not expanded by
    * any percent of the (far - near) on the near and far sides
    */
-  vtkSetClampMacro(ClippingRangeExpansion,double,0,0.99);
-  vtkGetMacro(ClippingRangeExpansion,double);
+  vtkSetClampMacro(ClippingRangeExpansion, double, 0, 0.99);
+  vtkGetMacro(ClippingRangeExpansion, double);
   //@}
 
   /**
@@ -399,8 +401,8 @@ public:
   /**
    * Alternative version of ResetCamera(bounds[6]);
    */
-  virtual void ResetCamera(double xmin, double xmax, double ymin, double ymax,
-                   double zmin, double zmax);
+  virtual void ResetCamera(
+    double xmin, double xmax, double ymin, double ymax, double zmin, double zmax);
 
   //@{
   /**
@@ -408,9 +410,9 @@ public:
    * when the renderer is created by MakeRenderer.  The user probably
    * shouldn't ever need to call this method.
    */
-  void SetRenderWindow(vtkRenderWindow *);
-  vtkRenderWindow *GetRenderWindow() {return this->RenderWindow;};
-  virtual vtkWindow *GetVTKWindow();
+  void SetRenderWindow(vtkRenderWindow*);
+  vtkRenderWindow* GetRenderWindow() { return this->RenderWindow; }
+  vtkWindow* GetVTKWindow() override;
   //@}
 
   //@{
@@ -420,9 +422,9 @@ public:
    * much faster when the image has not changed, such as during an
    * expose event.
    */
-  vtkSetMacro(BackingStore,int);
-  vtkGetMacro(BackingStore,int);
-  vtkBooleanMacro(BackingStore,int);
+  vtkSetMacro(BackingStore, vtkTypeBool);
+  vtkGetMacro(BackingStore, vtkTypeBool);
+  vtkBooleanMacro(BackingStore, vtkTypeBool);
   //@}
 
   //@{
@@ -431,9 +433,9 @@ public:
    * can receive events from an interactor.  Should only be set if
    * there are multiple renderers in the same section of the viewport.
    */
-  vtkSetMacro(Interactive,int);
-  vtkGetMacro(Interactive,int);
-  vtkBooleanMacro(Interactive,int);
+  vtkSetMacro(Interactive, vtkTypeBool);
+  vtkGetMacro(Interactive, vtkTypeBool);
+  vtkBooleanMacro(Interactive, vtkTypeBool);
   //@}
 
   //@{
@@ -463,9 +465,9 @@ public:
    * This flag influences the Transparent() method, and is updated by calls to
    * SetLayer(). For this reason it should only be set after changing the layer.
    */
-  vtkGetMacro(PreserveColorBuffer, int);
-  vtkSetMacro(PreserveColorBuffer, int);
-  vtkBooleanMacro(PreserveColorBuffer, int);
+  vtkGetMacro(PreserveColorBuffer, vtkTypeBool);
+  vtkSetMacro(PreserveColorBuffer, vtkTypeBool);
+  vtkBooleanMacro(PreserveColorBuffer, vtkTypeBool);
   //@}
 
   //@{
@@ -473,51 +475,61 @@ public:
    * By default, the depth buffer is reset for each renderer. If this flag is
    * true, this renderer will use the existing depth buffer for its rendering.
    */
-  vtkSetMacro(PreserveDepthBuffer, int);
-  vtkGetMacro(PreserveDepthBuffer, int);
-  vtkBooleanMacro(PreserveDepthBuffer, int);
+  vtkSetMacro(PreserveDepthBuffer, vtkTypeBool);
+  vtkGetMacro(PreserveDepthBuffer, vtkTypeBool);
+  vtkBooleanMacro(PreserveDepthBuffer, vtkTypeBool);
   //@}
 
   /**
    * Returns a boolean indicating if this renderer is transparent.  It is
    * transparent if it is not in the deepest layer of its render window.
    */
-  int  Transparent();
+  int Transparent();
 
   /**
    * Convert world point coordinates to view coordinates.
    */
-  void WorldToView();
+  void WorldToView() override;
 
   //@{
   /**
    * Convert view point coordinates to world coordinates.
    */
-  void ViewToWorld();
-  virtual void ViewToWorld(double &wx, double &wy, double &wz);
+  void ViewToWorld() override;
+  void ViewToWorld(double& wx, double& wy, double& wz) override;
   //@}
 
   /**
    * Convert world point coordinates to view coordinates.
    */
-  virtual void WorldToView(double &wx, double &wy, double &wz);
+  void WorldToView(double& wx, double& wy, double& wz) override;
+
+  //@{
+  /**
+   * Convert to from pose coordinates
+   */
+  void WorldToPose(double& wx, double& wy, double& wz) override;
+  void PoseToWorld(double& wx, double& wy, double& wz) override;
+  void ViewToPose(double& wx, double& wy, double& wz) override;
+  void PoseToView(double& wx, double& wy, double& wz) override;
+  //@}
 
   /**
    * Given a pixel location, return the Z value. The z value is
    * normalized (0,1) between the front and back clipping planes.
    */
-  double GetZ (int x, int y);
+  double GetZ(int x, int y);
 
   /**
    * Return the MTime of the renderer also considering its ivars.
    */
-  vtkMTimeType GetMTime();
+  vtkMTimeType GetMTime() override;
 
   //@{
   /**
    * Get the time required, in seconds, for the last Render call.
    */
-  vtkGetMacro( LastRenderTimeInSeconds, double );
+  vtkGetMacro(LastRenderTimeInSeconds, double);
   //@}
 
   //@{
@@ -527,7 +539,7 @@ public:
    * RenderOpaqueGeometry or RenderTranslucentPolygonalGeometry call.
    * This is used to know if something is in the frame buffer.
    */
-  vtkGetMacro( NumberOfPropsRendered, int );
+  vtkGetMacro(NumberOfPropsRendered, int);
   //@}
 
   //@{
@@ -538,12 +550,12 @@ public:
    * If nothing was picked then NULL is returned.  This method selects from
    * the renderers Prop list.
    */
-  vtkAssemblyPath* PickProp(double selectionX, double selectionY)
+  vtkAssemblyPath* PickProp(double selectionX, double selectionY) override
   {
     return this->PickProp(selectionX, selectionY, selectionX, selectionY);
   }
-  vtkAssemblyPath* PickProp(double selectionX1, double selectionY1,
-                            double selectionX2, double selectionY2);
+  vtkAssemblyPath* PickProp(
+    double selectionX1, double selectionY1, double selectionX2, double selectionY2) override;
   //@}
 
   /**
@@ -551,13 +563,13 @@ public:
    * in a stereo render. Doesn't do anything except in the derived
    * vtkIceTRenderer in ParaView.
    */
-  virtual void StereoMidpoint() { return; };
+  virtual void StereoMidpoint() { return; }
 
   /**
    * Compute the aspect ratio of this renderer for the current tile. When
    * tiled displays are used the aspect ratio of the renderer for a given
    * tile may be different that the aspect ratio of the renderer when rendered
-   * in it entirity
+   * in it entirety
    */
   double GetTiledAspectRatio();
 
@@ -566,9 +578,7 @@ public:
    * automatically created by the renderer. It returns 0 if the
    * ActiveCamera does not yet exist.
    */
-  int IsActiveCameraCreated()
-    { return (this->ActiveCamera != NULL); }
-
+  vtkTypeBool IsActiveCameraCreated() { return (this->ActiveCamera != nullptr); }
 
   //@{
   /**
@@ -581,11 +591,20 @@ public:
    * If UseDepthPeeling is off, alpha blending is used.
    * Initial value is off.
    */
-  vtkSetMacro(UseDepthPeeling,int);
-  vtkGetMacro(UseDepthPeeling,int);
-  vtkBooleanMacro(UseDepthPeeling,int);
+  vtkSetMacro(UseDepthPeeling, vtkTypeBool);
+  vtkGetMacro(UseDepthPeeling, vtkTypeBool);
+  vtkBooleanMacro(UseDepthPeeling, vtkTypeBool);
   //@}
 
+  /**
+   * This flag is on and the GPU supports it, depth-peel volumes along with
+   * the translucent geometry. Only supported on OpenGL2 with dual-depth
+   * peeling. Default is false.
+   */
+  vtkSetMacro(UseDepthPeelingForVolumes, bool);
+  vtkGetMacro(UseDepthPeelingForVolumes, bool);
+  vtkBooleanMacro(UseDepthPeelingForVolumes, bool);
+
   //@{
   /**
    * In case of use of depth peeling technique for rendering translucent
@@ -596,8 +615,8 @@ public:
    * Initial value is 0.0, meaning rendering have to be exact. Greater values
    * may speed-up the rendering with small impact on the quality.
    */
-  vtkSetClampMacro(OcclusionRatio,double,0.0,0.5);
-  vtkGetMacro(OcclusionRatio,double);
+  vtkSetClampMacro(OcclusionRatio, double, 0.0, 0.5);
+  vtkGetMacro(OcclusionRatio, double);
   //@}
 
   //@{
@@ -606,8 +625,8 @@ public:
    * Initial value is 4. A special value of 0 means no maximum limit.
    * It has to be a positive value.
    */
-  vtkSetMacro(MaximumNumberOfPeels,int);
-  vtkGetMacro(MaximumNumberOfPeels,int);
+  vtkSetMacro(MaximumNumberOfPeels, int);
+  vtkGetMacro(MaximumNumberOfPeels, int);
   //@}
 
   //@{
@@ -616,7 +635,7 @@ public:
    * actually used depth peeling.
    * Initial value is false.
    */
-  vtkGetMacro(LastRenderingUsedDepthPeeling,int);
+  vtkGetMacro(LastRenderingUsedDepthPeeling, vtkTypeBool);
   //@}
 
   //@{
@@ -626,8 +645,8 @@ public:
    * is not NULL and its Used ivar is set to true.
    * Initial value is NULL.
    */
-  void SetDelegate(vtkRendererDelegate *d);
-  vtkGetObjectMacro(Delegate,vtkRendererDelegate);
+  void SetDelegate(vtkRendererDelegate* d);
+  vtkGetObjectMacro(Delegate, vtkRendererDelegate);
   //@}
 
   //@{
@@ -641,40 +660,52 @@ public:
 
   //@{
   /**
-   * Set/Get the texture to be used for the background. If set
-   * and enabled this gets the priority over the gradient background.
+   * Set/Get the texture to be used for the monocular or stereo left eye
+   * background. If set and enabled this gets the priority over the gradient
+   * background.
    */
+  virtual void SetLeftBackgroundTexture(vtkTexture*);
+  vtkTexture* GetLeftBackgroundTexture();
   virtual void SetBackgroundTexture(vtkTexture*);
   vtkGetObjectMacro(BackgroundTexture, vtkTexture);
   //@}
 
+  //@{
+  /**
+   * Set/Get the texture to be used for the right eye background. If set
+   * and enabled this gets the priority over the gradient background.
+   */
+  virtual void SetRightBackgroundTexture(vtkTexture*);
+  vtkGetObjectMacro(RightBackgroundTexture, vtkTexture);
+  //@}
+
   //@{
   /**
    * Set/Get whether this viewport should have a textured background.
    * Default is off.
    */
-  vtkSetMacro(TexturedBackground,bool);
-  vtkGetMacro(TexturedBackground,bool);
-  vtkBooleanMacro(TexturedBackground,bool);
+  vtkSetMacro(TexturedBackground, bool);
+  vtkGetMacro(TexturedBackground, bool);
+  vtkBooleanMacro(TexturedBackground, bool);
   //@}
 
   // method to release graphics resources in any derived renderers.
-  virtual void ReleaseGraphicsResources(vtkWindow *);
+  virtual void ReleaseGraphicsResources(vtkWindow*);
 
   //@{
   /**
    * Turn on/off FXAA anti-aliasing, if supported. Initial value is off.
    */
-  vtkSetMacro(UseFXAA, bool)
-  vtkGetMacro(UseFXAA, bool)
-  vtkBooleanMacro(UseFXAA, bool)
+  vtkSetMacro(UseFXAA, bool);
+  vtkGetMacro(UseFXAA, bool);
+  vtkBooleanMacro(UseFXAA, bool);
   //@}
 
   //@{
   /**
    * The configuration object for FXAA antialiasing.
    */
-  vtkGetObjectMacro(FXAAOptions, vtkFXAAOptions)
+  vtkGetObjectMacro(FXAAOptions, vtkFXAAOptions);
   virtual void SetFXAAOptions(vtkFXAAOptions*);
   //@}
 
@@ -683,9 +714,9 @@ public:
    * Turn on/off rendering of shadows if supported
    * Initial value is off.
    */
-  vtkSetMacro(UseShadows,int);
-  vtkGetMacro(UseShadows,int);
-  vtkBooleanMacro(UseShadows,int);
+  vtkSetMacro(UseShadows, vtkTypeBool);
+  vtkGetMacro(UseShadows, vtkTypeBool);
+  vtkBooleanMacro(UseShadows, vtkTypeBool);
   //@}
 
   //@{
@@ -693,14 +724,14 @@ public:
    * If this flag is true and the rendering engine supports it, wireframe
    * geometry will be drawn using hidden line removal.
    */
-  vtkSetMacro(UseHiddenLineRemoval, int)
-  vtkGetMacro(UseHiddenLineRemoval, int)
-  vtkBooleanMacro(UseHiddenLineRemoval, int)
+  vtkSetMacro(UseHiddenLineRemoval, vtkTypeBool);
+  vtkGetMacro(UseHiddenLineRemoval, vtkTypeBool);
+  vtkBooleanMacro(UseHiddenLineRemoval, vtkTypeBool);
   //@}
 
   // Set/Get a custom render pass.
   // Initial value is NULL.
-  void SetPass(vtkRenderPass *p);
+  void SetPass(vtkRenderPass* p);
   vtkGetObjectMacro(Pass, vtkRenderPass);
 
   //@{
@@ -711,72 +742,108 @@ public:
   virtual void SetInformation(vtkInformation*);
   //@}
 
+  //@{
+  /**
+   * If this flag is true and the rendering engine supports it, image based
+   * lighting is enabled and surface rendering displays environment reflections.
+   * The input cube map have to be set with SetEnvironmentCubeMap.
+   * If not cubemap is specified, this feature is disable.
+   */
+  vtkSetMacro(UseImageBasedLighting, bool);
+  vtkGetMacro(UseImageBasedLighting, bool);
+  vtkBooleanMacro(UseImageBasedLighting, bool);
+  //@}
+
+  //@{
+  /**
+   * Set/Get the environment texture used for image based lighting.
+   * This texture is supposed to represent the scene background.
+   * If it is not a cubemap, the texture is supposed to represent an equirectangular projection.
+   * If used with raytracing backends, the texture must be an equirectangular projection and must be
+   * constructed with a valid vtkImageData.
+   * Warning, this texture must be expressed in linear color space.
+   * If the texture is in sRGB color space, set the color flag on the texture or
+   * set the argument isSRGB to true.
+   * @sa vtkTexture::UseSRGBColorSpaceOn
+   */
+  vtkGetObjectMacro(EnvironmentTexture, vtkTexture);
+  virtual void SetEnvironmentTexture(vtkTexture* texture, bool isSRGB = false);
+  //@}
+
+  //@{
+  /**
+   * Set/Get the environment up vector.
+   */
+  vtkGetVector3Macro(EnvironmentUp, double);
+  vtkSetVector3Macro(EnvironmentUp, double);
+  //@}
+
+  //@{
+  /**
+   * Set/Get the environment right vector.
+   */
+  vtkGetVector3Macro(EnvironmentRight, double);
+  vtkSetVector3Macro(EnvironmentRight, double);
+  //@}
+
 protected:
   vtkRenderer();
-  ~vtkRenderer();
-
-  // internal method for doing a render for picking purposes
-  virtual void PickRender(vtkPropCollection *props);
-  virtual void PickGeometry();
+  ~vtkRenderer() override;
 
   // internal method to expand bounding box to consider model transform
   // matrix or model view transform matrix based on whether or not deering
   // frustum is used.
-  virtual void ExpandBounds(double bounds[6], vtkMatrix4x4 *matrix);
+  virtual void ExpandBounds(double bounds[6], vtkMatrix4x4* matrix);
 
-  vtkCamera *ActiveCamera;
-  vtkLight  *CreatedLight;
+  vtkCamera* ActiveCamera;
+  vtkLight* CreatedLight;
 
-  vtkLightCollection *Lights;
-  vtkCullerCollection *Cullers;
+  vtkLightCollection* Lights;
+  vtkCullerCollection* Cullers;
 
-  vtkActorCollection *Actors;
-  vtkVolumeCollection *Volumes;
+  vtkActorCollection* Actors;
+  vtkVolumeCollection* Volumes;
 
-  double              Ambient[3];
-  vtkRenderWindow    *RenderWindow;
-  double              AllocatedRenderTime;
-  double              TimeFactor;
-  int                TwoSidedLighting;
-  int                AutomaticLightCreation;
-  int                BackingStore;
-  unsigned char      *BackingImage;
-  int                BackingStoreSize[2];
-  vtkTimeStamp       RenderTime;
+  double Ambient[3];
+  vtkRenderWindow* RenderWindow;
+  double AllocatedRenderTime;
+  double TimeFactor;
+  vtkTypeBool TwoSidedLighting;
+  vtkTypeBool AutomaticLightCreation;
+  vtkTypeBool BackingStore;
+  unsigned char* BackingImage;
+  int BackingStoreSize[2];
+  vtkTimeStamp RenderTime;
 
-  double              LastRenderTimeInSeconds;
+  double LastRenderTimeInSeconds;
 
-  int                LightFollowCamera;
+  vtkTypeBool LightFollowCamera;
 
   // Allocate the time for each prop
-  void               AllocateTime();
+  void AllocateTime();
 
   // Internal variables indicating the number of props
   // that have been or will be rendered in each category.
-  int                NumberOfPropsRendered;
+  int NumberOfPropsRendered;
 
   // A temporary list of props used for culling, and traversal
   // of all props when rendering
-  vtkProp            **PropArray;
-  int                PropArrayCount;
-
-  // A temporary list used for picking
-  vtkAssemblyPath    **PathArray;
-  int                PathArrayCount;
+  vtkProp** PropArray;
+  int PropArrayCount;
 
   // Indicates if the renderer should receive events from an interactor.
   // Typically only used in conjunction with transparent renderers.
-  int                Interactive;
+  vtkTypeBool Interactive;
 
   // Shows what layer this renderer belongs to.  Only of interested when
   // there are layered renderers.
-  int                Layer;
-  int                PreserveColorBuffer;
-  int                PreserveDepthBuffer;
+  int Layer;
+  vtkTypeBool PreserveColorBuffer;
+  vtkTypeBool PreserveDepthBuffer;
 
   // Holds the result of ComputeVisiblePropBounds so that it is visible from
   // wrapped languages
-  double              ComputedVisiblePropBounds[6];
+  double ComputedVisiblePropBounds[6];
 
   /**
    * Specifies the minimum distance of the near clipping
@@ -785,7 +852,7 @@ protected:
    * Note that values which are too small may cause problems on systems
    * with low z-buffer resolution.
    */
-  double              NearClippingPlaneTolerance;
+  double NearClippingPlaneTolerance;
 
   /**
    * Specify enlargement of bounds when resetting the
@@ -799,26 +866,26 @@ protected:
    * Both the RenderWindow Erase and Render Erase must be on
    * for the camera to clear the renderer.  By default, Erase is on.
    */
-  int Erase;
+  vtkTypeBool Erase;
 
   /**
    * When this flag is off, render commands are ignored.  It is used to either
    * multiplex a vtkRenderWindow or render only part of a vtkRenderWindow.
    * By default, Draw is on.
    */
-  int Draw;
+  vtkTypeBool Draw;
 
   /**
    * Temporary collection used by vtkRenderWindow::CaptureGL2PSSpecialProps.
    */
-  vtkPropCollection *GL2PSSpecialPropCollection;
+  vtkPropCollection* GL2PSSpecialPropCollection;
 
   /**
    * Ask all props to update and draw any opaque and translucent
    * geometry. This includes both vtkActors and vtkVolumes
    * Returns the number of props that rendered geometry.
    */
-  virtual int UpdateGeometry();
+  virtual int UpdateGeometry(vtkFrameBufferObjectBase* fbo = nullptr);
 
   /**
    * Ask all props to update and draw any translucent polygonal
@@ -847,20 +914,20 @@ protected:
    * space (for instance, Headlights or CameraLights that are attached to the
    * camera).
    */
-  virtual int UpdateLightGeometry(void);
+  virtual vtkTypeBool UpdateLightGeometry(void);
 
   /**
    * Ask all lights to load themselves into rendering pipeline.
    * This method will return the actual number of lights that were on.
    */
-  virtual int UpdateLights(void) {return 0;}
+  virtual int UpdateLights(void) { return 0; }
 
   /**
    * Get the current camera and reset it only if it gets created
    * automatically (see GetActiveCamera).
    * This is only used internally.
    */
-  vtkCamera *GetActiveCameraAndResetIfCreated();
+  vtkCamera* GetActiveCameraAndResetIfCreated();
 
   /**
    * If this flag is on and the rendering engine supports it, FXAA will be used
@@ -871,19 +938,19 @@ protected:
   /**
    * Holds the FXAA configuration.
    */
-  vtkFXAAOptions *FXAAOptions;
+  vtkFXAAOptions* FXAAOptions;
 
   /**
    * If this flag is on and the rendering engine supports it render shadows
    * Initial value is off.
    */
-  int UseShadows;
+  vtkTypeBool UseShadows;
 
   /**
    * When this flag is on and the rendering engine supports it, wireframe
    * polydata will be rendered using hidden line removal.
    */
-  int UseHiddenLineRemoval;
+  vtkTypeBool UseHiddenLineRemoval;
 
   /**
    * If this flag is on and the GPU supports it, depth peeling is used
@@ -891,7 +958,13 @@ protected:
    * If this flag is off, alpha blending is used.
    * Initial value is off.
    */
-  int UseDepthPeeling;
+  vtkTypeBool UseDepthPeeling;
+
+  /**
+   * This flag is on and the GPU supports it, depth-peel volumes along with
+   * the translucent geometry. Default is false;
+   */
+  bool UseDepthPeelingForVolumes;
 
   /**
    * In case of use of depth peeling technique for rendering translucent
@@ -916,7 +989,7 @@ protected:
    * actually used depth peeling.
    * Initial value is false.
    */
-  int LastRenderingUsedDepthPeeling;
+  vtkTypeBool LastRenderingUsedDepthPeeling;
 
   // HARDWARE SELECTION ----------------------------------------
   friend class vtkHardwareSelector;
@@ -925,37 +998,50 @@ protected:
    * Called by vtkHardwareSelector when it begins rendering for selection.
    */
   void SetSelector(vtkHardwareSelector* selector)
-    { this->Selector = selector; this->Modified(); }
+  {
+    this->Selector = selector;
+    this->Modified();
+  }
 
   // End Ivars for visible cell selecting.
   vtkHardwareSelector* Selector;
 
   //---------------------------------------------------------------
   friend class vtkRendererDelegate;
-  vtkRendererDelegate *Delegate;
+  vtkRendererDelegate* Delegate;
 
   bool TexturedBackground;
   vtkTexture* BackgroundTexture;
+  vtkTexture* RightBackgroundTexture;
 
   friend class vtkRenderPass;
-  vtkRenderPass *Pass;
+  vtkRenderPass* Pass;
 
   // Arbitrary extra information associated with this renderer
   vtkInformation* Information;
 
-private:
-  vtkRenderer(const vtkRenderer&) VTK_DELETE_FUNCTION;
-  void operator=(const vtkRenderer&) VTK_DELETE_FUNCTION;
+  bool UseImageBasedLighting;
+  vtkTexture* EnvironmentTexture;
 
+  double EnvironmentUp[3];
+  double EnvironmentRight[3];
+
+private:
+  vtkRenderer(const vtkRenderer&) = delete;
+  void operator=(const vtkRenderer&) = delete;
 };
 
-inline vtkLightCollection *vtkRenderer::GetLights() {
+inline vtkLightCollection* vtkRenderer::GetLights()
+{
   return this->Lights;
 }
 
 /**
  * Get the list of cullers for this renderer.
  */
-inline vtkCullerCollection *vtkRenderer::GetCullers(){return this->Cullers;}
+inline vtkCullerCollection* vtkRenderer::GetCullers()
+{
+  return this->Cullers;
+}
 
 #endif
