@@ -14,19 +14,21 @@
 =========================================================================*/
 #include "vtkWindowToImageFilter.h"
 
-#include "vtkMath.h"
+#include "vtkActor2D.h"
+#include "vtkActor2DCollection.h"
 #include "vtkCamera.h"
+#include "vtkCoordinate.h"
 #include "vtkImageData.h"
 #include "vtkInformation.h"
 #include "vtkInformationVector.h"
+#include "vtkMath.h"
 #include "vtkObjectFactory.h"
 #include "vtkRenderWindow.h"
+#include "vtkRenderWindowInteractor.h"
 #include "vtkRendererCollection.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
-#include "vtkRenderWindowInteractor.h"
-#include "vtkCoordinate.h"
-#include "vtkActor2D.h"
-#include "vtkActor2DCollection.h"
+
+#include <algorithm>
 #include <vector>
 
 #define BORDER_PIXELS 2
@@ -37,13 +39,13 @@ class vtkWTI2DHelperClass
 {
 public:
   // maintain a list of 2D actors
-  vtkActor2DCollection *StoredActors;
+  vtkActor2DCollection* StoredActors;
   // maintain lists of their vtkCoordinate objects
-  vtkCollection        *Coord1s;
-  vtkCollection        *Coord2s;
+  vtkCollection* Coord1s;
+  vtkCollection* Coord2s;
   // Store the display coords for adjustment during tiling
-  std::vector< std::pair<int, int> > Coords1;
-  std::vector< std::pair<int, int> > Coords2;
+  std::vector<std::pair<int, int> > Coords1;
+  std::vector<std::pair<int, int> > Coords2;
   //
   vtkWTI2DHelperClass()
   {
@@ -65,8 +67,8 @@ public:
 //----------------------------------------------------------------------------
 vtkWindowToImageFilter::vtkWindowToImageFilter()
 {
-  this->Input = NULL;
-  this->Magnification = 1;
+  this->Input = nullptr;
+  this->Scale[0] = this->Scale[1] = 1;
   this->ReadFrontBuffer = 1;
   this->ShouldRerender = 1;
   this->Viewport[0] = 0;
@@ -87,7 +89,7 @@ vtkWindowToImageFilter::~vtkWindowToImageFilter()
   if (this->Input)
   {
     this->Input->UnRegister(this);
-    this->Input = NULL;
+    this->Input = nullptr;
   }
   delete this->StoredData;
 }
@@ -99,13 +101,19 @@ vtkImageData* vtkWindowToImageFilter::GetOutput()
 }
 
 //----------------------------------------------------------------------------
-void vtkWindowToImageFilter::SetInput(vtkWindow *input)
+void vtkWindowToImageFilter::SetInput(vtkWindow* input)
 {
   if (input != this->Input)
   {
-    if (this->Input) {this->Input->UnRegister(this);}
+    if (this->Input)
+    {
+      this->Input->UnRegister(this);
+    }
     this->Input = input;
-    if (this->Input) {this->Input->Register(this);}
+    if (this->Input)
+    {
+      this->Input->Register(this);
+    }
     this->Modified();
   }
 }
@@ -113,22 +121,22 @@ void vtkWindowToImageFilter::SetInput(vtkWindow *input)
 //----------------------------------------------------------------------------
 void vtkWindowToImageFilter::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 
-  if ( this->Input )
+  if (this->Input)
   {
     os << indent << "Input:\n";
-    this->Input->PrintSelf(os,indent.GetNextIndent());
+    this->Input->PrintSelf(os, indent.GetNextIndent());
   }
   else
   {
     os << indent << "Input: (none)\n";
   }
   os << indent << "ReadFrontBuffer: " << this->ReadFrontBuffer << "\n";
-  os << indent << "Magnification: " << this->Magnification << "\n";
+  os << indent << "Scale: " << this->Scale[0] << ", " << this->Scale[1] << "\n";
   os << indent << "ShouldRerender: " << this->ShouldRerender << "\n";
-  os << indent << "Viewport: " << this->Viewport[0] << "," << this->Viewport[1]
-     << "," << this->Viewport[2] << "," << this->Viewport[3] << "\n";
+  os << indent << "Viewport: " << this->Viewport[0] << "," << this->Viewport[1] << ","
+     << this->Viewport[2] << "," << this->Viewport[3] << "\n";
   os << indent << "InputBufferType: " << this->InputBufferType << "\n";
   os << indent << "FixBoundary: " << this->FixBoundary << endl;
 }
@@ -141,8 +149,10 @@ void vtkWindowToImageFilter::SetViewport(double a1, double a2, double a3, double
   a3 = vtkMath::ClampValue(a3, 0.0, 1.0);
   a4 = vtkMath::ClampValue(a4, 0.0, 1.0);
 
-  vtkDebugMacro(<< this->GetClassName() << " (" << this << "): setting Viewport to (" << a1 << "," << a2 << "," << a3 << "," << a4 << ")");
-  if ((this->Viewport[0] != a1) || (this->Viewport[1] != a2) || (this->Viewport[2] != a3) || (this->Viewport[3] != a4))
+  vtkDebugMacro(<< this->GetClassName() << " (" << this << "): setting Viewport to (" << a1 << ","
+                << a2 << "," << a3 << "," << a4 << ")");
+  if ((this->Viewport[0] != a1) || (this->Viewport[1] != a2) || (this->Viewport[2] != a3) ||
+    (this->Viewport[3] != a4))
   {
     this->Viewport[0] = a1;
     this->Viewport[1] = a2;
@@ -160,44 +170,54 @@ void vtkWindowToImageFilter::SetViewport(double vp[4])
 
 //----------------------------------------------------------------------------
 // This method returns the largest region that can be generated.
-void vtkWindowToImageFilter::RequestInformation (
-  vtkInformation * vtkNotUsed(request),
-  vtkInformationVector** vtkNotUsed( inputVector ),
-  vtkInformationVector *outputVector)
+void vtkWindowToImageFilter::RequestInformation(vtkInformation* vtkNotUsed(request),
+  vtkInformationVector** vtkNotUsed(inputVector), vtkInformationVector* outputVector)
 {
-  if (this->Input == NULL )
+  if (this->Input == nullptr)
   {
-    vtkErrorMacro(<<"Please specify a renderer as input!");
+    vtkErrorMacro(<< "Please specify a renderer as input!");
     return;
   }
 
+  if (this->Scale[0] < 1)
+  {
+    vtkWarningMacro("Scale[0] cannot be less than 1. Clamping to 1.");
+    this->Scale[0] = 1;
+  }
+
+  if (this->Scale[1] < 1)
+  {
+    vtkWarningMacro("Scale[1] cannot be less than 1. Clamping to 1.");
+    this->Scale[1] = 1;
+  }
+
   int tileScale[2];
   this->Input->GetTileScale(tileScale);
-  int magTileScale[2] = {tileScale[0] * this->Magnification,
-                         tileScale[1] * this->Magnification};
+  int magTileScale[2] = { tileScale[0] * this->Scale[0], tileScale[1] * this->Scale[1] };
 
-  if((magTileScale[0] > 1 || magTileScale[1] > 1) &&
-     (this->Viewport[0] != 0 || this->Viewport[1] != 0 ||
-      this->Viewport[2] != 1 || this->Viewport[3] != 1))
+  if ((magTileScale[0] > 1 || magTileScale[1] > 1) &&
+    (this->Viewport[0] != 0 || this->Viewport[1] != 0 || this->Viewport[2] != 1 ||
+      this->Viewport[3] != 1))
   {
-    vtkWarningMacro(<<"Viewport extents are not used when Magnification > 1 "
-                    "or tiled displays are used.");
+    vtkWarningMacro(<< "Viewport extents are not used when scale factors > 1 "
+                       "or tiled displays are used.");
     this->Viewport[0] = 0;
     this->Viewport[1] = 0;
     this->Viewport[2] = 1;
     this->Viewport[3] = 1;
   }
 
-
   // set the extent
-  int *size = this->Input->GetSize();
+  const int* size = this->Input->GetSize();
   int wExtent[6];
-  wExtent[0]= 0;
-  wExtent[1] = (int(this->Viewport[2] * size[0] + 0.5)-
-    int(this->Viewport[0] * size[0])) * this->Magnification - 1;
+  wExtent[0] = 0;
+  wExtent[1] =
+    (int(this->Viewport[2] * size[0] + 0.5) - int(this->Viewport[0] * size[0])) * this->Scale[0] -
+    1;
   wExtent[2] = 0;
-  wExtent[3] = (int(this->Viewport[3] * size[1] + 0.5)-
-    int(this->Viewport[1] * size[1])) * this->Magnification - 1;
+  wExtent[3] =
+    (int(this->Viewport[3] * size[1] + 0.5) - int(this->Viewport[1] * size[1])) * this->Scale[1] -
+    1;
   wExtent[4] = 0;
   wExtent[5] = 0;
 
@@ -205,7 +225,7 @@ void vtkWindowToImageFilter::RequestInformation (
   vtkInformation* outInfo = outputVector->GetInformationObject(0);
   outInfo->Set(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT(), wExtent, 6);
 
-  switch( this->InputBufferType )
+  switch (this->InputBufferType)
   {
     case VTK_RGB:
       vtkDataObject::SetPointDataActiveScalarInfo(outInfo, VTK_UNSIGNED_CHAR, 3);
@@ -224,19 +244,18 @@ void vtkWindowToImageFilter::RequestInformation (
 }
 
 //----------------------------------------------------------------------------
-int vtkWindowToImageFilter::ProcessRequest(vtkInformation* request,
-                                           vtkInformationVector** inputVector,
-                                           vtkInformationVector* outputVector)
+vtkTypeBool vtkWindowToImageFilter::ProcessRequest(
+  vtkInformation* request, vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
   // generate the data
-  if(request->Has(vtkDemandDrivenPipeline::REQUEST_DATA()))
+  if (request->Has(vtkDemandDrivenPipeline::REQUEST_DATA()))
   {
     this->RequestData(request, inputVector, outputVector);
     return 1;
   }
 
   // execute information
-  if(request->Has(vtkDemandDrivenPipeline::REQUEST_INFORMATION()))
+  if (request->Has(vtkDemandDrivenPipeline::REQUEST_INFORMATION()))
   {
     this->RequestInformation(request, inputVector, outputVector);
     return 1;
@@ -245,20 +264,15 @@ int vtkWindowToImageFilter::ProcessRequest(vtkInformation* request,
   return this->Superclass::ProcessRequest(request, inputVector, outputVector);
 }
 
-
 //----------------------------------------------------------------------------
 // This function reads a region from a file.  The regions extent/axes
 // are assumed to be the same as the file extent/order.
-void vtkWindowToImageFilter::RequestData(
-  vtkInformation* vtkNotUsed( request ),
-  vtkInformationVector** vtkNotUsed( inputVector ),
-  vtkInformationVector* outputVector)
+void vtkWindowToImageFilter::RequestData(vtkInformation* vtkNotUsed(request),
+  vtkInformationVector** vtkNotUsed(inputVector), vtkInformationVector* outputVector)
 {
-  vtkInformation *outInfo = outputVector->GetInformationObject(0);
-  vtkImageData *out =
-    vtkImageData::SafeDownCast(outInfo->Get(vtkDataObject::DATA_OBJECT()));
-  out->SetExtent(
-    outInfo->Get(vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT()));
+  vtkInformation* outInfo = outputVector->GetInformationObject(0);
+  vtkImageData* out = vtkImageData::SafeDownCast(outInfo->Get(vtkDataObject::DATA_OBJECT()));
+  out->SetExtent(outInfo->Get(vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT()));
   out->AllocateScalars(outInfo);
 
   if (!this->Input)
@@ -266,7 +280,19 @@ void vtkWindowToImageFilter::RequestData(
     return;
   }
 
-  vtkRenderWindow *renWin = vtkRenderWindow::SafeDownCast(this->Input);
+  if (this->Scale[0] < 1)
+  {
+    vtkWarningMacro("Scale[0] cannot be less than 1. Clamping to 1.");
+    this->Scale[0] = 1;
+  }
+
+  if (this->Scale[1] < 1)
+  {
+    vtkWarningMacro("Scale[1] cannot be less than 1. Clamping to 1.");
+    this->Scale[1] = 1;
+  }
+
+  vtkRenderWindow* renWin = vtkRenderWindow::SafeDownCast(this->Input);
   if (!renWin)
   {
     vtkWarningMacro(
@@ -274,8 +300,8 @@ void vtkWindowToImageFilter::RequestData(
     return;
   }
 
-  if (! ((out->GetScalarType() == VTK_UNSIGNED_CHAR &&
-        (this->InputBufferType == VTK_RGB || this->InputBufferType == VTK_RGBA)) ||
+  if (!((out->GetScalarType() == VTK_UNSIGNED_CHAR &&
+          (this->InputBufferType == VTK_RGB || this->InputBufferType == VTK_RGBA)) ||
         (out->GetScalarType() == VTK_FLOAT && this->InputBufferType == VTK_ZBUFFER)))
   {
     vtkErrorMacro("mismatch in scalar types!");
@@ -284,45 +310,36 @@ void vtkWindowToImageFilter::RequestData(
 
   int tileScale[2];
   this->Input->GetTileScale(tileScale);
-  int magTileScale[2] = {this->Magnification * tileScale[0],
-                         this->Magnification * tileScale[1]};
+  int magTileScale[2] = { this->Scale[0] * tileScale[0], this->Scale[1] * tileScale[1] };
 
-  int tileSize[2] = {this->Input->GetActualSize()[0],
-                     this->Input->GetActualSize()[1]};
+  int tileSize[2] = { this->Input->GetActualSize()[0], this->Input->GetActualSize()[1] };
 
   // This is the size of the window with all tiles accounted for:
-  int winSize[2] = {this->Input->GetSize()[0], this->Input->GetSize()[1]};
+  int winSize[2] = { this->Input->GetSize()[0], this->Input->GetSize()[1] };
 
-  int imageBounds[4] =
-    {
-    int(this->Viewport[0] * tileSize[0]),
-    int(this->Viewport[1] * tileSize[1]),
+  int imageBounds[4] = { int(this->Viewport[0] * tileSize[0]), int(this->Viewport[1] * tileSize[1]),
     int(this->Viewport[2] * tileSize[0] + 0.5) - 1,
-    int(this->Viewport[3] * tileSize[1] + 0.5) - 1
-    };
+    int(this->Viewport[3] * tileSize[1] + 0.5) - 1 };
 
-  int vpSize[2] = {imageBounds[2] - imageBounds[0] + 1,
-                   imageBounds[3] - imageBounds[1] + 1};
+  int vpSize[2] = { imageBounds[2] - imageBounds[0] + 1, imageBounds[3] - imageBounds[1] + 1 };
 
-  int imageSize[2] = {vpSize[0] * magTileScale[0],
-                      vpSize[1] * magTileScale[1]};
+  int imageSize[2] = { vpSize[0] * magTileScale[0], vpSize[1] * magTileScale[1] };
 
   int inIncrY = vpSize[0];
-  inIncrY *= (this->InputBufferType == VTK_RGB) ? 3 :
-    ((this->InputBufferType == VTK_RGBA) ? 4 : 1);
+  inIncrY *= (this->InputBufferType == VTK_RGB) ? 3 : ((this->InputBufferType == VTK_RGBA) ? 4 : 1);
 
   int outIncrY = imageSize[0] * out->GetNumberOfScalarComponents();
 
-  vtkRendererCollection *rc = renWin->GetRenderers();
-  vtkRenderer *aren;
-  vtkCamera *cam;
+  vtkRendererCollection* rc = renWin->GetRenderers();
+  vtkRenderer* aren;
+  vtkCamera* cam;
   int numRenderers = rc->GetNumberOfItems();
 
   // for each renderer
-  vtkCamera **cams = new vtkCamera *[numRenderers];
-  float* viewAngles = new float [numRenderers];
-  double* windowCenters = new double [numRenderers*2];
-  double *parallelScale = new double [numRenderers];
+  vtkCamera** cams = new vtkCamera*[numRenderers];
+  float* viewAngles = new float[numRenderers];
+  double* windowCenters = new double[numRenderers * 2];
+  double* parallelScale = new double[numRenderers];
   vtkCollectionSimpleIterator rsit;
   rc->InitTraversal(rsit);
   for (int i = 0; i < numRenderers; ++i)
@@ -330,8 +347,8 @@ void vtkWindowToImageFilter::RequestData(
     aren = rc->GetNextRenderer(rsit);
     cams[i] = aren->GetActiveCamera();
     cams[i]->Register(this);
-    cams[i]->GetWindowCenter(windowCenters+i*2);
-    viewAngles[i] = cams[i]->GetViewAngle();
+    cams[i]->GetWindowCenter(windowCenters + i * 2);
+    viewAngles[i] = vtkMath::RadiansFromDegrees(cams[i]->GetViewAngle());
     parallelScale[i] = cams[i]->GetParallelScale();
     cam = cams[i]->NewInstance();
     cam->ShallowCopy(cams[i]);
@@ -342,9 +359,9 @@ void vtkWindowToImageFilter::RequestData(
   this->Input->SetTileScale(magTileScale);
   this->Input->GetSize();
 
-  //this->Rescale2DActors();
+  // this->Rescale2DActors();
 
-  int num_iterations[2] = {magTileScale[0], magTileScale[1]};
+  int num_iterations[2] = { magTileScale[0], magTileScale[1] };
   bool overlap_viewports = false;
   if (this->FixBoundary)
   {
@@ -357,12 +374,12 @@ void vtkWindowToImageFilter::RequestData(
   }
 
   // Precompute the tile this->Viewport for each iteration.
-  double *viewports = new double[4 * num_iterations[0] * num_iterations[1]];
+  double* viewports = new double[4 * num_iterations[0] * num_iterations[1]];
   for (int y = 0; y < num_iterations[1]; y++)
   {
     for (int x = 0; x < num_iterations[0]; x++)
     {
-      double* cur_viewport = &viewports[(num_iterations[1] * y + x) * 4];
+      double* cur_viewport = &viewports[(num_iterations[0] * y + x) * 4];
       cur_viewport[0] = static_cast<double>(x) / magTileScale[0];
       cur_viewport[1] = static_cast<double>(y) / magTileScale[1];
       cur_viewport[2] = (x + 1.0) / magTileScale[0];
@@ -379,7 +396,6 @@ void vtkWindowToImageFilter::RequestData(
         {
           cur_viewport[0] = static_cast<double>(x - 1) / magTileScale[0];
           cur_viewport[2] = static_cast<double>(x) / magTileScale[0];
-
         }
         if (y > 0 && y < num_iterations[1] - 1)
         {
@@ -400,9 +416,9 @@ void vtkWindowToImageFilter::RequestData(
     for (int x = 0; x < num_iterations[0]; x++)
     {
       // setup the Window ivars
-      double* cur_viewport = &viewports[(num_iterations[1] * y + x) * 4];
+      double* cur_viewport = &viewports[(num_iterations[0] * y + x) * 4];
       this->Input->SetTileViewport(cur_viewport);
-      double *tvp = this->Input->GetTileViewport();
+      double* tvp = this->Input->GetTileViewport();
 
       // for each renderer, setup camera
       rc->InitTraversal(rsit);
@@ -410,7 +426,7 @@ void vtkWindowToImageFilter::RequestData(
       {
         aren = rc->GetNextRenderer(rsit);
         cam = aren->GetActiveCamera();
-        double *vp = aren->GetViewport();
+        double* vp = aren->GetViewport();
         double visVP[4];
         visVP[0] = (vp[0] < tvp[0]) ? tvp[0] : vp[0];
         visVP[0] = (visVP[0] > tvp[2]) ? tvp[2] : visVP[0];
@@ -422,43 +438,31 @@ void vtkWindowToImageFilter::RequestData(
         visVP[3] = (visVP[3] < tvp[1]) ? tvp[1] : visVP[3];
 
         // compute magnification
-        double mag = (visVP[3] - visVP[1])/(vp[3] - vp[1]);
+        double mag = (visVP[3] - visVP[1]) / (vp[3] - vp[1]);
         // compute the delta
-        double deltax = (visVP[2] + visVP[0])/2.0 - (vp[2] + vp[0])/2.0;
-        double deltay = (visVP[3] + visVP[1])/2.0 - (vp[3] + vp[1])/2.0;
+        double deltax = (visVP[2] + visVP[0]) / 2.0 - (vp[2] + vp[0]) / 2.0;
+        double deltay = (visVP[3] + visVP[1]) / 2.0 - (vp[3] + vp[1]) / 2.0;
         // scale by original window size
         if (visVP[2] - visVP[0] > 0)
         {
-          deltax = 2.0*deltax/(visVP[2] - visVP[0]);
+          deltax = 2.0 * deltax / (visVP[2] - visVP[0]);
         }
         if (visVP[3] - visVP[1] > 0)
         {
-          deltay = 2.0*deltay/(visVP[3] - visVP[1]);
+          deltay = 2.0 * deltay / (visVP[3] - visVP[1]);
         }
-        cam->SetWindowCenter(windowCenters[i*2]+deltax,windowCenters[i*2+1]+deltay);
-        //cam->SetViewAngle(atan(tan(viewAngles[i]*vtkMath::Pi()/360.0)*mag)  //FIXME
-        cam->SetViewAngle(asin(sin(viewAngles[i]*vtkMath::Pi()/360.0)*mag)
-                          * 360.0 / vtkMath::Pi());
-        cam->SetParallelScale(parallelScale[i]*mag);
+        cam->SetWindowCenter(windowCenters[i * 2] + deltax, windowCenters[i * 2 + 1] + deltay);
+        double angle = 2.0 * atan(tan(viewAngles[i] / 2.0) * mag);
+        cam->SetViewAngle(vtkMath::DegreesFromRadians(angle));
+        cam->SetParallelScale(parallelScale[i] * mag);
       }
 
       // Shift 2d actors just before rendering
-      //this->Shift2DActors(size[0]*x, size[1]*y);
+      // this->Shift2DActors(size[0]*x, size[1]*y);
       // now render the tile and get the data
-      if (this->ShouldRerender ||
-          num_iterations[0] > 1 || num_iterations[1] > 1)
+      if (this->ShouldRerender || num_iterations[0] > 1 || num_iterations[1] > 1)
       {
-        // if interactor is present, trigger render through interactor. This
-        // allows for custom applications that provide interactors that
-        // customize rendering e.g. ParaView.
-        if (renWin->GetInteractor())
-        {
-          renWin->GetInteractor()->Render();
-        }
-        else
-        {
-          this->Input->Render();
-        }
+        this->Render();
       }
       this->Input->MakeCurrent();
 
@@ -488,16 +492,14 @@ void vtkWindowToImageFilter::RequestData(
           int xpos = int(cur_viewport[0] * imageSize[0] + 0.5);
           int ypos = int(cur_viewport[1] * imageSize[1] + 0.5);
 
-          outPtr = static_cast<unsigned char *>(
-            out->GetScalarPointer(xpos,ypos, 0));
+          outPtr = static_cast<unsigned char*>(out->GetScalarPointer(xpos, ypos, 0));
 
           // We skip padding pixels around internal borders.
           int ncomp = out->GetNumberOfScalarComponents();
-          int start_x_offset = (x != 0)? BORDER_PIXELS : 0;
-          int end_x_offset = (x != num_iterations[0]-1 && x!=0) ? BORDER_PIXELS
-                                                                : 0;
-          int start_y_offset = (y != 0)? BORDER_PIXELS : 0;
-          int end_y_offset = (y != num_iterations[1]-1)? BORDER_PIXELS : 0;
+          int start_x_offset = (x != 0) ? BORDER_PIXELS : 0;
+          int end_x_offset = (x != num_iterations[0] - 1 && x != 0) ? BORDER_PIXELS : 0;
+          int start_y_offset = (y != 0) ? BORDER_PIXELS : 0;
+          int end_y_offset = (y != num_iterations[1] - 1) ? BORDER_PIXELS : 0;
           start_x_offset *= ncomp;
           end_x_offset *= ncomp;
 
@@ -514,8 +516,8 @@ void vtkWindowToImageFilter::RequestData(
         }
         else
         {
-          outPtr = static_cast<unsigned char *>(
-            out->GetScalarPointer(x * vpSize[0], y * vpSize[1], 0));
+          outPtr =
+            static_cast<unsigned char*>(out->GetScalarPointer(x * vpSize[0], y * vpSize[1], 0));
 
           for (int idxY = 0; idxY < vpSize[1]; idxY++)
           {
@@ -523,21 +525,19 @@ void vtkWindowToImageFilter::RequestData(
             outPtr += outIncrY;
             pixels1 += inIncrY;
           }
-
         }
 
         // free the memory
-        delete [] pixels;
+        delete[] pixels;
       }
       else
       { // VTK_ZBUFFER
-        float* pixels = renWin->GetZbufferData(
-          imageBounds[0], imageBounds[1], imageBounds[2], imageBounds[3]);
+        float* pixels =
+          renWin->GetZbufferData(imageBounds[0], imageBounds[1], imageBounds[2], imageBounds[3]);
         float* pixels1 = pixels;
 
         // now write the data to the output image
-        float* outPtr = static_cast<float *>(
-          out->GetScalarPointer(x * vpSize[0], y * vpSize[1], 0));
+        float* outPtr = static_cast<float*>(out->GetScalarPointer(x * vpSize[0], y * vpSize[1], 0));
 
         for (int idxY = 0; idxY < vpSize[1]; idxY++)
         {
@@ -547,7 +547,7 @@ void vtkWindowToImageFilter::RequestData(
         }
 
         // free the memory
-        delete [] pixels;
+        delete[] pixels;
       }
     }
   }
@@ -564,18 +564,18 @@ void vtkWindowToImageFilter::RequestData(
     cams[i]->UnRegister(this);
     cam->Delete();
   }
-  delete [] viewAngles;
-  delete [] windowCenters;
-  delete [] parallelScale;
-  delete [] cams;
-  delete [] viewports;
+  delete[] viewAngles;
+  delete[] windowCenters;
+  delete[] parallelScale;
+  delete[] cams;
+  delete[] viewports;
 
   // render each of the tiles required to fill this request
   this->Input->SetTileScale(tileScale);
-  this->Input->SetTileViewport(0.0,0.0,1.0,1.0);
+  this->Input->SetTileViewport(0.0, 0.0, 1.0, 1.0);
   this->Input->GetSize();
   // restore every 2d actors
-  //this->Restore2DActors();
+  // this->Restore2DActors();
 }
 
 //----------------------------------------------------------------------------
@@ -583,13 +583,13 @@ void vtkWindowToImageFilter::RequestData(
 // it appears in the corrrect relative location
 void vtkWindowToImageFilter::Restore2DActors()
 {
-  vtkActor2D            *actor;
-  vtkCoordinate         *c1, *c2;
-  vtkCoordinate         *n1, *n2;
+  vtkActor2D* actor;
+  vtkCoordinate *c1, *c2;
+  vtkCoordinate *n1, *n2;
   int i;
   //
-  for (this->StoredData->StoredActors->InitTraversal(), i=0;
-    (actor = this->StoredData->StoredActors->GetNextItem()); i++)
+  for (this->StoredData->StoredActors->InitTraversal(), i = 0;
+       (actor = this->StoredData->StoredActors->GetNextItem()); i++)
   {
     c1 = actor->GetPositionCoordinate();
     c2 = actor->GetPosition2Coordinate();
@@ -611,24 +611,24 @@ void vtkWindowToImageFilter::Restore2DActors()
 //----------------------------------------------------------------------------
 void vtkWindowToImageFilter::Rescale2DActors()
 {
-  vtkActor2D            *actor;
-  vtkProp               *aProp;
-  vtkRenderer           *aren;
-  vtkPropCollection     *pc;
-  vtkRendererCollection *rc;
-  vtkCoordinate         *c1, *c2;
-  vtkCoordinate         *n1, *n2;
-  int                   *p1, *p2;
-  double                d1[3], d2[3];
+  vtkActor2D* actor;
+  vtkProp* aProp;
+  vtkRenderer* aren;
+  vtkPropCollection* pc;
+  vtkRendererCollection* rc;
+  vtkCoordinate *c1, *c2;
+  vtkCoordinate *n1, *n2;
+  int *p1, *p2;
+  double d1[3], d2[3];
   //
-  vtkRenderWindow *renWin = vtkRenderWindow::SafeDownCast(this->Input);
+  vtkRenderWindow* renWin = vtkRenderWindow::SafeDownCast(this->Input);
   rc = renWin->GetRenderers();
-  for (rc->InitTraversal(); (aren = rc->GetNextItem()); )
+  for (rc->InitTraversal(); (aren = rc->GetNextItem());)
   {
     pc = aren->GetViewProps();
     if (pc)
     {
-      for ( pc->InitTraversal(); (aProp = pc->GetNextProp()); )
+      for (pc->InitTraversal(); (aProp = pc->GetNextProp());)
       {
         actor = vtkActor2D::SafeDownCast((aProp));
         if (actor)
@@ -654,21 +654,21 @@ void vtkWindowToImageFilter::Rescale2DActors()
           // work out the position in new magnified pixels
           p1 = n1->GetComputedDisplayValue(aren);
           p2 = n2->GetComputedDisplayValue(aren);
-          d1[0] = p1[0]*this->Magnification;
-          d1[1] = p1[1]*this->Magnification;
+          d1[0] = p1[0] * this->Scale[0];
+          d1[1] = p1[1] * this->Scale[1];
           d1[2] = 0.0;
-          d2[0] = p2[0]*this->Magnification;
-          d2[1] = p2[1]*this->Magnification;
+          d2[0] = p2[0] * this->Scale[0];
+          d2[1] = p2[1] * this->Scale[1];
           d2[2] = 0.0;
           this->StoredData->Coords1.push_back(
-            std::pair<int, int>(static_cast<int>(d1[0]), static_cast<int>(d1[1])) );
+            std::pair<int, int>(static_cast<int>(d1[0]), static_cast<int>(d1[1])));
           this->StoredData->Coords2.push_back(
-            std::pair<int, int>(static_cast<int>(d2[0]), static_cast<int>(d2[1])) );
+            std::pair<int, int>(static_cast<int>(d2[0]), static_cast<int>(d2[1])));
           // Make sure they have no dodgy offsets
           n1->SetCoordinateSystemToDisplay();
           n2->SetCoordinateSystemToDisplay();
-          n1->SetReferenceCoordinate(NULL);
-          n2->SetReferenceCoordinate(NULL);
+          n1->SetReferenceCoordinate(nullptr);
+          n2->SetReferenceCoordinate(nullptr);
           n1->SetValue(d1[0], d1[1]);
           n2->SetValue(d2[0], d2[1]);
           //
@@ -682,21 +682,21 @@ void vtkWindowToImageFilter::Rescale2DActors()
 // it appears in the correct relative location
 void vtkWindowToImageFilter::Shift2DActors(int x, int y)
 {
-  vtkActor2D    *actor;
+  vtkActor2D* actor;
   vtkCoordinate *c1, *c2;
-  double        d1[3], d2[3];
-  int           i;
+  double d1[3], d2[3];
+  int i;
   //
-  for (this->StoredData->StoredActors->InitTraversal(), i=0;
-    (actor = this->StoredData->StoredActors->GetNextItem()); i++)
+  for (this->StoredData->StoredActors->InitTraversal(), i = 0;
+       (actor = this->StoredData->StoredActors->GetNextItem()); i++)
   {
     c1 = actor->GetPositionCoordinate();
     c2 = actor->GetPosition2Coordinate();
     c1->GetValue(d1);
     c2->GetValue(d2);
-    d1[0] = this->StoredData->Coords1[i].first  - x;
+    d1[0] = this->StoredData->Coords1[i].first - x;
     d1[1] = this->StoredData->Coords1[i].second - y + 1;
-    d2[0] = this->StoredData->Coords2[i].first  - x;
+    d2[0] = this->StoredData->Coords2[i].first - x;
     d2[1] = this->StoredData->Coords2[i].second - y + 1;
     c1->SetValue(d1);
     c2->SetValue(d2);
@@ -704,10 +704,27 @@ void vtkWindowToImageFilter::Shift2DActors(int x, int y)
 }
 
 //----------------------------------------------------------------------------
-int vtkWindowToImageFilter::FillOutputPortInformation(
-  int vtkNotUsed(port), vtkInformation* info)
+int vtkWindowToImageFilter::FillOutputPortInformation(int vtkNotUsed(port), vtkInformation* info)
 {
   // now add our info
   info->Set(vtkDataObject::DATA_TYPE_NAME(), "vtkImageData");
   return 1;
 }
+//----------------------------------------------------------------------------
+void vtkWindowToImageFilter::Render()
+{
+  if (vtkRenderWindow* renWin = vtkRenderWindow::SafeDownCast(this->Input))
+  {
+    // if interactor is present, trigger render through interactor. This
+    // allows for custom applications that provide interactors that
+    // customize rendering e.g. ParaView.
+    if (renWin->GetInteractor())
+    {
+      renWin->GetInteractor()->Render();
+    }
+    else
+    {
+      renWin->Render();
+    }
+  }
+}
