@@ -18,6 +18,7 @@
   the U.S. Government retains certain rights in this software.
 -------------------------------------------------------------------------*/
 
+#include "vtkLabeledTreeMapDataMapper.h"
 #include "vtkActor2D.h"
 #include "vtkCoordinate.h"
 #include "vtkDataArray.h"
@@ -26,7 +27,6 @@
 #include "vtkFloatArray.h"
 #include "vtkIdList.h"
 #include "vtkInformation.h"
-#include "vtkLabeledTreeMapDataMapper.h"
 #include "vtkObjectFactory.h"
 #include "vtkPointData.h"
 #include "vtkPoints.h"
@@ -41,9 +41,16 @@
 vtkStandardNewMacro(vtkLabeledTreeMapDataMapper);
 
 vtkLabeledTreeMapDataMapper::vtkLabeledTreeMapDataMapper()
-  : CurrentViewPort(0), FontHeights(0), FontWidths(0), MaxFontLevel(0),
-    MaxTreeLevels(100), ClipTextMode(0), ChildMotion(0),
-    StartLevel(0), EndLevel(-1), DynamicLevel(0)
+  : CurrentViewPort(nullptr)
+  , FontHeights(nullptr)
+  , FontWidths(nullptr)
+  , MaxFontLevel(0)
+  , MaxTreeLevels(100)
+  , ClipTextMode(0)
+  , ChildMotion(0)
+  , StartLevel(0)
+  , EndLevel(-1)
+  , DynamicLevel(0)
 {
   this->BoxTrans[0][0] = this->BoxTrans[1][0] = 0.0;
   this->BoxTrans[0][1] = this->BoxTrans[1][1] = 1.0;
@@ -69,21 +76,21 @@ vtkLabeledTreeMapDataMapper::vtkLabeledTreeMapDataMapper()
   this->GetLabelTextProperty()->SetColor(1, 1, 1);
   this->GetLabelTextProperty()->SetFontSize(12);
   this->SetFontSizeRange(24, 10);
-  this->ChildrenCount = new int[this->MaxTreeLevels+1];
-  this->LabelMasks = new float[this->MaxTreeLevels+1][4];
+  this->ChildrenCount = new int[this->MaxTreeLevels + 1];
+  this->LabelMasks = new float[this->MaxTreeLevels + 1][4];
   this->SetRectanglesArrayName("area");
   this->SetLabelFormat("%s");
 
   // Take control of the TextMappers array.
   // The superclass just created new TextMapper instances
   // up to the currently allocated amount (default 50).
-  // Instead, we will store NULL values until we need them.
+  // Instead, we will store nullptr values until we need them.
   // This class will manage the maintenance and deletion of
   // this array.
   for (int i = 0; i < this->NumberOfLabelsAllocated; i++)
   {
     this->TextMappers[i]->Delete();
-    this->TextMappers[i] = NULL;
+    this->TextMappers[i] = nullptr;
   }
 }
 
@@ -96,25 +103,25 @@ vtkLabeledTreeMapDataMapper::~vtkLabeledTreeMapDataMapper()
   int i;
   for (i = 0; i <= this->MaxFontLevel; i++)
   {
-    delete [] this->FontWidths[i];
+    delete[] this->FontWidths[i];
     this->HLabelProperties[i]->Delete();
   }
-  delete [] this->FontWidths;
-  delete [] this->FontHeights;
-  delete [] this->HLabelProperties;
-  delete [] this->ChildrenCount;
-  delete [] this->LabelMasks;
+  delete[] this->FontWidths;
+  delete[] this->FontHeights;
+  delete[] this->HLabelProperties;
+  delete[] this->ChildrenCount;
+  delete[] this->LabelMasks;
   if (this->TextMappers)
   {
-    for (i=0; i < this->NumberOfLabelsAllocated; i++)
+    for (i = 0; i < this->NumberOfLabelsAllocated; i++)
     {
       if (this->TextMappers[i])
       {
         this->TextMappers[i]->Delete();
       }
     }
-    delete [] this->TextMappers;
-    this->TextMappers = NULL;
+    delete[] this->TextMappers;
+    this->TextMappers = nullptr;
   }
 }
 
@@ -126,11 +133,11 @@ void vtkLabeledTreeMapDataMapper::SetRectanglesArrayName(const char* name)
 
 //----------------------------------------------------------------------------
 // Release any graphics resources that are being consumed by this mapper.
-void vtkLabeledTreeMapDataMapper::ReleaseGraphicsResources(vtkWindow *win)
+void vtkLabeledTreeMapDataMapper::ReleaseGraphicsResources(vtkWindow* win)
 {
-  if (this->TextMappers != NULL )
+  if (this->TextMappers != nullptr)
   {
-    for (int i=0; i < this->NumberOfLabelsAllocated; i++)
+    for (int i = 0; i < this->NumberOfLabelsAllocated; i++)
     {
       if (this->TextMappers[i])
       {
@@ -140,7 +147,7 @@ void vtkLabeledTreeMapDataMapper::ReleaseGraphicsResources(vtkWindow *win)
   }
 }
 
-vtkTree *vtkLabeledTreeMapDataMapper::GetInputTree()
+vtkTree* vtkLabeledTreeMapDataMapper::GetInputTree()
 {
   return vtkTree::SafeDownCast(this->GetExecutive()->GetInputData(0, 0));
 }
@@ -165,7 +172,7 @@ void vtkLabeledTreeMapDataMapper::UpdateFontSizes()
     {
       this->TextMappers[0]->SetInput(test);
       this->TextMappers[0]->GetSize(this->CurrentViewPort, tSize);
-      this->FontWidths[i][test[0]-32] = tSize[0];
+      this->FontWidths[i][test[0] - 32] = tSize[0];
       if (this->FontHeights[i] < tSize[1])
       {
         this->FontHeights[i] = tSize[1];
@@ -188,23 +195,22 @@ void vtkLabeledTreeMapDataMapper::PrintSelf(ostream& os, vtkIndent indent)
   }
   os << endl;
 
-  os << indent << "Level Range: [" << this->StartLevel
-     << ", " << this->EndLevel << "]" << endl;
+  os << indent << "Level Range: [" << this->StartLevel << ", " << this->EndLevel << "]" << endl;
 }
 
-int vtkLabeledTreeMapDataMapper::UpdateWindowInfo(vtkViewport *viewport)
+int vtkLabeledTreeMapDataMapper::UpdateWindowInfo(vtkViewport* viewport)
 {
   // Assumes that the view is not rotated w/r to the tree map!
-  int *dc;
+  int* dc;
   float p[2][2];
   this->VCoord->SetViewport(viewport);
   // Transform 0,0 and 1,1 into screen coordinates
   this->VCoord->SetValue(0.0, 0.0, 0.0);
-  dc = VCoord->GetComputedDisplayValue(0);
+  dc = VCoord->GetComputedDisplayValue(nullptr);
   p[0][0] = dc[0];
   p[0][1] = dc[1];
   this->VCoord->SetValue(1.0, 1.0, 0.0);
-  dc = this->VCoord->GetComputedDisplayValue(0);
+  dc = this->VCoord->GetComputedDisplayValue(nullptr);
   p[1][0] = dc[0];
   p[1][1] = dc[1];
 
@@ -217,16 +223,16 @@ int vtkLabeledTreeMapDataMapper::UpdateWindowInfo(vtkViewport *viewport)
   this->BoxTrans[1][1] = p[1][1] - p[0][1];
 
   // Get the window extents
-  vtkWindow * win = viewport->GetVTKWindow();
-  int *winPos = win->GetPosition();
+  vtkWindow* win = viewport->GetVTKWindow();
+  const int* winPos = win->GetPosition();
   this->WindowLimits[0][0] = winPos[0];
   this->WindowLimits[1][0] = winPos[1];
-  int *winSize = win->GetSize();
+  const int* winSize = win->GetSize();
   this->WindowLimits[0][1] = this->WindowLimits[0][0] + winSize[0];
   this->WindowLimits[1][1] = this->WindowLimits[1][0] + winSize[1];
 
   // We are done with the coordinate, so release the viewport
-  this->VCoord->SetViewport(NULL);
+  this->VCoord->SetViewport(nullptr);
 
   // Ideally we can compare the new scales with the original and
   // see if the change has exceeded some threshold - in that case
@@ -234,76 +240,73 @@ int vtkLabeledTreeMapDataMapper::UpdateWindowInfo(vtkViewport *viewport)
   return 1;
 }
 
-void vtkLabeledTreeMapDataMapper::GetVertexLabel(vtkIdType vertex,
-                                               vtkDataArray *numericData,
-                                               vtkStringArray *stringData,
-                                               int activeComp, int numComp,
-                                               char *string)
+void vtkLabeledTreeMapDataMapper::GetVertexLabel(vtkIdType vertex, vtkDataArray* numericData,
+  vtkStringArray* stringData, int activeComp, int numComp, char* string, size_t stringSize)
 {
   char format[1024];
   double val;
   int j;
-  if ( numericData )
+  if (numericData)
   {
-    if ( numComp == 1 )
+    if (numComp == 1)
     {
       if (numericData->GetDataType() == VTK_CHAR)
       {
-        if (strcmp(this->LabelFormat,"%c") != 0)
+        if (strcmp(this->LabelFormat, "%c") != 0)
         {
-          vtkErrorMacro(<<"Label format must be %c to use with char");
+          vtkErrorMacro(<< "Label format must be %c to use with char");
           string[0] = '\0';
           return;
         }
-        sprintf(string, this->LabelFormat,
-                static_cast<char>(numericData->GetComponent(vertex, activeComp)));
+        snprintf(string, stringSize, this->LabelFormat,
+          static_cast<char>(numericData->GetComponent(vertex, activeComp)));
       }
       else
       {
-        sprintf(string, this->LabelFormat,
-                numericData->GetComponent(vertex, activeComp));
+        snprintf(
+          string, stringSize, this->LabelFormat, numericData->GetComponent(vertex, activeComp));
       }
     }
     else
     {
-      strcpy(format, "("); strcat(format, this->LabelFormat);
-      for (j=0; j<(numComp-1); j++)
+      strcpy(format, "(");
+      strcat(format, this->LabelFormat);
+      for (j = 0; j < (numComp - 1); j++)
       {
-        sprintf(string, format, numericData->GetComponent(vertex, j));
-        strcpy(format,string); strcat(format,", ");
+        snprintf(string, stringSize, format, numericData->GetComponent(vertex, j));
+        strcpy(format, string);
+        strcat(format, ", ");
         strcat(format, this->LabelFormat);
       }
-      sprintf(string, format, numericData->GetComponent(vertex, numComp-1));
+      snprintf(string, stringSize, format, numericData->GetComponent(vertex, numComp - 1));
       strcat(string, ")");
     }
   }
-  else if (stringData)// rendering string data
+  else if (stringData) // rendering string data
   {
-    if (strcmp(this->LabelFormat,"%s") != 0)
+    if (strcmp(this->LabelFormat, "%s") != 0)
     {
-      vtkErrorMacro(<<"Label format must be %s to use with strings");
+      vtkErrorMacro(<< "Label format must be %s to use with strings");
       string[0] = '\0';
       return;
     }
-    sprintf(string, this->LabelFormat,
-            stringData->GetValue(vertex).c_str());
+    snprintf(string, stringSize, this->LabelFormat, stringData->GetValue(vertex).c_str());
   }
   else // Use the vertex id
   {
     val = static_cast<double>(vertex);
-    sprintf(string, this->LabelFormat, val);
+    snprintf(string, stringSize, this->LabelFormat, val);
   }
 }
 
 //----------------------------------------------------------------------------
-void vtkLabeledTreeMapDataMapper::RenderOverlay(vtkViewport *viewport,
-                                                vtkActor2D *actor)
+void vtkLabeledTreeMapDataMapper::RenderOverlay(vtkViewport* viewport, vtkActor2D* actor)
 {
   int i;
   double x[3];
-  for (i=0; i<this->NumberOfLabels; i++)
+  for (i = 0; i < this->NumberOfLabels; i++)
   {
-    this->TextPoints->GetPoint(i,x);
+    this->TextPoints->GetPoint(i, x);
     actor->GetPositionCoordinate()->SetCoordinateSystemToWorld();
     actor->GetPositionCoordinate()->SetValue(x);
     this->TextMappers[i]->RenderOverlay(viewport, actor);
@@ -311,26 +314,25 @@ void vtkLabeledTreeMapDataMapper::RenderOverlay(vtkViewport *viewport,
 }
 
 //----------------------------------------------------------------------------
-void vtkLabeledTreeMapDataMapper::RenderOpaqueGeometry(vtkViewport *viewport,
-                                                       vtkActor2D *actor)
+void vtkLabeledTreeMapDataMapper::RenderOpaqueGeometry(vtkViewport* viewport, vtkActor2D* actor)
 {
   int i, numComp = 0, pointIdLabels, activeComp = 0;
   int numVertices;
   double x[3];
-  vtkAbstractArray *abstractData;
+  vtkAbstractArray* abstractData;
   vtkDataArray *numericData, *tempData;
-  vtkStringArray *stringData;
-  vtkTree *input=this->GetInputTree();
-  if ( ! input )
+  vtkStringArray* stringData;
+  vtkTree* input = this->GetInputTree();
+  if (!input)
   {
-    vtkErrorMacro(<<"Need input tree to render labels (2)");
+    vtkErrorMacro(<< "Need input tree to render labels (2)");
     return;
   }
 
-  vtkTextProperty *tprop = this->GetLabelTextProperty();
+  vtkTextProperty* tprop = this->GetLabelTextProperty();
   if (!tprop)
   {
-    vtkErrorMacro(<<"Need text property to render labels");
+    vtkErrorMacro(<< "Need text property to render labels");
     return;
   }
 
@@ -338,7 +340,7 @@ void vtkLabeledTreeMapDataMapper::RenderOpaqueGeometry(vtkViewport *viewport,
 
   // Input might have changed
   input = this->GetInputTree();
-  vtkDataSetAttributes *pd = input->GetVertexData();
+  vtkDataSetAttributes* pd = input->GetVertexData();
   // Get the treeMap info
   tempData = this->GetInputArrayToProcess(0, input);
   if (!tempData)
@@ -346,16 +348,14 @@ void vtkLabeledTreeMapDataMapper::RenderOpaqueGeometry(vtkViewport *viewport,
     vtkErrorMacro(<< "Input Tree does not have box information.");
     return;
   }
-  vtkFloatArray *boxInfo = vtkArrayDownCast<vtkFloatArray>(tempData);
+  vtkFloatArray* boxInfo = vtkArrayDownCast<vtkFloatArray>(tempData);
 
   // Check to see whether we have to rebuild everything
-  if ( this->UpdateWindowInfo(viewport) ||
-       this->CurrentViewPort != viewport ||
-       this->GetMTime() > this->BuildTime ||
-       input->GetMTime() > this->BuildTime ||
-       tprop->GetMTime() > this->BuildTime)
+  if (this->UpdateWindowInfo(viewport) || this->CurrentViewPort != viewport ||
+    this->GetMTime() > this->BuildTime || input->GetMTime() > this->BuildTime ||
+    tprop->GetMTime() > this->BuildTime)
   {
-    vtkDebugMacro(<<"Rebuilding labels");
+    vtkDebugMacro(<< "Rebuilding labels");
 
     // See if we have to recalculate fonts sizes
     if (this->CurrentViewPort != viewport)
@@ -366,81 +366,81 @@ void vtkLabeledTreeMapDataMapper::RenderOpaqueGeometry(vtkViewport *viewport,
 
     // figure out what to label, and if we can label it
     pointIdLabels = 0;
-    abstractData = NULL;
-    numericData = NULL;
-    stringData = NULL;
+    abstractData = nullptr;
+    numericData = nullptr;
+    stringData = nullptr;
     switch (this->LabelMode)
     {
       case VTK_LABEL_IDS:
         pointIdLabels = 1;
         break;
       case VTK_LABEL_SCALARS:
-        if ( pd->GetScalars() )
+        if (pd->GetScalars())
         {
           numericData = pd->GetScalars();
         }
         break;
       case VTK_LABEL_VECTORS:
-        if ( pd->GetVectors() )
+        if (pd->GetVectors())
         {
           numericData = pd->GetVectors();
         }
         break;
       case VTK_LABEL_NORMALS:
-        if ( pd->GetNormals() )
+        if (pd->GetNormals())
         {
           numericData = pd->GetNormals();
         }
         break;
       case VTK_LABEL_TCOORDS:
-        if ( pd->GetTCoords() )
+        if (pd->GetTCoords())
         {
           numericData = pd->GetTCoords();
         }
         break;
       case VTK_LABEL_TENSORS:
-        if ( pd->GetTensors() )
+        if (pd->GetTensors())
         {
           numericData = pd->GetTensors();
         }
         break;
       case VTK_LABEL_FIELD_DATA:
       {
-      int arrayNum;
-      if (this->FieldDataName != NULL)
-      {
-        abstractData = pd->GetAbstractArray(this->FieldDataName, arrayNum);
-      }
-      else
-      {
-        arrayNum = (this->FieldDataArray < pd->GetNumberOfArrays() ?
-                    this->FieldDataArray : pd->GetNumberOfArrays() - 1);
-        abstractData = pd->GetAbstractArray(arrayNum);
-      }
-      numericData = vtkArrayDownCast<vtkDataArray>(abstractData);
-      stringData = vtkArrayDownCast<vtkStringArray>(abstractData);
-      }; break;
+        int arrayNum;
+        if (this->FieldDataName != nullptr)
+        {
+          abstractData = pd->GetAbstractArray(this->FieldDataName, arrayNum);
+        }
+        else
+        {
+          arrayNum = (this->FieldDataArray < pd->GetNumberOfArrays() ? this->FieldDataArray
+                                                                     : pd->GetNumberOfArrays() - 1);
+          abstractData = pd->GetAbstractArray(arrayNum);
+        }
+        numericData = vtkArrayDownCast<vtkDataArray>(abstractData);
+        stringData = vtkArrayDownCast<vtkStringArray>(abstractData);
+      };
+      break;
     }
 
     // determine number of components and check input
-    if ( pointIdLabels )
+    if (pointIdLabels)
     {
       ;
     }
-    else if ( numericData )
+    else if (numericData)
     {
       numComp = numericData->GetNumberOfComponents();
       activeComp = 0;
-      if ( this->LabeledComponent >= 0 )
+      if (this->LabeledComponent >= 0)
       {
-        activeComp = (this->LabeledComponent < numComp ?
-                      this->LabeledComponent : numComp - 1);
+        activeComp = (this->LabeledComponent < numComp ? this->LabeledComponent : numComp - 1);
         numComp = 1;
       }
     }
-    else if ( !stringData )
+    else if (!stringData)
     {
-      vtkErrorMacro(<<"Need input data to render labels (3)");
+      vtkErrorMacro(<< "Need input data to render labels (3)");
       return;
     }
 
@@ -449,54 +449,48 @@ void vtkLabeledTreeMapDataMapper::RenderOpaqueGeometry(vtkViewport *viewport,
     // not create the actual mappers
 
     numVertices = input->GetNumberOfVertices();
-    if ( numVertices > this->NumberOfLabelsAllocated )
+    if (numVertices > this->NumberOfLabelsAllocated)
     {
       // delete old stuff
-      for (i=0; i < this->NumberOfLabelsAllocated; i++)
+      for (i = 0; i < this->NumberOfLabelsAllocated; i++)
       {
-          if (this->TextMappers[i])
-          {
+        if (this->TextMappers[i])
+        {
           this->TextMappers[i]->Delete();
-          }
+        }
       }
-      delete [] this->TextMappers;
+      delete[] this->TextMappers;
 
       this->NumberOfLabelsAllocated = numVertices;
-      this->TextMappers = new vtkTextMapper * [numVertices];
+      this->TextMappers = new vtkTextMapper*[numVertices];
       this->VertexList->SetNumberOfIds(numVertices);
       this->TextPoints->Allocate(numVertices);
       for (i = 0; i < numVertices; i++)
       {
-        this->TextMappers[i] = 0;
+        this->TextMappers[i] = nullptr;
       }
     }
 
-    this->LabelTree(input, boxInfo, numericData, stringData,
-                    activeComp, numComp);
+    this->LabelTree(input, boxInfo, numericData, stringData, activeComp, numComp);
   }
 
-
-  for (i=0; i<this->NumberOfLabels; i++)
+  for (i = 0; i < this->NumberOfLabels; i++)
   {
-    this->TextPoints->GetPoint(i,x);
+    this->TextPoints->GetPoint(i, x);
     actor->GetPositionCoordinate()->SetCoordinateSystemToWorld();
     actor->GetPositionCoordinate()->SetValue(x);
     this->TextMappers[i]->RenderOpaqueGeometry(viewport, actor);
   }
 }
 
-void vtkLabeledTreeMapDataMapper::LabelTree(vtkTree *tree,
-                                            vtkFloatArray *boxInfo,
-                                            vtkDataArray *numericData,
-                                            vtkStringArray *stringData,
-                                            int activeComp,
-                                            int numComps)
+void vtkLabeledTreeMapDataMapper::LabelTree(vtkTree* tree, vtkFloatArray* boxInfo,
+  vtkDataArray* numericData, vtkStringArray* stringData, int activeComp, int numComps)
 {
 
   float blimits[4], blimitsDC[4], textPosWC[3];
   char string[1024];
   int results;
-  vtkTextProperty *tprop = NULL;
+  vtkTextProperty* tprop = nullptr;
   vtkIdType vertex, level, root = tree->GetRoot();
   if (root < 0)
   {
@@ -521,8 +515,8 @@ void vtkLabeledTreeMapDataMapper::LabelTree(vtkTree *tree,
         continue;
       }
 
-      this->GetVertexLabel(vertex, numericData, stringData, activeComp, numComps,
-                         string);
+      this->GetVertexLabel(
+        vertex, numericData, stringData, activeComp, numComps, string, sizeof(string));
       results = this->AnalyseLabel(string, level, blimitsDC, textPosWC, &tprop);
       if (results == 1)
       {
@@ -535,7 +529,7 @@ void vtkLabeledTreeMapDataMapper::LabelTree(vtkTree *tree,
       // results == 2 from AnalyseLabel means that the label can't be
       // displayed due to reasons other than size - well in this
       // case we can't display due to the level limit we
-      // also have to deactive the maks for this level
+      // also have to deactivate the mask for this level
       this->LabelMasks[level][0] = -1.0;
       results = 2;
     }
@@ -547,8 +541,7 @@ void vtkLabeledTreeMapDataMapper::LabelTree(vtkTree *tree,
         this->TextMappers[this->NumberOfLabels] = vtkTextMapper::New();
       }
       this->TextMappers[this->NumberOfLabels]->SetInput(string);
-      this->TextMappers[this->NumberOfLabels]->
-        SetTextProperty(tprop);
+      this->TextMappers[this->NumberOfLabels]->SetTextProperty(tprop);
       this->TextPoints->SetPoint(this->NumberOfLabels, textPosWC);
       ++(this->NumberOfLabels);
     }
@@ -563,7 +556,7 @@ void vtkLabeledTreeMapDataMapper::LabelTree(vtkTree *tree,
   this->BuildTime.Modified();
 }
 
-int vtkLabeledTreeMapDataMapper::GetStringSize(char *string, int level)
+int vtkLabeledTreeMapDataMapper::GetStringSize(char* string, int level)
 {
 
   if (level > this->MaxFontLevel)
@@ -571,7 +564,7 @@ int vtkLabeledTreeMapDataMapper::GetStringSize(char *string, int level)
     level = this->MaxFontLevel;
   }
   int size = 0, i;
-  for(i = 0; string[i] != '\0'; i++)
+  for (i = 0; string[i] != '\0'; i++)
   {
     if (string[i] < 32)
     {
@@ -583,18 +576,18 @@ int vtkLabeledTreeMapDataMapper::GetStringSize(char *string, int level)
       continue;
     }
 
-    size += this->FontWidths[level][string[i]-32];
+    size += this->FontWidths[level][string[i] - 32];
   }
   return size;
 }
 
-int vtkLabeledTreeMapDataMapper::ConvertToDC(float *binfo, float *newBinfo)
+int vtkLabeledTreeMapDataMapper::ConvertToDC(float* binfo, float* newBinfo)
 {
 
-  newBinfo[0] = this->BoxTrans[0][0] + (binfo[0]*this->BoxTrans[0][1]);
-  newBinfo[1] = this->BoxTrans[0][0] + (binfo[1]*this->BoxTrans[0][1]);
-  newBinfo[2] = this->BoxTrans[1][0] + (binfo[2]*this->BoxTrans[1][1]);
-  newBinfo[3] = this->BoxTrans[1][0] + (binfo[3]*this->BoxTrans[1][1]);
+  newBinfo[0] = this->BoxTrans[0][0] + (binfo[0] * this->BoxTrans[0][1]);
+  newBinfo[1] = this->BoxTrans[0][0] + (binfo[1] * this->BoxTrans[0][1]);
+  newBinfo[2] = this->BoxTrans[1][0] + (binfo[2] * this->BoxTrans[1][1]);
+  newBinfo[3] = this->BoxTrans[1][0] + (binfo[3] * this->BoxTrans[1][1]);
 
   // See the comments in AnalyseLabel for why we're comparing against
   // these numbers.
@@ -649,16 +642,21 @@ int vtkLabeledTreeMapDataMapper::ConvertToDC(float *binfo, float *newBinfo)
   return 0;
 }
 
-void vtkLabeledTreeMapDataMapper::SetFontSizeRange(int maxSize, int minSize,
-                                                   int delta)
+void vtkLabeledTreeMapDataMapper::SetFontSizeRange(int maxSize, int minSize, int delta)
 {
-  int nLevels = (maxSize - minSize) / delta;
-  int i, s;
-  if (nLevels < 0)
+  if (maxSize < minSize)
   {
-    vtkErrorMacro(<<"maxSize is smaller than minSize");
+    vtkErrorMacro(<< "maxSize is smaller than minSize");
     return;
   }
+  if (delta < 1)
+  {
+    vtkErrorMacro(<< "delta must be positive");
+    return;
+  }
+
+  int nLevels = (maxSize - minSize) / delta;
+  int i, s;
 
   if ((maxSize - (nLevels * delta)) > minSize)
   {
@@ -669,20 +667,20 @@ void vtkLabeledTreeMapDataMapper::SetFontSizeRange(int maxSize, int minSize,
   {
     if (this->MaxFontLevel)
     {
-      delete [] this->FontHeights;
+      delete[] this->FontHeights;
       for (i = 0; i <= this->MaxFontLevel; i++)
       {
-        delete [] this->FontWidths[i];
+        delete[] this->FontWidths[i];
         this->HLabelProperties[i]->Delete();
       }
-      delete [] this->FontWidths;
-      delete [] this->HLabelProperties;
+      delete[] this->FontWidths;
+      delete[] this->HLabelProperties;
     }
     this->MaxFontLevel = nLevels;
-    this->FontHeights = new int[this->MaxFontLevel+1];
-    this->FontWidths = new int *[this->MaxFontLevel+1];
-    this->HLabelProperties = new vtkTextProperty *[this->MaxFontLevel+1];
-    for(i = 0; i <= this->MaxFontLevel; i++)
+    this->FontHeights = new int[this->MaxFontLevel + 1];
+    this->FontWidths = new int*[this->MaxFontLevel + 1];
+    this->HLabelProperties = new vtkTextProperty*[this->MaxFontLevel + 1];
+    for (i = 0; i <= this->MaxFontLevel; i++)
     {
       this->FontWidths[i] = new int[95];
       this->HLabelProperties[i] = vtkTextProperty::New();
@@ -696,13 +694,13 @@ void vtkLabeledTreeMapDataMapper::SetFontSizeRange(int maxSize, int minSize,
       this->HLabelProperties[i]->SetColor(1, 1, 1);
     }
   }
-  for(i = 0, s = maxSize; i < this->MaxFontLevel; i++, s -= delta)
+  for (i = 0, s = maxSize; i < this->MaxFontLevel; i++, s -= delta)
   {
     this->HLabelProperties[i]->SetFontSize(s);
   }
   this->HLabelProperties[i]->SetFontSize(minSize);
 
-  this->CurrentViewPort = 0;
+  this->CurrentViewPort = nullptr;
 }
 
 void vtkLabeledTreeMapDataMapper::GetFontSizeRange(int range[3])
@@ -712,25 +710,22 @@ void vtkLabeledTreeMapDataMapper::GetFontSizeRange(int range[3])
   range[2] = (range[0] - range[1]) / (this->MaxFontLevel - 1);
 }
 
-int vtkLabeledTreeMapDataMapper::AnalyseLabel(char * string, int level,
-                                              float *blimitsDC,
-                                              float *textPosWC,
-                                              vtkTextProperty **tprop)
+int vtkLabeledTreeMapDataMapper::AnalyseLabel(
+  char* string, int level, float* blimitsDC, float* textPosWC, vtkTextProperty** tprop)
 {
   float sizes[2], tPosDC[2], delta, flimits[4];
   int fsize, trueLevel, oDir; // oDir is the text orientation
   // Calculate the size of the box in DC
   sizes[0] = blimitsDC[1] - blimitsDC[0];
   sizes[1] = blimitsDC[3] - blimitsDC[2];
-  trueLevel = level -  this->StartLevel;
+  trueLevel = level - this->StartLevel;
   if (trueLevel < 0)
   {
     vtkErrorMacro(<< "Invalid level.");
     trueLevel = 0;
   }
-  trueLevel =
-    (trueLevel > this->MaxFontLevel) ? this->MaxFontLevel : trueLevel;
-   fsize = this->GetStringSize(string, trueLevel);
+  trueLevel = (trueLevel > this->MaxFontLevel) ? this->MaxFontLevel : trueLevel;
+  fsize = this->GetStringSize(string, trueLevel);
 
   // Horizontal label.
   // (Vertical labels don't work due to issues with vtkTextActor.)
@@ -744,7 +739,7 @@ int vtkLabeledTreeMapDataMapper::AnalyseLabel(char * string, int level,
     // See if the text will not even fit in the box
     if (sizes[!oDir] < this->FontHeights[trueLevel])
     {
-    // Text will not fit
+      // Text will not fit
       return 1;
     }
 
@@ -756,13 +751,13 @@ int vtkLabeledTreeMapDataMapper::AnalyseLabel(char * string, int level,
   }
   // Calculate the bounding box of the text
   // Determine where to place the text
-  tPosDC[0] = 0.5 *(blimitsDC[0] + blimitsDC[1]);
-  tPosDC[1] = 0.5 *(blimitsDC[2] + blimitsDC[3]);
+  tPosDC[0] = 0.5 * (blimitsDC[0] + blimitsDC[1]);
+  tPosDC[1] = 0.5 * (blimitsDC[2] + blimitsDC[3]);
   // Compute mask for this level
-  delta = 0.5 * 1.05 * (!oDir?fsize:this->FontHeights[trueLevel]);
+  delta = 0.5 * 1.05 * (!oDir ? fsize : this->FontHeights[trueLevel]);
   flimits[0] = tPosDC[0] - delta;
   flimits[1] = tPosDC[0] + delta;
-  delta = 0.5 * 1.05 * (oDir?fsize:this->FontHeights[trueLevel]);
+  delta = 0.5 * 1.05 * (oDir ? fsize : this->FontHeights[trueLevel]);
   flimits[2] = tPosDC[1] - delta;
   flimits[3] = tPosDC[1] + delta;
 
@@ -779,10 +774,8 @@ int vtkLabeledTreeMapDataMapper::AnalyseLabel(char * string, int level,
     double windowWidth = this->WindowLimits[0][1] - this->WindowLimits[0][0];
     double windowHeight = this->WindowLimits[1][1] - this->WindowLimits[0][0];
 
-    if ((flimits[0] >= windowWidth) ||
-        (flimits[1] <= 0) ||
-        (flimits[2] >= windowHeight) ||
-        (flimits[3] <= 0))
+    if ((flimits[0] >= windowWidth) || (flimits[1] <= 0) || (flimits[2] >= windowHeight) ||
+      (flimits[3] <= 0))
     {
       this->LabelMasks[level][0] = -1.0;
       return 2;
@@ -809,19 +802,18 @@ int vtkLabeledTreeMapDataMapper::AnalyseLabel(char * string, int level,
   this->LabelMasks[level][3] = flimits[3];
   // since applying the masks can shift the label calculate the
   // new position
-  tPosDC[0] = 0.5 *(flimits[0] + flimits[1]);
-  tPosDC[1] = 0.5 *(flimits[2] + flimits[3]);
+  tPosDC[0] = 0.5 * (flimits[0] + flimits[1]);
+  tPosDC[1] = 0.5 * (flimits[2] + flimits[3]);
 
-  textPosWC[0] = (tPosDC[0] - this->BoxTrans[0][0])/ this->BoxTrans[0][1];
-  textPosWC[1] = (tPosDC[1] - this->BoxTrans[1][0])/ this->BoxTrans[1][1];
+  textPosWC[0] = (tPosDC[0] - this->BoxTrans[0][0]) / this->BoxTrans[0][1];
+  textPosWC[1] = (tPosDC[1] - this->BoxTrans[1][0]) / this->BoxTrans[1][1];
   textPosWC[2] = 1.0;
   return 0;
 }
 
-int vtkLabeledTreeMapDataMapper::ApplyMasks(int level, float flimits[4],
-                                            float blimits[4])
+int vtkLabeledTreeMapDataMapper::ApplyMasks(int level, float flimits[4], float blimits[4])
 {
-// Note that all limits and mask information is in Device Coordinates
+  // Note that all limits and mask information is in Device Coordinates
 
   float dy = 0.0;
   int changed = 1, dir = 0, l;
@@ -871,9 +863,8 @@ int vtkLabeledTreeMapDataMapper::ApplyMasks(int level, float flimits[4],
       // (i.e. the second component < 0)
       // or has been already fixed in the y-direction
       // (.i.e the third component < 0)
-      if ((this->LabelMasks[l][0] < 0.0) ||
-          (this->LabelMasks[l][1] < 0.0) ||
-          (this->LabelMasks[l][2] < 0.0))
+      if ((this->LabelMasks[l][0] < 0.0) || (this->LabelMasks[l][1] < 0.0) ||
+        (this->LabelMasks[l][2] < 0.0))
       {
         continue;
       }
@@ -892,7 +883,7 @@ int vtkLabeledTreeMapDataMapper::ApplyMasks(int level, float flimits[4],
         this->LabelMasks[l][1] = -1.0 * (this->LabelMasks[l][1] + 1.0);
         continue;
       }
-      if (this->LabelMasks[l][2] > (flimits[3]+dy))
+      if (this->LabelMasks[l][2] > (flimits[3] + dy))
       {
         // If dy < 0 then this condition will always be true and
         // this check can be turned off
@@ -902,7 +893,7 @@ int vtkLabeledTreeMapDataMapper::ApplyMasks(int level, float flimits[4],
         }
         continue;
       }
-      if (this->LabelMasks[l][3] < (flimits[2]+dy))
+      if (this->LabelMasks[l][3] < (flimits[2] + dy))
       {
         // If dy > 0 then this condition will always be true and
         // this check can be turned off
@@ -947,7 +938,7 @@ int vtkLabeledTreeMapDataMapper::ApplyMasks(int level, float flimits[4],
         {
           if (this->LabelMasks[l][2] < 0.0)
           {
-            this->LabelMasks[l][2] = - 1.0 * (this->LabelMasks[l][2]+ 1.0);
+            this->LabelMasks[l][2] = -1.0 * (this->LabelMasks[l][2] + 1.0);
           }
         }
       }
@@ -963,22 +954,22 @@ int vtkLabeledTreeMapDataMapper::ApplyMasks(int level, float flimits[4],
     }
   }
 
-    // Reset masks that were deactivated
-    for (l = 0; l < level; l++)
+  // Reset masks that were deactivated
+  for (l = 0; l < level; l++)
+  {
+    if (this->LabelMasks[l][1] < 0.0)
     {
-      if (this->LabelMasks[l][1] < 0.0)
-      {
-        this->LabelMasks[l][1] = - 1.0 * (this->LabelMasks[l][1]+ 1.0);
-        continue;
-      }
-
-      if (this->LabelMasks[l][2] < 0.0)
-      {
-        this->LabelMasks[l][2] = - 1.0 * (this->LabelMasks[l][2]+ 1.0);
-        continue;
-      }
+      this->LabelMasks[l][1] = -1.0 * (this->LabelMasks[l][1] + 1.0);
+      continue;
     }
 
+    if (this->LabelMasks[l][2] < 0.0)
+    {
+      this->LabelMasks[l][2] = -1.0 * (this->LabelMasks[l][2] + 1.0);
+      continue;
+    }
+  }
+
   return status;
 }
 
@@ -986,7 +977,7 @@ void vtkLabeledTreeMapDataMapper::SetLevelRange(int start, int end)
 {
   if (((end != -1) && (start > end)) || (start < 0))
   {
-    vtkErrorMacro(<<"Invalid level range specified.");
+    vtkErrorMacro(<< "Invalid level range specified.");
     return;
   }
 
