@@ -15,8 +15,8 @@
 
 #include "vtkActor.h"
 #include "vtkBandedPolyDataContourFilter.h"
-#include "vtkCommand.h"
 #include "vtkColorSeries.h"
+#include "vtkCommand.h"
 #include "vtkDataArray.h"
 #include "vtkInteractorEventRecorder.h"
 #include "vtkLookupTable.h"
@@ -25,16 +25,16 @@
 #include "vtkNew.h"
 #include "vtkPointData.h"
 #include "vtkPolyDataMapper.h"
-#include "vtkRenderer.h"
 #include "vtkRenderWindow.h"
 #include "vtkRenderWindowInteractor.h"
+#include "vtkRenderer.h"
 #include "vtkScalarBarActor.h"
 #include "vtkSmartPointer.h"
-#include "vtkStructuredGridGeometryFilter.h"
 #include "vtkStructuredGrid.h"
+#include "vtkStructuredGridGeometryFilter.h"
 #include "vtkTestUtilities.h"
-#include "vtkTextProperty.h"
 #include "vtkTesting.h"
+#include "vtkTextProperty.h"
 
 #include <stdlib.h> // for atof
 
@@ -53,18 +53,26 @@ struct vtkScalarBarTestCondition
   int Enabled;
   int VTitleSeparation;
 } conditions[] = {
-  {"$T_1$", VTK_ORIENT_HORIZONTAL, vtkScalarBarActor::PrecedeScalarBar, 1, 1, 1, 0, {0.000, 0.015}, {0.400, 0.135}, 1, 1, 0},
-  {"$T_2$", VTK_ORIENT_HORIZONTAL, vtkScalarBarActor::PrecedeScalarBar, 1, 0, 1, 1, {0.000, 0.230}, {0.400, 0.146}, 1, 1, 0},
-  {"$T_3$", VTK_ORIENT_HORIZONTAL, vtkScalarBarActor::SucceedScalarBar, 1, 1, 1, 1, {0.000, 0.850}, {0.630, 0.154}, 1, 1, 5},
-  {"$T_4$", VTK_ORIENT_VERTICAL,   vtkScalarBarActor::PrecedeScalarBar, 1, 1, 1, 0, {0.799, 0.032}, {0.061, 0.794}, 1, 1, 5},
-  {"$T_5$", VTK_ORIENT_VERTICAL,   vtkScalarBarActor::PrecedeScalarBar, 1, 0, 1, 1, {0.893, 0.036}, {0.052, 0.752}, 1, 1, 0},
-  {"$T_6$", VTK_ORIENT_VERTICAL,   vtkScalarBarActor::SucceedScalarBar, 1, 1, 1, 1, {0.792, 0.081}, {0.061, 0.617}, 1, 1, 0},
-  {"$T_7$", VTK_ORIENT_VERTICAL,   vtkScalarBarActor::SucceedScalarBar, 1, 1, 0, 0, {0.646, 0.061}, {0.084, 0.714}, 1, 1, 0},
-  {"$T_8$", VTK_ORIENT_HORIZONTAL, vtkScalarBarActor::SucceedScalarBar, 0, 1, 0, 1, {0.076, 0.535}, {0.313, 0.225}, 1, 1, 0},
+  { "$T_1$", VTK_ORIENT_HORIZONTAL, vtkScalarBarActor::PrecedeScalarBar, 1, 1, 1, 0,
+    { 0.000, 0.015 }, { 0.400, 0.135 }, 1, 1, 0 },
+  { "$T_2$", VTK_ORIENT_HORIZONTAL, vtkScalarBarActor::PrecedeScalarBar, 1, 0, 1, 1,
+    { 0.000, 0.230 }, { 0.400, 0.146 }, 1, 1, 0 },
+  { "$T_3$", VTK_ORIENT_HORIZONTAL, vtkScalarBarActor::SucceedScalarBar, 1, 1, 1, 1,
+    { 0.000, 0.850 }, { 0.630, 0.154 }, 1, 1, 5 },
+  { "$T_4$", VTK_ORIENT_VERTICAL, vtkScalarBarActor::PrecedeScalarBar, 1, 1, 1, 0, { 0.799, 0.032 },
+    { 0.061, 0.794 }, 1, 1, 5 },
+  { "$T_5$", VTK_ORIENT_VERTICAL, vtkScalarBarActor::PrecedeScalarBar, 1, 0, 1, 1, { 0.893, 0.036 },
+    { 0.052, 0.752 }, 1, 1, 0 },
+  { "$T_6$", VTK_ORIENT_VERTICAL, vtkScalarBarActor::SucceedScalarBar, 1, 1, 1, 1, { 0.792, 0.081 },
+    { 0.061, 0.617 }, 1, 1, 0 },
+  { "$T_7$", VTK_ORIENT_VERTICAL, vtkScalarBarActor::SucceedScalarBar, 1, 1, 0, 0, { 0.646, 0.061 },
+    { 0.084, 0.714 }, 1, 1, 0 },
+  { "$T_8$", VTK_ORIENT_HORIZONTAL, vtkScalarBarActor::SucceedScalarBar, 0, 1, 0, 1,
+    { 0.076, 0.535 }, { 0.313, 0.225 }, 1, 1, 0 },
 };
 
-static vtkSmartPointer<vtkScalarBarActor> CreateScalarBar(
-  vtkScalarBarTestCondition& cond, vtkScalarsToColors* idxLut, vtkScalarsToColors* conLut, vtkRenderer* ren)
+static vtkSmartPointer<vtkScalarBarActor> CreateScalarBar(vtkScalarBarTestCondition& cond,
+  vtkScalarsToColors* idxLut, vtkScalarsToColors* conLut, vtkRenderer* ren)
 {
   vtkNew<vtkScalarBarActor> sba;
   sba->SetTitle(cond.Title);
@@ -77,8 +85,8 @@ static vtkSmartPointer<vtkScalarBarActor> CreateScalarBar(
   sba->SetPosition(cond.Position[0], cond.Position[1]);
   sba->SetPosition2(cond.Position2[0], cond.Position2[1]);
   sba->SetVerticalTitleSeparation(cond.VTitleSeparation);
-  ren->AddActor(sba.GetPointer());
-  return sba.GetPointer();
+  ren->AddActor(sba);
+  return sba;
 }
 
 int TestScalarBarCombinatorics(int argc, char* argv[])
@@ -97,10 +105,10 @@ int TestScalarBarCombinatorics(int argc, char* argv[])
 
   vtkNew<vtkRenderer> ren1;
   vtkNew<vtkRenderWindow> renWin;
-  renWin->AddRenderer(ren1.GetPointer());
+  renWin->AddRenderer(ren1);
 
   vtkNew<vtkRenderWindowInteractor> iren;
-  iren->SetRenderWindow(renWin.GetPointer());
+  iren->SetRenderWindow(renWin);
 
   vtkNew<vtkLookupTable> lutA;
   vtkNew<vtkLookupTable> lutB;
@@ -110,7 +118,7 @@ int TestScalarBarCombinatorics(int argc, char* argv[])
   actors.reserve(numBars);
   for (int c = 0; c < numBars; ++c)
   {
-    actors.push_back(CreateScalarBar(conditions[c], lutA.GetPointer(), lutB.GetPointer(), ren1.GetPointer()));
+    actors.push_back(CreateScalarBar(conditions[c], lutA, lutB, ren1));
   }
 
   // Add the actors to the renderer, set the background and size
@@ -120,7 +128,7 @@ int TestScalarBarCombinatorics(int argc, char* argv[])
 
   vtkNew<vtkColorSeries> pal;
   pal->SetColorSchemeByName("Brewer Sequential Blue-Green (5)");
-  pal->BuildLookupTable(lutB.GetPointer());
+  pal->BuildLookupTable(lutB);
   lutB->IndexedLookupOff();
   lutB->Build();
   lutB->SetAnnotation(5.00, "Just Wow");
@@ -134,7 +142,7 @@ int TestScalarBarCombinatorics(int argc, char* argv[])
   // Now make a second set of annotations with an even number of entries (10).
   // This tests another branch of the annotation label positioning code.
   pal->SetColorSchemeByName("Brewer Diverging Purple-Orange (10)");
-  pal->BuildLookupTable(lutA.GetPointer());
+  pal->BuildLookupTable(lutA);
   lutA->SetAnnotation(5.00, "A");
   lutA->SetAnnotation(4.00, "B");
   lutA->SetAnnotation(3.00, "C");
@@ -149,7 +157,7 @@ int TestScalarBarCombinatorics(int argc, char* argv[])
   // render the image
   iren->Initialize();
   renWin->Render();
-  t->SetRenderWindow(renWin.GetPointer());
+  t->SetRenderWindow(renWin);
   int res = t->RegressionTest(threshold);
   t->Delete();
 
