@@ -3,30 +3,13 @@
    Program: ParaView
    Module:    vtkEDLShading.cxx
 
-   Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
-   All rights reserved.
+  Copyright (c) Sandia Corporation, Kitware Inc.
+  All rights reserved.
+  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
 
-   ParaView is a free software; you can redistribute it and/or modify it
-   under the terms of the ParaView license version 1.2.
-
-   See License_v1.2.txt for the full ParaView license.
-   A copy of this license can be obtained by contacting
-   Kitware Inc.
-   28 Corporate Drive
-   Clifton Park, NY 12065
-   USA
-
-THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
-CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
-EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
-PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
-PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
-LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
-NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
-SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+     This software is distributed WITHOUT ANY WARRANTY; without even
+     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
+     PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
 /*----------------------------------------------------------------------
@@ -39,12 +22,14 @@ Ph.D. thesis of Christian BOUCHENY.
 #include "vtkEDLShading.h"
 
 #include "vtkCamera.h"
-#include "vtkFrameBufferObject.h"
 #include "vtkMath.h"
 #include "vtkObjectFactory.h"
 #include "vtkOpenGLError.h"
+#include "vtkOpenGLFramebufferObject.h"
+#include "vtkOpenGLRenderUtilities.h"
 #include "vtkOpenGLRenderWindow.h"
 #include "vtkOpenGLShaderCache.h"
+#include "vtkOpenGLState.h"
 #include "vtkPropCollection.h"
 #include "vtkRenderState.h"
 #include "vtkRenderer.h"
@@ -55,39 +40,46 @@ Ph.D. thesis of Christian BOUCHENY.
 #include <sstream>
 #include <string>
 
-
-#include "vtkTextureObjectVS.h"
-#include "vtkEDLShadeFS.h"
-#include "vtkEDLComposeFS.h"
 #include "vtkEDLBilateralFilterFS.h"
+#include "vtkEDLComposeFS.h"
+#include "vtkEDLShadeFS.h"
+#include "vtkTextureObjectVS.h"
 
 //#define VTK_EDL_SHADING_DEBUG
 
+namespace
+{
+void annotate(const std::string& str)
+{
+  vtkOpenGLRenderUtilities::MarkDebugEvent(str);
+}
+}
+
 vtkStandardNewMacro(vtkEDLShading);
 
 // ----------------------------------------------------------------------------
 vtkEDLShading::vtkEDLShading()
 {
 
-  this->ProjectionFBO = 0;
-  this->ProjectionColorTexture = 0;
-  this->ProjectionDepthTexture = 0;
+  this->ProjectionFBO = nullptr;
+  this->ProjectionColorTexture = nullptr;
+  this->ProjectionDepthTexture = nullptr;
 
-  this->EDLHighFBO = 0;
-  this->EDLHighShadeTexture = 0;
-  this->EDLLowFBO = 0;
-  this->EDLLowShadeTexture = 0;
-  this->EDLLowBlurTexture = 0;
+  this->EDLHighFBO = nullptr;
+  this->EDLHighShadeTexture = nullptr;
+  this->EDLLowFBO = nullptr;
+  this->EDLLowShadeTexture = nullptr;
+  this->EDLLowBlurTexture = nullptr;
 
   this->EDLIsFiltered = true;
   // init neighbours in image space
   for (int c = 0; c < 8; c++)
   {
     float x, y;
-    x = cos(2* 3.14159 * float (c)/8.);
-    y = sin(2*3.14159*float(c)/8.);
-    this->EDLNeighbours[c][0] = x / sqrt(x*x+y*y);
-    this->EDLNeighbours[c][1] = y / sqrt(x*x+y*y);
+    x = cos(2 * vtkMath::Pi() * float(c) / 8.);
+    y = sin(2 * vtkMath::Pi() * float(c) / 8.);
+    this->EDLNeighbours[c][0] = x / sqrt(x * x + y * y);
+    this->EDLNeighbours[c][1] = y / sqrt(x * x + y * y);
     this->EDLNeighbours[c][2] = 0.;
     this->EDLNeighbours[c][3] = 0.;
   }
@@ -99,45 +91,45 @@ vtkEDLShading::vtkEDLShading()
 // ----------------------------------------------------------------------------
 vtkEDLShading::~vtkEDLShading()
 {
-  if (this->ProjectionFBO != 0)
+  if (this->ProjectionFBO != nullptr)
   {
-    vtkErrorMacro(<<"FrameBufferObject should have been deleted in "
-      <<"ReleaseGraphicsResources().");
+    vtkErrorMacro(<< "FrameBufferObject should have been deleted in "
+                  << "ReleaseGraphicsResources().");
   }
-  if (this->ProjectionColorTexture != 0)
+  if (this->ProjectionColorTexture != nullptr)
   {
-    vtkErrorMacro(<<"ColorTexture should have been deleted in "
-      <<"ReleaseGraphicsResources().");
+    vtkErrorMacro(<< "ColorTexture should have been deleted in "
+                  << "ReleaseGraphicsResources().");
   }
-  if (this->ProjectionDepthTexture != 0)
+  if (this->ProjectionDepthTexture != nullptr)
   {
-    vtkErrorMacro(<<"DepthTexture should have been deleted in "
-      <<"ReleaseGraphicsResources().");
+    vtkErrorMacro(<< "DepthTexture should have been deleted in "
+                  << "ReleaseGraphicsResources().");
   }
-  if (this->EDLHighFBO != 0)
+  if (this->EDLHighFBO != nullptr)
   {
-    vtkErrorMacro(<<"FrameBufferObject should have been deleted in "
-      <<"ReleaseGraphicsResources().");
+    vtkErrorMacro(<< "FrameBufferObject should have been deleted in "
+                  << "ReleaseGraphicsResources().");
   }
-  if (this->EDLHighShadeTexture != 0)
+  if (this->EDLHighShadeTexture != nullptr)
   {
-    vtkErrorMacro(<<"ColorTexture should have been deleted in "
-      <<"ReleaseGraphicsResources().");
+    vtkErrorMacro(<< "ColorTexture should have been deleted in "
+                  << "ReleaseGraphicsResources().");
   }
-  if (this->EDLLowFBO != 0)
+  if (this->EDLLowFBO != nullptr)
   {
-    vtkErrorMacro(<<"FrameBufferObject should have been deleted in "
-      <<"ReleaseGraphicsResources().");
+    vtkErrorMacro(<< "FrameBufferObject should have been deleted in "
+                  << "ReleaseGraphicsResources().");
   }
-  if (this->EDLLowShadeTexture != 0)
+  if (this->EDLLowShadeTexture != nullptr)
   {
-    vtkErrorMacro(<<"ColorTexture should have been deleted in "
-      <<"ReleaseGraphicsResources().");
+    vtkErrorMacro(<< "ColorTexture should have been deleted in "
+                  << "ReleaseGraphicsResources().");
   }
-  if (this->EDLLowBlurTexture != 0)
+  if (this->EDLLowBlurTexture != nullptr)
   {
-    vtkErrorMacro(<<"ColorTexture should have been deleted in "
-      <<"ReleaseGraphicsResources().");
+    vtkErrorMacro(<< "ColorTexture should have been deleted in "
+                  << "ReleaseGraphicsResources().");
   }
 }
 
@@ -147,7 +139,7 @@ void vtkEDLShading::PrintSelf(ostream& os, vtkIndent indent)
   this->Superclass::PrintSelf(os, indent);
 
   os << indent << "DelegatePass:";
-  if (this->DelegatePass != 0)
+  if (this->DelegatePass != nullptr)
   {
     this->DelegatePass->PrintSelf(os, indent);
   }
@@ -161,57 +153,52 @@ void vtkEDLShading::PrintSelf(ostream& os, vtkIndent indent)
 // Description:
 // Initialize framebuffers and associated texture objects,
 // with link to render state s
-void vtkEDLShading::EDLInitializeFramebuffers(vtkRenderState &s)
+void vtkEDLShading::EDLInitializeFramebuffers(vtkRenderState& s)
 {
-  vtkRenderer *r = s.GetRenderer();
+  vtkRenderer* r = s.GetRenderer();
 
   vtkOpenGLCheckErrorMacro("failed before Initialize");
 
-  vtkOpenGLRenderWindow *renWin =
-    vtkOpenGLRenderWindow::SafeDownCast(r->GetRenderWindow());
+  vtkOpenGLRenderWindow* renWin = vtkOpenGLRenderWindow::SafeDownCast(r->GetRenderWindow());
 
   //  PROJECTION FBO and TEXTURES
   //
-  if (this->ProjectionFBO == 0)
+  if (this->ProjectionFBO == nullptr)
   {
-    this->ProjectionFBO = vtkFrameBufferObject::New();
+    this->ProjectionFBO = vtkOpenGLFramebufferObject::New();
     this->ProjectionFBO->SetContext(renWin);
   }
   s.SetFrameBuffer(this->ProjectionFBO);
+  renWin->GetState()->PushFramebufferBindings();
   this->ProjectionFBO->Bind();
   // Color texture
-  if (this->ProjectionColorTexture == 0)
+  if (this->ProjectionColorTexture == nullptr)
   {
     this->ProjectionColorTexture = vtkTextureObject::New();
     this->ProjectionColorTexture->SetContext(this->ProjectionFBO->GetContext());
   }
-  if (this->ProjectionColorTexture->GetWidth() != static_cast<unsigned int>
-    (this->W)
-      || this->ProjectionColorTexture->GetHeight()
-          != static_cast<unsigned int> (this->H))
+  if (this->ProjectionColorTexture->GetWidth() != static_cast<unsigned int>(this->W) ||
+    this->ProjectionColorTexture->GetHeight() != static_cast<unsigned int>(this->H))
   {
     this->ProjectionColorTexture->Create2D(this->W, this->H, 4, VTK_FLOAT, false);
   }
   // Depth texture
-  if (this->ProjectionDepthTexture == 0)
+  if (this->ProjectionDepthTexture == nullptr)
   {
     this->ProjectionDepthTexture = vtkTextureObject::New();
     this->ProjectionDepthTexture->SetContext(this->ProjectionFBO->GetContext());
   }
-  if (this->ProjectionDepthTexture->GetWidth() != static_cast<unsigned int> (this->W)
-      || this->ProjectionDepthTexture->GetHeight()
-          != static_cast<unsigned int> (this->H))
+  if (this->ProjectionDepthTexture->GetWidth() != static_cast<unsigned int>(this->W) ||
+    this->ProjectionDepthTexture->GetHeight() != static_cast<unsigned int>(this->H))
   {
-    this->ProjectionDepthTexture->AllocateDepth(
-      this->W, this->H, vtkTextureObject::Float32);
+    this->ProjectionDepthTexture->AllocateDepth(this->W, this->H, vtkTextureObject::Float32);
   }
 
   // Apply textures
   // to make things clear, we write all
-  this->ProjectionFBO->SetNumberOfRenderTargets(1);
-  this->ProjectionFBO->SetColorBuffer(0, this->ProjectionColorTexture);
-  this->ProjectionFBO->SetActiveBuffer(0);
-  this->ProjectionFBO->SetDepthBuffer(this->ProjectionDepthTexture);
+  this->ProjectionFBO->AddColorAttachment(0, this->ProjectionColorTexture);
+  this->ProjectionFBO->ActivateDrawBuffer(0);
+  this->ProjectionFBO->AddDepthAttachment(this->ProjectionDepthTexture);
 
   this->ProjectionDepthTexture->SetWrapS(vtkTextureObject::ClampToEdge);
   this->ProjectionDepthTexture->SetWrapT(vtkTextureObject::ClampToEdge);
@@ -220,72 +207,72 @@ void vtkEDLShading::EDLInitializeFramebuffers(vtkRenderState &s)
   this->ProjectionDepthTexture->Bind();
   this->ProjectionDepthTexture->SendParameters();
 
-  this->ProjectionFBO->UnBind();
+  renWin->GetState()->PopFramebufferBindings();
 
   //  EDL-RES1 FBO and TEXTURE
   //
-  if (this->EDLHighFBO == 0)
+  if (this->EDLHighFBO == nullptr)
   {
-    this->EDLHighFBO = vtkFrameBufferObject::New();
+    this->EDLHighFBO = vtkOpenGLFramebufferObject::New();
     this->EDLHighFBO->SetContext(renWin);
   }
   s.SetFrameBuffer(EDLHighFBO);
   // Color texture
-  if (this->EDLHighShadeTexture == 0)
+  if (this->EDLHighShadeTexture == nullptr)
   {
     this->EDLHighShadeTexture = vtkTextureObject::New();
     this->EDLHighShadeTexture->SetContext(this->EDLHighFBO->GetContext());
   }
-  if (this->EDLHighShadeTexture->GetWidth() != static_cast<unsigned int> (this->W)
-      || this->EDLHighShadeTexture->GetHeight()
-          != static_cast<unsigned int> (this->H))
+  if (this->EDLHighShadeTexture->GetWidth() != static_cast<unsigned int>(this->W) ||
+    this->EDLHighShadeTexture->GetHeight() != static_cast<unsigned int>(this->H))
   {
     this->EDLHighShadeTexture->Create2D(this->W, this->H, 4, VTK_FLOAT, false);
   }
-  this->EDLHighFBO->SetNumberOfRenderTargets(1);
-  this->EDLHighFBO->SetColorBuffer(0, this->EDLHighShadeTexture);
-  this->EDLHighFBO->SetActiveBuffer(0);
-  this->EDLHighFBO->SetDepthBufferNeeded(false);
-  this->EDLHighFBO->UnBind();
+  renWin->GetState()->PushFramebufferBindings();
+  this->EDLHighFBO->Bind();
+  this->EDLHighFBO->AddColorAttachment(0, this->EDLHighShadeTexture);
+  this->EDLHighFBO->ActivateDrawBuffer(0);
+  this->EDLHighFBO->AddDepthAttachment();
+  renWin->GetState()->PopFramebufferBindings();
 
   //  EDL-RES2 FBO and TEXTURE
   //
-  if (this->EDLLowFBO == 0)
+  if (this->EDLLowFBO == nullptr)
   {
-    this->EDLLowFBO = vtkFrameBufferObject::New();
+    this->EDLLowFBO = vtkOpenGLFramebufferObject::New();
     this->EDLLowFBO->SetContext(renWin);
   }
   s.SetFrameBuffer(EDLLowFBO);
   // Color texture
-  if (this->EDLLowShadeTexture == 0)
+  if (this->EDLLowShadeTexture == nullptr)
   {
     this->EDLLowShadeTexture = vtkTextureObject::New();
     this->EDLLowShadeTexture->SetContext(this->EDLLowFBO->GetContext());
   }
-  if (this->EDLLowShadeTexture->GetWidth() != static_cast<unsigned int> (this->W
-      / EDLLowResFactor) || this->EDLLowShadeTexture->GetHeight()
-      != static_cast<unsigned int> (this->H / EDLLowResFactor))
+  if (this->EDLLowShadeTexture->GetWidth() !=
+      static_cast<unsigned int>(this->W / EDLLowResFactor) ||
+    this->EDLLowShadeTexture->GetHeight() != static_cast<unsigned int>(this->H / EDLLowResFactor))
   {
-    this->EDLLowShadeTexture->Create2D(this->W / EDLLowResFactor,
-        this->H / EDLLowResFactor, 4, VTK_FLOAT, false);
+    this->EDLLowShadeTexture->Create2D(
+      this->W / EDLLowResFactor, this->H / EDLLowResFactor, 4, VTK_FLOAT, false);
   }
   // Blur texture
-  if (this->EDLLowBlurTexture == 0)
+  if (this->EDLLowBlurTexture == nullptr)
   {
     this->EDLLowBlurTexture = vtkTextureObject::New();
     this->EDLLowBlurTexture->SetContext(this->EDLLowFBO->GetContext());
   }
-  if (this->EDLLowBlurTexture->GetWidth() != static_cast<unsigned int> (this->W
-      / EDLLowResFactor) || this->EDLLowBlurTexture->GetHeight()
-      != static_cast<unsigned int> (this->H / EDLLowResFactor))
+  if (this->EDLLowBlurTexture->GetWidth() != static_cast<unsigned int>(this->W / EDLLowResFactor) ||
+    this->EDLLowBlurTexture->GetHeight() != static_cast<unsigned int>(this->H / EDLLowResFactor))
   {
-    this->EDLLowBlurTexture->Create2D(this->W / EDLLowResFactor, this->H / EDLLowResFactor,
-        4, VTK_FLOAT, false);
+    this->EDLLowBlurTexture->Create2D(
+      this->W / EDLLowResFactor, this->H / EDLLowResFactor, 4, VTK_FLOAT, false);
   }
-  this->EDLLowFBO->SetNumberOfRenderTargets(1);
-  this->EDLLowFBO->SetColorBuffer(0, this->EDLLowShadeTexture);
-  this->EDLLowFBO->SetActiveBuffer(0);
-  this->EDLLowFBO->SetDepthBufferNeeded(false);
+  renWin->GetState()->PushFramebufferBindings();
+  this->EDLLowFBO->Bind();
+  this->EDLLowFBO->AddColorAttachment(0, this->EDLLowShadeTexture);
+  this->EDLLowFBO->ActivateDrawBuffer(0);
+  this->EDLLowFBO->AddDepthAttachment();
 
   this->EDLLowShadeTexture->SetWrapS(vtkTextureObject::ClampToEdge);
   this->EDLLowShadeTexture->SetWrapT(vtkTextureObject::ClampToEdge);
@@ -301,7 +288,7 @@ void vtkEDLShading::EDLInitializeFramebuffers(vtkRenderState &s)
   this->EDLLowBlurTexture->Bind();
   this->EDLLowBlurTexture->SendParameters();
 
-  this->EDLLowFBO->UnBind();
+  renWin->GetState()->PopFramebufferBindings();
 
   vtkOpenGLCheckErrorMacro("failed after Initialize");
 }
@@ -309,7 +296,7 @@ void vtkEDLShading::EDLInitializeFramebuffers(vtkRenderState &s)
 // Description:
 // Initialize shaders
 //
-void vtkEDLShading::EDLInitializeShaders(vtkOpenGLRenderWindow *renWin)
+void vtkEDLShading::EDLInitializeShaders(vtkOpenGLRenderWindow* renWin)
 {
 #ifdef VTK_EDL_SHADING_DEBUG
   cout << "EDL: INITIALIZE SHADERS" << endl;
@@ -317,35 +304,26 @@ void vtkEDLShading::EDLInitializeShaders(vtkOpenGLRenderWindow *renWin)
 
   //  EDL SHADE
   //
-  if (this->EDLShadeProgram.Program == 0)
+  if (this->EDLShadeProgram.Program == nullptr)
   {
     this->EDLShadeProgram.Program =
-      renWin->GetShaderCache()->ReadyShaderProgram(
-        vtkTextureObjectVS,
-        vtkEDLShadeFS,
-        "");
+      renWin->GetShaderCache()->ReadyShaderProgram(vtkTextureObjectVS, vtkEDLShadeFS, "");
   }
 
   //  EDL COMPOSE
   //
-  if (this->EDLComposeProgram.Program == 0)
+  if (this->EDLComposeProgram.Program == nullptr)
   {
     this->EDLComposeProgram.Program =
-      renWin->GetShaderCache()->ReadyShaderProgram(
-        vtkTextureObjectVS,
-        vtkEDLComposeFS,
-        "");
+      renWin->GetShaderCache()->ReadyShaderProgram(vtkTextureObjectVS, vtkEDLComposeFS, "");
   }
 
   //  BILATERAL FILTER
   //
-  if (this->BilateralProgram.Program == 0)
+  if (this->BilateralProgram.Program == nullptr)
   {
     this->BilateralProgram.Program =
-      renWin->GetShaderCache()->ReadyShaderProgram(
-        vtkTextureObjectVS,
-        vtkEDLBilateralFilterFS,
-        "");
+      renWin->GetShaderCache()->ReadyShaderProgram(vtkTextureObjectVS, vtkEDLBilateralFilterFS, "");
   }
 
 #ifdef VTK_EDL_SHADING_DEBUG
@@ -357,9 +335,7 @@ void vtkEDLShading::EDLInitializeShaders(vtkOpenGLRenderWindow *renWin)
 // Description:
 // Render EDL in full resolution
 //
-bool vtkEDLShading::EDLShadeHigh(
-  vtkRenderState &s,
-  vtkOpenGLRenderWindow *renWin)
+bool vtkEDLShading::EDLShadeHigh(vtkRenderState& s, vtkOpenGLRenderWindow* renWin)
 {
   //  VARIABLES
   //
@@ -367,8 +343,7 @@ bool vtkEDLShading::EDLShadeHigh(
   float F_scale = 5.0;
   float SX = 1. / float(this->W);
   float SY = 1. / float(this->H);
-  float L[3] =
-    { 0., 0., -1. };
+  float L[3] = { 0., 0., -1. };
 
   // ACTIVATE SHADER
   //
@@ -378,13 +353,15 @@ bool vtkEDLShading::EDLShadeHigh(
   //
   s.SetFrameBuffer(this->EDLHighFBO);
   this->EDLHighShadeTexture->Activate();
-  this->EDLHighFBO->SetColorBuffer(0, this->EDLHighShadeTexture);
-  this->EDLHighFBO->SetActiveBuffer(0);
-  this->EDLHighFBO->Start(this->W, this->H, false);
+  renWin->GetState()->PushFramebufferBindings();
+  this->EDLHighFBO->Bind();
+  this->EDLHighFBO->AddColorAttachment(0, this->EDLHighShadeTexture);
+  this->EDLHighFBO->ActivateDrawBuffer(0);
+  this->EDLHighFBO->Start(this->W, this->H);
 
   // DEPTH TEXTURE PARAMETERS
   this->ProjectionDepthTexture->Activate();
-  vtkShaderProgram *prog = this->EDLShadeProgram.Program;
+  vtkShaderProgram* prog = this->EDLShadeProgram.Program;
 
   // shader parameters
   prog->SetUniformi("s2_depth", this->ProjectionDepthTexture->GetTextureUnit());
@@ -401,12 +378,12 @@ bool vtkEDLShading::EDLShadeHigh(
   double bb[6];
   vtkMath::UninitializeBounds(bb);
   bool boundsSet = false;
-  for(int i=0; i<s.GetPropArrayCount(); i++)
+  for (int i = 0; i < s.GetPropArrayCount(); i++)
   {
-    double* bounds = s.GetPropArray()[i]->GetBounds();
+    const double* bounds = s.GetPropArray()[i]->GetBounds();
     if (bounds)
     {
-      if(!boundsSet)
+      if (!boundsSet)
       {
         bb[0] = bounds[0];
         bb[1] = bounds[1];
@@ -427,19 +404,18 @@ bool vtkEDLShading::EDLShadeHigh(
       }
     }
   }
-  float diag = (bb[1]-bb[0])*(bb[1]-bb[0]) + (bb[3]-bb[2])*(bb[3]-bb[2])
-               + (bb[5]-bb[4])*(bb[5]-bb[4]);
+  float diag = (bb[1] - bb[0]) * (bb[1] - bb[0]) + (bb[3] - bb[2]) * (bb[3] - bb[2]) +
+    (bb[5] - bb[4]) * (bb[5] - bb[4]);
   diag = sqrt(diag);
   prog->SetUniformf("SceneSize", diag);
 
   // RENDER AND FREE ALL
-  this->EDLHighFBO->RenderQuad(0, this->W - 1, 0, this->H - 1,
-    prog, this->EDLShadeProgram.VAO);
+  this->EDLHighFBO->RenderQuad(0, this->W - 1, 0, this->H - 1, prog, this->EDLShadeProgram.VAO);
 
   //
   this->ProjectionDepthTexture->Deactivate();
   this->EDLHighShadeTexture->Deactivate();
-  this->EDLHighFBO->UnBind();
+  renWin->GetState()->PopFramebufferBindings();
 
   return true; // succeeded
 }
@@ -448,9 +424,7 @@ bool vtkEDLShading::EDLShadeHigh(
 // Description:
 // Render EDL in low resolution
 //
-bool vtkEDLShading::EDLShadeLow(
-  vtkRenderState &s,
-  vtkOpenGLRenderWindow *renWin)
+bool vtkEDLShading::EDLShadeLow(vtkRenderState& s, vtkOpenGLRenderWindow* renWin)
 {
   //  VARIABLES
   //
@@ -458,8 +432,7 @@ bool vtkEDLShading::EDLShadeLow(
   float F_scale = 5.0;
   float SX = 1. / float(this->W / this->EDLLowResFactor);
   float SY = 1. / float(this->H / this->EDLLowResFactor);
-  float L[3] =
-    { 0., 0., -1. };
+  float L[3] = { 0., 0., -1. };
 
   // ACTIVATE FBO
   //
@@ -467,16 +440,17 @@ bool vtkEDLShading::EDLShadeLow(
   this->EDLLowShadeTexture->Activate();
   this->EDLLowShadeTexture->SetLinearMagnification(true);
   this->EDLLowShadeTexture->SendParameters();
-  this->EDLLowFBO->SetColorBuffer(0, this->EDLLowShadeTexture);
-  this->EDLLowFBO->SetActiveBuffer(0);
-  this->EDLLowFBO->Start(this->W / this->EDLLowResFactor,
-    this->H / this->EDLLowResFactor, false);
+  renWin->GetState()->PushFramebufferBindings();
+  this->EDLLowFBO->Bind();
+  this->EDLLowFBO->AddColorAttachment(0, this->EDLLowShadeTexture);
+  this->EDLLowFBO->ActivateDrawBuffer(0);
+  this->EDLLowFBO->Start(this->W / this->EDLLowResFactor, this->H / this->EDLLowResFactor);
 
   // ACTIVATE SHADER
   //
   renWin->GetShaderCache()->ReadyShaderProgram(this->EDLShadeProgram.Program);
   // DEPTH TEXTURE PARAMETERS
-  vtkShaderProgram *prog = this->EDLShadeProgram.Program;
+  vtkShaderProgram* prog = this->EDLShadeProgram.Program;
   this->ProjectionDepthTexture->Activate();
   // shader parameters
   prog->SetUniformi("s2_depth", this->ProjectionDepthTexture->GetTextureUnit());
@@ -491,13 +465,12 @@ bool vtkEDLShading::EDLShadeLow(
 
   // RENDER AND FREE ALL
   //
-  this->EDLLowFBO->RenderQuad(0, this->W / this->EDLLowResFactor - 1,
-    0, this->H / this->EDLLowResFactor - 1,
-    prog, this->EDLShadeProgram.VAO);
+  this->EDLLowFBO->RenderQuad(0, this->W / this->EDLLowResFactor - 1, 0,
+    this->H / this->EDLLowResFactor - 1, prog, this->EDLShadeProgram.VAO);
 
   this->ProjectionDepthTexture->Deactivate();
   this->EDLLowShadeTexture->Deactivate();
-  this->EDLLowFBO->UnBind();
+  renWin->GetState()->PopFramebufferBindings();
 
   return true; // succeeded
 }
@@ -506,8 +479,7 @@ bool vtkEDLShading::EDLShadeLow(
 // Description:
 // Bilateral Filter low resolution shaded image
 //
-bool vtkEDLShading::EDLBlurLow(vtkRenderState &s,
-  vtkOpenGLRenderWindow *renWin)
+bool vtkEDLShading::EDLBlurLow(vtkRenderState& s, vtkOpenGLRenderWindow* renWin)
 {
   // shader parameters
   float SX = 1. / float(this->W / this->EDLLowResFactor);
@@ -523,13 +495,14 @@ bool vtkEDLShading::EDLBlurLow(vtkRenderState &s,
   //
   s.SetFrameBuffer(this->EDLLowFBO);
   this->EDLLowBlurTexture->Activate();
-  this->EDLLowFBO->SetColorBuffer(0, this->EDLLowBlurTexture);
-  this->EDLLowFBO->SetActiveBuffer(0);
-  this->EDLLowFBO->Start(this->W / EDLLowResFactor, this->H / EDLLowResFactor,
-      false);
+  renWin->GetState()->PushFramebufferBindings();
+  this->EDLLowFBO->Bind();
+  this->EDLLowFBO->AddColorAttachment(0, this->EDLLowBlurTexture);
+  this->EDLLowFBO->ActivateDrawBuffer(0);
+  this->EDLLowFBO->Start(this->W / EDLLowResFactor, this->H / EDLLowResFactor);
 
   // DEPTH TEXTURE PARAMETERS
-  vtkShaderProgram *prog = this->BilateralProgram.Program;
+  vtkShaderProgram* prog = this->BilateralProgram.Program;
 
   // DEPTH TEXTURE PARAMETERS
   this->EDLLowShadeTexture->Activate();
@@ -543,16 +516,14 @@ bool vtkEDLShading::EDLBlurLow(vtkRenderState &s,
   prog->SetUniformi("N", EDL_Bilateral_N);
   prog->SetUniformf("sigma", EDL_Bilateral_Sigma);
 
-  this->EDLLowFBO->RenderQuad(
-    0, this->W / this->EDLLowResFactor - 1,
-    0, this->H / this->EDLLowResFactor - 1,
-    prog, this->BilateralProgram.VAO);
+  this->EDLLowFBO->RenderQuad(0, this->W / this->EDLLowResFactor - 1, 0,
+    this->H / this->EDLLowResFactor - 1, prog, this->BilateralProgram.VAO);
 
   this->EDLLowBlurTexture->Deactivate();
   this->EDLLowShadeTexture->Deactivate();
   this->ProjectionDepthTexture->Deactivate();
 
-  this->EDLLowFBO->UnBind();
+  renWin->GetState()->PopFramebufferBindings();
 
   return EDLIsFiltered;
 }
@@ -561,24 +532,25 @@ bool vtkEDLShading::EDLBlurLow(vtkRenderState &s,
 // Description:
 // Compose color and shaded images
 //
-bool vtkEDLShading::EDLCompose(const vtkRenderState *,
-  vtkOpenGLRenderWindow *renWin)
+bool vtkEDLShading::EDLCompose(const vtkRenderState*, vtkOpenGLRenderWindow* renWin)
 {
   //  this->EDLIsFiltered = true;
 
   // ACTIVATE SHADER
   //
   renWin->GetShaderCache()->ReadyShaderProgram(this->EDLComposeProgram.Program);
+  vtkOpenGLState* ostate = renWin->GetState();
+
   // DEPTH TEXTURE PARAMETERS
-  vtkShaderProgram *prog = this->EDLComposeProgram.Program;
+  vtkShaderProgram* prog = this->EDLComposeProgram.Program;
 
   //  EDL shaded texture - full res
   this->EDLHighShadeTexture->Activate();
   prog->SetUniformi("s2_S1", this->EDLHighShadeTexture->GetTextureUnit());
 
   //  EDL shaded texture - low res
-  //this->EDLLowBlurTexture->SetLinearMagnification(true);
-  //this->EDLLowBlurTexture->SendParameters();
+  // this->EDLLowBlurTexture->SetLinearMagnification(true);
+  // this->EDLLowBlurTexture->SendParameters();
   if (this->EDLIsFiltered)
   {
     this->EDLLowBlurTexture->Activate();
@@ -594,31 +566,23 @@ bool vtkEDLShading::EDLCompose(const vtkRenderState *,
   this->ProjectionColorTexture->Activate();
   prog->SetUniformi("s2_C", this->ProjectionColorTexture->GetTextureUnit());
 
-  //  initial depth texture
-  this->ProjectionDepthTexture->Activate();
-  prog->SetUniformi("s2_Z", this->ProjectionDepthTexture->GetTextureUnit());
-
   //  DRAW CONTEXT - prepare blitting
   //
   // Prepare blitting
-  glClearColor(1., 1., 1., 1.);
-#if GL_ES_VERSION_2_0 == 1
-  glClearDepthf(static_cast<GLclampf>(1.0));
-#else
-  glClearDepth(static_cast<GLclampf>(1.0));
-#endif
-  glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
+  ostate->vtkglClearColor(1., 1., 1., 1.);
+  ostate->vtkglClearDepth(1.0);
+  ostate->vtkglClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
   // IMPORTANT since we enable depth writing hereafter
-  glDisable(GL_BLEND);
-  glEnable(GL_DEPTH_TEST);
+  ostate->vtkglDisable(GL_BLEND);
+  ostate->vtkglEnable(GL_DEPTH_TEST);
   // IMPORTANT : so that depth information is propagated
-  glDisable(GL_SCISSOR_TEST);
+  ostate->vtkglDisable(GL_SCISSOR_TEST);
 
-  this->EDLHighShadeTexture->CopyToFrameBuffer( 0,  0,
-      this->W - 1 - 2 * this->ExtraPixels,
-      this->H - 1 - 2 * this->ExtraPixels, 0, 0,
-      this->Width, this->Height,
-      prog, this->EDLComposeProgram.VAO );
+  int blitSize[2] = { this->W - 1 - 2 * this->ExtraPixels, this->H - 1 - 2 * this->ExtraPixels };
+
+  this->EDLHighShadeTexture->CopyToFrameBuffer(this->ExtraPixels, this->ExtraPixels, blitSize[0],
+    blitSize[1], this->Origin[0], this->Origin[1], this->Origin[0] + blitSize[0],
+    this->Origin[1] + blitSize[1], prog, this->EDLComposeProgram.VAO);
 
   //  FREE ALL
   //
@@ -632,7 +596,6 @@ bool vtkEDLShading::EDLCompose(const vtkRenderState *,
   }
   this->EDLHighShadeTexture->Deactivate();
   this->ProjectionColorTexture->Deactivate();
-  this->ProjectionDepthTexture->Deactivate();
 
   return true;
 }
@@ -641,21 +604,17 @@ bool vtkEDLShading::EDLCompose(const vtkRenderState *,
 // Description:
 // Perform rendering according to a render state \p s.
 // \pre s_exists: s!=0
-void vtkEDLShading::Render(const vtkRenderState *s)
+void vtkEDLShading::Render(const vtkRenderState* s)
 {
-  assert("pre: s_exists" && s!=0);
+  assert("pre: s_exists" && s != nullptr);
+  annotate("Start vtkEDLShading::Render");
 
   this->NumberOfRenderedProps = 0;
-  vtkRenderer *r = s->GetRenderer();
-  vtkOpenGLRenderWindow *renWin =
-    vtkOpenGLRenderWindow::SafeDownCast(r->GetRenderWindow());
+  vtkRenderer* r = s->GetRenderer();
+  vtkOpenGLRenderWindow* renWin = vtkOpenGLRenderWindow::SafeDownCast(r->GetRenderWindow());
 
-  if (this->DelegatePass != 0)
+  if (this->DelegatePass != nullptr)
   {
-#if GL_ES_VERSION_2_0 != 1
-    GLint savedCurrentDrawBuffer;
-    glGetIntegerv(GL_DRAW_BUFFER,&savedCurrentDrawBuffer);
-#endif
 
     //////////////////////////////////////////////////////
     //
@@ -664,10 +623,10 @@ void vtkEDLShading::Render(const vtkRenderState *s)
     this->ReadWindowSize(s);
     // this->extraPixels = 20; Obsolete
     this->ExtraPixels = 0; // extra pixels to zero in the new system
-    this->W = this->Width + 2* this ->ExtraPixels;
-    this->H=this->Height+2*this->ExtraPixels;
+    this->W = this->Width + 2 * this->ExtraPixels;
+    this->H = this->Height + 2 * this->ExtraPixels;
     vtkRenderState s2(r);
-    s2.SetPropArrayAndCount(s->GetPropArray(),s->GetPropArrayCount());
+    s2.SetPropArrayAndCount(s->GetPropArray(), s->GetPropArrayCount());
 
     //////////////////////////////////////////////////////
     //
@@ -675,39 +634,51 @@ void vtkEDLShading::Render(const vtkRenderState *s)
     //
     //  FBOs
     //
+    annotate("Start vtkEDLShading Initialization");
     this->EDLInitializeFramebuffers(s2);
     //  Shaders
     //
     this->EDLInitializeShaders(renWin);
+    annotate("End vtkEDLShading Initialization");
+
+    if (this->EDLShadeProgram.Program == nullptr || this->EDLComposeProgram.Program == nullptr ||
+      this->BilateralProgram.Program == nullptr)
+    {
+      return;
+    }
 
     //////////////////////////////////////////////////////
     //
     // 4. DELEGATE RENDER IN PROJECTION FBO
     //
     //
-    double znear,zfar;
-    r->GetActiveCamera()->GetClippingRange(znear,zfar);
+    double znear, zfar;
+    r->GetActiveCamera()->GetClippingRange(znear, zfar);
     this->Zf = zfar;
     this->Zn = znear;
-    //cout << " -- ZNEAR/ZFAR : " << Zn << " || " << Zf << endl;
+    // cout << " -- ZNEAR/ZFAR : " << Zn << " || " << Zf << endl;
+    renWin->GetState()->PushFramebufferBindings();
     this->ProjectionFBO->Bind();
-    this->RenderDelegate(s,this->Width,this->Height,
-         this->W,this->H,this->ProjectionFBO,
-         this->ProjectionColorTexture,this->ProjectionDepthTexture);
+    annotate("Start vtkEDLShading::RenderDelegate");
+    this->RenderDelegate(s, this->Width, this->Height, this->W, this->H, this->ProjectionFBO,
+      this->ProjectionColorTexture, this->ProjectionDepthTexture);
+    annotate("End vtkEDLShading::RenderDelegate");
 
     this->ProjectionFBO->UnBind();
 
-    //system("PAUSE");
+    // system("PAUSE");
 
     //////////////////////////////////////////////////////
     //
     // 5. EDL SHADING PASS - FULL RESOLUTION
     //
 #if EDL_HIGH_RESOLUTION_ON
-    if(! this->EDLShadeHigh(s2,renWin) )
+    annotate("Start vtkEDLShading::ShadeHigh");
+    if (!this->EDLShadeHigh(s2, renWin))
     {
-      glDrawBuffer(savedCurrentDrawBuffer);
+      renWin->GetState()->PopFramebufferBindings();
     }
+    annotate("End vtkEDLShading::ShadeHigh");
 #endif // EDL_HIGH_RESOLUTION_ON
 
     //////////////////////////////////////////////////////
@@ -715,15 +686,17 @@ void vtkEDLShading::Render(const vtkRenderState *s)
     // 6. EDL SHADING PASS - LOW RESOLUTION + blur pass
     //
 #if EDL_LOW_RESOLUTION_ON
-    if(! this->EDLShadeLow(s2, renWin) )
+    annotate("Start vtkEDLShading::ShadeLow");
+    if (!this->EDLShadeLow(s2, renWin))
     {
-#if GL_ES_VERSION_2_0 != 1
-      glDrawBuffer(static_cast<GLenum>(savedCurrentDrawBuffer));
-#endif
+      renWin->GetState()->PopFramebufferBindings();
     }
+    annotate("End vtkEDLShading::ShadeLow");
     if (this->EDLIsFiltered)
     {
+      annotate("Start vtkEDLShading::BlurLow");
       this->EDLBlurLow(s2, renWin);
+      annotate("End vtkEDLShading::BlurLow");
     }
 #endif // EDL_LOW_RESOLUTION_ON
 
@@ -731,23 +704,25 @@ void vtkEDLShading::Render(const vtkRenderState *s)
     //
     // 7. COMPOSITING PASS (in original framebuffer)
     //
-    if(s->GetFrameBuffer() != NULL)
+    if (s->GetFrameBuffer() != nullptr)
     {
-      vtkFrameBufferObject::SafeDownCast(s->GetFrameBuffer())->Bind();
+      vtkOpenGLFramebufferObject::SafeDownCast(s->GetFrameBuffer())->Bind();
     }
-#if GL_ES_VERSION_2_0 != 1
-    glDrawBuffer(static_cast<GLenum>(savedCurrentDrawBuffer));
-#endif
+    renWin->GetState()->PopFramebufferBindings();
 
-    if( ! this->EDLCompose(s, renWin))
+    annotate("Start vtkEDLShading::Compose");
+    if (!this->EDLCompose(s, renWin))
     {
       return;
     }
+    annotate("End vtkEDLShading::Compose");
   }
   else
   {
-    vtkWarningMacro(<<" no delegate.");
+    vtkWarningMacro(<< " no delegate.");
   }
+
+  annotate("END vtkEDLShading::Render");
 }
 
 // --------------------------------------------------------------------------
@@ -755,9 +730,9 @@ void vtkEDLShading::Render(const vtkRenderState *s)
 // Release graphics resources and ask components to release their own
 // resources.
 // \pre w_exists: w!=0
-void vtkEDLShading::ReleaseGraphicsResources(vtkWindow *w)
+void vtkEDLShading::ReleaseGraphicsResources(vtkWindow* w)
 {
-  assert("pre: w_exists" && w!=0);
+  assert("pre: w_exists" && w != nullptr);
 
   //  SHADERS
   this->EDLShadeProgram.ReleaseGraphicsResources(w);
@@ -766,45 +741,45 @@ void vtkEDLShading::ReleaseGraphicsResources(vtkWindow *w)
 
   // FBOs and TOs
   //
-  if (this->ProjectionFBO != 0)
+  if (this->ProjectionFBO != nullptr)
   {
     this->ProjectionFBO->Delete();
-    this->ProjectionFBO = 0;
+    this->ProjectionFBO = nullptr;
   }
-  if (this->ProjectionColorTexture != 0)
+  if (this->ProjectionColorTexture != nullptr)
   {
     this->ProjectionColorTexture->Delete();
-    this->ProjectionColorTexture = 0;
+    this->ProjectionColorTexture = nullptr;
   }
-  if (this->ProjectionDepthTexture != 0)
+  if (this->ProjectionDepthTexture != nullptr)
   {
     this->ProjectionDepthTexture->Delete();
-    this->ProjectionDepthTexture = 0;
+    this->ProjectionDepthTexture = nullptr;
   }
-  if (this->EDLHighFBO != 0)
+  if (this->EDLHighFBO != nullptr)
   {
     this->EDLHighFBO->Delete();
-    this->EDLHighFBO = 0;
+    this->EDLHighFBO = nullptr;
   }
-  if (this->EDLHighShadeTexture != 0)
+  if (this->EDLHighShadeTexture != nullptr)
   {
     this->EDLHighShadeTexture->Delete();
-    this->EDLHighShadeTexture = 0;
+    this->EDLHighShadeTexture = nullptr;
   }
-  if (this->EDLLowFBO != 0)
+  if (this->EDLLowFBO != nullptr)
   {
     this->EDLLowFBO->Delete();
-    this->EDLLowFBO = 0;
+    this->EDLLowFBO = nullptr;
   }
-  if (this->EDLLowShadeTexture != 0)
+  if (this->EDLLowShadeTexture != nullptr)
   {
     this->EDLLowShadeTexture->Delete();
-    this->EDLLowShadeTexture = 0;
+    this->EDLLowShadeTexture = nullptr;
   }
-  if (this->EDLLowBlurTexture != 0)
+  if (this->EDLLowBlurTexture != nullptr)
   {
     this->EDLLowBlurTexture->Delete();
-    this->EDLLowBlurTexture = 0;
+    this->EDLLowBlurTexture = nullptr;
   }
 
   this->Superclass::ReleaseGraphicsResources(w);
