@@ -15,19 +15,19 @@ PURPOSE.  See the above copyright notice for more information.
 
 #include "vtkOpenGLRenderWindow.h"
 
-#import "vtkIOSRenderWindow.h"
-#import "vtkRenderWindowInteractor.h"
 #import "vtkCommand.h"
+#import "vtkIOSRenderWindow.h"
 #import "vtkIdList.h"
 #import "vtkObjectFactory.h"
+#import "vtkRenderWindowInteractor.h"
 #import "vtkRendererCollection.h"
-#import "vtkIOSGLView.h"
 
-#import <vtksys/ios/sstream>
+#import <sstream>
+
+#include "vtk_glew.h"
 
 vtkStandardNewMacro(vtkIOSRenderWindow);
 
-
 //----------------------------------------------------------------------------
 vtkIOSRenderWindow::vtkIOSRenderWindow()
 {
@@ -36,52 +36,53 @@ vtkIOSRenderWindow::vtkIOSRenderWindow()
   this->SetWindowName("Visualization Toolkit - IOS");
   this->CursorHidden = 0;
   this->ForceMakeCurrent = 0;
-  this->Capabilities = 0;
   this->OnScreenInitialized = 0;
   this->OffScreenInitialized = 0;
+  // it seems that LEFT/RIGHT cause issues on IOS so we just use
+  // generic BACK/FRONT
+  this->BackLeftBuffer = static_cast<unsigned int>(GL_BACK);
+  this->BackRightBuffer = static_cast<unsigned int>(GL_BACK);
+  this->FrontLeftBuffer = static_cast<unsigned int>(GL_FRONT);
+  this->FrontRightBuffer = static_cast<unsigned int>(GL_FRONT);
 }
 
 //----------------------------------------------------------------------------
 vtkIOSRenderWindow::~vtkIOSRenderWindow()
 {
   if (this->CursorHidden)
-    {
+  {
     this->ShowCursor();
-    }
+  }
   this->Finalize();
 
-  vtkRenderer *ren;
+  vtkRenderer* ren;
   vtkCollectionSimpleIterator rit;
   this->Renderers->InitTraversal(rit);
-  while ( (ren = this->Renderers->GetNextRenderer(rit)) )
-    {
+  while ((ren = this->Renderers->GetNextRenderer(rit)))
+  {
     ren->SetRenderWindow(NULL);
-    }
-
-  delete[] this->Capabilities;
-  this->Capabilities = 0;
+  }
 
   this->SetContextId(NULL);
   this->SetPixelFormat(NULL);
   this->SetRootWindow(NULL);
   this->SetWindowId(NULL);
   this->SetParentId(NULL);
-
 }
 
 //----------------------------------------------------------------------------
 void vtkIOSRenderWindow::Finalize()
 {
-  if(this->OffScreenInitialized)
-    {
+  if (this->OffScreenInitialized)
+  {
     this->OffScreenInitialized = 0;
     this->DestroyOffScreenWindow();
-    }
-  if(this->OnScreenInitialized)
-    {
+  }
+  if (this->OnScreenInitialized)
+  {
     this->OnScreenInitialized = 0;
     this->DestroyWindow();
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -89,20 +90,9 @@ void vtkIOSRenderWindow::DestroyWindow()
 {
   // finish OpenGL rendering
   if (this->OwnContext && this->GetContextId())
-    {
+  {
     this->MakeCurrent();
-
-    // tell each of the renderers that this render window/graphics context
-    // is being removed (the RendererCollection is removed by vtkRenderWindow's
-    // destructor)
-    vtkCollectionSimpleIterator rsit;
-    vtkRenderer *ren;
-    for ( this->Renderers->InitTraversal(rsit);
-          (ren = this->Renderers->GetNextRenderer(rsit));)
-      {
-      ren->SetRenderWindow(NULL);
-      ren->SetRenderWindow(this);
-      }
+    this->ReleaseGraphicsResources(this);
   }
   this->SetContextId(NULL);
   this->SetPixelFormat(NULL);
@@ -112,8 +102,36 @@ void vtkIOSRenderWindow::DestroyWindow()
   this->SetRootWindow(NULL);
 }
 
+int vtkIOSRenderWindow::ReadPixels(
+  const vtkRecti& rect, int front, int glFormat, int glType, void* data, int right)
+{
+  if (glFormat != GL_RGB || glType != GL_UNSIGNED_BYTE)
+  {
+    return this->Superclass::ReadPixels(rect, front, glFormat, glType, data, right);
+  }
+
+  // iOS has issues with getting RGB so we get RGBA
+  unsigned char* uc4data = new unsigned char[rect.GetWidth() * rect.GetHeight() * 4];
+  int retVal = this->Superclass::ReadPixels(rect, front, GL_RGBA, GL_UNSIGNED_BYTE, uc4data, right);
+
+  unsigned char* dPtr = reinterpret_cast<unsigned char*>(data);
+  const unsigned char* lPtr = uc4data;
+  for (int i = 0, height = rect.GetHeight(); i < height; i++)
+  {
+    for (int j = 0, width = rect.GetWidth(); j < width; j++)
+    {
+      *(dPtr++) = *(lPtr++);
+      *(dPtr++) = *(lPtr++);
+      *(dPtr++) = *(lPtr++);
+      lPtr++;
+    }
+  }
+  delete[] uc4data;
+  return retVal;
+}
+
 //----------------------------------------------------------------------------
-void vtkIOSRenderWindow::SetWindowName( const char * _arg )
+void vtkIOSRenderWindow::SetWindowName(const char* _arg)
 {
   vtkWindow::SetWindowName(_arg);
 }
@@ -121,26 +139,19 @@ void vtkIOSRenderWindow::SetWindowName( const char * _arg )
 //----------------------------------------------------------------------------
 bool vtkIOSRenderWindow::InitializeFromCurrentContext()
 {
-  // NSOpenGLContext *currentContext = [NSOpenGLContext currentContext];
-  // if (currentContext != NULL)
-  //   {
-  //   UIView *currentView = [currentContext view];
-  //   if (currentView != NULL)
-  //     {
-  //     UIWindow *window = [currentView window];
-  //     this->SetWindowId(currentView);
-  //     this->SetRootWindow(window);
-  //     this->SetContextId((void*)currentContext);
-  //     this->OpenGLInit();
-  //     this->OwnContext = 0;
-  //     return true;
-  //     }
-  //   }
+  // NSOpenGLContext* currentContext = [NSOpenGLContext currentContext];
+  // if (currentContext != nullptr)
+  // {
+  //   this->SetContextId(currentContext);
+  //   this->SetPixelFormat([currentContext pixelFormat]);
+  //
+  //   return this->Superclass::InitializeFromCurrentContext();
+  //}
   return false;
 }
 
 //----------------------------------------------------------------------------
-int vtkIOSRenderWindow::GetEventPending()
+vtkTypeBool vtkIOSRenderWindow::GetEventPending()
 {
   return 0;
 }
@@ -173,6 +184,7 @@ bool vtkIOSRenderWindow::IsCurrent()
 }
 
 //----------------------------------------------------------------------------
+#ifndef VTK_LEGACY_REMOVE
 bool vtkIOSRenderWindow::IsDrawable()
 {
   // you must initialize it first
@@ -181,27 +193,25 @@ bool vtkIOSRenderWindow::IsDrawable()
 
   return true;
 }
+#endif
 
 //----------------------------------------------------------------------------
-void vtkIOSRenderWindow::UpdateContext()
-{
-}
+void vtkIOSRenderWindow::UpdateContext() {}
 
 //----------------------------------------------------------------------------
 const char* vtkIOSRenderWindow::ReportCapabilities()
 {
   this->MakeCurrent();
 
-  const char* glVendor = (const char*) glGetString(GL_VENDOR);
-  const char* glRenderer = (const char*) glGetString(GL_RENDERER);
-  const char* glVersion = (const char*) glGetString(GL_VERSION);
-  const char* glExtensions = (const char*) glGetString(GL_EXTENSIONS);
+  const char* glVendor = (const char*)glGetString(GL_VENDOR);
+  const char* glRenderer = (const char*)glGetString(GL_RENDERER);
+  const char* glVersion = (const char*)glGetString(GL_VERSION);
+  const char* glExtensions = (const char*)glGetString(GL_EXTENSIONS);
 
-  vtksys_ios::ostringstream strm;
-  strm << "OpenGL vendor string:  " << glVendor
-       << "\nOpenGL renderer string:  " << glRenderer
-       << "\nOpenGL version string:  " << glVersion
-       << "\nOpenGL extensions:  " << glExtensions << endl;
+  std::ostringstream strm;
+  strm << "OpenGL vendor string:  " << glVendor << "\nOpenGL renderer string:  " << glRenderer
+       << "\nOpenGL version string:  " << glVersion << "\nOpenGL extensions:  " << glExtensions
+       << endl;
 
   delete[] this->Capabilities;
 
@@ -217,40 +227,32 @@ int vtkIOSRenderWindow::SupportsOpenGL()
 {
   this->MakeCurrent();
   if (!this->GetContextId() || !this->GetPixelFormat())
-    {
+  {
     return 0;
-    }
+  }
   return 1;
 }
 
 //----------------------------------------------------------------------------
-int vtkIOSRenderWindow::IsDirect()
+vtkTypeBool vtkIOSRenderWindow::IsDirect()
 {
   this->MakeCurrent();
   if (!this->GetContextId() || !this->GetPixelFormat())
-    {
+  {
     return 0;
-    }
+  }
   return 1;
 }
 
 //----------------------------------------------------------------------------
-void vtkIOSRenderWindow::SetSize(int* a)
+void vtkIOSRenderWindow::SetSize(int width, int height)
 {
-  this->SetSize( a[0], a[1] );
-}
-
-//----------------------------------------------------------------------------
-void vtkIOSRenderWindow::SetSize(int x, int y)
-{
-  static int resizing = 0;
-
-  if ((this->Size[0] != x) || (this->Size[1] != y) || (this->GetParentId()))
-    {
+  if ((this->Size[0] != width) || (this->Size[1] != height) || this->GetParentId())
+  {
     this->Modified();
-    this->Size[0] = x;
-    this->Size[1] = y;
-    }
+    this->Size[0] = width;
+    this->Size[1] = height;
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -259,24 +261,15 @@ void vtkIOSRenderWindow::SetForceMakeCurrent()
   this->ForceMakeCurrent = 1;
 }
 
-//----------------------------------------------------------------------------
-void vtkIOSRenderWindow::SetPosition(int* a)
-{
-  this->SetPosition( a[0], a[1] );
-}
-
 //----------------------------------------------------------------------------
 void vtkIOSRenderWindow::SetPosition(int x, int y)
 {
-  static int resizing = 0;
-
-  if ((this->Position[0] != x) || (this->Position[1] != y)
-      || (this->GetParentId()))
-    {
+  if ((this->Position[0] != x) || (this->Position[1] != y) || this->GetParentId())
+  {
     this->Modified();
     this->Position[0] = x;
     this->Position[1] = y;
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -284,76 +277,12 @@ void vtkIOSRenderWindow::SetPosition(int x, int y)
 void vtkIOSRenderWindow::Frame()
 {
   this->MakeCurrent();
+  this->Superclass::Frame();
 
   if (!this->AbortRender && this->DoubleBuffer && this->SwapBuffers)
-    {
-//    [(NSOpenGLContext*)this->GetContextId() flushBuffer];
-    }
-   else
-    {
-    glFlush();
-    }
-}
-
-//----------------------------------------------------------------------------
-// Update system if needed due to stereo rendering.
-void vtkIOSRenderWindow::StereoUpdate()
-{
-  // if stereo is on and it wasn't before
-  if (this->StereoRender && (!this->StereoStatus))
-    {
-    switch (this->StereoType)
-      {
-      case VTK_STEREO_CRYSTAL_EYES:
-        this->StereoStatus = 1;
-        break;
-      case VTK_STEREO_RED_BLUE:
-        this->StereoStatus = 1;
-        break;
-      case VTK_STEREO_ANAGLYPH:
-        this->StereoStatus = 1;
-        break;
-      case VTK_STEREO_DRESDEN:
-        this->StereoStatus = 1;
-        break;
-      case VTK_STEREO_INTERLACED:
-        this->StereoStatus = 1;
-        break;
-      case VTK_STEREO_CHECKERBOARD:
-        this->StereoStatus = 1;
-        break;
-      case VTK_STEREO_SPLITVIEWPORT_HORIZONTAL:
-        this->StereoStatus = 1;
-        break;
-      }
-    }
-  else if ((!this->StereoRender) && this->StereoStatus)
-    {
-    switch (this->StereoType)
-      {
-      case VTK_STEREO_CRYSTAL_EYES:
-        this->StereoStatus = 0;
-        break;
-      case VTK_STEREO_RED_BLUE:
-        this->StereoStatus = 0;
-        break;
-      case VTK_STEREO_ANAGLYPH:
-        this->StereoStatus = 0;
-        break;
-      case VTK_STEREO_DRESDEN:
-        this->StereoStatus = 0;
-        break;
-      case VTK_STEREO_INTERLACED:
-        this->StereoStatus = 0;
-        break;
-      case VTK_STEREO_CHECKERBOARD:
-        this->StereoStatus = 0;
-        break;
-      case VTK_STEREO_SPLITVIEWPORT_HORIZONTAL:
-        this->StereoStatus = 0;
-        break;
-      }
-    }
+  {
+    //    [(NSOpenGLContext*)this->GetContextId() flushBuffer];
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -379,100 +308,95 @@ void vtkIOSRenderWindow::SetupPalette(void*)
 // Initialize the window for rendering.
 void vtkIOSRenderWindow::CreateAWindow()
 {
-  static unsigned count = 1;
-
   this->CreateGLContext();
 
   this->MakeCurrent();
 
   // wipe out any existing display lists
-  vtkRenderer *renderer = NULL;
+  vtkRenderer* renderer = NULL;
   vtkCollectionSimpleIterator rsit;
 
-  for ( this->Renderers->InitTraversal(rsit);
-        (renderer = this->Renderers->GetNextRenderer(rsit));)
-    {
+  for (this->Renderers->InitTraversal(rsit); (renderer = this->Renderers->GetNextRenderer(rsit));)
+  {
     renderer->SetRenderWindow(0);
     renderer->SetRenderWindow(this);
-    }
+  }
   this->OpenGLInit();
   this->Mapped = 1;
 }
 
 //----------------------------------------------------------------------------
-void vtkIOSRenderWindow::CreateGLContext()
-{
-}
+void vtkIOSRenderWindow::CreateGLContext() {}
 
 //----------------------------------------------------------------------------
 // Initialize the rendering window.
-void vtkIOSRenderWindow::Initialize ()
+void vtkIOSRenderWindow::Initialize()
 {
+  this->OpenGLInit();
+  this->Mapped = 1;
 }
 
 //-----------------------------------------------------------------------------
-void vtkIOSRenderWindow::DestroyOffScreenWindow()
-{
-}
+void vtkIOSRenderWindow::DestroyOffScreenWindow() {}
 
 //----------------------------------------------------------------------------
 // Get the current size of the window.
-int *vtkIOSRenderWindow::GetSize()
+int* vtkIOSRenderWindow::GetSize()
 {
-  // if we aren't mapped then just return the ivar
+  // if we aren't mapped then just return call super
   if (!this->Mapped)
-    {
+  {
     return this->Superclass::GetSize();
-    }
+  }
 
   return this->Superclass::GetSize();
 }
 
 //----------------------------------------------------------------------------
 // Get the current size of the screen in pixels.
-int *vtkIOSRenderWindow::GetScreenSize()
+int* vtkIOSRenderWindow::GetScreenSize()
 {
-  return this->Size;
+  // TODO: use UISceen to actually determine screen size.
+
+  return this->ScreenSize;
 }
 
 //----------------------------------------------------------------------------
 // Get the position in screen coordinates of the window.
-int *vtkIOSRenderWindow::GetPosition()
+int* vtkIOSRenderWindow::GetPosition()
 {
   return this->Position;
 }
 
 //----------------------------------------------------------------------------
 // Change the window to fill the entire screen.
-void vtkIOSRenderWindow::SetFullScreen(int arg)
-{
-}
+void vtkIOSRenderWindow::SetFullScreen(vtkTypeBool arg) {}
 
 //----------------------------------------------------------------------------
 //
 // Set the variable that indicates that we want a stereo capable window
 // be created. This method can only be called before a window is realized.
 //
-void vtkIOSRenderWindow::SetStereoCapableWindow(int capable)
+void vtkIOSRenderWindow::SetStereoCapableWindow(vtkTypeBool capable)
 {
   if (this->GetContextId() == 0)
-    {
+  {
     vtkRenderWindow::SetStereoCapableWindow(capable);
-    }
+  }
   else
-    {
+  {
     vtkWarningMacro(<< "Requesting a StereoCapableWindow must be performed "
                     << "before the window is realized, i.e. before a render.");
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
 // Set the preferred window size to full screen.
 void vtkIOSRenderWindow::PrefFullScreen()
 {
-  int *size = this->GetScreenSize();
-  vtkWarningMacro(<< "Can only set FullScreen before showing window: "
-                  << size[0] << 'x' << size[1] << ".");
+  const int* size = this->GetScreenSize();
+  vtkWarningMacro(<< "Can only set FullScreen before showing window: " << size[0] << 'x' << size[1]
+                  << ".");
 }
 
 //----------------------------------------------------------------------------
@@ -488,9 +412,8 @@ void vtkIOSRenderWindow::WindowRemap()
 //----------------------------------------------------------------------------
 void vtkIOSRenderWindow::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 
-  os << indent << "MultiSamples: " << this->MultiSamples << endl;
   os << indent << "RootWindow (UIWindow): " << this->GetRootWindow() << endl;
   os << indent << "WindowId (UIView): " << this->GetWindowId() << endl;
   os << indent << "ParentId: " << this->GetParentId() << endl;
@@ -503,120 +426,109 @@ void vtkIOSRenderWindow::PrintSelf(ostream& os, vtkIndent indent)
 //----------------------------------------------------------------------------
 int vtkIOSRenderWindow::GetDepthBufferSize()
 {
-  if ( this->Mapped )
-    {
+  if (this->Mapped)
+  {
     GLint size = 0;
-    glGetIntegerv( GL_DEPTH_BITS, &size );
-    return (int) size;
-    }
+    glGetIntegerv(GL_DEPTH_BITS, &size);
+    return (int)size;
+  }
   else
-    {
-    vtkDebugMacro(<< "Window is not mapped yet!" );
+  {
+    vtkDebugMacro(<< "Window is not mapped yet!");
     return 24;
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
 // Returns the UIWindow* associated with this vtkRenderWindow.
-void *vtkIOSRenderWindow::GetRootWindow()
+void* vtkIOSRenderWindow::GetRootWindow()
 {
   return NULL;
 }
 
 //----------------------------------------------------------------------------
 // Sets the UIWindow* associated with this vtkRenderWindow.
-void vtkIOSRenderWindow::SetRootWindow(void *vtkNotUsed(arg))
-{
-}
+void vtkIOSRenderWindow::SetRootWindow(void* vtkNotUsed(arg)) {}
 
 //----------------------------------------------------------------------------
 // Returns the UIView* associated with this vtkRenderWindow.
-void *vtkIOSRenderWindow::GetWindowId()
+void* vtkIOSRenderWindow::GetWindowId()
 {
   return NULL;
 }
 
 //----------------------------------------------------------------------------
 // Sets the UIView* associated with this vtkRenderWindow.
-void vtkIOSRenderWindow::SetWindowId(void *vtkNotUsed(arg))
-{
-}
+void vtkIOSRenderWindow::SetWindowId(void* vtkNotUsed(arg)) {}
 
 //----------------------------------------------------------------------------
 // Returns the UIView* that is the parent of this vtkRenderWindow.
-void *vtkIOSRenderWindow::GetParentId()
+void* vtkIOSRenderWindow::GetParentId()
 {
   return NULL;
 }
 
 //----------------------------------------------------------------------------
 // Sets the UIView* that this vtkRenderWindow should use as a parent.
-void vtkIOSRenderWindow::SetParentId(void *vtkNotUsed(arg))
-{
-}
+void vtkIOSRenderWindow::SetParentId(void* vtkNotUsed(arg)) {}
 
 //----------------------------------------------------------------------------
 // Sets the NSOpenGLContext* associated with this vtkRenderWindow.
-void vtkIOSRenderWindow::SetContextId(void *vtkNotUsed(contextId))
-{
-}
+void vtkIOSRenderWindow::SetContextId(void* vtkNotUsed(contextId)) {}
 
 //----------------------------------------------------------------------------
 // Returns the NSOpenGLContext* associated with this vtkRenderWindow.
-void *vtkIOSRenderWindow::GetContextId()
+void* vtkIOSRenderWindow::GetContextId()
 {
   return NULL;
 }
 
 //----------------------------------------------------------------------------
 // Sets the NSOpenGLPixelFormat* associated with this vtkRenderWindow.
-void vtkIOSRenderWindow::SetPixelFormat(void *vtkNotUsed(pixelFormat))
-{
-}
+void vtkIOSRenderWindow::SetPixelFormat(void* vtkNotUsed(pixelFormat)) {}
 
 //----------------------------------------------------------------------------
 // Returns the NSOpenGLPixelFormat* associated with this vtkRenderWindow.
-void *vtkIOSRenderWindow::GetPixelFormat()
+void* vtkIOSRenderWindow::GetPixelFormat()
 {
   return NULL;
 }
 
-
 //----------------------------------------------------------------------------
-void vtkIOSRenderWindow::SetWindowInfo(char *info)
+void vtkIOSRenderWindow::SetWindowInfo(const char* info)
 {
-  // The paramater is an ASCII string of a decimal number representing
+  // The parameter is an ASCII string of a decimal number representing
   // a pointer to the window. Convert it back to a pointer.
   ptrdiff_t tmp = 0;
   if (info)
-    {
+  {
     (void)sscanf(info, "%tu", &tmp);
-    }
+  }
 
-  this->SetWindowId (reinterpret_cast<void *>(tmp));
+  this->SetWindowId(reinterpret_cast<void*>(tmp));
 }
 
 //----------------------------------------------------------------------------
-void vtkIOSRenderWindow::SetParentInfo(char *info)
+void vtkIOSRenderWindow::SetParentInfo(const char* info)
 {
-  // The paramater is an ASCII string of a decimal number representing
+  // The parameter is an ASCII string of a decimal number representing
   // a pointer to the window. Convert it back to a pointer.
   ptrdiff_t tmp = 0;
   if (info)
-    {
+  {
     (void)sscanf(info, "%tu", &tmp);
-    }
+  }
 
-  this->SetParentId (reinterpret_cast<void *>(tmp));
+  this->SetParentId(reinterpret_cast<void*>(tmp));
 }
 
 //----------------------------------------------------------------------------
 void vtkIOSRenderWindow::HideCursor()
 {
   if (this->CursorHidden)
-    {
+  {
     return;
-    }
+  }
   this->CursorHidden = 1;
 }
 
@@ -624,9 +536,9 @@ void vtkIOSRenderWindow::HideCursor()
 void vtkIOSRenderWindow::ShowCursor()
 {
   if (!this->CursorHidden)
-    {
+  {
     return;
-    }
+  }
   this->CursorHidden = 0;
 }
 
@@ -637,16 +549,14 @@ int vtkIOSRenderWindow::GetWindowCreated()
 }
 
 //----------------------------------------------------------------------------
-void vtkIOSRenderWindow::SetCursorPosition(int x, int y)
-{
-}
+void vtkIOSRenderWindow::SetCursorPosition(int x, int y) {}
 
 //----------------------------------------------------------------------------
 void vtkIOSRenderWindow::SetCurrentCursor(int shape)
 {
   if (this->InvokeEvent(vtkCommand::CursorChangedEvent, &shape))
-    {
+  {
     return;
-    }
+  }
   this->Superclass::SetCurrentCursor(shape);
 }
