@@ -18,13 +18,16 @@
 #include "vtkConfigure.h"
 #include "vtkRenderingOpenGLConfigure.h" // For VTK_USE_COCOA
 
+// Must be included before `gl.h` due to glew.
+#include "vtkOpenGLError.h"
+
 // To prevent gl.h to include glext.h provided by the system
 #define GL_GLEXT_LEGACY
 #if defined(__APPLE__) && defined(VTK_USE_COCOA)
-# include <OpenGL/gl.h> // Include OpenGL API.
+#include <OpenGL/gl.h> // Include OpenGL API.
 #else
-# include "vtkWindows.h" // Needed to include OpenGL header on Windows.
-# include <GL/gl.h> // Include OpenGL API.
+#include "vtkWindows.h" // Needed to include OpenGL header on Windows.
+#include <GL/gl.h>      // Include OpenGL API.
 #endif
 
 #endif
