@@ -11,37 +11,41 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
-// .NAME vtkOpenGLLight - OpenGL light
-// .SECTION Description
-// vtkOpenGLLight is a concrete implementation of the abstract class vtkLight.
-// vtkOpenGLLight interfaces to the OpenGL rendering library.
+/**
+ * @class   vtkOpenGLLight
+ * @brief   OpenGL light
+ *
+ * vtkOpenGLLight is a concrete implementation of the abstract class vtkLight.
+ * vtkOpenGLLight interfaces to the OpenGL rendering library.
+ */
 
 #ifndef vtkOpenGLLight_h
 #define vtkOpenGLLight_h
 
-#include "vtkRenderingOpenGL2Module.h" // For export macro
 #include "vtkLight.h"
+#include "vtkRenderingOpenGL2Module.h" // For export macro
 
 class vtkOpenGLRenderer;
 
 class VTKRENDERINGOPENGL2_EXPORT vtkOpenGLLight : public vtkLight
 {
 public:
-  static vtkOpenGLLight *New();
+  static vtkOpenGLLight* New();
   vtkTypeMacro(vtkOpenGLLight, vtkLight);
-  virtual void PrintSelf(ostream& os, vtkIndent indent);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  // Description:
-  // Implement base class method.
-  void Render(vtkRenderer *ren, int light_index);
+  /**
+   * Implement base class method.
+   */
+  void Render(vtkRenderer* ren, int light_index) override;
 
 protected:
   vtkOpenGLLight() {}
-  ~vtkOpenGLLight() {}
+  ~vtkOpenGLLight() override {}
 
 private:
-  vtkOpenGLLight(const vtkOpenGLLight&);  // Not implemented.
-  void operator=(const vtkOpenGLLight&);  // Not implemented.
+  vtkOpenGLLight(const vtkOpenGLLight&) = delete;
+  void operator=(const vtkOpenGLLight&) = delete;
 };
 
 #endif
