@@ -19,38 +19,43 @@
  * vtkGPUVolumeRayCastMapper is a volume mapper that performs ray casting on
  * the GPU using fragment programs.
  *
-*/
-
+ * This mapper supports connections in multiple ports of input 0 (port 0 being
+ * the only required connection). It is up to the concrete implementation
+ * whether additional inputs will be used during rendering. This class maintains
+ * a list of the currently active input ports (Ports) as well as a list of the
+ * ports that have been disconnected (RemovedPorts). RemovedPorts is used the
+ * the concrete implementation to clean up internal structures.
+ *
+ */
 #ifndef vtkGPUVolumeRayCastMapper_h
 #define vtkGPUVolumeRayCastMapper_h
-
-#include <vtkRenderingVolumeModule.h> // For export macro
+#include <unordered_map> // For std::unordered_map
+#include <vector>        // For std::vector
 
 #include "vtkVolumeMapper.h"
+#include <vtkRenderingVolumeModule.h> // For export macro
 
 class vtkContourValues;
 class vtkRenderWindow;
 class vtkVolumeProperty;
 
-//class vtkKWAMRVolumeMapper; // friend class.
-
 class VTKRENDERINGVOLUME_EXPORT vtkGPUVolumeRayCastMapper : public vtkVolumeMapper
 {
 public:
-  static vtkGPUVolumeRayCastMapper *New();
-  vtkTypeMacro(vtkGPUVolumeRayCastMapper,vtkVolumeMapper);
-  void PrintSelf( ostream& os, vtkIndent indent );
+  static vtkGPUVolumeRayCastMapper* New();
+  vtkTypeMacro(vtkGPUVolumeRayCastMapper, vtkVolumeMapper);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
   //@{
   /**
-   * If AutoAdjustSampleDistances is on, the the ImageSampleDistance
+   * If AutoAdjustSampleDistances is on, the ImageSampleDistance
    * will be varied to achieve the allocated render time of this
    * prop (controlled by the desired update rate and any culling in
    * use).
    */
-  vtkSetClampMacro( AutoAdjustSampleDistances, int, 0, 1 );
-  vtkGetMacro( AutoAdjustSampleDistances, int );
-  vtkBooleanMacro( AutoAdjustSampleDistances, int );
+  vtkSetClampMacro(AutoAdjustSampleDistances, vtkTypeBool, 0, 1);
+  vtkGetMacro(AutoAdjustSampleDistances, vtkTypeBool);
+  vtkBooleanMacro(AutoAdjustSampleDistances, vtkTypeBool);
   //@}
 
   //@{
@@ -59,9 +64,9 @@ public:
    * voxels is 8, the sample distance will be roughly 1/200 the average voxel
    * size. The distance will grow proportionally to numVoxels^(1/3). Off by default.
    */
-  vtkSetClampMacro( LockSampleDistanceToInputSpacing, int, 0, 1 );
-  vtkGetMacro( LockSampleDistanceToInputSpacing, int );
-  vtkBooleanMacro( LockSampleDistanceToInputSpacing, int );
+  vtkSetClampMacro(LockSampleDistanceToInputSpacing, vtkTypeBool, 0, 1);
+  vtkGetMacro(LockSampleDistanceToInputSpacing, vtkTypeBool);
+  vtkBooleanMacro(LockSampleDistanceToInputSpacing, vtkTypeBool);
   //@}
 
   //@{
@@ -70,9 +75,9 @@ public:
    * perturbed slightly using a noise-texture to get rid of wood-grain
    * effect.
    */
-  vtkSetClampMacro( UseJittering, int, 0, 1 );
-  vtkGetMacro( UseJittering, int );
-  vtkBooleanMacro( UseJittering, int );
+  vtkSetClampMacro(UseJittering, vtkTypeBool, 0, 1);
+  vtkGetMacro(UseJittering, vtkTypeBool);
+  vtkBooleanMacro(UseJittering, vtkTypeBool);
   //@}
 
   //@{
@@ -84,9 +89,9 @@ public:
    * reasonable contour values to be set which can be set by calling
    * GetDepthPassContourValues() method and using vtkControurValues API.
    */
-  vtkSetClampMacro( UseDepthPass, int, 0, 1 );
-  vtkGetMacro( UseDepthPass, int );
-  vtkBooleanMacro( UseDepthPass, int );
+  vtkSetClampMacro(UseDepthPass, vtkTypeBool, 0, 1);
+  vtkGetMacro(UseDepthPass, vtkTypeBool);
+  vtkBooleanMacro(UseDepthPass, vtkTypeBool);
   //@}
 
   /**
@@ -103,8 +108,8 @@ public:
    * has more than 1 second allocated to it for rendering.
    * Initial value is 1.0.
    */
-  vtkSetMacro( SampleDistance, float );
-  vtkGetMacro( SampleDistance, float );
+  vtkSetMacro(SampleDistance, float);
+  vtkGetMacro(SampleDistance, float);
   //@}
 
   //@{
@@ -115,8 +120,8 @@ public:
    * will be adjusted to meet a desired frame rate when AutoAdjustSampleDistances
    * is on.
    */
-  vtkSetClampMacro( ImageSampleDistance, float, 0.1f, 100.0f );
-  vtkGetMacro( ImageSampleDistance, float );
+  vtkSetClampMacro(ImageSampleDistance, float, 0.1f, 100.0f);
+  vtkGetMacro(ImageSampleDistance, float);
   //@}
 
   //@{
@@ -124,8 +129,8 @@ public:
    * This is the minimum image sample distance allow when the image
    * sample distance is being automatically adjusted.
    */
-  vtkSetClampMacro( MinimumImageSampleDistance, float, 0.1f, 100.0f );
-  vtkGetMacro( MinimumImageSampleDistance, float );
+  vtkSetClampMacro(MinimumImageSampleDistance, float, 0.1f, 100.0f);
+  vtkGetMacro(MinimumImageSampleDistance, float);
   //@}
 
   //@{
@@ -133,11 +138,10 @@ public:
    * This is the maximum image sample distance allow when the image
    * sample distance is being automatically adjusted.
    */
-  vtkSetClampMacro( MaximumImageSampleDistance, float, 0.1f, 100.0f );
-  vtkGetMacro( MaximumImageSampleDistance, float );
+  vtkSetClampMacro(MaximumImageSampleDistance, float, 0.1f, 100.0f);
+  vtkGetMacro(MaximumImageSampleDistance, float);
   //@}
 
-
   //@{
   /**
    * Set/Get the window / level applied to the final color.
@@ -152,10 +156,10 @@ public:
    * |window| can be larger than 1.0
    * level can be any real value.
    */
-  vtkSetMacro( FinalColorWindow, float );
-  vtkGetMacro( FinalColorWindow, float );
-  vtkSetMacro( FinalColorLevel,  float );
-  vtkGetMacro( FinalColorLevel,  float );
+  vtkSetMacro(FinalColorWindow, float);
+  vtkGetMacro(FinalColorWindow, float);
+  vtkSetMacro(FinalColorLevel, float);
+  vtkGetMacro(FinalColorLevel, float);
   //@}
 
   //@{
@@ -164,8 +168,8 @@ public:
    * Will default to the size computed from the graphics
    * card. Can be adjusted by the user.
    */
-  vtkSetMacro( MaxMemoryInBytes, vtkIdType );
-  vtkGetMacro( MaxMemoryInBytes, vtkIdType );
+  vtkSetMacro(MaxMemoryInBytes, vtkIdType);
+  vtkGetMacro(MaxMemoryInBytes, vtkIdType);
   //@}
 
   //@{
@@ -174,8 +178,8 @@ public:
    * be used to hold the texture. Valid values are 0.1 to
    * 1.0.
    */
-  vtkSetClampMacro( MaxMemoryFraction, float, 0.1f, 1.0f );
-  vtkGetMacro( MaxMemoryFraction, float );
+  vtkSetClampMacro(MaxMemoryFraction, float, 0.1f, 1.0f);
+  vtkGetMacro(MaxMemoryFraction, float);
   //@}
 
   //@{
@@ -187,8 +191,8 @@ public:
    * for big dataset or complex shading and streaming but to false for
    * small datasets.
    */
-  vtkSetMacro(ReportProgress,bool);
-  vtkGetMacro(ReportProgress,bool);
+  vtkSetMacro(ReportProgress, bool);
+  vtkGetMacro(ReportProgress, bool);
   //@}
 
   /**
@@ -197,18 +201,14 @@ public:
    * mapping is supported by the hardware, and if the other extensions
    * necessary to support the specific properties are available.
    */
-  virtual int IsRenderSupported(vtkRenderWindow *vtkNotUsed(window),
-                                vtkVolumeProperty *vtkNotUsed(property))
+  virtual int IsRenderSupported(
+    vtkRenderWindow* vtkNotUsed(window), vtkVolumeProperty* vtkNotUsed(property))
   {
-      return 0;
+    return 0;
   }
 
-  void CreateCanonicalView( vtkRenderer *ren,
-                            vtkVolume *volume,
-                            vtkImageData *image,
-                            int blend_mode,
-                            double viewDirection[3],
-                            double viewUp[3] );
+  void CreateCanonicalView(vtkRenderer* ren, vtkVolume* volume, vtkImageData* image, int blend_mode,
+    double viewDirection[3], double viewUp[3]);
 
   //@{
   /**
@@ -219,32 +219,35 @@ public:
    * within the binary mask. The binary mask is assumed to have a datatype of
    * UCHAR and values of 255 (inside) and 0 (outside).
 
-   * The mask may also be a label map. The label map is allowed to contain only
-   * 3 labels (values of 0, 1 and 2) and must have a datatype of UCHAR. In voxels
-   * with label value of 0, the color transfer function supplied by component
-   * 0 is used.
-   * In voxels with label value of 1, the color transfer function supplied by
-   * component 1 is used and blended with the transfer function supplied by
-   * component 0, with the blending weight being determined by
-   * MaskBlendFactor.
-   * In voxels with a label value of 2, the color transfer function supplied
-   * by component 2 is used and blended with the transfer function supplied by
-   * component 0, with the blending weight being determined by
-   * MaskBlendFactor.
+   * The mask may also be a label map. The label map must have a datatype of
+   * UCHAR i.e. it can have upto 256 labels. The label 0 is reserved as a
+   * special label. In voxels with label value of 0, the default transfer
+   * functions supplied by vtkVolumeProperty are used.
+   *
+   * For voxels with a label values greater than 0, the color transfer functions
+   * supplied using vtkVolumeProperty's label API are used.
+   *
+   * For voxels with a label value greater than 0, the color transfer function
+   * is blended with the default color transfer function, with the blending
+   * weight determined by MaskBlendFactor.
    */
-  void SetMaskInput(vtkImageData *mask);
+  void SetMaskInput(vtkImageData* mask);
   vtkGetObjectMacro(MaskInput, vtkImageData);
   //@}
 
-  enum { BinaryMaskType = 0, LabelMapMaskType };
+  enum
+  {
+    BinaryMaskType = 0,
+    LabelMapMaskType
+  };
 
   //@{
   /**
    * Set the mask type, if mask is to be used. See documentation for
    * SetMaskInput(). The default is a LabelMapMaskType.
    */
-  vtkSetMacro( MaskType, int );
-  vtkGetMacro( MaskType, int );
+  vtkSetMacro(MaskType, int);
+  vtkGetMacro(MaskType, int);
   void SetMaskTypeToBinary();
   void SetMaskTypeToLabelMap();
   //@}
@@ -258,8 +261,8 @@ public:
    * 1.0 means only mask color transfer function.
    * The default value is 1.0.
    */
-  vtkSetClampMacro(MaskBlendFactor,float,0.0f,1.0f);
-  vtkGetMacro(MaskBlendFactor,float);
+  vtkSetClampMacro(MaskBlendFactor, float, 0.0f, 1.0f);
+  vtkGetMacro(MaskBlendFactor, float);
   //@}
 
   //@{
@@ -277,9 +280,9 @@ public:
 
    * \sa GetDepthImage(), GetColorImage()
    */
-  vtkSetMacro(RenderToImage, int);
-  vtkGetMacro(RenderToImage, int);
-  vtkBooleanMacro(RenderToImage, int);
+  vtkSetMacro(RenderToImage, vtkTypeBool);
+  vtkGetMacro(RenderToImage, vtkTypeBool);
+  vtkBooleanMacro(RenderToImage, vtkTypeBool);
   //@}
 
   //@{
@@ -307,9 +310,9 @@ public:
    * By default, this is set to 0 (off).
    * \sa SetRenderToImage(), GetDepthImage()
    */
-  vtkSetMacro(ClampDepthToBackface, int);
-  vtkGetMacro(ClampDepthToBackface, int);
-  vtkBooleanMacro(ClampDepthToBackface, int);
+  vtkSetMacro(ClampDepthToBackface, vtkTypeBool);
+  vtkGetMacro(ClampDepthToBackface, vtkTypeBool);
+  vtkBooleanMacro(ClampDepthToBackface, vtkTypeBool);
   //@}
 
   /**
@@ -318,7 +321,7 @@ public:
    * Should be implemented by the graphics API specific mapper (GL or other).
    * \sa SetRenderToImage()
    */
-  virtual void GetDepthImage(vtkImageData*) {};
+  virtual void GetDepthImage(vtkImageData*) {}
 
   /**
    * Low level API to export the color texture as vtkImageData in
@@ -326,19 +329,19 @@ public:
    * Should be implemented by the graphics API specific mapper (GL or other).
    * \sa SetRenderToImage()
    */
-  virtual void GetColorImage(vtkImageData*) {};
+  virtual void GetColorImage(vtkImageData*) {}
 
   /**
    * Initialize rendering for this volume.
    * \warning INTERNAL METHOD - NOT INTENDED FOR GENERAL USE
    */
-  void Render( vtkRenderer *, vtkVolume * );
+  void Render(vtkRenderer*, vtkVolume*) override;
 
   /**
    * Handled in the subclass - the actual render method
    * \pre input is up-to-date.
    */
-  virtual void GPURender( vtkRenderer *, vtkVolume *) {}
+  virtual void GPURender(vtkRenderer*, vtkVolume*) {}
 
   /**
    * Release any graphics resources that are being consumed by this mapper.
@@ -346,7 +349,7 @@ public:
    * resources to release.
    * \warning INTERNAL METHOD - NOT INTENDED FOR GENERAL USE
    */
-  void ReleaseGraphicsResources(vtkWindow *) {}
+  void ReleaseGraphicsResources(vtkWindow*) override {}
 
   /**
    * Return how much the dataset has to be reduced in each dimension to
@@ -360,35 +363,128 @@ public:
    * \post valid_j_ratio: ratio[1]>0 && ratio[1]<=1.0
    * \post valid_k_ratio: ratio[2]>0 && ratio[2]<=1.0
    */
-  virtual void GetReductionRatio(double ratio[3])=0;
+  virtual void GetReductionRatio(double ratio[3]) = 0;
+
+  enum TFRangeType
+  {
+    SCALAR = 0, // default
+    NATIVE
+  };
+
+  //@{
+  /**
+   * Set whether to use the scalar range or the native transfer function range
+   * when looking up transfer functions for color and opacity values. When the
+   * range is set to TransferFunctionRange::SCALAR, the function is distributed
+   * over the entire scalar range. If it is set to
+   * TransferFunctionRange::NATIVE, the scalar values outside the native
+   * transfer function range will be truncated to native range. By
+   * default, the volume scalar range is used.
+   *
+   * \note The native range of the transfer function is the range returned by
+   * vtkColorTransferFunction::GetRange() or vtkPiecewiseFunction::GetRange().
+   *
+   * \note There is no special API provided for 2D transfer functions
+   * considering that they are set as a pre-generated vtkImageData on this
+   * class i.e. the range is already encoded.
+   */
+  vtkSetMacro(ColorRangeType, int);
+  vtkGetMacro(ColorRangeType, int);
+  vtkSetMacro(ScalarOpacityRangeType, int);
+  vtkGetMacro(ScalarOpacityRangeType, int);
+  vtkSetMacro(GradientOpacityRangeType, int);
+  vtkGetMacro(GradientOpacityRangeType, int);
+  //@}
+
+  vtkImageData* GetInput() override { return this->GetInput(0); };
+
+  //@{
+  /**
+   * Add/Remove input connections. Active and removed ports are cached in
+   * Ports and RemovedPorts respectively.
+   */
+  void RemoveInputConnection(int port, vtkAlgorithmOutput* input) override;
+  void RemoveInputConnection(int port, int idx) override;
+  void SetInputConnection(int port, vtkAlgorithmOutput* input) override;
+  void SetInputConnection(vtkAlgorithmOutput* input) override
+  {
+    this->SetInputConnection(0, input);
+  }
+  //@}
+
+  /**
+   * Number of currently active ports.
+   */
+  int GetInputCount();
+
+  vtkImageData* GetTransformedInput(const int port = 0);
+
+  double* GetBoundsFromPort(const int port) VTK_SIZEHINT(6);
 
 protected:
   vtkGPUVolumeRayCastMapper();
-  ~vtkGPUVolumeRayCastMapper();
+  ~vtkGPUVolumeRayCastMapper() override;
 
-  // Check to see that the render will be OK
-  int ValidateRender( vtkRenderer *, vtkVolume * );
+  /**
+   * Handle inputs. This mapper provides an interface to support multiple
+   * inputs but it is up to the OpenGL implementation use them during rendering.
+   * Currently, only VolumeOpenGL2/vtkOpenGLGPUVolumeRayCastMapper makes use
+   * of these inputs.
+   *
+   * \sa vtkOpenGLGPUVolumeRayCastMapper vtkMultiVolume
+   */
+  int FillInputPortInformation(int port, vtkInformation* info) override;
 
+  /**
+   * A transformation is applied (translation) to the input.  The resulting
+   * data is stored in TransformedInputs. Takes as an argumet the port of an
+   * input connection.
+   *
+   * ///TODO Elaborate on why this is an issue, texture coords (?)
+   * @TODO: This is the workaround to deal with GPUVolumeRayCastMapper
+   * not able to handle extents starting from non zero values.
+   * There is not a easy fix in the GPU volume ray cast mapper hence
+   * this fix has been introduced.
+   */
+  void TransformInput(const int port);
+
+  //@{
+  /**
+   * This method is used by the Render() method to validate everything before
+   * attempting to render. This method returns 0 if something is not right -
+   * such as missing input, a null renderer or a null volume, no scalars, etc.
+   * In some cases it will produce a vtkErrorMacro message, and in others
+   * (for example, in the case of cropping planes that define a region with
+   * a volume or 0 or less) it will fail silently. If everything is OK, it will
+   * return with a value of 1.
+   */
+  int ValidateRender(vtkRenderer*, vtkVolume*);
+  int ValidateInputs();
+  int ValidateInput(vtkVolumeProperty* property, const int port);
+  //@}
+
+  //@{
+  /**
+   * Shallow-copy the inputs into a transform-adjusted clone.
+   * \sa vtkGPUVolumeRayCastMapper::TransformInput
+   */
+  void CloneInputs();
+  void CloneInput(vtkImageData* input, const int port);
+  //@}
 
   // Special version of render called during the creation
   // of a canonical view.
-  void CanonicalViewRender( vtkRenderer *, vtkVolume * );
+  void CanonicalViewRender(vtkRenderer*, vtkVolume*);
 
   // Methods called by the AMR Volume Mapper.
-  virtual void PreRender(vtkRenderer *ren,
-                         vtkVolume *vol,
-                         double datasetBounds[6],
-                         double scalarRange[2],
-                         int numberOfScalarComponents,
-                         unsigned int numberOfLevels)=0;
+  virtual void PreRender(vtkRenderer* ren, vtkVolume* vol, double datasetBounds[6],
+    double scalarRange[2], int numberOfScalarComponents, unsigned int numberOfLevels) = 0;
 
   // \pre input is up-to-date
-  virtual void RenderBlock(vtkRenderer *ren,
-                           vtkVolume *vol,
-                           unsigned int level)=0;
+  virtual void RenderBlock(vtkRenderer* ren, vtkVolume* vol, unsigned int level) = 0;
 
-  virtual void PostRender(vtkRenderer *ren,
-                          int numberOfScalarComponents)=0;
+  virtual void PostRender(vtkRenderer* ren, int numberOfScalarComponents) = 0;
+  vtkImageData* GetInput(const int port) override;
 
   /**
    * Called by the AMR Volume Mapper.
@@ -396,34 +492,35 @@ protected:
    * cell data (1).
    */
   void SetCellFlag(int cellFlag);
+  void RemovePortInternal(const int port);
 
-  int LockSampleDistanceToInputSpacing;
-  int    AutoAdjustSampleDistances;
-  float  ImageSampleDistance;
-  float  MinimumImageSampleDistance;
-  float  MaximumImageSampleDistance;
+  vtkTypeBool LockSampleDistanceToInputSpacing;
+  vtkTypeBool AutoAdjustSampleDistances;
+  float ImageSampleDistance;
+  float MinimumImageSampleDistance;
+  float MaximumImageSampleDistance;
 
   // Render to texture mode flag
-  int RenderToImage;
+  vtkTypeBool RenderToImage;
 
   // Depth image scalar type
   int DepthImageScalarType;
 
   // Clamp depth values to the depth of the face at which the ray
   // exits the volume
-  int ClampDepthToBackface;
+  vtkTypeBool ClampDepthToBackface;
 
   // Enable / disable stochastic jittering
-  int UseJittering;
+  vtkTypeBool UseJittering;
 
   // Enable / disable two pass rendering
-  int UseDepthPass;
+  vtkTypeBool UseDepthPass;
   vtkContourValues* DepthPassContourValues;
 
   // The distance between sample points along the ray
-  float  SampleDistance;
+  float SampleDistance;
 
-  int    SmallVolumeRender;
+  int SmallVolumeRender;
   double BigTimeToDraw;
   double SmallTimeToDraw;
 
@@ -431,24 +528,29 @@ protected:
   float FinalColorLevel;
 
   // 1 if we are generating the canonical image, 0 otherwise
-  int   GeneratingCanonicalView;
-  vtkImageData *CanonicalViewImageData;
+  int GeneratingCanonicalView;
+  vtkImageData* CanonicalViewImageData;
 
   //@{
   /**
    * Set the mapper in AMR Mode or not. Initial value is false.
    * Called only by the vtkKWAMRVolumeMapper
    */
-  vtkSetClampMacro(AMRMode,int,0,1);
-  vtkGetMacro(AMRMode,int);
-  vtkBooleanMacro(AMRMode,int);
+  vtkSetClampMacro(AMRMode, vtkTypeBool, 0, 1);
+  vtkGetMacro(AMRMode, vtkTypeBool);
+  vtkBooleanMacro(AMRMode, vtkTypeBool);
   //@}
 
-  vtkImageData * MaskInput;
-  float          MaskBlendFactor;
-  int            MaskType;
+  vtkImageData* MaskInput;
+  float MaskBlendFactor;
+  int MaskType;
 
-  int AMRMode;
+  vtkTypeBool AMRMode;
+
+  // Transfer function range type
+  int ColorRangeType;
+  int ScalarOpacityRangeType;
+  int GradientOpacityRangeType;
 
   // Point data or cell data (or field data, not handled) ?
   int CellFlag;
@@ -467,28 +569,29 @@ protected:
    */
   virtual void ClipCroppingRegionPlanes();
 
-  double         ClippedCroppingRegionPlanes[6];
+  using DataMap = std::unordered_map<int, vtkImageData*>;
+  void SetTransformedInput(vtkImageData*);
+  vtkImageData* FindData(int port, DataMap& container);
+
+  double ClippedCroppingRegionPlanes[6];
 
   vtkIdType MaxMemoryInBytes;
   float MaxMemoryFraction;
 
-  bool           ReportProgress;
-
-  vtkImageData * TransformedInput;
-
-  vtkGetObjectMacro(TransformedInput, vtkImageData);
-  void SetTransformedInput(vtkImageData*);
+  bool ReportProgress;
+  std::vector<int> Ports;
+  std::vector<int> RemovedPorts;
+  DataMap TransformedInputs;
 
   /**
    * This is needed only to check if the input data has been changed since the last
    * Render() call.
    */
-  vtkImageData* LastInput;
+  DataMap LastInputs;
 
 private:
-  vtkGPUVolumeRayCastMapper(const vtkGPUVolumeRayCastMapper&) VTK_DELETE_FUNCTION;
-  void operator=(const vtkGPUVolumeRayCastMapper&) VTK_DELETE_FUNCTION;
+  vtkGPUVolumeRayCastMapper(const vtkGPUVolumeRayCastMapper&) = delete;
+  void operator=(const vtkGPUVolumeRayCastMapper&) = delete;
 };
 
 #endif
-
