@@ -14,30 +14,29 @@
 =========================================================================*/
 #include "vtkTesting.h"
 
-#include "vtkObjectFactory.h"
-#include "vtkWindowToImageFilter.h"
-#include "vtkPNGReader.h"
-#include "vtkPNGWriter.h"
-#include "vtkImageShiftScale.h"
-#include "vtkImageDifference.h"
-#include "vtkRenderWindow.h"
-#include "vtkImageData.h"
-#include "vtkTimerLog.h"
-#include "vtkNew.h"
-#include "vtkRenderWindowInteractor.h"
-#include "vtkInteractorEventRecorder.h"
-#include "vtkImageClip.h"
-#include "vtkToolkits.h"
-#include "vtkDataSet.h"
-#include "vtkPointSet.h"
-#include "vtkPointData.h"
 #include "vtkDataArray.h"
+#include "vtkDataSet.h"
 #include "vtkDoubleArray.h"
 #include "vtkFloatArray.h"
-#include "vtkStreamingDemandDrivenPipeline.h"
+#include "vtkImageClip.h"
+#include "vtkImageData.h"
+#include "vtkImageDifference.h"
+#include "vtkImageExtractComponents.h"
+#include "vtkImageShiftScale.h"
 #include "vtkInformation.h"
-
-#include <sys/stat.h>
+#include "vtkInteractorEventRecorder.h"
+#include "vtkNew.h"
+#include "vtkObjectFactory.h"
+#include "vtkPNGReader.h"
+#include "vtkPNGWriter.h"
+#include "vtkPointData.h"
+#include "vtkPointSet.h"
+#include "vtkRenderWindow.h"
+#include "vtkRenderWindowInteractor.h"
+#include "vtkStreamingDemandDrivenPipeline.h"
+#include "vtkTimerLog.h"
+#include "vtkToolkits.h"
+#include "vtkWindowToImageFilter.h"
 
 #include <sstream>
 #include <vtksys/SystemTools.hxx>
@@ -45,22 +44,22 @@
 vtkStandardNewMacro(vtkTesting);
 vtkCxxSetObjectMacro(vtkTesting, RenderWindow, vtkRenderWindow);
 
-using std::vector;
 using std::string;
+using std::vector;
 
 //-----------------------------------------------------------------------------
 // Find in command tail, failing that find in environment,
 // failing that return a default.
 // Up to caller to delete the string returned.
 static string vtkTestingGetArgOrEnvOrDefault(
-          string argName,       // argument idnetifier flag. eg "-D"
-          vector<string> &argv, // command tail
-          string env,           // environment variable name to find
-          string def)           // default to use if "env" is not found.
+  const string& argName, // argument idnetifier flag. eg "-D"
+  vector<string>& argv,  // command tail
+  const string& env,     // environment variable name to find
+  const string& def)     // default to use if "env" is not found.
 {
   string argValue;
 
-  // Serach command tail.
+  // Search command tail.
   int argc = static_cast<int>(argv.size());
   for (int i = 0; i < argc; i++)
   {
@@ -70,10 +69,9 @@ static string vtkTestingGetArgOrEnvOrDefault(
     }
   }
   // If not found search environment.
-  if (argValue.empty()
-      && !(env.empty() || def.empty()))
+  if (argValue.empty() && !(env.empty() || def.empty()))
   {
-    char *foundenv=getenv(env.c_str());
+    char* foundenv = getenv(env.c_str());
     if (foundenv)
     {
       argValue = foundenv;
@@ -88,19 +86,17 @@ static string vtkTestingGetArgOrEnvOrDefault(
   return argValue;
 }
 
-
 //-----------------------------------------------------------------------------
 // Description:
 // Sum the L2 Norm point wise over all tuples. Each term
 // is scaled by the magnitude of one of the inputs.
 // Return sum and the number of terms.
 template <class T>
-vtkIdType AccumulateScaledL2Norm(
-        T *pA,           // pointer to first data array
-        T *pB,           // pointer to second data array
-        vtkIdType nTups, // number of tuples
-        int nComps,      // number of comps
-        double &SumModR) // result
+vtkIdType AccumulateScaledL2Norm(T* pA, // pointer to first data array
+  T* pB,                                // pointer to second data array
+  vtkIdType nTups,                      // number of tuples
+  int nComps,                           // number of comps
+  double& SumModR)                      // result
 {
   //
   SumModR = 0.0;
@@ -117,7 +113,7 @@ vtkIdType AccumulateScaledL2Norm(
       modR += r * r;
     }
     modA = sqrt(modA);
-    modA = modA<1.0 ? 1.0 : modA;
+    modA = modA < 1.0 ? 1.0 : modA;
     SumModR += sqrt(modR) / modA;
     pA += nComps;
     pB += nComps;
@@ -129,11 +125,11 @@ vtkIdType AccumulateScaledL2Norm(
 vtkTesting::vtkTesting()
 {
   this->FrontBuffer = 0;
-  this->RenderWindow = 0;
-  this->ValidImageFileName = 0;
+  this->RenderWindow = nullptr;
+  this->ValidImageFileName = nullptr;
   this->ImageDifference = 0;
-  this->DataRoot = 0;
-  this->TempDirectory = 0;
+  this->DataRoot = nullptr;
+  this->TempDirectory = nullptr;
   this->BorderOffset = 0;
   this->Verbose = 0;
 
@@ -145,20 +141,20 @@ vtkTesting::vtkTesting()
 //-----------------------------------------------------------------------------
 vtkTesting::~vtkTesting()
 {
-  this->SetRenderWindow(0);
-  this->SetValidImageFileName(0);
-  this->SetDataRoot(0);
-  this->SetTempDirectory(0);
+  this->SetRenderWindow(nullptr);
+  this->SetValidImageFileName(nullptr);
+  this->SetDataRoot(nullptr);
+  this->SetTempDirectory(nullptr);
 }
 
 //-----------------------------------------------------------------------------
-void vtkTesting::AddArgument(const char *arg)
+void vtkTesting::AddArgument(const char* arg)
 {
   this->Args.push_back(arg);
 }
 
 //-----------------------------------------------------------------------------
-void vtkTesting::AddArguments(int argc, const char **argv)
+void vtkTesting::AddArguments(int argc, const char** argv)
 {
   for (int i = 0; i < argc; ++i)
   {
@@ -167,7 +163,7 @@ void vtkTesting::AddArguments(int argc, const char **argv)
 }
 
 //-----------------------------------------------------------------------------
-void vtkTesting::AddArguments(int argc, char **argv)
+void vtkTesting::AddArguments(int argc, char** argv)
 {
   for (int i = 0; i < argc; ++i)
   {
@@ -176,12 +172,11 @@ void vtkTesting::AddArguments(int argc, char **argv)
 }
 
 //-----------------------------------------------------------------------------
-char *vtkTesting::GetArgument(const char *argName)
+char* vtkTesting::GetArgument(const char* argName)
 {
-  string argValue
-    = vtkTestingGetArgOrEnvOrDefault(argName, this->Args, "", "");
+  string argValue = vtkTestingGetArgOrEnvOrDefault(argName, this->Args, "", "");
 
-  char *cArgValue = new char[argValue.size() + 1];
+  char* cArgValue = new char[argValue.size() + 1];
   strcpy(cArgValue, argValue.c_str());
 
   return cArgValue;
@@ -189,56 +184,53 @@ char *vtkTesting::GetArgument(const char *argName)
 //-----------------------------------------------------------------------------
 void vtkTesting::CleanArguments()
 {
-  this->Args.erase( this->Args.begin(), this->Args.end() );
+  this->Args.erase(this->Args.begin(), this->Args.end());
 }
 //-----------------------------------------------------------------------------
-const char *vtkTesting::GetDataRoot()
+const char* vtkTesting::GetDataRoot()
 {
 #ifdef VTK_DATA_ROOT
-  string dr=vtkTestingGetArgOrEnvOrDefault(
-                "-D",this->Args,"VTK_DATA_ROOT",VTK_DATA_ROOT);
+  string dr = vtkTestingGetArgOrEnvOrDefault("-D", this->Args, "VTK_DATA_ROOT", VTK_DATA_ROOT);
 #else
-  string dr=vtkTestingGetArgOrEnvOrDefault(
-                "-D",this->Args, "VTK_DATA_ROOT","../../../../VTKData");
+  string dr =
+    vtkTestingGetArgOrEnvOrDefault("-D", this->Args, "VTK_DATA_ROOT", "../../../../VTKData");
 #endif
-  this->SetDataRoot(
-     vtksys::SystemTools::CollapseFullPath(dr.c_str()).c_str());
+  this->SetDataRoot(vtksys::SystemTools::CollapseFullPath(dr).c_str());
 
   return this->DataRoot;
 }
 //-----------------------------------------------------------------------------
-const char *vtkTesting::GetTempDirectory()
+const char* vtkTesting::GetTempDirectory()
 {
-  string td=vtkTestingGetArgOrEnvOrDefault(
-                "-T",this->Args, "VTK_TEMP_DIR","../../../Testing/Temporary");
-  this->SetTempDirectory(
-    vtksys::SystemTools::CollapseFullPath(td.c_str()).c_str());
+  string td =
+    vtkTestingGetArgOrEnvOrDefault("-T", this->Args, "VTK_TEMP_DIR", "../../../Testing/Temporary");
+  this->SetTempDirectory(vtksys::SystemTools::CollapseFullPath(td).c_str());
 
   return this->TempDirectory;
 }
 //-----------------------------------------------------------------------------
-const char *vtkTesting::GetValidImageFileName()
+const char* vtkTesting::GetValidImageFileName()
 {
-  this->SetValidImageFileName(0);
+  this->SetValidImageFileName(nullptr);
   if (!this->IsValidImageSpecified())
   {
     return this->ValidImageFileName;
   }
 
-  string baseline=vtkTestingGetArgOrEnvOrDefault(
-                "-B", this->Args,"VTK_BASELINE_ROOT", this->GetDataRoot());
+  string baseline =
+    vtkTestingGetArgOrEnvOrDefault("-B", this->Args, "VTK_BASELINE_ROOT", this->GetDataRoot());
 
   for (size_t i = 0; i < (this->Args.size() - 1); ++i)
   {
     if (this->Args[i] == "-V")
     {
-      const char *ch = this->Args[i + 1].c_str();
+      const char* ch = this->Args[i + 1].c_str();
       if (ch[0] == '/'
 #ifdef _WIN32
-        || (ch[0] >= 'a' && ch[0] <= 'z' && ch[1] == ':')
-        || (ch[0] >= 'A' && ch[0] <= 'Z' && ch[1] == ':')
+        || (ch[0] >= 'a' && ch[0] <= 'z' && ch[1] == ':') ||
+        (ch[0] >= 'A' && ch[0] <= 'Z' && ch[1] == ':')
 #endif
-        )
+      )
       {
         baseline = this->Args[i + 1];
       }
@@ -268,7 +260,7 @@ int vtkTesting::IsInteractiveModeSpecified()
   return 0;
 }
 //-----------------------------------------------------------------------------
-int vtkTesting::IsFlagSpecified(const char *flag)
+int vtkTesting::IsFlagSpecified(const char* flag)
 {
   for (size_t i = 0; i < this->Args.size(); ++i)
   {
@@ -284,7 +276,7 @@ int vtkTesting::IsValidImageSpecified()
 {
   for (size_t i = 1; i < this->Args.size(); ++i)
   {
-    if (this->Args[i-1] == "-V")
+    if (this->Args[i - 1] == "-V")
     {
       return 1;
     }
@@ -295,12 +287,12 @@ int vtkTesting::IsValidImageSpecified()
 char* vtkTesting::IncrementFileName(const char* fname, int count)
 {
   char counts[256];
-  sprintf(counts, "%d", count);
+  snprintf(counts, sizeof(counts), "%d", count);
 
   int orgLen = static_cast<int>(strlen(fname));
   if (orgLen < 5)
   {
-    return 0;
+    return nullptr;
   }
   int extLen = static_cast<int>(strlen(counts));
   char* newFileName = new char[orgLen + extLen + 2];
@@ -308,8 +300,7 @@ char* vtkTesting::IncrementFileName(const char* fname, int count)
 
   newFileName[orgLen - 4] = '_';
   int i, marker;
-  for (marker = orgLen - 3, i = 0; marker < orgLen - 3 + extLen;
-       marker++, i++)
+  for (marker = orgLen - 3, i = 0; marker < orgLen - 3 + extLen; marker++, i++)
   {
     newFileName[marker] = counts[i];
   }
@@ -324,8 +315,8 @@ int vtkTesting::LookForFile(const char* newFileName)
   {
     return 0;
   }
-  struct stat fs;
-  if (stat(newFileName, &fs) != 0)
+  vtksys::SystemTools::Stat_t fs;
+  if (vtksys::SystemTools::Stat(newFileName, &fs) != 0)
   {
     return 0;
   }
@@ -336,7 +327,7 @@ int vtkTesting::LookForFile(const char* newFileName)
 }
 
 //-----------------------------------------------------------------------------
-void vtkTesting::SetFrontBuffer(int frontBuffer)
+void vtkTesting::SetFrontBuffer(vtkTypeBool frontBuffer)
 {
   vtkWarningMacro("SetFrontBuffer method is deprecated and has no effet anymore.");
   this->FrontBuffer = frontBuffer;
@@ -357,7 +348,7 @@ int vtkTesting::RegressionTest(vtkAlgorithm* imageSource, double thresh)
   return result;
 }
 //-----------------------------------------------------------------------------
-int vtkTesting::RegressionTestAndCaptureOutput(double thresh, ostream &os)
+int vtkTesting::RegressionTestAndCaptureOutput(double thresh, ostream& os)
 {
   int result = this->RegressionTest(thresh, os);
 
@@ -377,7 +368,7 @@ int vtkTesting::RegressionTest(double thresh)
   return result;
 }
 //-----------------------------------------------------------------------------
-int vtkTesting::RegressionTest(double thresh, ostream &os)
+int vtkTesting::RegressionTest(double thresh, ostream& os)
 {
   vtkNew<vtkWindowToImageFilter> rtW2if;
   rtW2if->SetInput(this->RenderWindow);
@@ -397,35 +388,40 @@ int vtkTesting::RegressionTest(double thresh, ostream &os)
 
   std::ostringstream out1;
   // perform and extra render to make sure it is displayed
+  int swapBuffers = this->RenderWindow->GetSwapBuffers();
+  // since we're reading from back-buffer, it's essential that we turn off swapping
+  // otherwise what remains in the back-buffer after the swap is undefined by OpenGL specs.
+  this->RenderWindow->SwapBuffersOff();
   this->RenderWindow->Render();
   rtW2if->ReadFrontBufferOff();
   rtW2if->Update();
-  int res = this->RegressionTest(rtW2if.Get(), thresh, out1);
+  this->RenderWindow->SetSwapBuffers(swapBuffers); // restore swap state.
+  int res = this->RegressionTest(rtW2if, thresh, out1);
   if (res == FAILED)
   {
-      std::ostringstream out2;
-      // tell it to read front buffer
-      rtW2if->ReadFrontBufferOn();
+    std::ostringstream out2;
+    // tell it to read front buffer
+    rtW2if->ReadFrontBufferOn();
+    rtW2if->Update();
+    res = this->RegressionTest(rtW2if, thresh, out2);
+    // If both tests fail, rerun the backbuffer tests to recreate the test
+    // image. Otherwise an incorrect image will be uploaded to CDash.
+    if (res == PASSED)
+    {
+      os << out2.str();
+    }
+    else
+    {
+      // we failed both back and front buffers so
+      // to help us debug, write out renderwindow capabilities
+      if (this->RenderWindow)
+      {
+        os << this->RenderWindow->ReportCapabilities();
+      }
+      rtW2if->ReadFrontBufferOff();
       rtW2if->Update();
-      res = this->RegressionTest(rtW2if.Get(), thresh, out2);
-      // If both tests fail, rerun the backbuffer tests to recreate the test
-      // image. Otherwise an incorrect image will be uploaded to CDash.
-      if (res == PASSED)
-      {
-        os << out2.str();
-      }
-      else
-      {
-        // we failed both back and front buffers so
-        // to help us debug, write out renderwindow capabilities
-        if (this->RenderWindow)
-        {
-          os << this->RenderWindow->ReportCapabilities();
-        }
-        rtW2if->ReadFrontBufferOff();
-        rtW2if->Update();
-        return this->RegressionTest(rtW2if.Get(), thresh, os);
-      }
+      return this->RegressionTest(rtW2if, thresh, os);
+    }
   }
   else
   {
@@ -434,23 +430,34 @@ int vtkTesting::RegressionTest(double thresh, ostream &os)
   return res;
 }
 //-----------------------------------------------------------------------------
-int vtkTesting::RegressionTest(const string &pngFileName, double thresh)
+int vtkTesting::RegressionTest(const string& pngFileName, double thresh)
 {
   return this->RegressionTest(pngFileName, thresh, cout);
 }
 //-----------------------------------------------------------------------------
-int vtkTesting::RegressionTest(const string &pngFileName, double thresh,
-                               ostream &os)
+int vtkTesting::RegressionTest(const string& pngFileName, double thresh, ostream& os)
 {
   vtkNew<vtkPNGReader> inputReader;
   inputReader->SetFileName(pngFileName.c_str());
   inputReader->Update();
-  return this->RegressionTest(inputReader.GetPointer(), thresh, os);
+
+  vtkAlgorithm* src = inputReader;
+
+  vtkSmartPointer<vtkImageExtractComponents> extract;
+  // Convert rgba to rgb if needed
+  if (inputReader->GetOutput() && inputReader->GetOutput()->GetNumberOfScalarComponents() == 4)
+  {
+    extract = vtkSmartPointer<vtkImageExtractComponents>::New();
+    extract->SetInputConnection(src->GetOutputPort());
+    extract->SetComponents(0, 1, 2);
+    extract->Update();
+    src = extract;
+  }
+
+  return this->RegressionTest(src, thresh, os);
 }
 //-----------------------------------------------------------------------------
-int vtkTesting::RegressionTest(vtkAlgorithm* imageSource,
-                               double thresh,
-                               ostream& os)
+int vtkTesting::RegressionTest(vtkAlgorithm* imageSource, double thresh, ostream& os)
 {
   // do a get to compute the real value
   this->GetValidImageFileName();
@@ -458,14 +465,18 @@ int vtkTesting::RegressionTest(vtkAlgorithm* imageSource,
 
   // construct the names for the error images
   string validName = this->ValidImageFileName;
-  string::size_type slashPos = validName.rfind("/");
+  string::size_type slashPos = validName.rfind('/');
   if (slashPos != string::npos)
   {
     validName = validName.substr(slashPos + 1);
   }
 
+  // We want to print the filename of the best matching image for better
+  // comparisons in CDash:
+  string bestImageFileName = this->ValidImageFileName;
+
   // check the valid image
-  FILE *rtFin = fopen(this->ValidImageFileName, "r");
+  FILE* rtFin = vtksys::SystemTools::Fopen(this->ValidImageFileName, "r");
   if (rtFin)
   {
     fclose(rtFin);
@@ -473,7 +484,7 @@ int vtkTesting::RegressionTest(vtkAlgorithm* imageSource,
   else // there was no valid image, so write one to the temp dir
   {
     string vImage = tmpDir + "/" + validName;
-    rtFin = fopen(vImage.c_str(), "wb");
+    rtFin = vtksys::SystemTools::Fopen(vImage, "wb");
     if (rtFin)
     {
       fclose(rtFin);
@@ -484,7 +495,7 @@ int vtkTesting::RegressionTest(vtkAlgorithm* imageSource,
       os << "<DartMeasurement name=\"ImageNotFound\" type=\"text/string\">"
          << this->ValidImageFileName << "</DartMeasurement>" << endl;
       // Write out the image upload tag for the test image.
-      os <<  "<DartMeasurementFile name=\"TestImage\" type=\"image/png\">";
+      os << "<DartMeasurementFile name=\"TestImage\" type=\"image/png\">";
       os << vImage;
       os << "</DartMeasurementFile>";
     }
@@ -495,10 +506,16 @@ int vtkTesting::RegressionTest(vtkAlgorithm* imageSource,
     return FAILED;
   }
 
+  imageSource->Update();
+
   vtkNew<vtkPNGReader> rtPng;
   rtPng->SetFileName(this->ValidImageFileName);
   rtPng->Update();
-  imageSource->Update();
+
+  vtkNew<vtkImageExtractComponents> rtExtract;
+  rtExtract->SetInputConnection(rtPng->GetOutputPort());
+  rtExtract->SetComponents(0, 1, 2);
+  rtExtract->Update();
 
   vtkNew<vtkImageDifference> rtId;
 
@@ -508,25 +525,15 @@ int vtkTesting::RegressionTest(vtkAlgorithm* imageSource,
 
   vtkNew<vtkImageClip> ic2;
   ic2->SetClipData(1);
-  ic2->SetInputConnection(rtPng->GetOutputPort());
+  ic2->SetInputConnection(rtExtract->GetOutputPort());
 
-  int* wExt1 = ic1->GetInputInformation()->Get(
-    vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT());
-  int* wExt2 = ic2->GetInputInformation()->Get(
-    vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT());
-  ic1->SetOutputWholeExtent(wExt1[0] + this->BorderOffset,
-                            wExt1[1] - this->BorderOffset,
-                            wExt1[2] + this->BorderOffset,
-                            wExt1[3] - this->BorderOffset,
-                            wExt1[4],
-                            wExt1[5]);
+  int* wExt1 = ic1->GetInputInformation()->Get(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT());
+  int* wExt2 = ic2->GetInputInformation()->Get(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT());
+  ic1->SetOutputWholeExtent(wExt1[0] + this->BorderOffset, wExt1[1] - this->BorderOffset,
+    wExt1[2] + this->BorderOffset, wExt1[3] - this->BorderOffset, wExt1[4], wExt1[5]);
 
-  ic2->SetOutputWholeExtent(wExt2[0] + this->BorderOffset,
-                            wExt2[1] - this->BorderOffset,
-                            wExt2[2] + this->BorderOffset,
-                            wExt2[3] - this->BorderOffset,
-                            wExt2[4],
-                            wExt2[5]);
+  ic2->SetOutputWholeExtent(wExt2[0] + this->BorderOffset, wExt2[1] - this->BorderOffset,
+    wExt2[2] + this->BorderOffset, wExt2[3] - this->BorderOffset, wExt2[4], wExt2[5]);
 
   int ext1[6], ext2[6];
   rtId->SetInputConnection(ic1->GetOutputPort());
@@ -538,9 +545,8 @@ int vtkTesting::RegressionTest(vtkAlgorithm* imageSource,
 
   double minError = VTK_DOUBLE_MAX;
 
-  if ((ext2[1]-ext2[0]) == (ext1[1]-ext1[0]) &&
-      (ext2[3]-ext2[2]) == (ext1[3]-ext1[2]) &&
-      (ext2[5]-ext2[4]) == (ext1[5]-ext1[4]))
+  if ((ext2[1] - ext2[0]) == (ext1[1] - ext1[0]) && (ext2[3] - ext2[2]) == (ext1[3] - ext1[2]) &&
+    (ext2[5] - ext2[4]) == (ext1[5] - ext1[4]))
   {
     // Cannot compute difference unless image sizes are the same
     rtId->Update();
@@ -558,7 +564,7 @@ int vtkTesting::RegressionTest(vtkAlgorithm* imageSource,
     {
       int dims[3];
       output->GetDimensions(dims);
-      if(dims[0] * dims[1] * dims[2] > 0)
+      if (dims[0] * dims[1] * dims[2] > 0)
       {
         passed = 1;
       }
@@ -593,18 +599,13 @@ int vtkTesting::RegressionTest(vtkAlgorithm* imageSource,
     // Need to reset the output whole extent cause we may have baselines
     // of differing sizes. (Yes, we have such cases !)
     ic2->ResetOutputWholeExtent();
-    ic2->SetOutputWholeExtent(wExt2[0] + this->BorderOffset,
-                              wExt2[1] - this->BorderOffset,
-                              wExt2[2] + this->BorderOffset,
-                              wExt2[3] - this->BorderOffset,
-                              wExt2[4],
-                              wExt2[5]);
+    ic2->SetOutputWholeExtent(wExt2[0] + this->BorderOffset, wExt2[1] - this->BorderOffset,
+      wExt2[2] + this->BorderOffset, wExt2[3] - this->BorderOffset, wExt2[4], wExt2[5]);
     ic2->UpdateWholeExtent();
 
     rtId->GetImage()->GetExtent(ext2);
-    if ((ext2[1] - ext2[0]) == (ext1[1] - ext1[0]) &&
-        (ext2[3] - ext2[2]) == (ext1[3] - ext1[2]) &&
-        (ext2[5] - ext2[4]) == (ext1[5] - ext1[4]))
+    if ((ext2[1] - ext2[0]) == (ext1[1] - ext1[0]) && (ext2[3] - ext2[2]) == (ext1[3] - ext1[2]) &&
+      (ext2[5] - ext2[4]) == (ext1[5] - ext1[4]))
     {
       // Cannot compute difference unless image sizes are the same
       rtId->Update();
@@ -637,6 +638,7 @@ int vtkTesting::RegressionTest(vtkAlgorithm* imageSource,
       {
         errIndex = count;
         minError = error;
+        bestImageFileName = newFileName;
       }
     }
     ++count;
@@ -655,7 +657,7 @@ int vtkTesting::RegressionTest(vtkAlgorithm* imageSource,
   }
   else
   {
-    os <<  "<DartMeasurement name=\"BaselineImage\" type=\"numeric/integer\">";
+    os << "<DartMeasurement name=\"BaselineImage\" type=\"numeric/integer\">";
     os << errIndex;
     os << "</DartMeasurement>";
   }
@@ -667,7 +669,7 @@ int vtkTesting::RegressionTest(vtkAlgorithm* imageSource,
 
   // write out the image that was generated
   string testImageFileName = tmpDir + "/" + validName;
-  FILE *testImageFile = fopen(testImageFileName.c_str(), "wb");
+  FILE* testImageFile = vtksys::SystemTools::Fopen(testImageFileName, "wb");
   if (testImageFile)
   {
     fclose(testImageFile);
@@ -683,11 +685,11 @@ int vtkTesting::RegressionTest(vtkAlgorithm* imageSource,
   }
   else
   {
-    vtkErrorMacro("Could not open file '" << testImageFileName << "' for "
-                  "writing.");
+    vtkErrorMacro("Could not open file '" << testImageFileName
+                                          << "' for "
+                                             "writing.");
   }
 
-
   os << "Failed Image Test ( " << validName << " ) : " << minError << endl;
   if (errIndex >= 0)
   {
@@ -710,17 +712,16 @@ int vtkTesting::RegressionTest(vtkAlgorithm* imageSource,
   {
     os << "Image differencing failed to produce an image." << endl;
   }
-  if (!(
-       (ext2[1] - ext2[0]) == (ext1[1] - ext1[0]) &&
-       (ext2[3] - ext2[2]) == (ext1[3] - ext1[2]) &&
-       (ext2[5] - ext2[4]) == (ext1[5] - ext1[4])))
+  if (!((ext2[1] - ext2[0]) == (ext1[1] - ext1[0]) && (ext2[3] - ext2[2]) == (ext1[3] - ext1[2]) &&
+        (ext2[5] - ext2[4]) == (ext1[5] - ext1[4])))
   {
     os << "Image differencing failed to produce an image because images are "
-      "different size:" << endl;
-    os << "Valid image: " << (ext2[1] - ext2[0]) << ", " << (ext2[3] - ext2[2])
-      << ", " << (ext2[5] - ext2[4]) << endl;
-    os << "Test image: " << (ext1[1] - ext1[0]) << ", " << (ext1[3] - ext1[2])
-      << ", " << (ext1[5] - ext1[4]) << endl;
+          "different size:"
+       << endl;
+    os << "Valid image: " << (ext2[1] - ext2[0] + 1) << ", " << (ext2[3] - ext2[2] + 1) << ", "
+       << (ext2[5] - ext2[4] + 1) << endl;
+    os << "Test image: " << (ext1[1] - ext1[0] + 1) << ", " << (ext1[3] - ext1[2] + 1) << ", "
+       << (ext1[5] - ext1[4] + 1) << endl;
     return FAILED;
   }
 
@@ -730,13 +731,13 @@ int vtkTesting::RegressionTest(vtkAlgorithm* imageSource,
   if (hasDiff)
   {
     string diffFilename = tmpDir + "/" + validName;
-    string::size_type dotPos = diffFilename.rfind(".");
+    string::size_type dotPos = diffFilename.rfind('.');
     if (dotPos != string::npos)
     {
       diffFilename = diffFilename.substr(0, dotPos);
     }
     diffFilename += ".diff.png";
-    FILE *rtDout = fopen(diffFilename.c_str(), "wb");
+    FILE* rtDout = vtksys::SystemTools::Fopen(diffFilename, "wb");
     if (rtDout)
     {
       fclose(rtDout);
@@ -746,6 +747,7 @@ int vtkTesting::RegressionTest(vtkAlgorithm* imageSource,
       rtGamma->SetInputConnection(rtId->GetOutputPort());
       rtGamma->SetShift(0);
       rtGamma->SetScale(10);
+      rtGamma->ClampOverflowOn();
 
       vtkNew<vtkPNGWriter> rtPngw;
       rtPngw->SetFileName(diffFilename.c_str());
@@ -758,20 +760,18 @@ int vtkTesting::RegressionTest(vtkAlgorithm* imageSource,
     }
     else
     {
-      vtkErrorMacro("Could not open file '" << diffFilename
-                    << "' for writing.");
+      vtkErrorMacro("Could not open file '" << diffFilename << "' for writing.");
     }
   }
 
   os << "<DartMeasurementFile name=\"ValidImage\" type=\"image/png\">";
-  os << this->ValidImageFileName;
-  os <<  "</DartMeasurementFile>";
+  os << bestImageFileName;
+  os << "</DartMeasurementFile>";
 
   return FAILED;
 }
 //-----------------------------------------------------------------------------
-int vtkTesting::Test(int argc, char *argv[], vtkRenderWindow *rw,
-                     double thresh )
+int vtkTesting::Test(int argc, char* argv[], vtkRenderWindow* rw, double thresh)
 {
   vtkNew<vtkTesting> testing;
   for (int i = 0; i < argc; ++i)
@@ -793,17 +793,13 @@ int vtkTesting::Test(int argc, char *argv[], vtkRenderWindow *rw,
   return NOT_RUN;
 }
 //-----------------------------------------------------------------------------
-int vtkTesting::CompareAverageOfL2Norm(vtkDataArray *daA,
-                                       vtkDataArray *daB,
-                                       double tol)
+int vtkTesting::CompareAverageOfL2Norm(vtkDataArray* daA, vtkDataArray* daB, double tol)
 {
   int typeA = daA->GetDataType();
   int typeB = daB->GetDataType();
   if (typeA != typeB)
   {
-    vtkWarningMacro("Incompatible data types: "
-                    << typeA << ","
-                    << typeB << ".");
+    vtkWarningMacro("Incompatible data types: " << typeA << "," << typeB << ".");
     return 0;
   }
   //
@@ -812,17 +808,12 @@ int vtkTesting::CompareAverageOfL2Norm(vtkDataArray *daA,
   int nCompsA = daA->GetNumberOfComponents();
   int nCompsB = daB->GetNumberOfComponents();
   //
-  if ((nTupsA != nTupsB)
-     || (nCompsA != nCompsB))
+  if ((nTupsA != nTupsB) || (nCompsA != nCompsB))
   {
-    vtkWarningMacro(
-              "Arrays: " << daA->GetName()
-              << " (nC=" << nCompsA
-              << " nT= "<< nTupsA << ")"
-              << " and " << daB->GetName()
-              << " (nC=" << nCompsB
-              << " nT= "<< nTupsB << ")"
-              << " do not have the same structure.");
+    vtkWarningMacro("Arrays: " << daA->GetName() << " (nC=" << nCompsA << " nT= " << nTupsA << ")"
+                               << " and " << daB->GetName() << " (nC=" << nCompsB
+                               << " nT= " << nTupsB << ")"
+                               << " do not have the same structure.");
     return 0;
   }
 
@@ -832,22 +823,22 @@ int vtkTesting::CompareAverageOfL2Norm(vtkDataArray *daA,
   {
     case VTK_DOUBLE:
     {
-      vtkDoubleArray *A = vtkArrayDownCast<vtkDoubleArray>(daA);
-      double *pA = A->GetPointer(0);
-      vtkDoubleArray *B = vtkArrayDownCast<vtkDoubleArray>(daB);
-      double *pB = B->GetPointer(0);
+      vtkDoubleArray* A = vtkArrayDownCast<vtkDoubleArray>(daA);
+      double* pA = A->GetPointer(0);
+      vtkDoubleArray* B = vtkArrayDownCast<vtkDoubleArray>(daB);
+      double* pB = B->GetPointer(0);
       N = AccumulateScaledL2Norm(pA, pB, nTupsA, nCompsA, L2);
     }
-      break;
+    break;
     case VTK_FLOAT:
     {
-      vtkFloatArray *A = vtkArrayDownCast<vtkFloatArray>(daA);
-      float *pA = A->GetPointer(0);
-      vtkFloatArray *B = vtkArrayDownCast<vtkFloatArray>(daB);
-      float *pB = B->GetPointer(0);
+      vtkFloatArray* A = vtkArrayDownCast<vtkFloatArray>(daA);
+      float* pA = A->GetPointer(0);
+      vtkFloatArray* B = vtkArrayDownCast<vtkFloatArray>(daB);
+      float* pB = B->GetPointer(0);
       N = AccumulateScaledL2Norm(pA, pB, nTupsA, nCompsA, L2);
     }
-      break;
+    break;
     default:
       if (this->Verbose)
       {
@@ -863,12 +854,8 @@ int vtkTesting::CompareAverageOfL2Norm(vtkDataArray *daA,
   //
   if (this->Verbose)
   {
-    cout << "Sum(L2)/N of "
-         << daA->GetName()
-         << " < " << tol
-         << "? = " << L2
-         << "/" << N
-         << "."  << endl;
+    cout << "Sum(L2)/N of " << daA->GetName() << " < " << tol << "? = " << L2 << "/" << N << "."
+         << endl;
   }
   //
   double avgL2 = L2 / static_cast<double>(N);
@@ -881,18 +868,17 @@ int vtkTesting::CompareAverageOfL2Norm(vtkDataArray *daA,
   return 1;
 }
 //-----------------------------------------------------------------------------
-int vtkTesting::CompareAverageOfL2Norm(vtkDataSet *dsA, vtkDataSet *dsB,
-                                       double tol)
+int vtkTesting::CompareAverageOfL2Norm(vtkDataSet* dsA, vtkDataSet* dsB, double tol)
 {
-  vtkDataArray *daA = 0;
-  vtkDataArray *daB = 0;
+  vtkDataArray* daA = nullptr;
+  vtkDataArray* daB = nullptr;
   int status = 0;
 
   // Compare points if the dataset derives from
   // vtkPointSet.
-  vtkPointSet *ptSetA = vtkPointSet::SafeDownCast(dsA);
-  vtkPointSet *ptSetB = vtkPointSet::SafeDownCast(dsB);
-  if (ptSetA != NULL && ptSetB != NULL)
+  vtkPointSet* ptSetA = vtkPointSet::SafeDownCast(dsA);
+  vtkPointSet* ptSetB = vtkPointSet::SafeDownCast(dsB);
+  if (ptSetA != nullptr && ptSetB != nullptr)
   {
     if (this->Verbose)
     {
@@ -917,9 +903,8 @@ int vtkTesting::CompareAverageOfL2Norm(vtkDataSet *dsA, vtkDataSet *dsB,
   int nDaB = dsB->GetPointData()->GetNumberOfArrays();
   if (nDaA != nDaB)
   {
-    vtkWarningMacro("Point data, " << dsA
-              <<  " and " << dsB << " differ in number of arrays"
-              <<  " and cannot be compared.");
+    vtkWarningMacro("Point data, " << dsA << " and " << dsB << " differ in number of arrays"
+                                   << " and cannot be compared.");
     return 0;
   }
   //
@@ -939,18 +924,16 @@ int vtkTesting::CompareAverageOfL2Norm(vtkDataSet *dsA, vtkDataSet *dsB,
 }
 
 //-----------------------------------------------------------------------------
-int vtkTesting::InteractorEventLoop(int argc,
-                                    char *argv[],
-                                    vtkRenderWindowInteractor *iren,
-                                    const char *playbackStream)
+int vtkTesting::InteractorEventLoop(
+  int argc, char* argv[], vtkRenderWindowInteractor* iren, const char* playbackStream)
 {
-  bool disableReplay = false, record = false, playbackFile = false;;
+  bool disableReplay = false, record = false, playbackFile = false;
   std::string playbackFileName;
   for (int i = 0; i < argc; i++)
   {
     disableReplay |= (strcmp("--DisableReplay", argv[i]) == 0);
-    record        |= (strcmp("--Record", argv[i]) == 0);
-    playbackFile  |= (strcmp("--PlaybackFile", argv[i]) == 0);
+    record |= (strcmp("--Record", argv[i]) == 0);
+    playbackFile |= (strcmp("--PlaybackFile", argv[i]) == 0);
     if (playbackFile && playbackFileName.empty())
     {
       if (i + 1 < argc)
@@ -1007,10 +990,12 @@ int vtkTesting::InteractorEventLoop(int argc,
 //-----------------------------------------------------------------------------
 void vtkTesting::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
   os << indent << "RenderWindow: " << this->RenderWindow << endl;
-  os << indent << "ValidImageFileName: " << (this->ValidImageFileName?this->ValidImageFileName:"(none)") << endl;
-  os << indent << "FrontBuffer: " << (this->FrontBuffer?"On":"Off") << endl;
+  os << indent
+     << "ValidImageFileName: " << (this->ValidImageFileName ? this->ValidImageFileName : "(none)")
+     << endl;
+  os << indent << "FrontBuffer: " << (this->FrontBuffer ? "On" : "Off") << endl;
   os << indent << "ImageDifference: " << this->ImageDifference << endl;
   os << indent << "DataRoot: " << this->GetDataRoot() << endl;
   os << indent << "Temp Directory: " << this->GetTempDirectory() << endl;
