@@ -8,16 +8,20 @@ readonly name="jsoncpp"
 readonly ownership="JsonCpp Upstream <kwrobot@kitware.com>"
 readonly subtree="ThirdParty/$name/vtk$name"
 readonly repo="https://gitlab.kitware.com/third-party/jsoncpp.git"
-readonly tag="for/vtk"
+readonly tag="for/vtk-20200302-1.9.2"
 readonly paths="
 .gitattributes
+CMakeLists.vtk.txt
+README.kitware.md
 LICENSE
 " # We amalgamate jsoncpp
 
 extract_source () {
-    python amalgamate.py
+    python2 amalgamate.py
     [ -n "$paths" ] && \
         mv -v $paths "dist"
+    mv "json/vtkjsoncpp_config.h.in" "dist/json"
+    mv "dist/CMakeLists.vtk.txt" "dist/CMakeLists.txt"
     mv "dist" "$name-reduced"
     tar -cv "$name-reduced/" | \
         tar -C "$extractdir" -x
