@@ -25,44 +25,44 @@ existing tests to get an idea of what to do.
 
 #include "vtkRenderTimings.h"
 
-#include "vtkAutoInit.h"
 #include "vtkActor.h"
+#include "vtkAutoInit.h"
 #include "vtkCamera.h"
 #include "vtkCellArray.h"
+#include "vtkCullerCollection.h"
+#include "vtkNew.h"
 #include "vtkPointData.h"
 #include "vtkPolyData.h"
 #include "vtkPolyDataMapper.h"
-#include "vtkRenderingOpenGLConfigure.h"
 #include "vtkRenderWindow.h"
 #include "vtkRenderer.h"
-#include "vtkNew.h"
+#include "vtkRenderingOpenGLConfigure.h"
 
 /*=========================================================================
 Define a test for simple triangle mesh surfaces
 =========================================================================*/
 #include "vtkParametricBoy.h"
-#include "vtkParametricTorus.h"
 #include "vtkParametricFunctionSource.h"
+#include "vtkParametricTorus.h"
 
 class surfaceTest : public vtkRTTest
 {
-  public:
-  surfaceTest(const char *name,
-    bool withColors, bool withNormals) : vtkRTTest(name)
+public:
+  surfaceTest(const char* name, bool withColors, bool withNormals)
+    : vtkRTTest(name)
   {
     this->WithColors = withColors;
     this->WithNormals = withNormals;
   }
 
-  const char *GetSummaryResultName() { return "Mtris/sec"; }
+  const char* GetSummaryResultName() override { return "Mtris/sec"; }
 
-  const char *GetSecondSummaryResultName() { return "Mtris"; }
+  const char* GetSecondSummaryResultName() override { return "Mtris"; }
 
-  virtual vtkRTTestResult Run(vtkRTTestSequence *ats,
-      int /*argc*/, char * /* argv */[])
-    {
+  vtkRTTestResult Run(vtkRTTestSequence* ats, int /*argc*/, char* /* argv */[]) override
+  {
     int ures, vres;
-    ats->GetSequenceNumbers(ures,vres);
+    ats->GetSequenceNumbers(ures, vres);
 
     // ------------------------------------------------------------
     // Create surface
@@ -72,17 +72,17 @@ class surfaceTest : public vtkRTTest
     vtkNew<vtkParametricFunctionSource> PFS;
     PFS->SetParametricFunction(PB.Get());
     if (this->WithColors)
-      {
+    {
       PFS->SetScalarModeToPhase();
-      }
+    }
     else
-      {
+    {
       PFS->SetScalarModeToNone();
-      }
+    }
     if (this->WithNormals == false)
-      {
+    {
       PFS->GenerateNormalsOff();
-      }
+    }
     PFS->SetUResolution(ures * 50);
     PFS->SetVResolution(vres * 100);
     PFS->Update();
@@ -113,19 +113,18 @@ class surfaceTest : public vtkRTTest
 
     int frameCount = 80;
     for (int i = 0; i < frameCount; i++)
-      {
+    {
       renWindow->Render();
       ren1->GetActiveCamera()->Azimuth(1);
       ren1->GetActiveCamera()->Elevation(1);
-      if ((vtkTimerLog::GetUniversalTime() - startTime - firstFrameTime) >
-          this->TargetTime * 1.5)
-        {
+      if ((vtkTimerLog::GetUniversalTime() - startTime - firstFrameTime) > this->TargetTime * 1.5)
+      {
         frameCount = i + 1;
         break;
-        }
       }
-    double subsequentFrameTime = (vtkTimerLog::GetUniversalTime() - startTime -
-                                  firstFrameTime) / frameCount;
+    }
+    double subsequentFrameTime =
+      (vtkTimerLog::GetUniversalTime() - startTime - firstFrameTime) / frameCount;
     double numTris = PFS->GetOutput()->GetPolys()->GetNumberOfCells();
 
     vtkRTTestResult result;
@@ -136,9 +135,9 @@ class surfaceTest : public vtkRTTest
     result.Results["triangles"] = numTris;
 
     return result;
-    }
+  }
 
-  protected:
+protected:
   bool WithNormals;
   bool WithColors;
 };
@@ -146,25 +145,25 @@ class surfaceTest : public vtkRTTest
 /*=========================================================================
 Define a test for glyphing
 =========================================================================*/
+#include "vtkElevationFilter.h"
 #include "vtkGlyph3DMapper.h"
 #include "vtkPlaneSource.h"
-#include "vtkElevationFilter.h"
 #include "vtkSphereSource.h"
 
 class glyphTest : public vtkRTTest
 {
-  public:
-  glyphTest(const char *name) : vtkRTTest(name)
+public:
+  glyphTest(const char* name)
+    : vtkRTTest(name)
   {
   }
 
-  const char *GetSummaryResultName() { return "Mtris/sec"; }
+  const char* GetSummaryResultName() override { return "Mtris/sec"; }
 
-  const char *GetSecondSummaryResultName() { return "triangles"; }
+  const char* GetSecondSummaryResultName() override { return "triangles"; }
 
-  virtual vtkRTTestResult Run(vtkRTTestSequence *ats,
-      int /*argc*/, char * /* argv */[])
-    {
+  vtkRTTestResult Run(vtkRTTestSequence* ats, int /*argc*/, char* /* argv */[]) override
+  {
     int res1, res2, res3, res4;
     ats->GetSequenceNumbers(res1, res2, res3, res4);
 
@@ -172,8 +171,8 @@ class glyphTest : public vtkRTTest
     vtkNew<vtkPlaneSource> plane;
     plane->SetResolution(res1 * 10, res2 * 10);
     plane->SetOrigin(-res1 * 5.0, -res2 * 5.0, 0.0);
-    plane->SetPoint1(res1 * 5.0,-res2 * 5.0, 0.0);
-    plane->SetPoint2(-res1 * 5.0,res2 * 5.0, 0.0);
+    plane->SetPoint1(res1 * 5.0, -res2 * 5.0, 0.0);
+    plane->SetPoint2(-res1 * 5.0, res2 * 5.0, 0.0);
     vtkNew<vtkElevationFilter> colors;
     colors->SetInputConnection(plane->GetOutputPort());
     colors->SetLowPoint(plane->GetOrigin());
@@ -214,69 +213,65 @@ class glyphTest : public vtkRTTest
 
     int frameCount = 80;
     for (int i = 0; i < frameCount; i++)
-      {
+    {
       renWindow->Render();
       ren1->GetActiveCamera()->Azimuth(0.5);
       ren1->GetActiveCamera()->Elevation(0.5);
       ren1->GetActiveCamera()->Zoom(1.01);
       ren1->ResetCameraClippingRange();
-      if ((vtkTimerLog::GetUniversalTime() - startTime - firstFrameTime) >
-          this->TargetTime * 1.5)
-        {
+      if ((vtkTimerLog::GetUniversalTime() - startTime - firstFrameTime) > this->TargetTime * 1.5)
+      {
         frameCount = i + 1;
         break;
-        }
       }
-    double subsequentFrameTime = (vtkTimerLog::GetUniversalTime() - startTime -
-                                  firstFrameTime)/frameCount;
-    double numTris = 100.0 * res1 * res2 *
-                     sphere->GetOutput()->GetPolys()->GetNumberOfCells();
+    }
+    double subsequentFrameTime =
+      (vtkTimerLog::GetUniversalTime() - startTime - firstFrameTime) / frameCount;
+    double numTris = 100.0 * res1 * res2 * sphere->GetOutput()->GetPolys()->GetNumberOfCells();
 
     vtkRTTestResult result;
     result.Results["first frame time"] = firstFrameTime;
     result.Results["subsequent frame time"] = subsequentFrameTime;
     result.Results["Mtris"] = 1.0e-6 * numTris;
-    result.Results["Mtris/sec"] = 1.0e-6 * numTris/subsequentFrameTime;
+    result.Results["Mtris/sec"] = 1.0e-6 * numTris / subsequentFrameTime;
     result.Results["triangles"] = numTris;
 
     return result;
-    }
+  }
 
-  protected:
+protected:
 };
 
-
-#ifdef HAVE_CHEMISTRY
 /*=========================================================================
 Define a test for molecules
 =========================================================================*/
+#include "vtkBoxMuellerRandomSequence.h"
+#include "vtkMath.h"
 #include "vtkMolecule.h"
 #include "vtkMoleculeMapper.h"
-#include "vtkBoxMuellerRandomSequence.h"
 #include "vtkPointLocator.h"
-#include "vtkMath.h"
-
-#ifdef VTK_OPENGL2
-VTK_MODULE_INIT(vtkDomainsChemistryOpenGL2);
-#endif
 
 class moleculeTest : public vtkRTTest
 {
-  public:
-  moleculeTest(const char *name, bool atomsOnly = false) : vtkRTTest(name)
+public:
+  moleculeTest(const char* name, bool atomsOnly = false)
+    : vtkRTTest(name)
   {
     this->AtomsOnly = atomsOnly;
   }
 
-  const char *GetSummaryResultName() {
-    return this->AtomsOnly ? "Atoms/sec" : "Atoms+Bonds/sec"; }
+  const char* GetSummaryResultName() override
+  {
+    return this->AtomsOnly ? "Atoms/sec" : "Atoms+Bonds/sec";
+  }
 
-  const char *GetSecondSummaryResultName() {
-    return this->AtomsOnly ? "Atoms" : "Atoms+Bonds"; }
+  const char* GetSecondSummaryResultName() override
+  {
+    return this->AtomsOnly ? "Atoms" : "Atoms+Bonds";
+  }
 
-  virtual vtkRTTestResult Run(vtkRTTestSequence *ats,
-      int /*argc*/, char * /* argv */[])
-    {
+  vtkRTTestResult Run(vtkRTTestSequence* ats, int /*argc*/, char* /* argv */[]) override
+  {
     int res1;
     ats->GetSequenceNumbers(res1);
 
@@ -285,48 +280,57 @@ class moleculeTest : public vtkRTTest
     vtkNew<vtkPointLocator> pl;
 
     // build a molecule
-    float scale = 3.0*pow(static_cast<double>(res1),0.33);
+    float scale = 3.0 * pow(static_cast<double>(res1), 0.33);
     double pos[3];
     vtkNew<vtkPolyData> pointSet;
     vtkNew<vtkPoints> pts;
     pointSet->SetPoints(pts.GetPointer());
     double bounds[6];
-    bounds[0] = 0.0; bounds[2] = 0.0; bounds[4] = 0.0;
-    bounds[1] = scale; bounds[3] = scale; bounds[5] = scale;
+    bounds[0] = 0.0;
+    bounds[2] = 0.0;
+    bounds[4] = 0.0;
+    bounds[1] = scale;
+    bounds[3] = scale;
+    bounds[5] = scale;
     pl->SetDataSet(pointSet.GetPointer());
-    pl->InitPointInsertion(pointSet->GetPoints(), bounds, 10*res1);
-    for (int i = 0; i < res1*100; i++)
-      {
-      pos[0] = scale*rs->GetValue(); rs->Next();
-      pos[1] = scale*rs->GetValue(); rs->Next();
-      pos[2] = scale*rs->GetValue(); rs->Next();
-      pl->InsertPoint(i,pos);
-      int molType = i%9 > 5 ? i%9 : 1; // a lot of H, some N O CA
+    pl->InitPointInsertion(pointSet->GetPoints(), bounds, 10 * res1);
+    for (int i = 0; i < res1 * 100; i++)
+    {
+      pos[0] = scale * rs->GetValue();
+      rs->Next();
+      pos[1] = scale * rs->GetValue();
+      rs->Next();
+      pos[2] = scale * rs->GetValue();
+      rs->Next();
+      pl->InsertPoint(i, pos);
+      int molType = i % 9 > 5 ? i % 9 : 1; // a lot of H, some N O CA
       mol->AppendAtom(molType, pos[0], pos[1], pos[2]);
-      }
+    }
 
     // now add some bonds
     if (!this->AtomsOnly)
-      {
+    {
       vtkNew<vtkIdList> ids;
       int bondCount = 0;
-      while(bondCount < res1*60)
-        {
-        pos[0] = scale*rs->GetValue(); rs->Next();
-        pos[1] = scale*rs->GetValue(); rs->Next();
-        pos[2] = scale*rs->GetValue(); rs->Next();
+      while (bondCount < res1 * 60)
+      {
+        pos[0] = scale * rs->GetValue();
+        rs->Next();
+        pos[1] = scale * rs->GetValue();
+        rs->Next();
+        pos[2] = scale * rs->GetValue();
+        rs->Next();
         pl->FindClosestNPoints(2, pos, ids.GetPointer());
         // are the atoms close enough?
-        if (vtkMath::Distance2BetweenPoints(
-            mol->GetAtomPosition(ids->GetId(0)).GetData(),
-            mol->GetAtomPosition(ids->GetId(1)).GetData()) < 4.0)
-          {
-          int bondType = bondCount%10 == 9 ? 3 : (bondCount%10)/7+1;
+        if (vtkMath::Distance2BetweenPoints(mol->GetAtomPosition(ids->GetId(0)).GetData(),
+              mol->GetAtomPosition(ids->GetId(1)).GetData()) < 4.0)
+        {
+          int bondType = bondCount % 10 == 9 ? 3 : (bondCount % 10) / 7 + 1;
           mol->AppendBond(ids->GetId(0), ids->GetId(1), bondType);
           bondCount++;
-          }
         }
       }
+    }
 
     vtkNew<vtkMoleculeMapper> mapper;
     mapper->SetInputData(mol.GetPointer());
@@ -343,7 +347,7 @@ class moleculeTest : public vtkRTTest
 
     // set the size/color of our window
     renWindow->SetSize(this->GetRenderWidth(), this->GetRenderHeight());
-    ren1->SetBackground(0.2,0.3,0.5);
+    ren1->SetBackground(0.2, 0.3, 0.5);
 
     // draw the resulting scene
     double startTime = vtkTimerLog::GetUniversalTime();
@@ -353,21 +357,20 @@ class moleculeTest : public vtkRTTest
 
     int frameCount = 80;
     for (int i = 0; i < frameCount; i++)
-      {
+    {
       renWindow->Render();
       ren1->GetActiveCamera()->Azimuth(0.5);
       ren1->GetActiveCamera()->Elevation(0.5);
       ren1->GetActiveCamera()->Zoom(1.01);
-      //ren1->ResetCameraClippingRange();
-      if ((vtkTimerLog::GetUniversalTime() - startTime - firstFrameTime)
-            > this->TargetTime * 1.5)
-        {
-        frameCount = i+1;
+      // ren1->ResetCameraClippingRange();
+      if ((vtkTimerLog::GetUniversalTime() - startTime - firstFrameTime) > this->TargetTime * 1.5)
+      {
+        frameCount = i + 1;
         break;
-        }
       }
-    double subsequentFrameTime = (vtkTimerLog::GetUniversalTime()
-      - startTime - firstFrameTime)/frameCount;
+    }
+    double subsequentFrameTime =
+      (vtkTimerLog::GetUniversalTime() - startTime - firstFrameTime) / frameCount;
     double numAtoms = mol->GetNumberOfAtoms();
 
     vtkRTTestResult result;
@@ -375,18 +378,16 @@ class moleculeTest : public vtkRTTest
     result.Results["subsequent frame time"] = subsequentFrameTime;
     result.Results["Atoms"] = numAtoms;
     result.Results["Bonds"] = mol->GetNumberOfBonds();
-    result.Results["Atoms+Bonds"] = (numAtoms+mol->GetNumberOfBonds());
-    result.Results["Atoms+Bonds/sec"] = (numAtoms+mol->GetNumberOfBonds())
-                                        /subsequentFrameTime;
-    result.Results["Atoms/sec"] = numAtoms/subsequentFrameTime;
+    result.Results["Atoms+Bonds"] = (numAtoms + mol->GetNumberOfBonds());
+    result.Results["Atoms+Bonds/sec"] = (numAtoms + mol->GetNumberOfBonds()) / subsequentFrameTime;
+    result.Results["Atoms/sec"] = numAtoms / subsequentFrameTime;
 
     return result;
-    }
+  }
 
-  protected:
-    bool AtomsOnly;
+protected:
+  bool AtomsOnly;
 };
-#endif
 
 /*=========================================================================
 Define a test for volume rendering
@@ -401,32 +402,25 @@ Define a test for volume rendering
 
 class volumeTest : public vtkRTTest
 {
-  public:
-  volumeTest(const char *name, bool withShading) : vtkRTTest(name)
-    {
+public:
+  volumeTest(const char* name, bool withShading)
+    : vtkRTTest(name)
+  {
     this->WithShading = withShading;
-    }
+  }
 
-  const char *GetSummaryResultName()
-    {
-    return "Mvoxels/sec" ;
-    }
+  const char* GetSummaryResultName() override { return "Mvoxels/sec"; }
 
-  const char *GetSecondSummaryResultName()
-    {
-    return "Mvoxels";
-    }
+  const char* GetSecondSummaryResultName() override { return "Mvoxels"; }
 
-  virtual vtkRTTestResult Run(vtkRTTestSequence *ats,
-      int /*argc*/, char * /* argv */[])
-    {
+  vtkRTTestResult Run(vtkRTTestSequence* ats, int /*argc*/, char* /* argv */[]) override
+  {
     int res1, res2, res3;
-    ats->GetSequenceNumbers(res1,res2,res3);
+    ats->GetSequenceNumbers(res1, res2, res3);
 
     vtkNew<vtkRTAnalyticSource> wavelet;
-    wavelet->SetWholeExtent(-50*res1 - 1, 50*res1,
-                            -50*res2 - 1, 50*res2,
-                            -50*res3 - 1, 50*res3);
+    wavelet->SetWholeExtent(
+      -50 * res1 - 1, 50 * res1, -50 * res2 - 1, 50 * res2, -50 * res3 - 1, 50 * res3);
     wavelet->Update();
 
     vtkNew<vtkGPUVolumeRayCastMapper> volumeMapper;
@@ -462,9 +456,9 @@ class volumeTest : public vtkRTTest
     volume->SetMapper(volumeMapper.GetPointer());
     volume->SetProperty(volumeProperty.GetPointer());
     if (this->WithShading)
-      {
+    {
       volumeProperty->ShadeOn();
-      }
+    }
 
     // create a rendering window and renderer
     vtkNew<vtkRenderer> ren1;
@@ -485,60 +479,58 @@ class volumeTest : public vtkRTTest
 
     int frameCount = 80;
     for (int i = 0; i < frameCount; i++)
-      {
+    {
       renWindow->Render();
       ren1->GetActiveCamera()->Azimuth(0.5);
       ren1->GetActiveCamera()->Elevation(0.5);
       ren1->ResetCameraClippingRange();
-      if ((vtkTimerLog::GetUniversalTime() - startTime - firstFrameTime)
-            > this->TargetTime * 1.5)
-        {
-        frameCount = i+1;
+      if ((vtkTimerLog::GetUniversalTime() - startTime - firstFrameTime) > this->TargetTime * 1.5)
+      {
+        frameCount = i + 1;
         break;
-        }
       }
-    double subsequentFrameTime = (vtkTimerLog::GetUniversalTime()
-      - startTime - firstFrameTime)/frameCount;
+    }
+    double subsequentFrameTime =
+      (vtkTimerLog::GetUniversalTime() - startTime - firstFrameTime) / frameCount;
 
     vtkRTTestResult result;
     result.Results["first frame time"] = firstFrameTime;
     result.Results["subsequent frame time"] = subsequentFrameTime;
-    result.Results["Mvoxels/sec"] = static_cast<double>(res1*res2*res3)/subsequentFrameTime;
+    result.Results["Mvoxels/sec"] = static_cast<double>(res1 * res2 * res3) / subsequentFrameTime;
     result.Results["Mvoxels"] = res1 * res2 * res3;
 
     return result;
-    }
+  }
 
-  protected:
+protected:
   bool WithShading;
 };
 
 /*=========================================================================
 Define a test for depth peeling transluscent geometry.
 =========================================================================*/
-#include "vtkParametricTorus.h"
 #include "vtkParametricFunctionSource.h"
+#include "vtkParametricTorus.h"
 #include "vtkProperty.h"
 #include "vtkTransform.h"
 
 class depthPeelingTest : public vtkRTTest
 {
-  public:
-  depthPeelingTest(const char *name, bool withNormals)
-    : vtkRTTest(name),
-      WithNormals(withNormals)
+public:
+  depthPeelingTest(const char* name, bool withNormals)
+    : vtkRTTest(name)
+    , WithNormals(withNormals)
   {
   }
 
-  const char *GetSummaryResultName() { return "subsequent frame time"; }
+  const char* GetSummaryResultName() override { return "subsequent frame time"; }
 
-  const char *GetSecondSummaryResultName() { return "first frame time"; }
+  const char* GetSecondSummaryResultName() override { return "first frame time"; }
 
-  virtual vtkRTTestResult Run(vtkRTTestSequence *ats,
-      int /*argc*/, char * /* argv */[])
-    {
+  vtkRTTestResult Run(vtkRTTestSequence* ats, int /*argc*/, char* /* argv */[]) override
+  {
     int ures, vres;
-    ats->GetSequenceNumbers(ures,vres);
+    ats->GetSequenceNumbers(ures, vres);
 
     // ------------------------------------------------------------
     // Create surface
@@ -547,9 +539,9 @@ class depthPeelingTest : public vtkRTTest
     vtkNew<vtkParametricFunctionSource> PFS;
     PFS->SetParametricFunction(PB.Get());
     if (this->WithNormals == false)
-      {
+    {
       PFS->GenerateNormalsOff();
-      }
+    }
     PFS->SetUResolution(ures * 50);
     PFS->SetVResolution(vres * 100);
     PFS->Update();
@@ -572,24 +564,24 @@ class depthPeelingTest : public vtkRTTest
 
     // Create a set of 10 colored translucent actors at slight offsets:
     const int NUM_ACTORS = 10;
-    const unsigned char colors[NUM_ACTORS][4] = { { 255,   0,   0, 32 },
-                                                  {   0, 255,   0, 32 },
-                                                  {   0,   0, 255, 32 },
-                                                  { 128, 128,   0, 32 },
-                                                  {   0, 128, 128, 32 },
-                                                  { 128,   0, 128, 32 },
-                                                  { 128,  64,  64, 32 },
-                                                  {  64, 128,  64, 32 },
-                                                  {  64,  64, 128, 32 },
-                                                  {  64,  64,  64, 32 } };
+    const unsigned char colors[NUM_ACTORS][4] = {
+      { 255, 0, 0, 32 },
+      { 0, 255, 0, 32 },
+      { 0, 0, 255, 32 },
+      { 128, 128, 0, 32 },
+      { 0, 128, 128, 32 },
+      { 128, 0, 128, 32 },
+      { 128, 64, 64, 32 },
+      { 64, 128, 64, 32 },
+      { 64, 64, 128, 32 },
+      { 64, 64, 64, 32 },
+    };
 
     for (int i = 0; i < NUM_ACTORS; ++i)
-      {
+    {
       vtkNew<vtkActor> actor;
       actor->SetMapper(mapper.Get());
-      actor->GetProperty()->SetColor(colors[i][0] / 255.,
-                                     colors[i][1] / 255.,
-                                     colors[i][2] / 255.);
+      actor->GetProperty()->SetColor(colors[i][0] / 255., colors[i][1] / 255., colors[i][2] / 255.);
       actor->GetProperty()->SetOpacity(colors[i][3] / 255.);
 
       vtkNew<vtkTransform> xform;
@@ -598,7 +590,7 @@ class depthPeelingTest : public vtkRTTest
       actor->SetUserTransform(xform.Get());
 
       ren1->AddActor(actor.Get());
-      }
+    }
 
     // set the size/color of our window
     renWindow->SetSize(this->GetRenderWidth(), this->GetRenderHeight());
@@ -613,19 +605,18 @@ class depthPeelingTest : public vtkRTTest
 
     int frameCount = 80;
     for (int i = 0; i < frameCount; i++)
-      {
+    {
       renWindow->Render();
       ren1->GetActiveCamera()->Azimuth(1);
       ren1->GetActiveCamera()->Elevation(1);
-      if ((vtkTimerLog::GetUniversalTime() - startTime - firstFrameTime) >
-          this->TargetTime * 1.5)
-        {
+      if ((vtkTimerLog::GetUniversalTime() - startTime - firstFrameTime) > this->TargetTime * 1.5)
+      {
         frameCount = i + 1;
         break;
-        }
       }
-    double subsequentFrameTime = (vtkTimerLog::GetUniversalTime() - startTime -
-                                  firstFrameTime) / frameCount;
+    }
+    double subsequentFrameTime =
+      (vtkTimerLog::GetUniversalTime() - startTime - firstFrameTime) / frameCount;
     double numTris = PFS->GetOutput()->GetPolys()->GetNumberOfCells();
     numTris *= NUM_ACTORS;
 
@@ -636,10 +627,111 @@ class depthPeelingTest : public vtkRTTest
     result.Results["triangles"] = numTris;
 
     return result;
-    }
+  }
 
-  protected:
+protected:
   bool WithNormals;
 };
 
+/*=========================================================================
+Define a test for simple triangle mesh surfaces
+=========================================================================*/
+#include "vtkParametricBoy.h"
+#include "vtkParametricFunctionSource.h"
+#include "vtkParametricTorus.h"
+
+class manyActorTest : public vtkRTTest
+{
+public:
+  manyActorTest(const char* name)
+    : vtkRTTest(name)
+  {
+  }
+
+  const char* GetSummaryResultName() override { return "actors"; }
+
+  const char* GetSecondSummaryResultName() override { return "frames/sec"; }
+
+  vtkRTTestResult Run(vtkRTTestSequence* ats, int /*argc*/, char* /* argv */[]) override
+  {
+    int ures, vres;
+    ats->GetSequenceNumbers(ures, vres);
+
+    // ------------------------------------------------------------
+    // Create surface
+    // ------------------------------------------------------------
+    //  vtkNew<vtkParametricBoy> PB;
+    vtkNew<vtkParametricTorus> PB;
+    vtkNew<vtkParametricFunctionSource> PFS;
+    PFS->SetParametricFunction(PB.Get());
+    //  PFS->SetScalarModeToPhase();
+    PFS->SetScalarModeToNone();
+    //  PFS->GenerateNormalsOff();
+    PFS->SetUResolution(10);
+    PFS->SetVResolution(20);
+    PFS->Update();
+
+    // create a rendering window and renderer
+    vtkNew<vtkRenderer> ren1;
+    // ren1->RemoveCuller(ren1->GetCullers()->GetLastItem());
+    vtkNew<vtkRenderWindow> renWindow;
+    renWindow->AddRenderer(ren1.Get());
+
+    // create many actors
+    for (int u = 0; u < ures * 10; ++u)
+    {
+      for (int v = 0; v < vres * 10; ++v)
+      {
+        vtkNew<vtkPolyDataMapper> mapper;
+        mapper->SetInputConnection(PFS->GetOutputPort());
+        mapper->SetScalarRange(0.0, 360.0);
+        mapper->StaticOn();
+
+        vtkNew<vtkActor> actor;
+        actor->SetMapper(mapper.Get());
+        actor->ForceOpaqueOn();
+        ren1->AddActor(actor.Get());
+      }
+    }
+
+    // set the size/color of our window
+    renWindow->SetSize(this->GetRenderWidth(), this->GetRenderHeight());
+    ren1->SetBackground(0.2, 0.3, 0.5);
+
+    // draw the resulting scene
+    double startTime = vtkTimerLog::GetUniversalTime();
+    renWindow->Render();
+    double firstFrameTime = vtkTimerLog::GetUniversalTime() - startTime;
+    ren1->GetActiveCamera()->Azimuth(90);
+    ren1->GetActiveCamera()->Zoom(0.3);
+    ren1->ResetCameraClippingRange();
+
+    int frameCount = 80;
+    for (int i = 0; i < frameCount; i++)
+    {
+      renWindow->Render();
+      ren1->GetActiveCamera()->Azimuth(1);
+      ren1->GetActiveCamera()->Elevation(1);
+      if ((vtkTimerLog::GetUniversalTime() - startTime - firstFrameTime) > this->TargetTime * 1.5)
+      {
+        frameCount = i + 1;
+        break;
+      }
+    }
+    double subsequentFrameTime =
+      (vtkTimerLog::GetUniversalTime() - startTime - firstFrameTime) / frameCount;
+
+    vtkRTTestResult result;
+    result.Results["first frame time"] = firstFrameTime;
+    result.Results["subsequent frame time"] = subsequentFrameTime;
+    result.Results["frames/sec"] = 1.0 / subsequentFrameTime;
+    result.Results["actors"] = 100 * ures * vres;
+
+    return result;
+  }
+
+protected:
+};
+
 #endif
+// VTK-HeaderTest-Exclude: vtkRenderTimingTests.h
