@@ -39,7 +39,7 @@ namespace METAIO_NAMESPACE {
 #endif
 
 class METAIO_EXPORT MetaGaussian : public MetaObject
-  {
+{
 
   /////
   //
@@ -61,13 +61,13 @@ class METAIO_EXPORT MetaGaussian : public MetaObject
 
     MetaGaussian(unsigned int dim);
 
-    ~MetaGaussian(void);
+    ~MetaGaussian(void) override;
 
-    void PrintInfo(void) const;
+    void PrintInfo(void) const override;
 
-    void CopyInfo(const MetaObject * _object);
+    void CopyInfo(const MetaObject * _object) override;
 
-    void  Clear(void);
+    void  Clear(void) override;
 
     /** Set/Get the maximum value. */
     void Maximum(float val) { m_Maximum = val; }
@@ -88,16 +88,16 @@ class METAIO_EXPORT MetaGaussian : public MetaObject
   ////
   protected:
 
-    void  M_Destroy(void);
+    void  M_Destroy(void) override;
 
     /** Set up the fields to read a MetaGaussian file. */
-    void  M_SetupReadFields(void);
+    void  M_SetupReadFields(void) override;
 
     /** Set up the fields to write a MetaGaussian file. */
-    void  M_SetupWriteFields(void);
+    void  M_SetupWriteFields(void) override;
 
     /** Read the MetaGaussian file properties. */
-    bool  M_Read(void);
+    bool  M_Read(void) override;
 
     /** The maximum value of the MetaGaussian object. */
     float m_Maximum;
@@ -108,7 +108,7 @@ class METAIO_EXPORT MetaGaussian : public MetaObject
     /** The standard deviation of the MetaGaussian object. */
     float m_Sigma;
 
-  };
+};
 
 
 #if (METAIO_USE_NAMESPACE)
