@@ -14,8 +14,8 @@
 =========================================================================*/
 
 #include "vtkHeatmapItem.h"
-#include "vtkNew.h"
 #include "vtkIntArray.h"
+#include "vtkNew.h"
 #include "vtkStringArray.h"
 #include "vtkTable.h"
 
@@ -23,9 +23,9 @@
 #include "vtkContextScene.h"
 #include "vtkContextTransform.h"
 #include "vtkContextView.h"
-#include "vtkRenderer.h"
 #include "vtkRenderWindow.h"
 #include "vtkRenderWindowInteractor.h"
+#include "vtkRenderer.h"
 
 #include "vtkRegressionTestImage.h"
 
@@ -48,19 +48,19 @@ int TestHeatmapScalarLegend(int argc, char* argv[])
   column->SetValue(1, 2);
   column->SetValue(2, 1);
 
-  table->AddColumn(tableNames.GetPointer());
-  table->AddColumn(column.GetPointer());
+  table->AddColumn(tableNames);
+  table->AddColumn(column);
 
   vtkNew<vtkHeatmapItem> heatmap;
-  heatmap->SetTable(table.GetPointer());
+  heatmap->SetTable(table);
 
   vtkNew<vtkContextTransform> trans;
   trans->SetInteractive(true);
-  trans->AddItem(heatmap.GetPointer());
+  trans->AddItem(heatmap);
   trans->Translate(125, 125);
 
   vtkNew<vtkContextView> contextView;
-  contextView->GetScene()->AddItem(trans.GetPointer());
+  contextView->GetScene()->AddItem(trans);
 
   contextView->GetRenderWindow()->SetMultiSamples(0);
   contextView->GetRenderWindow()->Render();
