@@ -16,8 +16,8 @@
 #include "vtkDendrogramItem.h"
 #include "vtkHeatmapItem.h"
 
-#include "vtkDataSetAttributes.h"
 #include "vtkBitArray.h"
+#include "vtkDataSetAttributes.h"
 #include "vtkObjectFactory.h"
 #include "vtkStringArray.h"
 #include "vtkTable.h"
@@ -53,165 +53,159 @@ vtkTreeHeatmapItem::vtkTreeHeatmapItem()
 }
 
 //-----------------------------------------------------------------------------
-vtkTreeHeatmapItem::~vtkTreeHeatmapItem()
-{
-}
+vtkTreeHeatmapItem::~vtkTreeHeatmapItem() = default;
 
 //-----------------------------------------------------------------------------
-void vtkTreeHeatmapItem::SetTree(vtkTree *tree)
+void vtkTreeHeatmapItem::SetTree(vtkTree* tree)
 {
   this->Dendrogram->SetTree(tree);
-  if (tree == NULL)
-    {
+  if (tree == nullptr)
+  {
     return;
-    }
+  }
 
-  if (this->GetTable() != NULL &&
-      this->GetTable()->GetNumberOfRows() != 0)
-    {
+  if (this->GetTable() != nullptr && this->GetTable()->GetNumberOfRows() != 0)
+  {
     this->Dendrogram->SetDrawLabels(false);
-    }
+  }
   this->Dendrogram->SetVisible(true);
 
   // rearrange our table to match the order of the leaf nodes in this tree.
-  if (this->GetTable() != NULL && this->GetTable()->GetNumberOfRows() != 0)
-    {
+  if (this->GetTable() != nullptr && this->GetTable()->GetNumberOfRows() != 0)
+  {
     this->ReorderTable();
-    }
+  }
 }
 
 //-----------------------------------------------------------------------------
-void vtkTreeHeatmapItem::SetTable(vtkTable *table)
+void vtkTreeHeatmapItem::SetTable(vtkTable* table)
 {
   this->Heatmap->SetTable(table);
-  if (table == NULL)
-    {
+  if (table == nullptr)
+  {
     return;
-    }
+  }
 
-  if (this->Dendrogram->GetTree() != NULL &&
-      this->Dendrogram->GetTree()->GetNumberOfVertices() != 0)
-    {
+  if (this->Dendrogram->GetTree() != nullptr &&
+    this->Dendrogram->GetTree()->GetNumberOfVertices() != 0)
+  {
     this->Dendrogram->SetDrawLabels(false);
-    }
+  }
   this->Heatmap->SetVisible(true);
 
-
   // rearrange our table to match the order of the leaf nodes in this tree.
-  if (this->GetTree() != NULL && this->GetTree()->GetNumberOfVertices() != 0)
-    {
+  if (this->GetTree() != nullptr && this->GetTree()->GetNumberOfVertices() != 0)
+  {
     this->ReorderTable();
-    }
+  }
 
   // add an array to this table's field data to keep track of collapsed rows
   // (unless it already has the array)
-  vtkBitArray *existingRowsArray = vtkBitArray::SafeDownCast(
-    this->GetTable()->GetFieldData()->GetArray("collapsed rows"));
+  vtkBitArray* existingRowsArray =
+    vtkArrayDownCast<vtkBitArray>(this->GetTable()->GetFieldData()->GetArray("collapsed rows"));
   if (existingRowsArray)
+  {
+    for (vtkIdType row = 0; row < this->GetTable()->GetNumberOfRows(); ++row)
     {
-    for(vtkIdType row = 0; row < this->GetTable()->GetNumberOfRows(); ++row)
-      {
       existingRowsArray->SetValue(row, 0);
-      }
     }
+  }
   else
-    {
-    vtkSmartPointer<vtkBitArray> collapsedRowsArray =
-      vtkSmartPointer<vtkBitArray>::New();
+  {
+    vtkSmartPointer<vtkBitArray> collapsedRowsArray = vtkSmartPointer<vtkBitArray>::New();
     collapsedRowsArray->SetNumberOfComponents(1);
     collapsedRowsArray->SetName("collapsed rows");
-    for(vtkIdType row = 0; row < this->GetTable()->GetNumberOfRows(); ++row)
-      {
+    for (vtkIdType row = 0; row < this->GetTable()->GetNumberOfRows(); ++row)
+    {
       collapsedRowsArray->InsertNextValue(0);
-      }
-    this->GetTable()->GetFieldData()->AddArray(collapsedRowsArray);
     }
+    this->GetTable()->GetFieldData()->AddArray(collapsedRowsArray);
+  }
 
   // add an array to this table's field data to keep track of collapsed columns
   // (unless it already has the array)
-  vtkBitArray *existingColumnsArray = vtkBitArray::SafeDownCast(
-    this->GetTable()->GetFieldData()->GetArray("collapsed columns"));
+  vtkBitArray* existingColumnsArray =
+    vtkArrayDownCast<vtkBitArray>(this->GetTable()->GetFieldData()->GetArray("collapsed columns"));
   if (existingColumnsArray)
+  {
+    for (vtkIdType col = 0; col < this->GetTable()->GetNumberOfColumns(); ++col)
     {
-    for(vtkIdType col = 0; col < this->GetTable()->GetNumberOfColumns(); ++col)
-      {
       existingColumnsArray->SetValue(col, 0);
-      }
     }
+  }
   else
-    {
-    vtkSmartPointer<vtkBitArray> collapsedColumnsArray =
-      vtkSmartPointer<vtkBitArray>::New();
+  {
+    vtkSmartPointer<vtkBitArray> collapsedColumnsArray = vtkSmartPointer<vtkBitArray>::New();
     collapsedColumnsArray->SetNumberOfComponents(1);
     collapsedColumnsArray->SetName("collapsed columns");
-    for(vtkIdType col = 0; col < this->GetTable()->GetNumberOfColumns(); ++col)
-      {
+    for (vtkIdType col = 0; col < this->GetTable()->GetNumberOfColumns(); ++col)
+    {
       collapsedColumnsArray->InsertNextValue(0);
-      }
-    this->GetTable()->GetFieldData()->AddArray(collapsedColumnsArray);
     }
+    this->GetTable()->GetFieldData()->AddArray(collapsedColumnsArray);
+  }
 }
 
 //-----------------------------------------------------------------------------
-void vtkTreeHeatmapItem::SetColumnTree(vtkTree *tree)
+void vtkTreeHeatmapItem::SetColumnTree(vtkTree* tree)
 {
   this->ColumnDendrogram->SetTree(tree);
-  if (tree == NULL)
-    {
+  if (tree == nullptr)
+  {
     return;
-    }
+  }
 
   if (this->Orientation == vtkDendrogramItem::LEFT_TO_RIGHT ||
-      this->Orientation == vtkDendrogramItem::LEFT_TO_RIGHT)
-    {
+    this->Orientation == vtkDendrogramItem::RIGHT_TO_LEFT)
+  {
     this->ColumnDendrogram->SetOrientation(vtkDendrogramItem::UP_TO_DOWN);
-    }
+  }
   else
-    {
+  {
     this->ColumnDendrogram->SetOrientation(vtkDendrogramItem::RIGHT_TO_LEFT);
-    }
+  }
 
   this->ColumnDendrogram->SetVisible(true);
 }
 
 //-----------------------------------------------------------------------------
-vtkTree * vtkTreeHeatmapItem::GetColumnTree()
+vtkTree* vtkTreeHeatmapItem::GetColumnTree()
 {
   return this->ColumnDendrogram->GetTree();
 }
 
 //-----------------------------------------------------------------------------
-vtkDendrogramItem * vtkTreeHeatmapItem::GetDendrogram()
+vtkDendrogramItem* vtkTreeHeatmapItem::GetDendrogram()
 {
-  return this->Dendrogram.GetPointer();
+  return this->Dendrogram;
 }
 
 //-----------------------------------------------------------------------------
-void vtkTreeHeatmapItem::SetDendrogram(vtkDendrogramItem *dendrogram)
+void vtkTreeHeatmapItem::SetDendrogram(vtkDendrogramItem* dendrogram)
 {
   this->Dendrogram = dendrogram;
 }
 
 //-----------------------------------------------------------------------------
-vtkHeatmapItem * vtkTreeHeatmapItem::GetHeatmap()
+vtkHeatmapItem* vtkTreeHeatmapItem::GetHeatmap()
 {
-  return this->Heatmap.GetPointer();
+  return this->Heatmap;
 }
 
 //-----------------------------------------------------------------------------
-void vtkTreeHeatmapItem::SetHeatmap(vtkHeatmapItem *heatmap)
+void vtkTreeHeatmapItem::SetHeatmap(vtkHeatmapItem* heatmap)
 {
   this->Heatmap = heatmap;
 }
 
 //-----------------------------------------------------------------------------
-vtkTree * vtkTreeHeatmapItem::GetTree()
+vtkTree* vtkTreeHeatmapItem::GetTree()
 {
   return this->Dendrogram->GetTree();
 }
 
 //-----------------------------------------------------------------------------
-vtkTable * vtkTreeHeatmapItem::GetTable()
+vtkTable* vtkTreeHeatmapItem::GetTable()
 {
   return this->Heatmap->GetTable();
 }
@@ -230,59 +224,56 @@ void vtkTreeHeatmapItem::ReorderTable()
   // we also need to know which number column it is
   vtkIdType rowNamesColNum = 0;
   for (vtkIdType col = 0; col < this->GetTable()->GetNumberOfColumns(); ++col)
-    {
+  {
     if (this->GetTable()->GetColumn(col) == this->Heatmap->GetRowNames())
-      {
+    {
       rowNamesColNum = col;
       break;
-      }
     }
+  }
 
   // empty out our original table.
   for (vtkIdType row = this->GetTable()->GetNumberOfRows() - 1; row > -1; --row)
-    {
+  {
     this->GetTable()->RemoveRow(row);
-    }
+  }
 
   // get the names of the vertices in our tree.
-  vtkStringArray *vertexNames = vtkStringArray::SafeDownCast(
+  vtkStringArray* vertexNames = vtkArrayDownCast<vtkStringArray>(
     this->GetTree()->GetVertexData()->GetAbstractArray("node name"));
 
-
-  for (vtkIdType vertex = 0; vertex < this->GetTree()->GetNumberOfVertices();
-       ++vertex)
-    {
+  for (vtkIdType vertex = 0; vertex < this->GetTree()->GetNumberOfVertices(); ++vertex)
+  {
     if (!this->GetTree()->IsLeaf(vertex))
-      {
+    {
       continue;
-      }
+    }
 
     // find the row in the table that corresponds to this vertex
     std::string vertexName = vertexNames->GetValue(vertex);
     vtkIdType tableRow = rowNames->LookupValue(vertexName);
     if (tableRow < 0)
-      {
+    {
       vtkIdType newRowNum = this->GetTable()->InsertNextBlankRow();
-      this->GetTable()->SetValue(newRowNum, rowNamesColNum,
-                                 vtkVariant(vertexName));
+      this->GetTable()->SetValue(newRowNum, rowNamesColNum, vtkVariant(vertexName));
       this->Heatmap->MarkRowAsBlank(vertexName);
       continue;
-      }
+    }
 
     // copy it back into our original table
     this->GetTable()->InsertNextRow(tableCopy->GetRow(tableRow));
-    }
+  }
 
   if (this->Orientation == vtkDendrogramItem::DOWN_TO_UP ||
-      this->Orientation == vtkDendrogramItem::UP_TO_DOWN)
-    {
+    this->Orientation == vtkDendrogramItem::UP_TO_DOWN)
+  {
     this->ReverseTableColumns();
-    }
+  }
   if (this->Orientation == vtkDendrogramItem::RIGHT_TO_LEFT ||
-      this->Orientation == vtkDendrogramItem::DOWN_TO_UP)
-    {
+    this->Orientation == vtkDendrogramItem::DOWN_TO_UP)
+  {
     this->ReverseTableRows();
-    }
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -292,16 +283,15 @@ void vtkTreeHeatmapItem::ReverseTableRows()
   vtkNew<vtkTable> tableCopy;
   tableCopy->DeepCopy(this->GetTable());
   for (vtkIdType row = 0; row < tableCopy->GetNumberOfRows(); ++row)
-    {
+  {
     this->GetTable()->RemoveRow(row);
-    }
+  }
 
   // re-insert the rows back into our original table in reverse order
-  for (vtkIdType tableRow = tableCopy->GetNumberOfRows() - 1; tableRow >= 0;
-       --tableRow)
-    {
+  for (vtkIdType tableRow = tableCopy->GetNumberOfRows() - 1; tableRow >= 0; --tableRow)
+  {
     this->GetTable()->InsertNextRow(tableCopy->GetRow(tableRow));
-    }
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -311,19 +301,19 @@ void vtkTreeHeatmapItem::ReverseTableColumns()
   vtkNew<vtkTable> tableCopy;
   tableCopy->DeepCopy(this->GetTable());
   for (vtkIdType col = tableCopy->GetNumberOfColumns() - 1; col > 0; --col)
-    {
+  {
     this->GetTable()->RemoveColumn(col);
-    }
+  }
 
   // re-insert the columns back into our original table in reverse order
   for (vtkIdType col = tableCopy->GetNumberOfColumns() - 1; col >= 1; --col)
-    {
+  {
     this->GetTable()->AddColumn(tableCopy->GetColumn(col));
-    }
+  }
 }
 
 //-----------------------------------------------------------------------------
-bool vtkTreeHeatmapItem::Paint(vtkContext2D *painter)
+bool vtkTreeHeatmapItem::Paint(vtkContext2D* painter)
 {
   this->Dendrogram->Paint(painter);
 
@@ -334,19 +324,19 @@ bool vtkTreeHeatmapItem::Paint(vtkContext2D *painter)
   double heatmapStartX, heatmapStartY;
 
   switch (this->Orientation)
-    {
+  {
     case vtkDendrogramItem::UP_TO_DOWN:
       heatmapStartX = treeBounds[0] - spacing;
-      heatmapStartY = treeBounds[2] - (this->GetTable()->GetNumberOfColumns() - 1) *
-                      this->Heatmap->GetCellWidth() - spacing;
+      heatmapStartY = treeBounds[2] -
+        (this->GetTable()->GetNumberOfColumns() - 1) * this->Heatmap->GetCellWidth() - spacing;
       break;
     case vtkDendrogramItem::DOWN_TO_UP:
       heatmapStartX = treeBounds[0] - spacing;
       heatmapStartY = treeBounds[3] + spacing;
       break;
     case vtkDendrogramItem::RIGHT_TO_LEFT:
-      heatmapStartX = treeBounds[0] - (this->GetTable()->GetNumberOfColumns() - 1) *
-                      this->Heatmap->GetCellWidth() - spacing;
+      heatmapStartX = treeBounds[0] -
+        (this->GetTable()->GetNumberOfColumns() - 1) * this->Heatmap->GetCellWidth() - spacing;
       heatmapStartY = treeBounds[2] - spacing;
       break;
     case vtkDendrogramItem::LEFT_TO_RIGHT:
@@ -354,12 +344,12 @@ bool vtkTreeHeatmapItem::Paint(vtkContext2D *painter)
       heatmapStartX = treeBounds[1] + spacing;
       heatmapStartY = treeBounds[2] - spacing;
       break;
-    }
+  }
   this->Heatmap->SetPosition(heatmapStartX, heatmapStartY);
   this->Heatmap->Paint(painter);
 
   if (this->ColumnDendrogram->GetVisible())
-    {
+  {
     double columnTreeStartX, columnTreeStartY;
 
     double heatmapBounds[4];
@@ -370,124 +360,115 @@ bool vtkTreeHeatmapItem::Paint(vtkContext2D *painter)
 
     float offset = 0.0;
     if (this->Heatmap->GetRowLabelWidth() > 0.0)
-      {
+    {
       offset = this->Heatmap->GetRowLabelWidth() + spacing;
-      }
+    }
     switch (this->Orientation)
-      {
+    {
       case vtkDendrogramItem::UP_TO_DOWN:
-        columnTreeStartX = heatmapBounds[1] + (treeBounds[1] - treeBounds[0]) +
-          spacing;
-        columnTreeStartY = heatmapBounds[3] -
-          this->ColumnDendrogram->GetLeafSpacing() / 2.0;
+        columnTreeStartX = heatmapBounds[1] + (treeBounds[1] - treeBounds[0]) + spacing;
+        columnTreeStartY = heatmapBounds[3] - this->ColumnDendrogram->GetLeafSpacing() / 2.0;
         break;
       case vtkDendrogramItem::DOWN_TO_UP:
-        columnTreeStartX = heatmapBounds[1] + (treeBounds[1] - treeBounds[0]) +
-          spacing;
-        columnTreeStartY = heatmapBounds[3] - offset -
-          this->ColumnDendrogram->GetLeafSpacing() / 2.0;
+        columnTreeStartX = heatmapBounds[1] + (treeBounds[1] - treeBounds[0]) + spacing;
+        columnTreeStartY =
+          heatmapBounds[3] - offset - this->ColumnDendrogram->GetLeafSpacing() / 2.0;
         break;
       case vtkDendrogramItem::RIGHT_TO_LEFT:
-        columnTreeStartX = heatmapBounds[0] + offset +
-          this->ColumnDendrogram->GetLeafSpacing() / 2.0;
-        columnTreeStartY = heatmapBounds[3] + spacing +
-          (treeBounds[3] - treeBounds[2]);
+        columnTreeStartX =
+          heatmapBounds[0] + offset + this->ColumnDendrogram->GetLeafSpacing() / 2.0;
+        columnTreeStartY = heatmapBounds[3] + spacing + (treeBounds[3] - treeBounds[2]);
         break;
       case vtkDendrogramItem::LEFT_TO_RIGHT:
       default:
-        columnTreeStartX = heatmapBounds[0] +
-          this->ColumnDendrogram->GetLeafSpacing() / 2.0;
-        columnTreeStartY = heatmapBounds[3] + spacing +
-          (treeBounds[3] - treeBounds[2]);
+        columnTreeStartX = heatmapBounds[0] + this->ColumnDendrogram->GetLeafSpacing() / 2.0;
+        columnTreeStartY = heatmapBounds[3] + spacing + (treeBounds[3] - treeBounds[2]);
         break;
-      }
+    }
 
     this->ColumnDendrogram->SetPosition(columnTreeStartX, columnTreeStartY);
     this->ColumnDendrogram->Paint(painter);
-    }
+  }
 
   return true;
 }
 
 //-----------------------------------------------------------------------------
-bool vtkTreeHeatmapItem::MouseDoubleClickEvent(
-  const vtkContextMouseEvent &event)
+bool vtkTreeHeatmapItem::MouseDoubleClickEvent(const vtkContextMouseEvent& event)
 {
   bool treeChanged = this->Dendrogram->MouseDoubleClickEvent(event);
 
   // update the heatmap if a subtree just collapsed or expanded.
   if (treeChanged)
-    {
+  {
     this->CollapseHeatmapRows();
-    }
+  }
   else
-    {
+  {
     treeChanged = this->ColumnDendrogram->MouseDoubleClickEvent(event);
     if (treeChanged)
-      {
+    {
       this->CollapseHeatmapColumns();
-      }
     }
+  }
   return treeChanged;
 }
 
 //-----------------------------------------------------------------------------
 void vtkTreeHeatmapItem::CollapseHeatmapRows()
 {
-  vtkBitArray *collapsedRowsArray = vtkBitArray::SafeDownCast(
-    this->GetTable()->GetFieldData()->GetArray("collapsed rows"));
+  vtkBitArray* collapsedRowsArray =
+    vtkArrayDownCast<vtkBitArray>(this->GetTable()->GetFieldData()->GetArray("collapsed rows"));
 
-  vtkStringArray *vertexNames = vtkStringArray::SafeDownCast(
-    this->Dendrogram->GetPrunedTree()->GetVertexData()
-    ->GetAbstractArray("node name"));
+  vtkStringArray* vertexNames = vtkArrayDownCast<vtkStringArray>(
+    this->Dendrogram->GetPrunedTree()->GetVertexData()->GetAbstractArray("node name"));
 
-  vtkStringArray *rowNames = this->Heatmap->GetRowNames();
+  vtkStringArray* rowNames = this->Heatmap->GetRowNames();
   if (!rowNames)
-    {
+  {
     return;
-    }
+  }
 
   for (vtkIdType row = 0; row < this->GetTable()->GetNumberOfRows(); ++row)
-    {
+  {
     std::string name = rowNames->GetValue(row);
     // if we can't find this name in the layout tree, then the corresponding
     // row in the heatmap should be marked as collapsed.
     if (vertexNames->LookupValue(name) == -1)
-      {
+    {
       collapsedRowsArray->SetValue(row, 1);
-      }
-    else
-      {
-      collapsedRowsArray->SetValue(row, 0);
-      }
     }
+    else
+    {
+      collapsedRowsArray->SetValue(row, 0);
+    }
+  }
 }
 
 //-----------------------------------------------------------------------------
 void vtkTreeHeatmapItem::CollapseHeatmapColumns()
 {
-  vtkBitArray *collapsedColumnsArray = vtkBitArray::SafeDownCast(
-    this->GetTable()->GetFieldData()->GetArray("collapsed columns"));
+  vtkBitArray* collapsedColumnsArray =
+    vtkArrayDownCast<vtkBitArray>(this->GetTable()->GetFieldData()->GetArray("collapsed columns"));
 
-  vtkStringArray *vertexNames = vtkStringArray::SafeDownCast(
-    this->ColumnDendrogram->GetPrunedTree()->GetVertexData()
-    ->GetAbstractArray("node name"));
+  vtkStringArray* vertexNames = vtkArrayDownCast<vtkStringArray>(
+    this->ColumnDendrogram->GetPrunedTree()->GetVertexData()->GetAbstractArray("node name"));
 
   for (vtkIdType col = 1; col < this->GetTable()->GetNumberOfColumns(); ++col)
-    {
+  {
     std::string name = this->GetTable()->GetColumn(col)->GetName();
 
     // if we can't find this name in the layout tree, then the corresponding
     // column in the heatmap should be marked as collapsed.
     if (vertexNames->LookupValue(name) == -1)
-      {
+    {
       collapsedColumnsArray->SetValue(col, 1);
-      }
-    else
-      {
-      collapsedColumnsArray->SetValue(col, 0);
-      }
     }
+    else
+    {
+      collapsedColumnsArray->SetValue(col, 0);
+    }
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -499,31 +480,31 @@ void vtkTreeHeatmapItem::SetOrientation(int orientation)
   this->Heatmap->SetOrientation(this->Orientation);
 
   if (this->Orientation == vtkDendrogramItem::LEFT_TO_RIGHT ||
-      this->Orientation == vtkDendrogramItem::RIGHT_TO_LEFT)
-    {
+    this->Orientation == vtkDendrogramItem::RIGHT_TO_LEFT)
+  {
     this->ColumnDendrogram->SetOrientation(vtkDendrogramItem::UP_TO_DOWN);
-    }
+  }
   else
-    {
+  {
     this->ColumnDendrogram->SetOrientation(vtkDendrogramItem::RIGHT_TO_LEFT);
-    }
+  }
 
   // reverse our table if we're changing from a "not backwards" orientation
   // to one that it backwards.
-  if ( (this->Orientation == vtkDendrogramItem::UP_TO_DOWN ||
+  if ((this->Orientation == vtkDendrogramItem::UP_TO_DOWN ||
         this->Orientation == vtkDendrogramItem::DOWN_TO_UP) &&
-       (previousOrientation != vtkDendrogramItem::UP_TO_DOWN &&
-        previousOrientation != vtkDendrogramItem::DOWN_TO_UP) )
-    {
+    (previousOrientation != vtkDendrogramItem::UP_TO_DOWN &&
+      previousOrientation != vtkDendrogramItem::DOWN_TO_UP))
+  {
     this->ReverseTableColumns();
-    }
-  if ( (this->Orientation == vtkDendrogramItem::RIGHT_TO_LEFT ||
+  }
+  if ((this->Orientation == vtkDendrogramItem::RIGHT_TO_LEFT ||
         this->Orientation == vtkDendrogramItem::DOWN_TO_UP) &&
-       (previousOrientation != vtkDendrogramItem::RIGHT_TO_LEFT &&
-        previousOrientation != vtkDendrogramItem::DOWN_TO_UP) )
-    {
+    (previousOrientation != vtkDendrogramItem::RIGHT_TO_LEFT &&
+      previousOrientation != vtkDendrogramItem::DOWN_TO_UP))
+  {
     this->ReverseTableRows();
-    }
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -535,26 +516,23 @@ int vtkTreeHeatmapItem::GetOrientation()
 //-----------------------------------------------------------------------------
 void vtkTreeHeatmapItem::GetBounds(double bounds[4])
 {
-  double treeBounds[4] =
-    {VTK_DOUBLE_MAX, VTK_DOUBLE_MIN, VTK_DOUBLE_MAX, VTK_DOUBLE_MIN};
+  double treeBounds[4] = { VTK_DOUBLE_MAX, VTK_DOUBLE_MIN, VTK_DOUBLE_MAX, VTK_DOUBLE_MIN };
   if (this->GetTree()->GetNumberOfVertices() > 0)
-    {
+  {
     this->Dendrogram->GetBounds(treeBounds);
-    }
+  }
 
-  double tableBounds[4] =
-    {VTK_DOUBLE_MAX, VTK_DOUBLE_MIN, VTK_DOUBLE_MAX, VTK_DOUBLE_MIN};
+  double tableBounds[4] = { VTK_DOUBLE_MAX, VTK_DOUBLE_MIN, VTK_DOUBLE_MAX, VTK_DOUBLE_MIN };
   if (this->GetTable()->GetNumberOfRows() > 0)
-    {
+  {
     this->Heatmap->GetBounds(tableBounds);
-    }
+  }
 
-  double columnTreeBounds[4] =
-    {VTK_DOUBLE_MAX, VTK_DOUBLE_MIN, VTK_DOUBLE_MAX, VTK_DOUBLE_MIN};
-  if (this->ColumnDendrogram->GetTree() != NULL)
-    {
+  double columnTreeBounds[4] = { VTK_DOUBLE_MAX, VTK_DOUBLE_MIN, VTK_DOUBLE_MAX, VTK_DOUBLE_MIN };
+  if (this->ColumnDendrogram->GetTree() != nullptr)
+  {
     this->ColumnDendrogram->GetBounds(columnTreeBounds);
-    }
+  }
 
   double xMin, xMax, yMin, yMax;
 
@@ -590,7 +568,7 @@ void vtkTreeHeatmapItem::GetSize(double size[2])
 }
 
 //-----------------------------------------------------------------------------
-void vtkTreeHeatmapItem::SetTreeColorArray(const char *arrayName)
+void vtkTreeHeatmapItem::SetTreeColorArray(const char* arrayName)
 {
   this->Dendrogram->SetColorArray(arrayName);
 }
@@ -616,13 +594,13 @@ void vtkTreeHeatmapItem::SetTreeLineWidth(float width)
 }
 
 //-----------------------------------------------------------------------------
-vtkTree * vtkTreeHeatmapItem::GetPrunedTree()
+vtkTree* vtkTreeHeatmapItem::GetPrunedTree()
 {
   return this->Dendrogram->GetPrunedTree();
 }
 
 //-----------------------------------------------------------------------------
-bool vtkTreeHeatmapItem::Hit(const vtkContextMouseEvent &vtkNotUsed(mouse))
+bool vtkTreeHeatmapItem::Hit(const vtkContextMouseEvent& vtkNotUsed(mouse))
 {
   // If we are interactive, we want to catch anything that propagates to the
   // background, otherwise we do not want any mouse events.
@@ -630,7 +608,7 @@ bool vtkTreeHeatmapItem::Hit(const vtkContextMouseEvent &vtkNotUsed(mouse))
 }
 
 //-----------------------------------------------------------------------------
-void vtkTreeHeatmapItem::PrintSelf(ostream &os, vtkIndent indent)
+void vtkTreeHeatmapItem::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
   this->Dendrogram->PrintSelf(os, indent);
