@@ -21,14 +21,14 @@
 #include "vtkWrapPythonMethodDef.h"
 #include "vtkWrapPythonTemplate.h"
 
+#include "vtkParseExtras.h"
 #include "vtkWrap.h"
 #include "vtkWrapText.h"
-#include "vtkParseExtras.h"
 
+#include <ctype.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <ctype.h>
 
 /* -------------------------------------------------------------------- */
 /* A struct for special types to store info about the type, it is fairly
@@ -46,18 +46,18 @@ typedef struct _SpecialTypeInfo
 /* -------------------------------------------------------------------- */
 
 /* -------------------------------------------------------------------- */
-/* generate function for printing a special object */
-static void vtkWrapPython_NewDeleteProtocol(
-  FILE *fp, const char *classname, ClassInfo *data)
+/* check if class has a wrapped constructor, and return its name if so */
+static const char* vtkWrapPython_WrappedConstructor(
+  ClassInfo* data, HierarchyInfo* hinfo, size_t* np)
 {
-  const char *constructor;
+  const char* constructor = data->Name;
   size_t n, m;
+  int i;
 
   /* remove namespaces and template parameters from the
    * class name to get the constructor name */
-  constructor = data->Name;
   m = vtkParse_UnscopedNameLength(constructor);
-  while (constructor[m] == ':' && constructor[m+1] == ':')
+  while (constructor[m] == ':' && constructor[m + 1] == ':')
   {
     constructor += m + 2;
     m = vtkParse_UnscopedNameLength(constructor);
@@ -70,77 +70,115 @@ static void vtkWrapPython_NewDeleteProtocol(
     }
   }
 
+  /* check if a public constructor exists */
+  for (i = 0; i < data->NumberOfFunctions; i++)
+  {
+    FunctionInfo* theFunc = data->Functions[i];
+
+    if (theFunc->Name && strncmp(theFunc->Name, constructor, n) == 0 && theFunc->Name[n] == '\0' &&
+      !theFunc->Template && vtkWrapPython_MethodCheck(data, theFunc, hinfo))
+    {
+      *np = n;
+      return constructor;
+    }
+  }
+
+  return NULL;
+}
+
+/* -------------------------------------------------------------------- */
+/* generate function for printing a special object */
+static void vtkWrapPython_NewDeleteProtocol(
+  FILE* fp, const char* classname, ClassInfo* data, HierarchyInfo* hinfo)
+{
+  size_t n = 0;
+  const char* constructor = NULL;
+
+  if (!data->IsAbstract)
+  {
+    constructor = vtkWrapPython_WrappedConstructor(data, hinfo, &n);
+  }
+
   /* the "new" method */
-  if (data->IsAbstract)
+  if (constructor)
   {
     fprintf(fp,
-    "static PyObject *\n"
-    "Py%s_New(PyTypeObject *, PyObject *, PyObject *)\n"
-    "{\n"
-    "  PyErr_SetString(PyExc_TypeError,\n"
-    "                  \"this abstract class cannot be instantiated\");\n"
-    "\n"
-    "  return NULL;\n"
-    "}\n"
-    "\n",
-    classname);
+      "static PyObject *\n"
+      "Py%s_New(PyTypeObject *, PyObject *args, PyObject *kwds)\n"
+      "{\n"
+      "  if (kwds && PyDict_Size(kwds))\n"
+      "  {\n"
+      "    PyErr_SetString(PyExc_TypeError,\n"
+      "                    \"this function takes no keyword arguments\");\n"
+      "    return nullptr;\n"
+      "  }\n"
+      "\n"
+      "  return Py%s_%*.*s(nullptr, args);\n"
+      "}\n"
+      "\n",
+      classname, classname, (int)n, (int)n, constructor);
   }
   else
   {
     fprintf(fp,
-    "static PyObject *\n"
-    "Py%s_New(PyTypeObject *, PyObject *args, PyObject *kwds)\n"
-    "{\n"
-    "  if (kwds && PyDict_Size(kwds))\n"
-    "  {\n"
-    "    PyErr_SetString(PyExc_TypeError,\n"
-    "                    \"this function takes no keyword arguments\");\n"
-    "    return NULL;\n"
-    "  }\n"
-    "\n"
-    "  return Py%s_%*.*s(NULL, args);\n"
-    "}\n"
-    "\n",
-    classname, classname, (int)n, (int)n, constructor);
+      "static PyObject *\n"
+      "Py%s_New(PyTypeObject * /*unused*/, PyObject * /*unused*/, PyObject * /*unused*/)\n"
+      "{\n"
+      "  PyErr_SetString(PyExc_TypeError,\n"
+      "                  \"this class cannot be instantiated\");\n"
+      "\n"
+      "  return nullptr;\n"
+      "}\n"
+      "\n",
+      classname);
   }
 
   /* the delete method */
-  fprintf(fp,
-    "static void Py%s_Delete(PyObject *self)\n"
-    "{\n"
-    "  PyVTKSpecialObject *obj = (PyVTKSpecialObject *)self;\n"
-    "  delete static_cast<%s *>(obj->vtk_ptr);\n"
-    "  PyObject_Del(self);\n"
-    "}\n"
-    "\n",
-    classname, data->Name);
+  if (vtkWrap_HasPublicDestructor(data))
+  {
+    fprintf(fp,
+      "static void Py%s_Delete(PyObject *self)\n"
+      "{\n"
+      "  PyVTKSpecialObject *obj = (PyVTKSpecialObject *)self;\n"
+      "  delete static_cast<%s *>(obj->vtk_ptr);\n"
+      "  PyObject_Del(self);\n"
+      "}\n"
+      "\n",
+      classname, data->Name);
+  }
+  else
+  {
+    fprintf(fp,
+      "static void Py%s_Delete(PyObject *self)\n"
+      "{\n"
+      "  PyObject_Del(self);\n"
+      "}\n"
+      "\n",
+      classname);
+  }
 }
 
-
 /* -------------------------------------------------------------------- */
 /* generate function for printing a special object */
 static void vtkWrapPython_PrintProtocol(
-  FILE *fp, const char *classname, ClassInfo *data,
-  FileInfo *finfo, SpecialTypeInfo *info)
+  FILE* fp, const char* classname, ClassInfo* data, FileInfo* finfo, SpecialTypeInfo* info)
 {
   int i;
-  FunctionInfo *func;
+  FunctionInfo* func;
 
   /* look in the file for "operator<<" for printing */
   for (i = 0; i < finfo->Contents->NumberOfFunctions; i++)
   {
     func = finfo->Contents->Functions[i];
-    if (func->Name && func->IsOperator &&
-        strcmp(func->Name, "operator<<") == 0)
+    if (func->Name && func->IsOperator && !func->IsDeleted && !func->IsExcluded &&
+      strcmp(func->Name, "operator<<") == 0)
     {
       if (func->NumberOfParameters == 2 &&
-          (func->Parameters[0]->Type & VTK_PARSE_UNQUALIFIED_TYPE) ==
-              VTK_PARSE_OSTREAM_REF &&
-          (func->Parameters[1]->Type & VTK_PARSE_BASE_TYPE) ==
-              VTK_PARSE_OBJECT &&
-          (func->Parameters[1]->Type & VTK_PARSE_POINTER_MASK) == 0 &&
-          !vtkWrap_IsNonConstRef(func->Parameters[1]) &&
-          strcmp(func->Parameters[1]->Class, data->Name) == 0)
+        (func->Parameters[0]->Type & VTK_PARSE_UNQUALIFIED_TYPE) == VTK_PARSE_OSTREAM_REF &&
+        (func->Parameters[1]->Type & VTK_PARSE_BASE_TYPE) == VTK_PARSE_OBJECT &&
+        (func->Parameters[1]->Type & VTK_PARSE_POINTER_MASK) == 0 &&
+        !vtkWrap_IsNonConstRef(func->Parameters[1]) &&
+        strcmp(func->Parameters[1]->Class, data->Name) == 0)
       {
         info->has_print = 1;
       }
@@ -170,16 +208,13 @@ static void vtkWrapPython_PrintProtocol(
 /* -------------------------------------------------------------------- */
 /* generate function for comparing special objects */
 static void vtkWrapPython_RichCompareProtocol(
-  FILE *fp, const char *classname, ClassInfo *data,
-  FileInfo *finfo, SpecialTypeInfo *info)
+  FILE* fp, const char* classname, ClassInfo* data, FileInfo* finfo, SpecialTypeInfo* info)
 {
-  static const char *compare_consts[6] = {
-    "Py_LT", "Py_LE", "Py_EQ", "Py_NE", "Py_GT", "Py_GE" };
-  static const char *compare_tokens[6] = {
-    "<", "<=", "==", "!=", ">", ">=" };
+  static const char* compare_consts[6] = { "Py_LT", "Py_LE", "Py_EQ", "Py_NE", "Py_GT", "Py_GE" };
+  static const char* compare_tokens[6] = { "<", "<=", "==", "!=", ">", ">=" };
   int compare_ops = 0;
   int i, n;
-  FunctionInfo *func;
+  FunctionInfo* func;
 
   /* look for comparison operator methods */
   n = data->NumberOfFunctions + finfo->Contents->NumberOfFunctions;
@@ -190,10 +225,9 @@ static void vtkWrapPython_RichCompareProtocol(
       /* member function */
       func = data->Functions[i];
       if (func->NumberOfParameters != 1 ||
-          (func->Parameters[0]->Type & VTK_PARSE_BASE_TYPE) !=
-              VTK_PARSE_OBJECT ||
-          (func->Parameters[0]->Type & VTK_PARSE_POINTER_MASK) != 0 ||
-          strcmp(func->Parameters[0]->Class, data->Name) != 0)
+        (func->Parameters[0]->Type & VTK_PARSE_BASE_TYPE) != VTK_PARSE_OBJECT ||
+        (func->Parameters[0]->Type & VTK_PARSE_POINTER_MASK) != 0 ||
+        strcmp(func->Parameters[0]->Class, data->Name) != 0)
       {
         continue;
       }
@@ -203,19 +237,17 @@ static void vtkWrapPython_RichCompareProtocol(
       /* non-member function: both args must be of our type */
       func = finfo->Contents->Functions[i - data->NumberOfFunctions];
       if (func->NumberOfParameters != 2 ||
-          (func->Parameters[0]->Type & VTK_PARSE_BASE_TYPE) !=
-              VTK_PARSE_OBJECT ||
-          (func->Parameters[0]->Type & VTK_PARSE_POINTER_MASK) != 0 ||
-          strcmp(func->Parameters[0]->Class, data->Name) != 0 ||
-          (func->Parameters[1]->Type & VTK_PARSE_BASE_TYPE) !=
-              VTK_PARSE_OBJECT ||
-          (func->Parameters[1]->Type & VTK_PARSE_POINTER_MASK) != 0 ||
-          strcmp(func->Parameters[1]->Class, data->Name) != 0)
+        (func->Parameters[0]->Type & VTK_PARSE_BASE_TYPE) != VTK_PARSE_OBJECT ||
+        (func->Parameters[0]->Type & VTK_PARSE_POINTER_MASK) != 0 ||
+        strcmp(func->Parameters[0]->Class, data->Name) != 0 ||
+        (func->Parameters[1]->Type & VTK_PARSE_BASE_TYPE) != VTK_PARSE_OBJECT ||
+        (func->Parameters[1]->Type & VTK_PARSE_POINTER_MASK) != 0 ||
+        strcmp(func->Parameters[1]->Class, data->Name) != 0)
       {
         continue;
       }
     }
-    if (func->IsOperator && func->Name != NULL)
+    if (func->IsOperator && func->Name != NULL && !func->IsDeleted && !func->IsExcluded)
     {
       if (strcmp(func->Name, "operator<") == 0)
       {
@@ -249,18 +281,16 @@ static void vtkWrapPython_RichCompareProtocol(
   {
     info->has_compare = 1;
 
-    fprintf(fp,
-      "static int Py%s_CheckExact(PyObject *ob);\n\n",
-      classname);
+    fprintf(fp, "static int Py%s_CheckExact(PyObject *ob);\n\n", classname);
 
     fprintf(fp,
       "static PyObject *Py%s_RichCompare(\n"
       "  PyObject *o1, PyObject *o2, int opid)\n"
       "{\n"
-      "  PyObject *n1 = NULL;\n"
-      "  PyObject *n2 = NULL;\n"
-      "  const %s *so1 = NULL;\n"
-      "  const %s *so2 = NULL;\n"
+      "  PyObject *n1 = nullptr;\n"
+      "  PyObject *n2 = nullptr;\n"
+      "  const %s *so1 = nullptr;\n"
+      "  const %s *so2 = nullptr;\n"
       "  int result = -1;\n"
       "\n",
       classname, data->Name, data->Name);
@@ -280,7 +310,7 @@ static void vtkWrapPython_RichCompareProtocol(
         "    so%d = static_cast<const %s *>(\n"
         "      vtkPythonUtil::GetPointerFromSpecialObject(\n"
         "        o%d, \"%s\", &n%d));\n"
-        "    if (so%d == NULL)\n"
+        "    if (so%d == nullptr)\n"
         "    {\n"
         "      PyErr_Clear();\n"
         "      Py_INCREF(Py_NotImplemented);\n"
@@ -288,8 +318,7 @@ static void vtkWrapPython_RichCompareProtocol(
         "    }\n"
         "  }\n"
         "\n",
-        classname, i, i, i, i, data->Name, i, i, data->Name,
-        i, classname, i, i);
+        classname, i, i, i, i, data->Name, i, i, data->Name, i, classname, i, i);
     }
 
     /* the switch statement for all possible compare ops */
@@ -299,7 +328,7 @@ static void vtkWrapPython_RichCompareProtocol(
 
     for (i = 0; i < 6; i++)
     {
-      if ( ((compare_ops >> i) & 1) != 0 )
+      if (((compare_ops >> i) & 1) != 0)
       {
         fprintf(fp,
           "    case %s:\n"
@@ -337,7 +366,7 @@ static void vtkWrapPython_RichCompareProtocol(
       "  if (result == -1)\n"
       "  {\n"
       "    PyErr_SetString(PyExc_TypeError, \"operation not available\");\n"
-      "    return NULL;\n"
+      "    return nullptr;\n"
       "  }\n"
       "\n"
       "  // avoids aliasing issues with Py_INCREF(Py_False)\n"
@@ -350,25 +379,23 @@ static void vtkWrapPython_RichCompareProtocol(
 /* -------------------------------------------------------------------- */
 /* generate functions for indexing into special objects */
 static void vtkWrapPython_SequenceProtocol(
-  FILE *fp, const char *classname, ClassInfo *data,
-  HierarchyInfo *hinfo, SpecialTypeInfo *info)
+  FILE* fp, const char* classname, ClassInfo* data, HierarchyInfo* hinfo, SpecialTypeInfo* info)
 {
   int i;
-  FunctionInfo *func;
-  FunctionInfo *getItemFunc = 0;
-  FunctionInfo *setItemFunc = 0;
+  FunctionInfo* func;
+  FunctionInfo* getItemFunc = 0;
+  FunctionInfo* setItemFunc = 0;
 
   /* look for [] operator */
   for (i = 0; i < data->NumberOfFunctions; i++)
   {
     func = data->Functions[i];
 
-    if (func->Name && func->IsOperator &&
-        strcmp(func->Name, "operator[]") == 0  &&
-        vtkWrapPython_MethodCheck(data, func, hinfo))
+    if (func->Name && func->IsOperator && !func->IsDeleted && !func->IsExcluded &&
+      strcmp(func->Name, "operator[]") == 0 && vtkWrapPython_MethodCheck(data, func, hinfo))
     {
       if (func->NumberOfParameters == 1 && func->ReturnValue &&
-          vtkWrap_IsInteger(func->Parameters[0]))
+        vtkWrap_IsInteger(func->Parameters[0]))
       {
         if (!setItemFunc && vtkWrap_IsNonConstRef(func->ReturnValue))
         {
@@ -407,32 +434,32 @@ static void vtkWrapPython_SequenceProtocol(
     vtkWrapPython_DeclareVariables(fp, data, getItemFunc);
 
     fprintf(fp,
-            "  temp0 = static_cast<%s>(i);\n"
-            "\n"
-            "  if (temp0 < 0 || temp0 >= op->%s)\n"
-            "  {\n"
-            "    PyErr_SetString(PyExc_IndexError, \"index out of range\");\n"
-            "  }\n"
-            "  else\n"
-            "  {\n",
-            vtkWrap_GetTypeName(getItemFunc->Parameters[0]),
-            getItemFunc->SizeHint);
+      "  temp0 = static_cast<%s>(i);\n"
+      "\n"
+      "  if (temp0 < 0 || temp0 >= op->%s)\n"
+      "  {\n"
+      "    PyErr_SetString(PyExc_IndexError, \"index out of range\");\n"
+      "  }\n"
+      "  else\n"
+      "  {\n",
+      vtkWrap_GetTypeName(getItemFunc->Parameters[0]), getItemFunc->SizeHint);
 
     fprintf(fp, "  ");
-    vtkWrap_DeclareVariable(fp, data, getItemFunc->ReturnValue,
-      "tempr", -1, VTK_WRAP_RETURN | VTK_WRAP_NOSEMI);
+    vtkWrap_DeclareVariable(
+      fp, data, getItemFunc->ReturnValue, "tempr", -1, VTK_WRAP_RETURN | VTK_WRAP_NOSEMI);
 
-    fprintf(fp, " = %s(*op)[temp0];\n"
-            "\n",
-            (vtkWrap_IsRef(getItemFunc->ReturnValue) ? "&" : ""));
+    fprintf(fp,
+      " = %s(*op)[temp0];\n"
+      "\n",
+      (vtkWrap_IsRef(getItemFunc->ReturnValue) ? "&" : ""));
 
     vtkWrapPython_ReturnValue(fp, data, getItemFunc->ReturnValue, 1);
 
     fprintf(fp,
-            "  }\n"
-            "\n"
-            "  return result;\n"
-            "}\n\n");
+      "  }\n"
+      "\n"
+      "  return result;\n"
+      "}\n\n");
 
     if (setItemFunc)
     {
@@ -445,43 +472,41 @@ static void vtkWrapPython_SequenceProtocol(
         "\n",
         classname, data->Name, data->Name);
 
-      vtkWrap_DeclareVariable(fp, data, setItemFunc->Parameters[0],
-                              "temp", 0, VTK_WRAP_ARG);
-      vtkWrap_DeclareVariable(fp, data, setItemFunc->ReturnValue,
-                              "temp", 1, VTK_WRAP_ARG);
+      vtkWrap_DeclareVariable(fp, data, setItemFunc->Parameters[0], "temp", 0, VTK_WRAP_ARG);
+      vtkWrap_DeclareVariable(fp, data, setItemFunc->ReturnValue, "temp", 1, VTK_WRAP_ARG);
 
       fprintf(fp,
-              "  int result = -1;\n"
-              "\n"
-              "  temp0 = static_cast<%s>(i);\n"
-              "\n"
-              "  if (temp0 < 0 || temp0 >= op->%s)\n"
-              "  {\n"
-              "    PyErr_SetString(PyExc_IndexError, \"index out of range\");\n"
-              "  }\n"
-              "  else if (",
-              vtkWrap_GetTypeName(setItemFunc->Parameters[0]),
-              getItemFunc->SizeHint);
+        "  int result = -1;\n"
+        "\n"
+        "  temp0 = static_cast<%s>(i);\n"
+        "\n"
+        "  if (temp0 < 0 || temp0 >= op->%s)\n"
+        "  {\n"
+        "    PyErr_SetString(PyExc_IndexError, \"index out of range\");\n"
+        "  }\n"
+        "  else if (",
+        vtkWrap_GetTypeName(setItemFunc->Parameters[0]), getItemFunc->SizeHint);
 
-      vtkWrapPython_GetSingleArgument(
-        fp, data, 1, setItemFunc->ReturnValue, 1);
-
-      fprintf(fp,")\n"
-              "  {\n"
-              "    (*op)[temp0] = %stemp1;\n"
-              "\n",
-              ((vtkWrap_IsRef(getItemFunc->ReturnValue) &&
-                vtkWrap_IsObject(getItemFunc->ReturnValue)) ? "*" : ""));
+      vtkWrapPython_GetSingleArgument(fp, data, 1, setItemFunc->ReturnValue, 1);
 
       fprintf(fp,
-              "    if (PyErr_Occurred() == NULL)\n"
-              "    {\n"
-              "      result = 0;\n"
-              "    }\n"
-              "  }\n"
-              "\n"
-              "  return result;\n"
-              "}\n\n");
+        ")\n"
+        "  {\n"
+        "    (*op)[temp0] = %stemp1;\n"
+        "\n",
+        ((vtkWrap_IsRef(getItemFunc->ReturnValue) && vtkWrap_IsObject(getItemFunc->ReturnValue))
+            ? "*"
+            : ""));
+
+      fprintf(fp,
+        "    if (PyErr_Occurred() == nullptr)\n"
+        "    {\n"
+        "      result = 0;\n"
+        "    }\n"
+        "  }\n"
+        "\n"
+        "  return result;\n"
+        "}\n\n");
     }
 
     fprintf(fp,
@@ -495,14 +520,11 @@ static void vtkWrapPython_SequenceProtocol(
 
     if (setItemFunc)
     {
-      fprintf(fp,
-        "  Py%s_SequenceSetItem, // sq_ass_item\n",
-        classname);
+      fprintf(fp, "  Py%s_SequenceSetItem, // sq_ass_item\n", classname);
     }
     else
     {
-      fprintf(fp,
-        "  0, // sq_ass_item\n");
+      fprintf(fp, "  0, // sq_ass_item\n");
     }
 
     fprintf(fp,
@@ -516,13 +538,10 @@ static void vtkWrapPython_SequenceProtocol(
 
 /* -------------------------------------------------------------------- */
 /* generate function for hashing special objects */
-static void vtkWrapPython_HashProtocol(
-  FILE *fp, const char *classname, ClassInfo *data)
+static void vtkWrapPython_HashProtocol(FILE* fp, const char* classname, ClassInfo* data)
 {
   /* the hash function, defined only for specific types */
-  fprintf(fp,
-    "static Py_hash_t Py%s_Hash(PyObject *self)\n",
-    classname);
+  fprintf(fp, "static Py_hash_t Py%s_Hash(PyObject *self)\n", classname);
 
   if (strcmp(data->Name, "vtkTimeStamp") == 0)
   {
@@ -574,21 +593,19 @@ static void vtkWrapPython_HashProtocol(
       "}\n"
       "\n");
   }
-
 }
 
 /* -------------------------------------------------------------------- */
 /* generate extra functions for a special object */
-static void vtkWrapPython_SpecialTypeProtocols(
-  FILE *fp, const char *classname, ClassInfo *data,
-  FileInfo *finfo, HierarchyInfo *hinfo, SpecialTypeInfo *info)
+static void vtkWrapPython_SpecialTypeProtocols(FILE* fp, const char* classname, ClassInfo* data,
+  FileInfo* finfo, HierarchyInfo* hinfo, SpecialTypeInfo* info)
 {
   /* clear all info about the type */
   info->has_print = 0;
   info->has_compare = 0;
   info->has_sequence = 0;
 
-  vtkWrapPython_NewDeleteProtocol(fp, classname, data);
+  vtkWrapPython_NewDeleteProtocol(fp, classname, data, hinfo);
   vtkWrapPython_PrintProtocol(fp, classname, data, finfo, info);
   vtkWrapPython_RichCompareProtocol(fp, classname, data, finfo, info);
   vtkWrapPython_SequenceProtocol(fp, classname, data, hinfo, info);
@@ -598,9 +615,9 @@ static void vtkWrapPython_SpecialTypeProtocols(
 /* -------------------------------------------------------------------- */
 /* For classes that aren't derived from vtkObjectBase, check to see if
  * they are wrappable */
-int vtkWrapPython_IsSpecialTypeWrappable(ClassInfo *data)
+int vtkWrapPython_IsSpecialTypeWrappable(ClassInfo* data)
 {
-  /* no templated types */
+  /* wrapping templates is only possible after template instantiation */
   if (data->Template)
   {
     return 0;
@@ -612,168 +629,145 @@ int vtkWrapPython_IsSpecialTypeWrappable(ClassInfo *data)
     return 0;
   }
 
-  /* require public destructor and copy contructor */
-  if (!vtkWrap_HasPublicDestructor(data) ||
-      !vtkWrap_HasPublicCopyConstructor(data))
-  {
-    return 0;
-  }
-
   return 1;
 }
 
 /* -------------------------------------------------------------------- */
 /* write out a special type object */
-void vtkWrapPython_GenerateSpecialType(
-  FILE *fp, const char *module, const char *classname,
-  ClassInfo *data, FileInfo *finfo, HierarchyInfo *hinfo)
+void vtkWrapPython_GenerateSpecialType(FILE* fp, const char* module, const char* classname,
+  ClassInfo* data, FileInfo* finfo, HierarchyInfo* hinfo)
 {
   char supername[1024];
-  const char *name;
+  const char* supermodule;
+  const char* name;
   SpecialTypeInfo info;
-  const char *constructor;
-  size_t n, m;
+  const char* constructor = NULL;
+  size_t n = 0;
   int i;
   int has_constants = 0;
   int has_superclass = 0;
+  int has_copycons = 0;
   int is_external = 0;
 
   /* remove namespaces and template parameters from the
    * class name to get the constructor name */
-  constructor = data->Name;
-  m = vtkParse_UnscopedNameLength(constructor);
-  while (constructor[m] == ':' && constructor[m+1] == ':')
+  if (!data->IsAbstract)
   {
-    constructor += m + 2;
-    m = vtkParse_UnscopedNameLength(constructor);
-  }
-  for (n = 0; n < m; n++)
-  {
-    if (constructor[n] == '<')
-    {
-      break;
-    }
+    constructor = vtkWrapPython_WrappedConstructor(data, hinfo, &n);
   }
 
   /* get the superclass */
-  has_superclass = vtkWrapPython_HasWrappedSuperClass(
-    hinfo, data->Name, &is_external);
-  if (has_superclass)
+  supermodule = vtkWrapPython_HasWrappedSuperClass(hinfo, data->Name, &is_external);
+  if (supermodule)
   {
+    has_superclass = 1;
     name = vtkWrapPython_GetSuperClass(data, hinfo);
     vtkWrapText_PythonName(name, supername);
   }
 
   /* generate all constructor methods */
-  if (!data->IsAbstract)
+  if (constructor)
   {
     vtkWrapPython_GenerateMethods(fp, classname, data, finfo, hinfo, 0, 1);
   }
 
   /* generate all functions and protocols needed for the type */
-  vtkWrapPython_SpecialTypeProtocols(
-    fp, classname, data, finfo, hinfo, &info);
+  vtkWrapPython_SpecialTypeProtocols(fp, classname, data, finfo, hinfo, &info);
 
   /* Generate the TypeObject */
   fprintf(fp,
     "static PyTypeObject Py%s_Type = {\n"
     "  PyVarObject_HEAD_INIT(&PyType_Type, 0)\n"
-    "  \"%sPython.%s\", // tp_name\n"
+    "  PYTHON_PACKAGE_SCOPE \"%s.%s\", // tp_name\n"
     "  sizeof(PyVTKSpecialObject), // tp_basicsize\n"
     "  0, // tp_itemsize\n"
     "  Py%s_Delete, // tp_dealloc\n"
-    "  0, // tp_print\n"
-    "  0, // tp_getattr\n"
-    "  0, // tp_setattr\n"
-    "  0, // tp_compare\n"
+    "#if PY_VERSION_HEX >= 0x03080000\n"
+    "  0, // tp_vectorcall_offset\n"
+    "#else\n"
+    "  nullptr, // tp_print\n"
+    "#endif\n"
+    "  nullptr, // tp_getattr\n"
+    "  nullptr, // tp_setattr\n"
+    "  nullptr, // tp_compare\n"
     "  PyVTKSpecialObject_Repr, // tp_repr\n",
     classname, module, classname, classname);
 
-  fprintf(fp,
-    "  0, // tp_as_number\n");
+  fprintf(fp, "  nullptr, // tp_as_number\n");
 
   if (info.has_sequence)
   {
-    fprintf(fp,
-      "  &Py%s_AsSequence, // tp_as_sequence\n",
-    classname);
+    fprintf(fp, "  &Py%s_AsSequence, // tp_as_sequence\n", classname);
   }
   else
   {
-  fprintf(fp,
-      "  0, // tp_as_sequence\n");
+    fprintf(fp, "  nullptr, // tp_as_sequence\n");
   }
 
   fprintf(fp,
-    "  0, // tp_as_mapping\n"
+    "  nullptr, // tp_as_mapping\n"
     "  Py%s_Hash, // tp_hash\n"
-    "  0, // tp_call\n",
+    "  nullptr, // tp_call\n",
     classname);
 
   if (info.has_print)
   {
-    fprintf(fp,
-      "  Py%s_String, // tp_str\n",
-      classname);
+    fprintf(fp, "  Py%s_String, // tp_str\n", classname);
   }
   else if (info.has_sequence)
   {
-    fprintf(fp,
-      "  PyVTKSpecialObject_SequenceString, // tp_str\n");
+    fprintf(fp, "  PyVTKSpecialObject_SequenceString, // tp_str\n");
   }
   else
   {
-    fprintf(fp,
-      "  0, // tp_str\n");
+    fprintf(fp, "  nullptr, // tp_str\n");
   }
 
   fprintf(fp,
     "  PyObject_GenericGetAttr, // tp_getattro\n"
-    "  0, // tp_setattro\n"
-    "  0, // tp_as_buffer\n"
+    "  nullptr, // tp_setattro\n"
+    "  nullptr, // tp_as_buffer\n"
     "  Py_TPFLAGS_DEFAULT, // tp_flags\n"
-    "  0, // tp_doc\n"
-    "  0, // tp_traverse\n"
-    "  0, // tp_clear\n");
+    "  Py%s_Doc, // tp_doc\n"
+    "  nullptr, // tp_traverse\n"
+    "  nullptr, // tp_clear\n",
+    classname);
 
   if (info.has_compare)
   {
-    fprintf(fp,
-      "  Py%s_RichCompare, // tp_richcompare\n",
-      classname);
+    fprintf(fp, "  Py%s_RichCompare, // tp_richcompare\n", classname);
   }
   else
   {
-    fprintf(fp,
-      "  0, // tp_richcompare\n");
+    fprintf(fp, "  nullptr, // tp_richcompare\n");
   }
 
   fprintf(fp,
     "  0, // tp_weaklistoffset\n"
-    "  0, // tp_iter\n"
-    "  0, // tp_iternext\n"
-    "  0, // tp_methods\n"
-    "  0, // tp_members\n"
-    "  0, // tp_getset\n"
-    "  0, // tp_base\n"
-    "  0, // tp_dict\n"
-    "  0, // tp_descr_get\n"
-    "  0, // tp_descr_set\n"
+    "  nullptr, // tp_iter\n"
+    "  nullptr, // tp_iternext\n"
+    "  nullptr, // tp_methods\n"
+    "  nullptr, // tp_members\n"
+    "  nullptr, // tp_getset\n"
+    "  nullptr, // tp_base\n"
+    "  nullptr, // tp_dict\n"
+    "  nullptr, // tp_descr_get\n"
+    "  nullptr, // tp_descr_set\n"
     "  0, // tp_dictoffset\n"
-    "  0, // tp_init\n"
-    "  0, // tp_alloc\n"
+    "  nullptr, // tp_init\n"
+    "  nullptr, // tp_alloc\n"
     "  Py%s_New, // tp_new\n"
     "  PyObject_Del, // tp_free\n"
-    "  0, // tp_is_gc\n",
+    "  nullptr, // tp_is_gc\n",
     classname);
 
   /* fields set by python itself */
   fprintf(fp,
-    "  0, // tp_bases\n"
-    "  0, // tp_mro\n"
-    "  0, // tp_cache\n"
-    "  0, // tp_subclasses\n"
-    "  0, // tp_weaklist\n");
+    "  nullptr, // tp_bases\n"
+    "  nullptr, // tp_mro\n"
+    "  nullptr, // tp_cache\n"
+    "  nullptr, // tp_subclasses\n"
+    "  nullptr, // tp_weaklist\n");
 
   /* internal struct members */
   fprintf(fp,
@@ -793,28 +787,28 @@ void vtkWrapPython_GenerateSpecialType(
   }
 
   /* generate the copy constructor helper function */
-  if (!data->IsAbstract)
+  if (constructor && vtkWrap_HasPublicCopyConstructor(data))
   {
+    has_copycons = 1;
+
     fprintf(fp,
-    "static void *Py%s_CCopy(const void *obj)\n"
-    "{\n"
-    "  if (obj)\n"
-    "  {\n"
-    "    return new %s(*static_cast<const %s*>(obj));\n"
-    "  }\n"
-    "  return 0;\n"
-    "}\n"
-    "\n",
-    classname, data->Name, data->Name);
+      "static void *Py%s_CCopy(const void *obj)\n"
+      "{\n"
+      "  if (obj)\n"
+      "  {\n"
+      "    return new %s(*static_cast<const %s*>(obj));\n"
+      "  }\n"
+      "  return 0;\n"
+      "}\n"
+      "\n",
+      classname, data->Name, data->Name);
   }
 
   /* export New method for use by subclasses */
-  fprintf(fp,
-    "extern \"C\" { %s PyObject *Py%s_TypeNew(); }\n\n",
-    "VTK_ABI_EXPORT", classname);
+  fprintf(fp, "extern \"C\" { PyObject *Py%s_TypeNew(); }\n\n", classname);
 
   /* import New method of the superclass */
-  if (has_superclass)
+  if (has_superclass && !is_external)
   {
     fprintf(fp,
       "#ifndef DECLARED_Py%s_TypeNew\n"
@@ -831,35 +825,40 @@ void vtkWrapPython_GenerateSpecialType(
     "{\n",
     classname);
 
-  if (data->IsAbstract)
+  if (has_copycons)
   {
     fprintf(fp,
-    "  PyVTKSpecialType_Add(\n"
-    "    &Py%s_Type,\n"
-    "    Py%s_Methods,\n"
-    "    NULL,\n"
-    "    Py%s_Doc(), NULL);\n"
-    "\n",
-    classname, classname, classname);
+      "  PyTypeObject *pytype = PyVTKSpecialType_Add(\n"
+      "    &Py%s_Type,\n"
+      "    Py%s_Methods,\n"
+      "    Py%s_%*.*s_Methods,\n"
+      "    &Py%s_CCopy);\n"
+      "\n",
+      classname, classname, classname, (int)n, (int)n, constructor, classname);
+  }
+  else if (constructor)
+  {
+    fprintf(fp,
+      "  PyTypeObject *pytype = PyVTKSpecialType_Add(\n"
+      "    &Py%s_Type,\n"
+      "    Py%s_Methods,\n"
+      "    Py%s_%*.*s_Methods,\n"
+      "    nullptr);\n"
+      "\n",
+      classname, classname, classname, (int)n, (int)n, constructor);
   }
   else
   {
     fprintf(fp,
-    "  PyVTKSpecialType_Add(\n"
-    "    &Py%s_Type,\n"
-    "    Py%s_Methods,\n"
-    "    Py%s_%*.*s_Methods,\n"
-    "    Py%s_Doc(), &Py%s_CCopy);\n"
-    "\n",
-    classname, classname,
-    classname, (int)n, (int)n, constructor,
-    classname, classname);
+      "  PyTypeObject *pytype = PyVTKSpecialType_Add(\n"
+      "    &Py%s_Type,\n"
+      "    Py%s_Methods,\n"
+      "    nullptr,\n"
+      "    nullptr);\n"
+      "\n",
+      classname, classname);
   }
 
-  fprintf(fp,
-    "  PyTypeObject *pytype = &Py%s_Type;\n\n",
-    classname);
-
   /* if type is already ready, then return */
   fprintf(fp,
     "  if ((pytype->tp_flags & Py_TPFLAGS_READY) != 0)\n"
@@ -870,9 +869,17 @@ void vtkWrapPython_GenerateSpecialType(
   /* call the superclass New (initialize in dependency order) */
   if (has_superclass)
   {
-    fprintf(fp,
-      "  pytype->tp_base = (PyTypeObject *)Py%s_TypeNew();\n\n",
-      supername);
+    if (!is_external) /* superclass is in the same module */
+    {
+      fprintf(fp, "  pytype->tp_base = (PyTypeObject *)Py%s_TypeNew();\n\n", supername);
+    }
+    else /* superclass is in a different module */
+    {
+      fprintf(fp,
+        "  pytype->tp_base = vtkPythonUtil::FindSpecialTypeObject("
+        "\"%s\");\n\n",
+        supername);
+    }
   }
 
   /* check whether the class has any constants as members */
